(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    438835,       8382]*)
(*NotebookOutlinePosition[    511962,      11002]*)
(*  CellTagsIndexPosition[    511571,      10986]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Iterating one deme", "SubsectionIcon"],

Cell["This loads this package, as well as the Graphics package:", \
"MathCaption"],

Cell[BoxData[
    \(<< NumericalModels`ExactModel`; << Graphics`;\)], "Input",
  CellLabel->"In[62]:="],

Cell[CellGroupData[{

Cell["A single deme", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], 
              W, {0, 0}]\), \(gives\ genotype\ frequencies\ after\ one\ \
generation\ of\ selection\ and\ recombination . \ \ \[Psi]\ must\ represent\ \
a\ haploid\ \(\(population\)\(.\)\)\)},
          {
            RowBox[{"StoreExact", "[", 
              RowBox[{
              "\[Psi]", ",", \(\[Psi]\_0\), ",", "W", ",", \({0, 0}\), ",", 
                RowBox[{"{", 
                  RowBox[{"t", ",", 
                    StyleBox["dt",
                      FontSlant->"Italic"]}], 
                  StyleBox["}",
                    FontSlant->"Italic"]}]}], 
              "]"}], \(stores\ results\ at\ intervals\ dt\ in\ \[Psi][t], \ 
            starting\ with\ \[Psi][
                  0] = \[Psi]\_0 . \ \ Options\ are\ passed\ directly\ to\ \(\
\(IterateExact[]\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->{"IterateExact", "StoreExact"}],

Cell["\<\
This shows the allele frequency at three loci, with selection s=10% \
against heterozygotes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hp = 
        MakePopulation[3, 0.5, 100, 
          NumericalModel \[Rule] HaploidIndividuals];\)\), "\n", 
    \(\(\(w[s_, het]\)[x_, 
          y_] := \((1 - s)\)\^CountHeterozygotes[x, y];\)\), "\n", 
    \(\(hpc = 
        NestList[IterateExact[#, w[0.1, het], {0, 0}] &, hp, 
          100];\)\), "\n", 
    \(\(DisplayTogether @@ 
        MapThread[
          ListPlot[#1, PlotStyle \[Rule] #2] &, {Transpose[
              AlleleFrequencyTable[hpc]], {Red, Blue, Black}}];\)\)}], "Input",\

  CellLabel->"In[63]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00942951 0.0147151 0.588604 [
[.2124 .00222 -6 -9 ]
[.2124 .00222 6 0 ]
[.40099 .00222 -6 -9 ]
[.40099 .00222 6 0 ]
[.58958 .00222 -6 -9 ]
[.58958 .00222 6 0 ]
[.77817 .00222 -6 -9 ]
[.77817 .00222 6 0 ]
[.96676 .00222 -9 -9 ]
[.96676 .00222 9 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2124 .01472 m
.2124 .02097 L
s
[(20)] .2124 .00222 0 1 Mshowa
.40099 .01472 m
.40099 .02097 L
s
[(40)] .40099 .00222 0 1 Mshowa
.58958 .01472 m
.58958 .02097 L
s
[(60)] .58958 .00222 0 1 Mshowa
.77817 .01472 m
.77817 .02097 L
s
[(80)] .77817 .00222 0 1 Mshowa
.96676 .01472 m
.96676 .02097 L
s
[(100)] .96676 .00222 0 1 Mshowa
.125 Mabswid
.07096 .01472 m
.07096 .01847 L
s
.1181 .01472 m
.1181 .01847 L
s
.16525 .01472 m
.16525 .01847 L
s
.25955 .01472 m
.25955 .01847 L
s
.30669 .01472 m
.30669 .01847 L
s
.35384 .01472 m
.35384 .01847 L
s
.44814 .01472 m
.44814 .01847 L
s
.49529 .01472 m
.49529 .01847 L
s
.54243 .01472 m
.54243 .01847 L
s
.63673 .01472 m
.63673 .01847 L
s
.68388 .01472 m
.68388 .01847 L
s
.73102 .01472 m
.73102 .01847 L
s
.82532 .01472 m
.82532 .01847 L
s
.87247 .01472 m
.87247 .01847 L
s
.91961 .01472 m
.91961 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.008 w
.03324 .29136 Mdot
.04267 .30313 Mdot
.0521 .30902 Mdot
.06153 .34433 Mdot
.07096 .32079 Mdot
.08039 .30902 Mdot
.08982 .35611 Mdot
.09925 .33256 Mdot
.10868 .35022 Mdot
.1181 .36199 Mdot
.12753 .35022 Mdot
.13696 .35611 Mdot
.14639 .36788 Mdot
.15582 .33845 Mdot
.16525 .29136 Mdot
.17468 .29724 Mdot
.18411 .24427 Mdot
.19354 .23838 Mdot
.20297 .1913 Mdot
.2124 .22073 Mdot
.22183 .19718 Mdot
.23126 .2737 Mdot
.24069 .35022 Mdot
.25012 .34433 Mdot
.25955 .37376 Mdot
.26898 .36199 Mdot
.27841 .36199 Mdot
.28784 .32668 Mdot
.29727 .34433 Mdot
.30669 .39142 Mdot
.31612 .39731 Mdot
.32555 .43262 Mdot
.33498 .43262 Mdot
.34441 .47383 Mdot
.35384 .49148 Mdot
.36327 .50914 Mdot
.3727 .49737 Mdot
.38213 .54446 Mdot
.39156 .53857 Mdot
.40099 .56212 Mdot
.41042 .57389 Mdot
.41985 .57977 Mdot
.42928 .57977 Mdot
.43871 .59743 Mdot
.44814 .60332 Mdot
.45757 .60332 Mdot
.467 .60332 Mdot
.47643 .60332 Mdot
.48586 .60332 Mdot
.49529 .60332 Mdot
.50471 .60332 Mdot
.51414 .60332 Mdot
.52357 .60332 Mdot
.533 .60332 Mdot
.54243 .60332 Mdot
.55186 .60332 Mdot
.56129 .60332 Mdot
.57072 .60332 Mdot
.58015 .60332 Mdot
.58958 .60332 Mdot
.59901 .60332 Mdot
.60844 .60332 Mdot
.61787 .60332 Mdot
.6273 .60332 Mdot
.63673 .60332 Mdot
.64616 .60332 Mdot
.65559 .60332 Mdot
.66502 .60332 Mdot
.67445 .60332 Mdot
.68388 .60332 Mdot
.69331 .60332 Mdot
.70273 .60332 Mdot
.71216 .60332 Mdot
.72159 .60332 Mdot
.73102 .60332 Mdot
.74045 .60332 Mdot
.74988 .60332 Mdot
.75931 .60332 Mdot
.76874 .60332 Mdot
.77817 .60332 Mdot
.7876 .60332 Mdot
.79703 .60332 Mdot
.80646 .60332 Mdot
.81589 .60332 Mdot
.82532 .60332 Mdot
.83475 .60332 Mdot
.84418 .60332 Mdot
.85361 .60332 Mdot
.86304 .60332 Mdot
.87247 .60332 Mdot
.8819 .60332 Mdot
.89132 .60332 Mdot
.90075 .60332 Mdot
.91018 .60332 Mdot
.91961 .60332 Mdot
.92904 .60332 Mdot
.93847 .60332 Mdot
.9479 .60332 Mdot
.95733 .60332 Mdot
.96676 .60332 Mdot
.97619 .60332 Mdot
0 0 1 r
.03324 .29136 Mdot
.04267 .26781 Mdot
.0521 .26193 Mdot
.06153 .26193 Mdot
.07096 .2737 Mdot
.08039 .29724 Mdot
.08982 .23838 Mdot
.09925 .23838 Mdot
.10868 .29724 Mdot
.1181 .35611 Mdot
.12753 .36199 Mdot
.13696 .37965 Mdot
.14639 .36788 Mdot
.15582 .32668 Mdot
.16525 .32668 Mdot
.17468 .29724 Mdot
.18411 .29136 Mdot
.19354 .33845 Mdot
.20297 .35611 Mdot
.2124 .35611 Mdot
.22183 .35022 Mdot
.23126 .29724 Mdot
.24069 .33845 Mdot
.25012 .33256 Mdot
.25955 .3149 Mdot
.26898 .38554 Mdot
.27841 .41497 Mdot
.28784 .36788 Mdot
.29727 .37965 Mdot
.30669 .39142 Mdot
.31612 .41497 Mdot
.32555 .39142 Mdot
.33498 .36199 Mdot
.34441 .37376 Mdot
.35384 .35022 Mdot
.36327 .36199 Mdot
.3727 .32668 Mdot
.38213 .35022 Mdot
.39156 .36788 Mdot
.40099 .35611 Mdot
.41042 .35611 Mdot
.41985 .36199 Mdot
.42928 .34433 Mdot
.43871 .30902 Mdot
.44814 .29724 Mdot
.45757 .29136 Mdot
.467 .22661 Mdot
.47643 .24427 Mdot
.48586 .21484 Mdot
.49529 .19718 Mdot
.50471 .18541 Mdot
.51414 .19718 Mdot
.52357 .2325 Mdot
.533 .25016 Mdot
.54243 .25016 Mdot
.55186 .23838 Mdot
.56129 .26781 Mdot
.57072 .2325 Mdot
.58015 .20895 Mdot
.58958 .23838 Mdot
.59901 .25016 Mdot
.60844 .21484 Mdot
.61787 .20895 Mdot
.6273 .17952 Mdot
.63673 .13832 Mdot
.64616 .13832 Mdot
.65559 .10889 Mdot
.66502 .05003 Mdot
.67445 .03826 Mdot
.68388 .03237 Mdot
.69331 .03826 Mdot
.70273 .0206 Mdot
.71216 .0206 Mdot
.72159 .02649 Mdot
.73102 .0206 Mdot
.74045 .01472 Mdot
.74988 .01472 Mdot
.75931 .01472 Mdot
.76874 .01472 Mdot
.77817 .01472 Mdot
.7876 .01472 Mdot
.79703 .01472 Mdot
.80646 .01472 Mdot
.81589 .01472 Mdot
.82532 .01472 Mdot
.83475 .01472 Mdot
.84418 .01472 Mdot
.85361 .01472 Mdot
.86304 .01472 Mdot
.87247 .01472 Mdot
.8819 .01472 Mdot
.89132 .01472 Mdot
.90075 .01472 Mdot
.91018 .01472 Mdot
.91961 .01472 Mdot
.92904 .01472 Mdot
.93847 .01472 Mdot
.9479 .01472 Mdot
.95733 .01472 Mdot
.96676 .01472 Mdot
.97619 .01472 Mdot
0 0 0 r
.03324 .29724 Mdot
.04267 .26781 Mdot
.0521 .20895 Mdot
.06153 .16187 Mdot
.07096 .15598 Mdot
.08039 .15009 Mdot
.08982 .13832 Mdot
.09925 .13244 Mdot
.10868 .07946 Mdot
.1181 .04415 Mdot
.12753 .05003 Mdot
.13696 .02649 Mdot
.14639 .0206 Mdot
.15582 .01472 Mdot
.16525 .01472 Mdot
.17468 .01472 Mdot
.18411 .01472 Mdot
.19354 .01472 Mdot
.20297 .01472 Mdot
.2124 .01472 Mdot
.22183 .01472 Mdot
.23126 .01472 Mdot
.24069 .01472 Mdot
.25012 .01472 Mdot
.25955 .01472 Mdot
.26898 .01472 Mdot
.27841 .01472 Mdot
.28784 .01472 Mdot
.29727 .01472 Mdot
.30669 .01472 Mdot
.31612 .01472 Mdot
.32555 .01472 Mdot
.33498 .01472 Mdot
.34441 .01472 Mdot
.35384 .01472 Mdot
.36327 .01472 Mdot
.3727 .01472 Mdot
.38213 .01472 Mdot
.39156 .01472 Mdot
.40099 .01472 Mdot
.41042 .01472 Mdot
.41985 .01472 Mdot
.42928 .01472 Mdot
.43871 .01472 Mdot
.44814 .01472 Mdot
.45757 .01472 Mdot
.467 .01472 Mdot
.47643 .01472 Mdot
.48586 .01472 Mdot
.49529 .01472 Mdot
.50471 .01472 Mdot
.51414 .01472 Mdot
.52357 .01472 Mdot
.533 .01472 Mdot
.54243 .01472 Mdot
.55186 .01472 Mdot
.56129 .01472 Mdot
.57072 .01472 Mdot
.58015 .01472 Mdot
.58958 .01472 Mdot
.59901 .01472 Mdot
.60844 .01472 Mdot
.61787 .01472 Mdot
.6273 .01472 Mdot
.63673 .01472 Mdot
.64616 .01472 Mdot
.65559 .01472 Mdot
.66502 .01472 Mdot
.67445 .01472 Mdot
.68388 .01472 Mdot
.69331 .01472 Mdot
.70273 .01472 Mdot
.71216 .01472 Mdot
.72159 .01472 Mdot
.73102 .01472 Mdot
.74045 .01472 Mdot
.74988 .01472 Mdot
.75931 .01472 Mdot
.76874 .01472 Mdot
.77817 .01472 Mdot
.7876 .01472 Mdot
.79703 .01472 Mdot
.80646 .01472 Mdot
.81589 .01472 Mdot
.82532 .01472 Mdot
.83475 .01472 Mdot
.84418 .01472 Mdot
.85361 .01472 Mdot
.86304 .01472 Mdot
.87247 .01472 Mdot
.8819 .01472 Mdot
.89132 .01472 Mdot
.90075 .01472 Mdot
.91018 .01472 Mdot
.91961 .01472 Mdot
.92904 .01472 Mdot
.93847 .01472 Mdot
.9479 .01472 Mdot
.95733 .01472 Mdot
.96676 .01472 Mdot
.97619 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[63]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00@P3oool5000000<0oooo0P00000/0?ooo`<000000`3oool2000002X0oooo0`0000040?oo
o`800000:P3oool3000000@0oooo0P00000W0?ooo`<00000103oool2000000@0oooo0P0000040?oo
o`00@`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002`0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo000002P0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo000002L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000<0oooo00140?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000:@3oool500000080oooo00@000000?ooo`3oool00000:03oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000:03oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000009`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool004D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo02L0oooo00@000000?ooo`3oool000000`3oool0
10000000oooo0?ooo`00000X0?ooo`@000000`3oool010000000oooo0?ooo`00000Y0?ooo`<00000
0`3oool010000000oooo0?ooo`00000W0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000030?ooo`00@P3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool00000:P3oool00`000000oooo000000030?ooo`040000003o
ool0oooo000002P0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000X0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000W0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`00@P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000:`3oool2000000<0
oooo00@000000?ooo`3oool00000:@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
000002P0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000002H0oooo
0P0000040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool004<0
oooo0`0000040?ooo`800000;@3oool00`000000oooo0?ooo`020?ooo`800000:`3oool2000000@0
oooo0P00000Z0?ooo`<00000103oool2000002P0oooo00<000000?ooo`3oool00`3oool2000000@0
oooo0P0000040?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003o
ool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo000?0?ooool000004@0000010?ooo`005@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool4000000030?oo
o`00000000000080000000@0oooo000000000000oooo100000000`3oool000000000000200000003
0?ooo`00000000000080000000@0oooo000000000000oooo100000000`3oool00000000000020000
00030?ooo`00000000000080000000<0oooo0000000000000P000000103oool000000000003oool4
000000030?ooo`00000000000080000000<0oooo0000000000000P000000103oool000000000003o
ool4000000030?ooo`00000000000080000000<0oooo0000000000000P0000000`3oool000000000
0002000000040?ooo`00000000000?ooo`@0000000<0oooo0000000000000P0000000`3oool00000
00000002000000040?ooo`00000000000?ooo`@0000000<0oooo0000000000000P0000000`3oool0
000000000002000000040?ooo`00000000000?ooo`@0000000<0oooo0000000000000P0000000`3o
ool0000000000002000000030?ooo`00000000000080000000@0oooo000000000000oooo10000000
0`3oool0000000000002000000030?ooo`00000000000080000000@0oooo000000000000oooo1000
00000`3oool0000000000002000000030?ooo`00000000000080000000<0oooo0000000000000P00
0000103oool000000000003oool4000000030?ooo`00000000000080000000<0oooo000000000000
0P000000103oool000000000003oool4000000030?ooo`00000000000080000000<0oooo00000000
00000P0000070?ooo`005@3oool00`000000oooo0?ooo`0N0?ooo`800000403oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool06`3oool20000o`030?oo
o`000?l0003o00<0oooo0P000?l;0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
203oool001D0oooo00<000000?ooo`3oool06`3oool2000009d0oooo0P000?m<0?ooo`005@3oool0
0`000000oooo0?ooo`0K0?ooo`800000T`3oool20000o`P0oooo0P000?m<0?ooo`005@3oool00`00
0000oooo0?ooo`2`0?ooo`80003oEP3oool001D0oooo00<000000?ooo`3oool0[@3oool20000o`<0
oooo0P000?mD0?ooo`005@3oool00`000000oooo0?ooo`2]0?ooo`80003o0`3oool20000oe@0oooo
000E0?ooo`8000005`3oool200000?00oooo000E0?ooo`030000003oool0oooo01H0oooo0P000000
0`3oool000000000002@0?ooo`80003oF`3oool001D0oooo00<000000?ooo`3oool06@3oool20000
0900oooo0P000?mK0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000
003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0
oooo0P00003o0?ooo`X0oooo000E0?ooo`030000003oool0oooo01@0oooo0P00003b0?ooo`005@3o
ool00`000000oooo0?ooo`0D0?ooo`800000lP3oool001D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0
oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool00`000000oooo0?ooo`2X0?oo
o`80003oGP3oool001D0oooo00<000000?ooo`3oool0Z03oool20000oeh0oooo000E0?ooo`030000
003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`000P3oool2
000000@0oooo00@000000?ooo`3oool0oooo1@0000040?ooo`030000003oool0oooo0?l0oooo2@3o
ool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0?l0oooo2@3oool000050?ooo`000000oooo0?ooo`0000002@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0?l0oooo2@3oool000050?ooo`000000oooo0?ooo`000000
2P3oool00`000000oooo0?ooo`030?ooo`<000004@3oool200000?D0oooo00001@3oool000000?oo
o`3oool0000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00h0
oooo0P0000000`3oool000000000002@0?ooo`80003o00<0oooo0000o`000?l0H03oool000050?oo
o`000000oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool03P3oool2000009<0oooo0P000?l00`3oool0003o0000o`1P0?ooo`000P3oool2000000T0
oooo0`0000050?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0
303oool200000?X0oooo000E0?ooo`030000003oool0oooo00`0oooo0P00003j0?ooo`005@3oool0
0`000000oooo0?ooo`090?ooo`800000o@3oool001D0oooo00<000000?ooo`3oool02@3oool20000
0?d0oooo000E0?ooo`800000203oool200000?l0oooo000E0?ooo`030000003oool0oooo00L0oooo
0P00003o0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0
oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0X@3oool20000ofD0oooo000E0?ooo`03
0000003oool0oooo0:40oooo0P000?mU0?ooo`005@3oool00`000000oooo0?ooo`1o0?ooo`80003o
Q`3oool001D0oooo00<000000?ooo`3oool0O`3oool20000ohL0oooo000E0?ooo`800000;P3oool2
0?l00=T0oooo000E0?ooo`030000003oool0oooo02d0oooo0P3o00030?ooo`80o`00B@3oool20000
o`<0oooo0P000?n40?ooo`005@3oool00`000000oooo0?ooo`0b0?ooo`80o`00B@3oool20000o`<0
oooo0P000?n40?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003o
ool0oooo00@0oooo0P00002>0?ooo`80003o203oool20000ofP0oooo000E0?ooo`030000003oool0
oooo00@0oooo0P00002>0?ooo`80003o203oool20000ofP0oooo000E0?ooo`030000003oool0oooo
07X0oooo0P000?lO0?ooo`80003oJ`3oool001D0oooo00<000000?ooo`3oool0NP3oool20000oal0
oooo0P000?m[0?ooo`005@3oool200000340oooo0P3o003F0?ooo`005@3oool00`000000oooo0?oo
o`0`0?ooo`80o`00@`3oool20000oi40oooo000E0?ooo`030000003oool0oooo07D0oooo0P000?nA
0?ooo`005@3oool00`000000oooo0?ooo`240?ooo`80003o2`3oool20000ogD0oooo000E0?ooo`03
0000003oool0oooo00h0oooo0P000?l00`3oool0003o0000o`0H0?ooo`80o`00E`3oool20000o`H0
oooo0P000?l30?ooo`80003o0`3oool20000og00oooo00020?ooo`800000103oool00`000000oooo
0?ooo`030?ooo`<00000103oool00`000000oooo0?ooo`0>0?ooo`80003o00<0oooo0000o`000?l0
603oool20?l005l0oooo0P000?l80?ooo`80003oL03oool000050?ooo`000000oooo0?ooo`000000
2P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo0P3o001=0?ooo`80003o
S`3oool000050?ooo`000000oooo0?ooo`0000001`3oool5000000@0oooo00<000000?ooo`3oool0
:03oool20?l004d0oooo0P000?n?0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`040000
003oool0oooo000000D0oooo0`0000270?ooo`@0003o3P3oool20000ofd0oooo00001@3oool00000
0?ooo`3oool0000000P0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`270?ooo`@0
003o3P3oool20000ofd0oooo00001@3oool000000?ooo`3oool0000000T0oooo0P0000050?ooo`03
0000003oool0oooo0?l0oooo2@3oool00080oooo0P00000;0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool20000o`030?ooo`000?l0003o0?l0oooo000E0?ooo`030000003o
ool0oooo0080oooo0P0000020000o`030?ooo`000?l0003o08H0oooo0P000?mg0?ooo`005@3oool0
0`000000oooo0?ooo`020?ooo`800000R`3oool20000ogL0oooo000E0?ooo`030000003oool0oooo
00T0oooo0P000?lZ0?ooo`80o`00d@3oool001D0oooo00<000000?ooo`3oool02@3oool20000obX0
oooo0P3o003A0?ooo`005@3oool200000?l0oooo2P3oool001D0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`040000003oool0003o
0000ob80oooo0P3o00030?ooo`80003oB03oool20000oi@0oooo000E0?ooo`040000003oool00000
000000/0oooo0P000?l60?ooo`80003o3@3oool20?l00080003o00<0oooo0000o`000?l02`3oool2
0000ocT0oooo10000?nD0?ooo`005@3oool010000000oooo00000000000;0?ooo`80003o1P3oool2
0000o`l0oooo0P000?l>0?ooo`80003o>@3oool20000oiH0oooo000E0?ooo`030000003oool0oooo
0080oooo0P3o003o0?ooo`D0oooo000E0?ooo`030000003oool0oooo0080oooo0P3o003o0?ooo`D0
oooo000E0?ooo`8000001@3oool20?l000H0oooo0P3o001O0?ooo`80003oV@3oool001D0oooo00<0
00000?ooo`3oool0103oool20?l000H0oooo0P3o000_0?ooo`80003o;P3oool20000oiT0oooo000E
0?ooo`030000003oool0oooo03d0oooo0P000?o90?ooo`005@3oool00`000000oooo0?ooo`090?oo
o`80o`00o@3oool001D0oooo00<000000?ooo`3oool02@3oool20?l001D0oooo0P000?l00`3oool0
003o0000o`0O0?ooo`80o`005@3oool20000oj/0oooo000E0?ooo`030000003oool0oooo0200oooo
0P000?l00`3oool0003o0000o`0O0?ooo`80o`005@3oool20000oj/0oooo000E0?ooo`030000003o
ool0oooo0140oooo0P3o000W0?ooo`80003oc03oool001D0oooo00<000000?ooo`3oool04@3oool2
0?l002L0oooo0P000?o<0?ooo`005@3oool200000240oooo0P3o00090?ooo`80003o2P3oool20000
oll0oooo000E0?ooo`030000003oool0oooo00L0oooo0P3o000G0?ooo`80o`002@3oool20000o`X0
oooo0P000?l00`3oool0o`000?l0000;0?ooo`80o`008P3oool20000oi/0oooo000E0?ooo`030000
003oool0oooo00L0oooo0P3o000a0?ooo`80o`002`3oool20?l00280oooo0P000?nK0?ooo`005@3o
ool00`000000oooo0?ooo`0D0?ooo`80o`000`3oool20?l001L0oooo0P000?l30?ooo`80o`007@3o
ool20000o`H0oooo0P000?nX0?ooo`005@3oool00`000000oooo0?ooo`0>0?ooo`80o`00103oool2
0?l00080003o00<0oooo0?l0003o00000P3o000@0?ooo`80003o00<0oooo0000o`000?l00P000?l3
0?ooo`80o`007@3oool20000o`H0oooo0P000?l30?ooo`80003o00<0oooo0000o`000?l0X03oool0
0080oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo
00h0oooo0P3o00060?ooo`80003o0`3oool20?l00100oooo0P000?l00`3oool0003o0000o`0a0?oo
o`80003o00<0oooo0000o`000?l0X03oool000050?ooo`000000oooo0?ooo`0000001`3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool05P3oool20?l000030?ooo`000?l0
003o02@0oooo0P3o00000`3oool0o`000?l0000=0?ooo`80003o1P3oool20000o`d0oooo0P000?nN
0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`0F0?ooo`80o`0000<0oooo0000o`000?l0903oool20?l000030?ooo`3o
0000o`0000d0oooo0P000?l60?ooo`80003o3@3oool20000oih0oooo00001@3oool000000?ooo`3o
ool0000000L0oooo100000050?ooo`<000007P3oool20000ob@0oooo0P000?lJ0?ooo`80003oYP3o
ool000050?ooo`000000oooo0?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01h0oooo0P000?lM0?ooo`80o`001@3oool20000o`h0oooo0P000?l:0?ooo`80003oYP3o
ool000050?ooo`000000oooo0?ooo`000000203oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo03d0oooo0P3o000E0?ooo`80003o/P3oool00080oooo0P00000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`0K0?ooo`80003o:P3oool20000okl0oooo000E0?ooo`030000003oool0oooo
01/0oooo0P000?lR0?ooo`80003o1P3oool20000okl0oooo000E0?ooo`030000003oool0oooo03l0
oooo0P000?o70?ooo`005@3oool00`000000oooo0?ooo`190?ooo`80003o0`3oool20000okP0oooo
000E0?ooo`030000003oool0oooo04T0oooo0P000?l30?ooo`80003o^03oool001D0oooo0P00001=
0?ooo`80o`00^P3oool001D0oooo00<000000?ooo`3oool0C03oool20?l00;X0oooo000E0?ooo`03
0000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3o
ool00`000000oooo0?ooo`120?ooo`80003o203oool20000okX0oooo000E0?ooo`030000003oool0
oooo0480oooo0P000?l80?ooo`80003o^P3oool001D0oooo00<000000?ooo`3oool0o`3oool90?oo
o`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`800000o`3oool:0?ooo`005@3o
ool00`000000oooo0?ooo`1>0?ooo`80o`0000<0oooo0?l0003o0000]@3oool001D0oooo00<00000
0?ooo`3oool0CP3oool20?l000030?ooo`3o0000o`000;D0oooo000E0?ooo`030000003oool0oooo
0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<00000
0?ooo`3oool0o`3oool90?ooo`005@3oool200000?l0oooo2P3oool001D0oooo00<000000?ooo`3o
ool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003o
ool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0E03oool20?l00;80oooo00020?oo
o`800000103oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`1D0?oo
o`80o`00/P3oool000050?ooo`000000oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool0o`3oool90?ooo`0000D0oooo0000003oool0oooo00000007
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`3o0?ooo`T0oooo0000
1@3oool000000?ooo`3oool0000000P0oooo0`0000050?ooo`<00000o`3oool90?ooo`0000D0oooo
0000003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`1F0?ooo`80o`00/03oool000050?ooo`000000oooo0?ooo`0000001`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0EP3oool20?l00;00oooo00020?ooo`800000
2@3oool3000000D0oooo00<000000?ooo`3oool0F`3oool20?l00:/0oooo000E0?ooo`030000003o
ool0oooo05/0oooo0P3o002[0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?oo
o`030000003oool0oooo05T0oooo0P3o002]0?ooo`005@3oool00`000000oooo0?ooo`1I0?ooo`80
o`00[@3oool001D0oooo0P00003o0?ooo`X0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3o
ool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?oo
o`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0
o`3oool90?ooo`005@3oool00`000000oooo0?ooo`1P0?ooo`80o`00YP3oool001D0oooo00<00000
0?ooo`3oool0H03oool20?l00:H0oooo000E0?ooo`800000G`3oool20?l00:P0oooo000E0?ooo`03
0000003oool0oooo05h0oooo0P3o002X0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo
000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0H`3oool2
0?l00:<0oooo000E0?ooo`030000003oool0oooo06<0oooo0P3o002S0?ooo`005@3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo0P00
001W0?ooo`80o`00X03oool001D0oooo00<000000?ooo`3oool0IP3oool40?l000030?ooo`3o0000
o`0009/0oooo000E0?ooo`030000003oool0oooo06P0oooo0P3o00000`3oool0o`000?l0002K0?oo
o`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo
2@3oool000d0oooo0`0000050?ooo`030000003oool0oooo0?l0oooo2@3oool000h0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1]0?ooo`80o`00V@3oool000h0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1]0?ooo`80o`00V@3oool000h0oooo00<000000?ooo`3o
ool0103oool300000700oooo103o00000`3oool0o`000?l000020?l000040?ooo`3o0000o`000?oo
o`@0o`0000<0oooo0?l0003o00000P3o00000`3oool0o`000?l000020?l000040?ooo`3o0000o`00
0?ooo`@0o`0000<0oooo0?l0003o00000P3o00000`3oool0o`000?l000020?l000040?ooo`3o0000
o`000?ooo`@0o`0000<0oooo0?l0003o00000P3o00000`3oool0o`000?l000020?l000030?ooo`3o
0000o`000080o`0000@0oooo0?l0003o0000oooo103o00000`3oool0o`000?l000020?l000030?oo
o`3o0000o`000080o`0000@0oooo0?l0003o0000oooo103o00000`3oool0o`000?l000020?l00003
0?ooo`3o0000o`000080o`0000<0oooo0?l0003o00000P3o0000103oool0o`000?l0003oool40?l0
00030?ooo`3o0000o`000080o`0000<0oooo0?l0003o00000P3o0000103oool0o`000?l0003oool4
0?l000030?ooo`3o0000o`000080o`0000<0oooo0?l0003o00000P3o00070?ooo`003P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0700oooo103o00000`3oool0o`000?l000020?l0
00040?ooo`3o0000o`000?ooo`@0o`0000<0oooo0?l0003o00000P3o00000`3oool0o`000?l00002
0?l000040?ooo`3o0000o`000?ooo`@0o`0000<0oooo0?l0003o00000P3o00000`3oool0o`000?l0
00020?l000040?ooo`3o0000o`000?ooo`@0o`0000<0oooo0?l0003o00000P3o00000`3oool0o`00
0?l000020?l000030?ooo`3o0000o`000080o`0000@0oooo0?l0003o0000oooo103o00000`3oool0
o`000?l000020?l000030?ooo`3o0000o`000080o`0000@0oooo0?l0003o0000oooo103o00000`3o
ool0o`000?l000020?l000030?ooo`3o0000o`000080o`0000<0oooo0?l0003o00000P3o0000103o
ool0o`000?l0003oool40?l000030?ooo`3o0000o`000080o`0000<0oooo0?l0003o00000P3o0000
103oool0o`000?l0003oool40?l000030?ooo`3o0000o`000080o`0000<0oooo0?l0003o00000P3o
00070?ooo`003@3oool2000000H0oooo00<000000?ooo`3oool0o`3oool90?ooo`003P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3o
ool0o`3oool90?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-8.38151, -0.07747, \
0.390041, 0.00624851}}]
}, Closed]],

Cell["\<\
This stores genotype frequencies in pop[t], every 10 generations:\
\
\>", "MathCaption"],

Cell[BoxData[
    \(\(StoreExact[pop[0.1], hp, 
        w[0.1, het], {0, 0}, {100, 10}];\)\)], "Input",
  CellLabel->"In[111]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(?? pop\)], "Input",
  CellLabel->"In[112]:="],

Cell[BoxData[
    \("Global`pop"\)], "Print",
  CellLabel->"From In[112]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(\(pop[0.1`]\)[0] = 
                    HaploidIndividuals[{{0, 1, 1}, {1, 1, 0}, {0, 0, 1}, {1, 
                          0, 0}, {0, 0, 1}, {0, 1, 0}, {1, 0, 0}, {1, 0, 
                          0}, {1, 1, 0}, {0, 1, 1}, {1, 1, 0}, {1, 0, 1}, {1, 
                          1, 1}, {1, 0, 1}, {0, 0, 0}, {1, 1, 0}, {0, 1, 
                          1}, {1, 1, 0}, {1, 1, 1}, {0, 0, 0}, {1, 1, 0}, {1, 
                          0, 1}, {0, 0, 0}, {1, 0, 0}, {1, 1, 1}, {0, 0, 
                          1}, {0, 0, 0}, {0, 1, 0}, {1, 1, 0}, {0, 0, 1}, {0, 
                          0, 0}, {1, 1, 1}, {0, 1, 1}, {1, 0, 0}, {1, 0, 
                          0}, {0, 1, 0}, {0, 1, 0}, {0, 0, 1}, {0, 0, 1}, {1, 
                          0, 0}, {0, 1, 1}, {1, 1, 1}, {1, 1, 1}, {0, 0, 
                          0}, {0, 1, 1}, {1, 0, 0}, {0, 1, 0}, {0, 0, 0}, {0, 
                          0, 1}, {0, 0, 1}, {1, 1, 1}, {0, 1, 1}, {0, 1, 
                          1}, {0, 0, 0}, {0, 1, 1}, {0, 0, 1}, {0, 1, 1}, {0, 
                          0, 0}, {0, 0, 0}, {1, 0, 1}, {1, 0, 1}, {0, 1, 
                          1}, {0, 0, 0}, {0, 0, 1}, {1, 0, 1}, {0, 1, 0}, {1, 
                          0, 0}, {1, 0, 0}, {0, 1, 0}, {0, 1, 0}, {0, 0, 
                          0}, {1, 1, 0}, {0, 0, 0}, {0, 1, 1}, {0, 1, 0}, {0, 
                          0, 0}, {1, 0, 1}, {0, 0, 0}, {1, 0, 1}, {0, 0, 
                          1}, {0, 0, 1}, {0, 0, 0}, {0, 1, 0}, {0, 0, 0}, {1, 
                          1, 0}, {0, 1, 0}, {0, 1, 1}, {1, 0, 0}, {1, 0, 
                          0}, {1, 0, 0}, {0, 0, 1}, {0, 1, 1}, {0, 0, 1}, {1, 
                          1, 0}, {0, 1, 1}, {0, 0, 1}, {0, 1, 1}, {1, 1, 
                          1}, {0, 1, 0}, {1, 1, 1}}, 100]\)},
                {" "},
                {\(\(pop[0.1`]\)[10] = 
                    HaploidIndividuals[{{1, 1, 0}, {1, 1, 0}, {0, 1, 0}, {0, 
                          0, 0}, {1, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {1, 1, 0}, {0, 0, 0}, {1, 0, 1}, {1, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 1, 1}, {0, 0, 1}, {1, 1, 
                          0}, {1, 0, 0}, {0, 1, 0}, {0, 1, 0}, {1, 1, 0}, {0, 
                          0, 0}, {0, 1, 0}, {1, 0, 0}, {1, 1, 0}, {0, 1, 
                          1}, {1, 1, 0}, {0, 1, 1}, {0, 1, 0}, {1, 0, 0}, {0, 
                          0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 1, 0}, {0, 1, 
                          0}, {1, 0, 0}, {0, 0, 0}, {0, 1, 0}, {1, 1, 1}, {0, 
                          0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 1, 1}, {0, 0, 
                          1}, {0, 1, 0}, {0, 0, 1}, {0, 0, 0}, {1, 0, 1}, {1, 
                          1, 0}, {0, 1, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 
                          1}, {0, 0, 1}, {0, 0, 1}, {0, 0, 0}, {0, 1, 1}, {1, 
                          0, 1}, {0, 0, 0}, {0, 1, 0}, {0, 1, 0}, {0, 0, 
                          0}, {1, 1, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 1, 0}, {0, 1, 0}, {1, 1, 
                          1}, {1, 1, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 1}, {0, 
                          1, 0}, {0, 1, 1}, {0, 1, 1}, {0, 0, 1}, {0, 1, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 1, 0}, {0, 0, 0}, {1, 
                          0, 1}, {0, 1, 0}, {0, 0, 0}, {0, 1, 0}, {0, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 1, 1}, {0, 
                          0, 0}, {1, 1, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {1, 1, 0}, {0, 0, 0}}, 100]\)},
                {" "},
                {\(\(pop[0.1`]\)[20] = 
                    HaploidIndividuals[{{0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 
                          1, 0}, {0, 0, 0}, {1, 0, 0}, {0, 1, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 1, 0}, {0, 
                          0, 0}, {1, 0, 0}, {0, 0, 1}, {0, 1, 0}, {0, 0, 
                          0}, {1, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {0, 1, 0}, {0, 1, 0}, {0, 0, 0}, {0, 1, 
                          0}, {0, 1, 1}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 1, 0}, {0, 
                          0, 0}, {1, 1, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 1, 0}, {0, 1, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 1, 0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 1, 0}, {1, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 
                          0}, {1, 1, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          1, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 1}, {0, 1, 
                          0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {0, 1, 1}, {0, 0, 0}, {1, 0, 0}, {1, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 
                          0}, {0, 0, 1}, {1, 0, 0}}, 100]\)},
                {" "},
                {\(\(pop[0.1`]\)[30] = 
                    HaploidIndividuals[{{1, 0, 1}, {0, 0, 0}, {1, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 
                          0, 1}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {1, 0, 1}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 1}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 
                          0}, {1, 0, 0}, {1, 1, 0}, {1, 0, 0}, {0, 0, 0}, {0, 
                          0, 1}, {0, 0, 0}, {0, 0, 0}, {1, 0, 1}, {1, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {1, 1, 0}, {1, 0, 0}, {1, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 1}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 
                          0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {0, 1, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 1, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 1, 
                          0}, {0, 0, 0}, {0, 0, 0}}, 100]\)},
                {" "},
                {\(\(pop[0.1`]\)[40] = 
                    HaploidIndividuals[{{0, 0, 0}, {1, 0, 1}, {0, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {0, 1, 0}, {1, 0, 0}, {0, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 
                          1, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 1, 
                          0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 
                          0, 0}, {1, 0, 0}, {0, 1, 1}, {1, 0, 1}, {0, 0, 
                          1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 1}, {0, 
                          0, 1}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 
                          0, 0}, {1, 0, 1}, {0, 0, 1}, {1, 0, 0}, {0, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {0, 1, 0}, {0, 0, 1}, {1, 
                          0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {1, 0, 
                          1}, {1, 0, 0}, {1, 0, 1}, {0, 0, 0}, {1, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 1, 1}, {0, 1, 1}, {1, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 
                          0}, {1, 0, 0}, {1, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 
                          0}, {1, 0, 0}, {1, 0, 1}, {0, 0, 1}, {0, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {1, 1, 0}, {0, 0, 0}, {0, 0, 
                          0}, {1, 0, 1}, {0, 0, 1}}, 100]\)},
                {" "},
                {\(\(pop[0.1`]\)[50] = 
                    HaploidIndividuals[{{1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 
                          0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 
                          0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {1, 0, 1}, {1, 0, 0}, {1, 0, 1}, {1, 
                          0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 1}, {1, 0, 
                          0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 
                          0, 1}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 
                          0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 1}, {1, 0, 
                          0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 
                          0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 
                          0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 
                          0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 
                          1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 
                          0, 0}, {0, 0, 1}, {1, 0, 1}, {0, 0, 0}, {1, 0, 
                          0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 
                          0}, {0, 0, 0}, {1, 0, 1}}, 100]\)},
                {" "},
                {\(\(pop[0.1`]\)[60] = 
                    HaploidIndividuals[{{1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 
                          0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}}, 100]\)},
                {" "},
                {\(\(pop[0.1`]\)[70] = 
                    HaploidIndividuals[{{0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 
                          0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}}, 100]\)},
                {" "},
                {\(\(pop[0.1`]\)[80] = 
                    HaploidIndividuals[{{1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 
                          0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 
                          0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}}, 100]\)},
                {" "},
                {\(\(pop[0.1`]\)[90] = 
                    HaploidIndividuals[{{0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {1, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {1, 0, 0}}, 100]\)},
                {" "},
                {\(\(pop[0.1`]\)[100] = 
                    HaploidIndividuals[{{0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 
                          0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                          0}, {0, 0, 0}, {0, 0, 0}}, 100]\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ pop],
      Editable->False]], "Print",
  CellLabel->"From In[112]:="]
}, Closed]],

Cell["\<\
Storing large numbers of genotypes in every generation would waste \
memory.  \
\>", "Text"],

Cell["\<\
It is useful to store results in the form pop[pars] so that results \
for different parameter sets can be kept tidily.\
\>", "Text"],

Cell["This plots allele frequencies at the three loci:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pt[i_] := 
        Table[{t, \(AlleleFrequencyTable[\(pop[0.1]\)[
                  t]]\)\[LeftDoubleBracket]i\[RightDoubleBracket]}, {t, 0, 
            100, 10}];\)\), "\n", 
    \(\(DisplayTogether @@ 
        Table[ListPlot[pt[i], PlotJoined -> True], {i, 3}];\)\)}], "Input",
  CellLabel->"In[113]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0147151 0.997634 [
[.21429 .00222 -6 -9 ]
[.21429 .00222 6 0 ]
[.40476 .00222 -6 -9 ]
[.40476 .00222 6 0 ]
[.59524 .00222 -6 -9 ]
[.59524 .00222 6 0 ]
[.78571 .00222 -6 -9 ]
[.78571 .00222 6 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .11448 -18 -4.5 ]
[.01131 .11448 0 4.5 ]
[.01131 .21424 -18 -4.5 ]
[.01131 .21424 0 4.5 ]
[.01131 .31401 -18 -4.5 ]
[.01131 .31401 0 4.5 ]
[.01131 .41377 -18 -4.5 ]
[.01131 .41377 0 4.5 ]
[.01131 .51353 -18 -4.5 ]
[.01131 .51353 0 4.5 ]
[.01131 .6133 -18 -4.5 ]
[.01131 .6133 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(20)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(40)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(60)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(80)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(100)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11448 m
.03006 .11448 L
s
[(0.1)] .01131 .11448 1 0 Mshowa
.02381 .21424 m
.03006 .21424 L
s
[(0.2)] .01131 .21424 1 0 Mshowa
.02381 .31401 m
.03006 .31401 L
s
[(0.3)] .01131 .31401 1 0 Mshowa
.02381 .41377 m
.03006 .41377 L
s
[(0.4)] .01131 .41377 1 0 Mshowa
.02381 .51353 m
.03006 .51353 L
s
[(0.5)] .01131 .51353 1 0 Mshowa
.02381 .6133 m
.03006 .6133 L
s
[(0.6)] .01131 .6133 1 0 Mshowa
.125 Mabswid
.02381 .03467 m
.02756 .03467 L
s
.02381 .05462 m
.02756 .05462 L
s
.02381 .07457 m
.02756 .07457 L
s
.02381 .09453 m
.02756 .09453 L
s
.02381 .13443 m
.02756 .13443 L
s
.02381 .15438 m
.02756 .15438 L
s
.02381 .17434 m
.02756 .17434 L
s
.02381 .19429 m
.02756 .19429 L
s
.02381 .23419 m
.02756 .23419 L
s
.02381 .25415 m
.02756 .25415 L
s
.02381 .2741 m
.02756 .2741 L
s
.02381 .29405 m
.02756 .29405 L
s
.02381 .33396 m
.02756 .33396 L
s
.02381 .35391 m
.02756 .35391 L
s
.02381 .37386 m
.02756 .37386 L
s
.02381 .39382 m
.02756 .39382 L
s
.02381 .43372 m
.02756 .43372 L
s
.02381 .45367 m
.02756 .45367 L
s
.02381 .47363 m
.02756 .47363 L
s
.02381 .49358 m
.02756 .49358 L
s
.02381 .53348 m
.02756 .53348 L
s
.02381 .55344 m
.02756 .55344 L
s
.02381 .57339 m
.02756 .57339 L
s
.02381 .59334 m
.02756 .59334 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .41377 m
.11905 .32398 L
.21429 .38384 L
.30952 .49358 L
.40476 .49358 L
.5 .56341 L
.59524 .60332 L
.69048 .4836 L
.78571 .50356 L
.88095 .28408 L
.97619 .02469 L
s
.02381 .4836 m
.11905 .42374 L
.21429 .19429 L
.30952 .0646 L
.40476 .09453 L
.5 .01472 L
.59524 .01472 L
.69048 .01472 L
.78571 .01472 L
.88095 .01472 L
.97619 .01472 L
s
.02381 .49358 m
.11905 .2741 L
.21429 .07457 L
.30952 .1045 L
.40476 .22422 L
.5 .14441 L
.59524 .01472 L
.69048 .01472 L
.78571 .01472 L
.88095 .01472 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[113]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00@`3oool5000000<0oooo0P00000[0?ooo`<000000`3oool2000002X0oooo0`0000040?oo
o`800000:P3oool3000000@0oooo0P00000W0?ooo`<00000103oool2000000@0oooo0P0000040?oo
o`00A03oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002/0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo000002P0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo000002L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000<0oooo00150?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000:03oool500000080oooo00@000000?ooo`3oool00000:03oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000:03oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000009`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool004H0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool000000`3oool0
10000000oooo0?ooo`00000X0?ooo`@000000`3oool010000000oooo0?ooo`00000Y0?ooo`<00000
0`3oool010000000oooo0?ooo`00000W0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000030?ooo`00@`3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool00000:@3oool00`000000oooo000000030?ooo`040000003o
ool0oooo000002P0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000X0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000W0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`00@`3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000:P3oool2000000<0
oooo00@000000?ooo`3oool00000:@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
000002P0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000002H0oooo
0P0000040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool004@0
oooo0`0000040?ooo`800000;03oool00`000000oooo0?ooo`020?ooo`800000:`3oool2000000@0
oooo0P00000Z0?ooo`<00000103oool2000002P0oooo00<000000?ooo`3oool00`3oool2000000@0
oooo0P0000040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooo`P0oooo000F0?ooo`030000003o
ool0oooo0?l0oooo203oool001H0oooo00<000000?ooo`3oool0o`3oool80?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooo`P0oooo000?0?ooool000003P0000040?ooo`005P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool001H0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool06@3oool200000380oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`080?ooo`005P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`080?ooo`005P3oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`080?oo
o`005P3oool2000007H0oooo0P00000L0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3o
ool02@3oool001H0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo06H0oooo00<000000?ooo`3oool02@3oool001H0oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool02@3o
ool001H0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool02P3oool001H0oooo00<000000?ooo`3oool0L@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool02P3oool001H0
oooo00<000000?ooo`3oool0K`3oool2000001h0oooo00<000000?ooo`3oool0J03oool00`000000
oooo0?ooo`0:0?ooo`005P3oool2000006l0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1X0?ooo`030000003oool0oooo00/0oooo000F0?ooo`030000003oool0oooo06d0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00/0oooo000F
0?ooo`030000003oool0oooo04T0oooo0`00000P0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0J03oool00`000000oooo0?ooo`0<0?ooo`005P3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo00<00000703oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
06T0oooo00<000000?ooo`3oool0303oool001H0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`040?ooo`<00000603oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06X0
oooo00<000000?ooo`3oool0303oool001H0oooo0P00000a0?ooo`<00000503oool00`000000oooo
0?ooo`080?ooo`<000004`3oool200000200oooo00<000000?ooo`3oool0JP3oool00`000000oooo
0?ooo`0=0?ooo`005P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00<00000403o
ool00`000000oooo0?ooo`0<0?ooo`@000003P3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo06X0oooo00<000000?ooo`3oool03@3oool001H0oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`040?ooo`<000003@3oool00`000000oooo0?ooo`0@0?ooo`<000002P3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool03@3oool0
01H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`070?ooo`<000002@3oool00`00
0000oooo0?ooo`0D0?ooo`<000001P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
06/0oooo00<000000?ooo`3oool03P3oool001H0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`0;0?ooo`<000001@3oool00`000000oooo0?ooo`0H0?ooo`<000000P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool03P3oool001H0oooo
0P00000_0?ooo`030000003oool0oooo00h0oooo0`0000020?ooo`030000003oool0oooo01/0oooo
0P00000S0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool03`3oool001H0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0B0?ooo`<00000@@3oool00`000000oooo0?oo
o`1/0?ooo`030000003oool0oooo00l0oooo000F0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`03000003d0oooo00<000000?ooo`3oool0K@3oool0
0`000000oooo0?ooo`0?0?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool00P3oool30000
00H0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00@0oooo0P00000k0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0403oool00005
0?ooo`000000oooo0?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0@0?ooo`0000D0oooo0000003o
ool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`1^0?ooo`030000003oool0oooo0100oooo00001@3oool000000?ooo`3oool00000
00T0oooo00<000000?ooo`3oool01@3oool2000002`0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0KP3oool00`00
0000oooo0?ooo`0A0?ooo`0000D0oooo0000003oool0oooo000000090?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo
0140oooo00001@3oool000000?ooo`3oool0000000P0oooo0P0000070?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0B0?ooo`000P3oool2000000X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo06l0
oooo00<000000?ooo`3oool04P3oool001H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo0180oooo000F0?ooo`800000:@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`1_0?ooo`030000003oool0oooo01<0oooo000F0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0L03oool00`000000oooo0?ooo`0C0?ooo`005P3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0740oooo00<000000?ooo`3oool04`3oool001H0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool09P3oool2000007<0oooo00<000000?ooo`3oool0503oool001H0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo01@0oooo000F0?ooo`8000009`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo01D0oooo000F0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0E0?ooo`005P3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool05@3oool001H0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0703oool2000007L0oooo00<000000?ooo`3oool05P3oool001H0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo01H0oooo
000F0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`0G0?ooo`005P3oool2000002@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0G
0?ooo`005P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool05`3oool001H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool04P3oool2000007/0oooo00<000000?ooo`3o
ool0603oool001H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1k0?ooo`030000
003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0O03o
ool00`000000oooo0?ooo`0H0?ooo`005P3oool200000280oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`0I0?ooo`005P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
07d0oooo00<000000?ooo`3oool06@3oool001H0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`1m0?ooo`030000003oool0oooo01X0oooo00020?ooo`800000103oool010000000oooo
0?ooo`3oool5000000D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool200000800oooo00<000000?ooo`3o
ool06P3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`0J0?oo
o`0000D0oooo0000003oool0oooo000000090?ooo`030000003oool0oooo00D0oooo0P00000O0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0800oooo00<000000?ooo`3oool06`3oool000050?ooo`000000oooo0?oo
o`0000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0`0?ooo`050000003oool0oooo0?ooo`000000P`3oool0
0`000000oooo0?ooo`0K0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo000000240?ooo`030000003oool0oooo01/0oooo0000
1@3oool000000?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo0880oooo00<000000?ooo`3oool0703oool00080oooo0P0000090?ooo`<000001P3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0^@3o
ool00`000000oooo0?ooo`0L0?ooo`005P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0M0?ooo`005P3oool20000
01`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo
01d0oooo000F0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2i0?ooo`030000003oool0oooo01d0oooo000F0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01h0oooo
000F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`2i0?ooo`030000003oool0oooo01h0oooo000F0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01h0oooo000F0?oo
o`8000006P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0;T0oooo00<000000?oo
o`3oool07`3oool001H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0;T0oooo00<000000?ooo`3oool07`3oool001H0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0
803oool001H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0;T0oooo00<000000?ooo`3oool0803oool001H0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0803oool0
01H0oooo0P00000G0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0^@3oool00`00
0000oooo0?ooo`0Q0?ooo`005P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0Q0?ooo`005P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`0Q0?ooo`005P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0^@3oool00`000000oooo0?ooo`0R0?ooo`005P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0R
0?ooo`005P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0^@3oool00`000000oooo0?ooo`0S0?ooo`005P3oool2000001D0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo02<0oooo000F0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2j0?ooo`030000
003oool0oooo02<0oooo00020?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<000001P3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0^@3o
ool00`000000oooo0?ooo`0T0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003o
ool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0T0?ooo`0000D0oooo0000003oool0oooo
0000000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool09@3oool000050?ooo`00
0000oooo0?ooo`0000002@3oool2000000H0oooo0P00000C0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0U0?ooo`0000D0oooo0000003oool0oooo
0000000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool09P3oool000050?ooo`00
0000oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3o
ool09P3oool00080oooo0P0000090?ooo`<000001P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0080oooo0`0000090?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
9P3oool001H0oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo02L0oooo
000F0?ooo`800000403oool01@000000oooo0?ooo`3oool0000000D0oooo0P0000050?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool09`3oool001H0oooo00<000000?ooo`3oool03`3o
ool010000000oooo0?ooo`0000080?ooo`8000000`3oool00`000000oooo0?ooo`2i0?ooo`030000
003oool0oooo02P0oooo000F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`0000002`3o
ool010000000oooo0?ooo`00002k0?ooo`030000003oool0oooo02P0oooo000F0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`0000003@3oool200000;/0oooo00<000000?ooo`3oool0:@3o
ool001H0oooo00<000000?ooo`3oool03P3oool2000000l0oooo0`00002i0?ooo`030000003oool0
oooo02T0oooo000F0?ooo`030000003oool0oooo00d0oooo0P00000?0?ooo`050000003oool0oooo
0?ooo`000000^03oool00`000000oooo0?ooo`0Y0?ooo`005P3oool2000000h0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`020?ooo`800000]@3oool00`000000oooo0?ooo`0Z0?oo
o`005P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo02X0oooo000F0?ooo`030000
003oool0oooo00/0oooo0P00000@0?ooo`030000003oool0oooo00H0oooo0P00002a0?ooo`030000
003oool0oooo02/0oooo000F0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`000000403o
ool00`000000oooo0?ooo`080?ooo`800000[`3oool00`000000oooo0?ooo`0[0?ooo`005P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool000000100oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02`0oooo000F0?ooo`8000002@3oool01000
0000oooo0?ooo`00000@0?ooo`030000003oool0oooo00`0oooo0P00002[0?ooo`030000003oool0
oooo02`0oooo000F0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000403oool0
0`000000oooo0?ooo`0?0?ooo`800000Z@3oool00`000000oooo0?ooo`0/0?ooo`005P3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0;@3oool001H0oooo00<000000?oo
o`3oool01@3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02d0oooo000F0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0^0?ooo`005P3oool2000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0^0?ooo`005P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0;`3oool001H0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02l0oooo00020?ooo`800000103o
ool00`000000oooo0?ooo`030?ooo`<000001@3oool010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`2N0?ooo`030000
003oool0oooo02l0oooo00001@3oool000000?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
103oool00`000000oooo000000070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0300oooo00001@3oool000000?oo
o`3oool0000000L0oooo1@0000050?ooo`800000203oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`0000D0
oooo0000003oool0oooo000000070?ooo`040000003oool0oooo000000H0oooo0P0000070?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2J0?ooo`03
0000003oool0oooo0340oooo00001@3oool000000?ooo`3oool0000000P0oooo00<000000?ooo`00
00001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo00001@3oool00000
0?ooo`3oool0000000T0oooo0P0000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool03@3oool200000240oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0a0?ooo`00
0P3oool2000000/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`2F0?ooo`030000
003oool0oooo0380oooo000F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3o
ool2000002H0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0b0?ooo`005P3oool2
000000D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo09<0oooo00<000000?ooo`3oool0<`3oool001H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`800000:`3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo
03<0oooo000F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool2000002h0
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0d0?ooo`005P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo03@0oooo000F0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool200000380oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0d0?ooo`005P3oool2000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0=@3oool001H0oooo00D000000?oo
o`3oool0oooo000000050?ooo`800000=`3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo03D0oooo000F0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0=P3oool001H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`800000?03oool00`000000oooo0?ooo`290?ooo`030000003oool0
oooo03H0oooo000F0?ooo`050000003oool0oooo0000003oool00P00000o0?ooo`030000003oool0
oooo08L0oooo00<000000?ooo`3oool0=`3oool001H0oooo00<000000?ooo`3oool00P0000110?oo
o`030000003oool0oooo08L0oooo00<000000?ooo`3oool0=`3oool001H0oooo100000130?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool0=`3oool001H0oooo0`0000150?ooo`030000
003oool0oooo08@0oooo00<000000?ooo`3oool0>03oool001H0oooo0P0000170?ooo`030000003o
ool0oooo06H0oooo0`00000J0?ooo`030000003oool0oooo03P0oooo000F0?ooo`800000B03oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00D00000503oool00`000000oooo0?ooo`0i
0?ooo`005P3oool2000004T0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`060?oo
o`@00000403oool00`000000oooo0?ooo`0i0?ooo`005P3oool2000004X0oooo700000180?ooo`03
0000003oool0oooo00/0oooo1000000;0?ooo`030000003oool0oooo03X0oooo000F0?ooo`030000
003oool0oooo06D0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0@0?ooo`D00000
1P3oool00`000000oooo0?ooo`0j0?ooo`005P3oool00`000000oooo0?ooo`1V0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool05P3oool400000080oooo00<000000?ooo`3oool0>P3o
ool00080oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000060?ooo`030000003oool0
oooo06L0oooo0P0000120?ooo`030000003oool0oooo01X0oooo0P00000m0?ooo`0000D0oooo0000
003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`1Y0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0FP3oool000050?ooo`000000
oooo0?ooo`0000002`3oool00`000000oooo0?ooo`030?ooo`800000J`3oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo05/0oooo00001@3oool000000?ooo`3oool0000000/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`1[0?ooo`800000>`3oool00`000000oooo0?oo
o`1L0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`@000001P3oool00`000000oooo0?oo
o`1]0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0G03oool000050?ooo`000000
oooo0?ooo`0000001`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06h0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`1M0?ooo`000P3oool2000000P0oooo1@000005
0?ooo`030000003oool0oooo06l0oooo0P00000e0?ooo`030000003oool0oooo05h0oooo000F0?oo
o`030000003oool0oooo0740oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1O0?oo
o`005P3oool2000007<0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1P0?ooo`00
5P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
H03oool001H0oooo00<000000?ooo`3oool0M03oool2000002d0oooo00<000000?ooo`3oool0H@3o
ool001H0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo0680oooo000F0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`1S0?ooo`005P3oool2000007T0oooo0P00000W0?ooo`030000003oool0oooo06<0
oooo000F0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`1T0?ooo`005P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0I@3oool001H0oooo00<000000?ooo`3oool0O03oool200000200oooo00<00000
0?ooo`3oool0IP3oool001H0oooo00<000000?ooo`3oool0OP3oool3000001`0oooo00<000000?oo
o`3oool0I`3oool001H0oooo0P0000220?ooo`<000006@3oool00`000000oooo0?ooo`1W0?ooo`00
5P3oool00`000000oooo0?ooo`240?ooo`8000005P3oool00`000000oooo0?ooo`1X0?ooo`005P3o
ool00`000000oooo0?ooo`260?ooo`<000004P3oool00`000000oooo0?ooo`1Y0?ooo`005P3oool0
0`000000oooo0?ooo`290?ooo`8000003`3oool00`000000oooo0?ooo`1Z0?ooo`005P3oool00`00
0000oooo0?ooo`2;0?ooo`<00000303oool00`000000oooo0?ooo`1Z0?ooo`005P3oool00`000000
oooo0?ooo`2>0?ooo`<00000203oool00`000000oooo0?ooo`1[0?ooo`005P3oool200000980oooo
0P0000050?ooo`030000003oool0oooo06`0oooo000F0?ooo`030000003oool0oooo09<0oooo0`00
00000`3oool000000?ooo`1^0?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool00P3oool3
000000H0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`1^0?ooo`0000D0oooo0000
003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`3o0?ooo`P0oooo00001@3oool000000?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo
000000050?ooo`030000003oool0oooo0?l0oooo203oool000050?ooo`000000oooo0?ooo`000000
1`3oool4000000H0oooo0P00003o0?ooo`T0oooo00001@3oool000000?ooo`3oool0000000L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00001@3oool000000?oo
o`3oool0000000P0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`000P3oool2000000X0oooo0P00
003o0?oooa40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-8.75967, -0.0462582, \
0.392591, 0.00374783}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Immigration into one deme", "SubsubsectionIcon",
  CellTags->"Immigration"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], 
              W, {m, Nm}]\), \(allows\ for\ immigration\ of\ Nm\ individuals\ \
from\ a\ source\ fixed\ for\ {1, 1  \[Ellipsis]}, \ 
            and\ emigration\ with\ probability\ m\)},
          {\(IterateExact[\[Psi], W, {m, Nm}, 
              FixedEnds -> {HaploidFrequencies[\[Psi]\_s, 
                    n]}]\), \(allows\ for\ immigration\ from\ a\ haploid\ \
source\ with\ frequencies\ \[Psi]\_s; \ source\ size\ n\ is\ irrelevant\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->"IterateExact"],

Cell["This sets up a haploid population of 100 gametes:", "MathCaption"],

Cell[BoxData[
    \(\(hp = 
        MakePopulation[3, {0, 0.1, 0.5}, 100, 
          NumericalModel \[Rule] HaploidIndividuals];\)\)], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
This iterates random union, followed by migration, and selection \
against '1' alleles:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(w[s_, add]\)[x_, 
          y_] := \((1 - s)\)\^Plus @@ \((x + y)\);\)\), \
"\[IndentingNewLine]", 
    \(IterateExact[hp, w[0.1, add], {0.01, 10}]\)}], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(HaploidIndividuals[{{0, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 1}, {0, 0, 
          0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          1}, {0, 0, 0}, {0, 0, 0}, {1, 1, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 
          0}, {0, 0, 1}, {0, 0, 1}, {1, 1, 1}, {0, 0, 1}, {0, 0, 1}, {0, 0, 
          1}, {0, 0, 0}, {0, 0, 1}, {1, 1, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 
          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          1}, {0, 0, 1}, {0, 0, 0}, {1, 1, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 
          0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 
          1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 1, 1}, {0, 0, 
          1}, {0, 0, 1}, {0, 0, 1}, {0, 0, 1}, {1, 1, 1}, {0, 0, 1}, {0, 0, 
          1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 
          0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {1, 1, 
          1}, {0, 0, 1}, {0, 0, 0}, {1, 1, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 
          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 
          1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 
          0}, {0, 0, 0}, {0, 1, 0}, {0, 0, 0}, {0, 1, 0}, {1, 1, 1}, {0, 0, 
          1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          1}, {0, 0, 1}, {0, 0, 0}, {0, 1, 1}, {0, 0, 0}, {0, 1, 0}, {0, 0, 
          0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}}, 
      118]\)], "Output",
  CellLabel->"Out[5]="]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Varying deme size", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, m, 
              DemeSize -> F]\), \(changes\ deme\ size\ to\ F[n, W\&_]\)},
          {\(\(ExponentialF[r, \[Beta], \[Lambda]]\)[n, 
              W\&_]\), \(represents\ r\[VeryThinSpace]n\[VeryThinSpace]\(W\&_\
\^\[Beta]\) Exp[\(-\[Lambda]\)\[VeryThinSpace]n]\)},
          {\(\(PowerF[r, \[Beta], \[Lambda]]\)[n, 
              W\&_]\), \(represents\ r\[VeryThinSpace]n\^\(1 - \[Lambda]\)\
\[VeryThinSpace]W\&_\^\[Beta]\)},
          {\(StoreExact[\[Psi], \[Psi]\_0, W, m, {t, dt}, 
              DemeSize -> 
                F]\), \(stores\ results\ in\ \[Psi]\ for\ t\ generations\ at\ \
intervals\ dt\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->{"DemeSize", "PowerF", "ExponentialF"}],

Cell["This represents density regulation:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IterateExact[hp, w[0.1, add], {0.01, 10}, 
      DemeSize \[Rule] ExponentialF[2, 0, 0.02]]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(HaploidIndividuals[{{0, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 
          1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {1, 1, 
          1}, {0, 0, 0}, {1, 1, 1}, {0, 0, 0}, {1, 1, 1}, {1, 1, 1}, {1, 1, 
          1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 1}, {0, 0, 
          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 1}, {1, 1, 1}, {0, 1, 
          0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 
          1}, {0, 0, 1}, {0, 0, 1}, {0, 0, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 
          1}, {0, 1, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 1, 1}, {0, 1, 
          0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 
          1}, {0, 0, 0}, {0, 0, 0}, {0, 1, 1}, {0, 0, 0}, {0, 0, 0}, {0, 1, 
          1}, {0, 0, 1}, {0, 0, 1}, {0, 0, 1}, {0, 0, 1}, {1, 1, 1}, {0, 0, 
          1}, {1, 1, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 1, 
          1}, {0, 0, 0}}, 72]\)], "Output",
  CellLabel->"Out[7]="]
}, Closed]],

Cell[TextData[{
  "The number after selection changes to 2n Exp[-0.02n],where n is the number \
after migration and before selection.  ",
  ButtonBox["Other functions ",
    ButtonData:>{"Simulating individuals: reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "of the form ",
  Cell[BoxData[
      \(TraditionalForm\`F[n, W\&_]\)]],
  " can be given."
}], "Text"],

Cell["\<\
In this example, density rapidly moves to a deterministic \
equilibrium.  Random fluctuations of deme size could be included, as could \
dependence on mean fitness.\
\>", "Text"],

Cell["\<\
This shows the allele frequency at three loci (left) and deme size \
(right), with selection s=10% against '1' alleles, 1% emigration, and \
immigration by 10individuals per generation from a source fixed for \
'1':\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(StoreExact[pop[0.1, 0.01], hp, w[0.1, add], {0.01, 1}, {200, 10}, 
        DemeSize \[Rule] ExponentialF[2, 0, 0.02]];\)\), "\n", 
    \(\(pt[i_] := 
        Table[{t, \(AlleleFrequencyTable[\(pop[0.1, 0.01]\)[
                  t]]\)\[LeftDoubleBracket]i\[RightDoubleBracket]}, {t, 0, 
            200, 10}];\)\), "\n", 
    \(\(cs = {Red, Blue, Black};\)\), "\n", 
    \(\(Show[
        GraphicsArray[{DisplayTogether @@ 
              Table[ListPlot[pt[i], PlotJoined -> True, 
                  PlotStyle \[Rule] cs[\([\)\(i\)\(]\)]], {i, 
                  3}], \[IndentingNewLine]ListPlot[
              Table[{t, DemeSize[\(pop[0.1, 0.01]\)[t]]}, {t, 0, 200, 10}], 
              PlotJoined -> True, 
              PlotRange \[Rule] {{0, 200}, {0, 100}}]}]];\)\)}], "Input",
  CellLabel->"In[4]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.0147151 1.17721 [
[.2619 .00222 -6 -9 ]
[.2619 .00222 6 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -18 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(50)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(100)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(150)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(200)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.1)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.2)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.3)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.4)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(0.5)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03826 m
.02756 .03826 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .08535 m
.02756 .08535 L
s
.02381 .10889 m
.02756 .10889 L
s
.02381 .15598 m
.02756 .15598 L
s
.02381 .17952 m
.02756 .17952 L
s
.02381 .20307 m
.02756 .20307 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .2737 m
.02756 .2737 L
s
.02381 .29724 m
.02756 .29724 L
s
.02381 .32079 m
.02756 .32079 L
s
.02381 .34433 m
.02756 .34433 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .41497 m
.02756 .41497 L
s
.02381 .43851 m
.02756 .43851 L
s
.02381 .46205 m
.02756 .46205 L
s
.02381 .50914 m
.02756 .50914 L
s
.02381 .53269 m
.02756 .53269 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57977 m
.02756 .57977 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .01472 m
.07143 .04835 L
.11905 .38469 L
.16667 .44751 L
.21429 .11562 L
.2619 .11562 L
.30952 .14925 L
.35714 .14925 L
.40476 .16607 L
.45238 .11562 L
.5 .0988 L
.54762 .13244 L
.59524 .30061 L
.64286 .08198 L
.69048 .16607 L
.7381 .13244 L
.78571 .14925 L
.83333 .13244 L
.88095 .08198 L
.92857 .03153 L
.97619 .11562 L
s
0 0 1 r
.02381 .16775 m
.07143 .13244 L
.11905 .14925 L
.16667 .32633 L
.21429 .41833 L
.2619 .28379 L
.30952 .16607 L
.35714 .08198 L
.40476 .03153 L
.45238 .14925 L
.5 .08198 L
.54762 .23334 L
.59524 .18289 L
.64286 .06517 L
.69048 .06517 L
.7381 .03153 L
.78571 .13244 L
.83333 .06517 L
.88095 .0988 L
.92857 .33424 L
.97619 .06517 L
s
0 0 0 r
.02381 .60332 m
.07143 .28379 L
.11905 .21652 L
.16667 .1359 L
.21429 .0988 L
.2619 .13244 L
.30952 .04835 L
.35714 .13244 L
.40476 .03153 L
.45238 .0988 L
.5 .04835 L
.54762 .06517 L
.59524 .13244 L
.64286 .01472 L
.69048 .11562 L
.7381 .06517 L
.78571 .06517 L
.83333 .1997 L
.88095 .33424 L
.92857 .23334 L
.97619 .06517 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.005 0 0.00618034 [
[.125 -0.0125 -6 -9 ]
[.125 -0.0125 6 0 ]
[.25 -0.0125 -6 -9 ]
[.25 -0.0125 6 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[-0.0125 .12361 -12 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -12 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -12 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -12 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(50)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(125)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(150)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(175)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(200)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(20)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(40)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(60)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(80)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(100)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .61803 m
.05 .43262 L
.1 .43262 L
.15 .42026 L
.2 .43262 L
.25 .43262 L
.3 .43262 L
.35 .43262 L
.4 .43262 L
.45 .43262 L
.5 .43262 L
.55 .43262 L
.6 .43262 L
.65 .43262 L
.7 .43262 L
.75 .43262 L
.8 .43262 L
.85 .43262 L
.9 .43262 L
.95 .43262 L
1 .43262 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[36]:=",
  ImageSize->{582, 171.25},
  ImageMargins->{{1, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000960000Zb000`400?l00000o`00003oo`3ooooo
0?ooodP0oooo003o0?ooool0ooooB03oool00?l0ooooo`3ooom80?ooo`00o`3ooooo0?ooodP0oooo
003o0?ooool0ooooB03oool00?l0ooooo`3ooom80?ooo`00F@3oool3000000@0oooo0P00000^0?oo
o`<00000103oool2000000@0oooo0P00000[0?ooo`<000000`3oool3000000@0oooo0P00000Z0?oo
o`D000000`3oool2000000@0oooo0P0000180?ooo`D000000P3oool3000001@0oooo0`0000040?oo
o`8000005@3oool00`000000oooo0?ooo`020?ooo`<000004@3oool3000000@0oooo0P0000040?oo
o`8000003P3oool300000080oooo1@0000020?ooo`<000003P3oool3000000<0oooo0`0000040?oo
o`8000003P3oool3000000@0oooo00<000000?ooo`3oool00P3oool3000000d0oooo1@0000030?oo
o`800000103oool2000001<0oooo001H0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`00000^0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000004P0oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000h0oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00/0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000180oooo
001L0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000:`3oool00`00
0000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
B@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000003P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000004P3oool005`0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`00000[0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0D0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool005P0
oooo100000030?ooo`040000003oool0oooo000002h0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool0oooo
100000030?ooo`040000003oool0oooo000002T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000A`3oool01P000000oooo0?oo
o`3oool000000?ooo`@000004`3oool4000000<0oooo00@000000?ooo`3oool000005P3oool00`00
0000oooo0000000300000180oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000h0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0000000<000003`3oool010000000oooo0?ooo`3oool4000000<0oooo00@000000?ooo`3o
ool000003P3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000<000003@3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000B0?ooo`00F03oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000002d0oooo
0P0000040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000:P3oool20000
00<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000Y0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000004L0
oooo00L000000?ooo`3oool0oooo0000003oool0000001H0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`00000B0?ooo`070000003oool0oooo0?ooo`000000oooo0000000D0?ooo`80
0000103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000d0oooo0P000003
0?ooo`070000003oool0oooo0?ooo`000000oooo0000000A0?ooo`8000000`3oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo000000d0oooo0P0000030?ooo`070000003oool0oooo0?oo
o`000000oooo0000000@0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000180oooo001H0?ooo`D000000`3oool2000002l0oooo
00<000000?ooo`3oool00`3oool2000000@0oooo0P00000/0?ooo`040000003oool0oooo0?ooo`D0
00000`3oool2000002/0oooo0`0000040?ooo`800000103oool2000004T0oooo0`0000020?ooo`D0
00004P3oool5000000<0oooo0P00000C0?ooo`D0000000<0oooo0000000000000`00000A0?ooo`03
0000003oool0oooo00<0oooo0P0000040?ooo`8000003`3oool00`000000oooo0?ooo`020?ooo`<0
00000P3oool5000000h0oooo00@000000?ooo`3oool0oooo1@0000030?ooo`8000003`3oool01000
0000oooo0?ooo`3oool5000000030?ooo`000000000000<000003@3oool3000000@0oooo0P000004
0?ooo`8000004`3oool00?l0ooooo`3ooom80?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0
oooo8@3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooob40oooo000T0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolQ0?ooo`007P3oool600000080o`00k@00000a0?ooonT000006@3oool0
02@0oooo00<000000?ooo`3o0000203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`00903oool010000000
oooo0?ooo`3o000f0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0000000E0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool05`3oool002@0
oooo00D000000?ooo`3oool0oooo0?l0002A0?ooo`030000003oool0000008L0oooo00<000000?oo
o`3oool0o`3oool002@0oooo00<000000?ooo`3oool00P3oool20?l005D0oooo00<000000?ooo`3o
ool0=`3oool010000000oooo0?ooo`00000C0?ooo`80003o;@3oool00`3o0000oooo0?ooo`110?oo
o`030000003oool0oooo0?l0oooo000T0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`0f0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`00
0?l0oooo0000o`0]0?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3oool0o`3oool002@0
oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`1@0?ooo`030000003oool0000003L0
oooo00D000000?ooo`3oool0oooo0000000A0?ooo`050000o`3oool0oooo0?ooo`000?l0:`3oool0
0`3o0000oooo0?l000120?ooo`030000003oool0oooo0?l0oooo000T0?ooo`030000003oool0oooo
00H0oooo00<0o`000?ooo`3oool0CP3oool01@000?l000000?ooo`000?l0000003D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`80003o103oool00`000?l0oooo0?ooo`0X
0?ooo`040?l0003oool0oooo0?l00480oooo0P00003o0?ooo`40oooo000T0?ooo`030000003oool0
oooo00L0oooo00<0o`000?ooo`3oool0C03oool01P000?l000000?ooo`3oool0003o000003D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool09P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo03l0oooo
00<000000?ooo`3oool0o`3oool002@0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?oo
o`0g0?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`0000000`3oool00`000?l000000?oo
o`0C0?ooo`8000007@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0U0?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`3o0?ooo`00903oool00`000000oooo0?ooo`08
0?ooo`030?l0003oool0oooo03L0oooo00<000000?ooo`3oool03`3oool010000?l0oooo0?ooo`00
00030?ooo`030000o`3oool000000180oooo00<000000?ooo`3oool00`00000J0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool20000o`T0oooo00<0003o0?ooo`3oool0903o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo03h0oooo00<000000?ooo`3oool0o`3o
ool002@0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`0f0?ooo`030000003oool0
000000l0oooo00@0003o0?ooo`3oool000001@3oool00`000?l0oooo0000000@0?ooo`030000003o
ool0oooo00@0oooo0`00000G0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0280oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`0m0?ooo`030000003oool0oooo0?l0oooo000T0?ooo`030000003oool0
oooo00P0oooo00<0o`000?ooo`3oool0=P3oool010000000oooo0?ooo`00000>0?ooo`040000o`3o
ool0oooo000000D0oooo00<0003o0?ooo`0000003`3oool00`000000oooo0?ooo`080?ooo`<00000
4`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0
?@3oool00`000000oooo0?ooo`3o0?ooo`00903oool00`000000oooo0?ooo`090?ooo`030?l0003o
ool0oooo03@0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`040000o`3oool0oooo000000L0
oooo00<0003o0?ooo`0000003@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool00P3oool60000o`03000000000?l0003o00<0003o2`3oool<000000/0
oooo0P000?l>0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0103oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo0?l0oooo000T0?ooo`030000003oool0oooo00T0oooo
00<0o`000?ooo`3oool0=03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
00D0003o0?ooo`3oool0oooo000000070?ooo`040000o`3oool0oooo000000/0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<0003o0?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`030000o`3oool0003o00`0oooo00<0o`000?oo
o`3oool02P3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool0o`3oool002@0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0c0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool00000
00P0oooo00@0003o0?ooo`3oool000002P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000003oool0
oooo00L0oooo00@0003o0?ooo`3oool0oooo0P000?l90?ooo`030?l0003oool0oooo00`0oooo00<0
o`000?ooo`3oool00`3oool00`000000oooo0?ooo`0e0?ooo`800000o`3oool10?ooo`00903oool0
0`000000oooo0?ooo`090?ooo`030?l0003oool0oooo0380oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`3oool01`3oool0
10000?l0oooo0?ooo`0000080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool03P3o
ool01P3o0000oooo0?ooo`3oool000000000ocL0oooo00<000000?ooo`3oool0o`3oool002@0oooo
00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0b0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
00D0003o0?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3o
00001P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo0P000?l40?ooo`03
0?l0003oool0oooo00l0oooo00D0o`000?ooo`3oool0oooo0000000h0?ooo`030000003oool0oooo
0?l0oooo000T0?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool0<@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`000000
oooo0?ooo`090?ooo`050000o`3oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`060?oo
o`030000o`3oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?oo
o`030000o`3oool0o`0000L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?oo
o`030000o`3oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`080?oo
o`040000o`3oool0oooo0?l001<0oooo00@0o`000?ooo`3oool00000>03oool00`000000oooo0?oo
o`3o0?ooo`00903oool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo0340oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<00000
0?ooo`3oool02@3oool01@000?l0oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3o
ool20000o`h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`040000o`3o
ool0o`000?l000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000
o`3oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0:0?ooo`80003o
503oool0103o0000oooo000000000?lh0?ooo`030000003oool0oooo0?l0oooo000T0?ooo`030000
003oool0oooo00X0oooo00<0o`000?ooo`3oool0;`3oool00`000000oooo0?ooo`090?ooo`050000
003oool0oooo0?ooo`000?l01@3oool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0080
oooo00<000000?ooo`000000203oool010000?l0oooo0?ooo`000?l>0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool01@000?l0oooo0?l0003oool0o`0000L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0003o01@0oooo00<0o`00
000000000?l0>03oool00`000000oooo0?ooo`3o0?ooo`00903oool00`000000oooo0?ooo`0:0?oo
o`030?l0003oool0oooo01d0oooo0`00000?0?ooo`030000003oool0oooo00X0oooo00@000000?oo
o`3oool0003o1@3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo0080oooo00<00000
0?ooo`3oool01P3oool01@000?l0oooo0?l0003o0000003o00l0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`030000o`3oool0o`000080oooo00<0o`000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`3oool0103o
ool010000000oooo0?ooo`000?l=0?ooo`050?l0003oool0oooo0?ooo`000?l04`3oool00`3o0000
00000000o`0h0?ooo`030000003oool0oooo0?l0oooo000T0?ooo`030000003oool0oooo00X0oooo
00<0o`000?ooo`3oool0703oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3o
ool0303oool00`000000003o0?ooo`040?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000003o0?l000020?ooo`030000o`3o0000oooo00d0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`040000o`3oool0oooo0?l00080oooo00<0o`000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<0003o0?oo
o`3oool00`3oool010000000oooo0?ooo`000?l<0?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`800000o`3oool10?ooo`00903oool00`00
0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01/0oooo00<000000?ooo`3oool00`3oool20000
00/0oooo00<000000?ooo`3oool0303oool00`000000003o0?ooo`040?ooo`030000003oool0oooo
00d0oooo00<0003o0?ooo`3oool01P3oool30?l000030000o`3oool0oooo00<0oooo00<0003o0?l0
003oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@0003o0?oo
o`3oool0o`000`3oool00`3o0000oooo0?ooo`040?ooo`040000003oool0oooo00000140oooo00<0
003o0?ooo`3oool00`3oool00`000000oooo0000o`0<0?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool04@3oool00`000000003o0?l0000h0?ooo`030000003oool0oooo0?l0oooo000T
0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool06@3oool2000000P0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000o`000000oooo00<0oooo00<00000
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`030?ooo`<0o`000P3oool00`000?l0oooo0?ooo`04
0?ooo`040000o`3oool0o`000?l000d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`3o0000oooo0?ooo`030?ooo`030000
003oool0000001<0oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool04@3oool00`000000003o0?l0000h0?ooo`030000
003oool0oooo0?l0oooo000T0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool0603o
ool00`000000oooo0?ooo`030?ooo`H0o`000P0000060?l000030000003oool0oooo00d0oooo00<0
003o0?ooo`000000103oool00`000000oooo0?ooo`0>0?ooo`040000o`3oool0oooo0?ooo`80o`00
103oool00`000?l0oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`3o00003@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@0003o0?ooo`3oool0o`001@3oool00`3o
0000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo00<0003o0?ooo`3oool00P3oool00`00
0?l000000?ooo`0:0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0403oool01000
0000003o0?ooo`3o000g0?ooo`030000003oool0oooo0?l0oooo000T0?ooo`030000003oool0oooo
00X0oooo00<0o`000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`040000o`3oool0oooo
000000<0oooo00<000000?ooo`3oool03`3oool00`000?l0oooo0?l000060?ooo`030000o`3oool0
oooo00H0oooo00@0003o0?ooo`3oool0oooo0P3o000;0?ooo`050000003oool0oooo0?ooo`000000
1@3oool010000?l0oooo0?ooo`3o00060?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo000000090?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool03`3oool00`000000oooo0000o`0i0?ooo`030000003oool0oooo0?l0oooo000A0?ooo`800000
103oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`0;0?ooo`030?l0
003oool0oooo01@0oooo0P0000070?ooo`030?l0003oool0oooo00H0oooo0P0000020?ooo`030000
003oool0o`0000d0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0000000B0?ooo`030000
o`3o0000oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00T0oooo00@000000?ooo`3oool00000103oool01@000?l0oooo0?ooo`3oool0o`00
00H0oooo00<0o`000?ooo`3oool06@3oool010000?l0oooo0?ooo`000?l20?ooo`030000003oool0
oooo00H0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0
003o02X0oooo1@0000030?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`00403oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool0
0`000000oooo000000020?ooo`80o`002`3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0
00000180oooo00<0o`000000o`3oool0103oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool02@3oool00`000000oooo000000040?ooo`050000o`3oool0
oooo0?ooo`3o00001`3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0003o00<0oooo00<0
00000?ooo`3oool01@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00l0oooo00<0
00000000o`3oool0:`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0o`3oool00100oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`040?ooo`800000203oool40000o`030?l0003oool0oooo0180oooo00<000000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`040?ooo`030000003oool0oooo0100oooo00<0o`000?ooo`00
0?l0103oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool02@3oool00`000000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000203oool00`3o
0000oooo0?ooo`0=0?ooo`<0o`002@3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo0P3o000<0?ooo`030000o`3oool0oooo00h0oooo00<000000?ooo`000?l0;@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0P00003o0?ooo`40oooo000@0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000o`3oool0oooo0080oooo0`000?lA0?ooo`030000003oool0oooo00P0oooo00<0o`00
0?ooo`3oool04@3oool20?l000H0oooo00<0003o0?ooo`3oool05`3oool01@3o0000oooo0?ooo`3o
ool0003o00<0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00h0oooo00D0003o0?ooo`3oool0oooo0?l000090?ooo`030?l0003oool0oooo00/0oooo
00@0o`000?ooo`3oool0oooo0`3o000<0?ooo`030000003oool0o`000080o`003`3oool00`000?l0
oooo0?ooo`0=0?ooo`030000003oool0003o02h0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool00100oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`030000o`h0oooo00<000000?ooo`3oool0203oool00`3o
0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool05P3oool00`3o
0000oooo0?ooo`020?ooo`040000o`3oool0oooo0000o`d0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`090?ooo`80o`001`3oool30?l000P0oooo00<0o`000000003o00004P3oool0
0`000?l0oooo0?ooo`0=0?ooo`030000003oool0003o02/0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool00100oooo00@0
00000?ooo`3oool00000203oool2000000H0oooo00<000000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00<0oooo0`000?l:0?ooo`030000003oool0oooo00T0oooo
00<0o`000?ooo`3oool0503oool01@3o0000oooo0?ooo`3oool0003o01P0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0000o`0>0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`0:0?ooo`<0o`000P3oool30?l00080oooo00<000000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0=0?ooo`030000003oool0003o02/0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool0
0140oooo0P00000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool20000
o`L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030000003oool0oooo
00T0oooo00<0o`000?ooo`3oool05@3oool30?l000030000o`3o0000o`0000P0o`003@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`0<0?ooo`050000o`3oool0oooo0?ooo`3o0000303oool00`3o0000oooo0?ooo`04
0?ooo`80o`00403oool20?l000D0oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?ooo`0<
0?ooo`030000003oool0003o02d0oooo0`0000040?ooo`8000001@3oool00`000000oooo0?ooo`3o
0?ooo`00903oool01@000000oooo0?ooo`3oool0003o00X0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool05`3oool0
0`000?l0oooo0?ooo`090?ooo`<0o`002@3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo00X0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0G0?ooo`030000003oool0
oooo0100oooo00<0003o0?ooo`3oool0303oool00`000000oooo0000o`0k0?ooo`030000003oool0
oooo0?l0oooo000T0?ooo`040000003oool0oooo0000o`/0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool05P3oool0
0`000?l0oooo0?ooo`0=0?ooo`<0o`001@3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo00/0oooo00<0o`000?ooo`3oool00P3o000K0?ooo`030000003oool0oooo0100oooo00<0003o
0?ooo`3oool02`3oool00`000000oooo0000o`0k0?ooo`030000003oool0oooo0?l0oooo000T0?oo
o`030000003oool0003o00`0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?oo
o`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0@0?oo
o`<0o`0000<0oooo0?l0003oool06`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0o`00
01d0oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?ooo`0:0?ooo`040000003oool0oooo
0000oc/0oooo0P00003o0?ooo`40oooo000T0?ooo`03000000000?l0oooo00`0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<0o`000?oo
o`3oool05P3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0303oool00`3o0000oooo0?ooo`0M0?ooo`030000003oool0oooo00l0oooo00<0003o0?oo
o`3oool02P3oool010000000oooo0?ooo`000?lk0?ooo`030000003oool0oooo0?l0oooo000T0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?oo
o`030000003oool0oooo00/0oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0b0?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo02d0oooo00<000000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0:0?oo
o`030000003oool0003o03`0oooo00<000000?ooo`3oool0o`3oool002@0oooo00<000000?ooo`3o
ool0303oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo03<0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00X0oooo00<000000?ooo`00
0?l0?03oool00`000000oooo0?ooo`3o0?ooo`00903oool00`000000oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0000000>0?ooo`030?l0003oool0oooo01D0
oooo00<0003o0?ooo`3oool0=03oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0^0?ooo`030000003oool0oooo00l0
oooo00<0003o0?ooo`3oool0203oool010000000oooo0?ooo`000?ll0?ooo`030000003oool0oooo
0?l0oooo000T0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool01P3oool010000?l0
oooo0?ooo`00000?0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool0=03oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`0^0?ooo`030000003oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool01000
0000oooo0?ooo`000?ll0?ooo`030000003oool0oooo0?l0oooo000T0?ooo`030000003oool0oooo
00d0oooo00<0o`000?ooo`3oool01P3oool010000?l0oooo0?ooo`00000?0?ooo`030?l0003oool0
oooo01@0oooo00<0003o0?ooo`3oool0=@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0_0?ooo`030000003oool0
oooo00l0oooo00<0003o0?ooo`3oool0203oool010000000oooo0?ooo`000?ll0?ooo`030000003o
ool0oooo0?l0oooo000T0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0000000?0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool0=P3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`0`0?ooo`030000003oool0oooo00h0oooo00<0003o0?ooo`3oool01`3oool0
1@000000oooo0?ooo`3oool0003o03`0oooo0P00003o0?ooo`40oooo000T0?ooo`030000003oool0
oooo00d0oooo00<0o`000?ooo`3oool01`3oool00`000?l000000?ooo`0>0?ooo`030?l0003oool0
oooo01D0oooo00<0003o0?ooo`3oool0=P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0`0?ooo`030000003oool0
oooo00h0oooo00<0003o0?ooo`3oool01`3oool010000000oooo0?ooo`000?lm0?ooo`030000003o
ool0oooo0?l0oooo000T0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0=`3oool0
0`000?l0oooo0?ooo`050?ooo`050?l0003oool0oooo0?ooo`000?l0203oool00`3o0000oooo0?oo
o`0`0?ooo`030000003oool0oooo00l0oooo00<0003o0?ooo`3oool01P3oool010000000oooo0?oo
o`000?lm0?ooo`030000003oool0oooo0?l0oooo000T0?ooo`030000003oool0oooo00d0oooo00<0
o`000?ooo`3oool01P3oool00`000000003o0?ooo`0?0?ooo`030?l0003oool0oooo01@0oooo00<0
003o0?ooo`3oool0=`3oool00`000?l0oooo0?ooo`050?ooo`040?l0003oool0oooo0000o`T0oooo
00<0o`000?ooo`3oool0<@3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00D0oooo
00D000000?ooo`3oool0oooo0000o`0m0?ooo`030000003oool0oooo0?l0oooo000T0?ooo`030000
003oool0oooo00d0oooo00<0o`000?ooo`3oool01P3oool00`000000003o0?ooo`0?0?ooo`030?l0
003oool0oooo01<0oooo00<0003o0?ooo`3oool0>@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0003o00T0oooo00<0o`000?ooo`3oool0<P3oool00`000000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000o`0m0?ooo`030000003oool0oooo0?l0
oooo000T0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0103oool010000000oooo
0?ooo`000?l?0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0>@3oool00`000?l0
oooo0?ooo`040?ooo`030?l000000?l0oooo00T0oooo00<0o`000?ooo`3oool0<`3oool00`000000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000o`0m0?oo
o`030000003oool0oooo0?l0oooo000T0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3o
ool0103oool010000000oooo0?ooo`000?l?0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?oo
o`3oool0>@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o0000oooo00T0oooo00<0o`000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00D0oooo00@000000?oo
o`3oool0003o?P3oool00`000000oooo0?ooo`3o0?ooo`00903oool00`000000oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000o`0>0?ooo`030?l0003oool0
oooo01<0oooo00<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
o`0000X0oooo00<0o`000?ooo`3oool0<`3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00<0oooo00D000000?ooo`3oool0oooo0000o`0n0?ooo`030000003oool0oooo0?l0oooo000T
0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0003o00h0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0k0?ooo`050000o`3o
ool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo03D0oooo
00<000000?ooo`3oool03@3oool00`000?l0oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
0?l0?P3oool200000?l0oooo0@3oool002@0oooo00<000000?ooo`3oool03P3oool00`3o0000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0B0?ooo`030000o`3oool0oooo03`0oooo00@0003o0?ooo`3oool0003o103oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo03D0oooo00<000000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000?l0?P3oool00`000000oooo0?ooo`3o0?oo
o`00903oool00`000000oooo0?ooo`0>0?ooo`050?l0003oool0oooo0?ooo`0000001P3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0?@3oool20000
o`D0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0e0?ooo`030000003oool0oooo
00d0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo
03`0oooo00<000000?ooo`3oool0o`3oool002@0oooo00<000000?ooo`3oool03`3oool00`3o0000
oooo000000070?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0m0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0o`3oool00140oooo
0P0000040?ooo`040000003oool0oooo0?ooo`D00000103oool00`000000oooo0?ooo`0?0?ooo`03
0?l0003oool0000000P0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo04D0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0f0?ooo`03
0000003oool0oooo00`0oooo00<0003o0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0003o
0380oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`00403oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool03`3oool0
0`3o000000000?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`160?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0<0?ooo`040000o`3oool0oooo000000@0oooo00<0003o0?ooo`3oool0<@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`3o0?ooo`00403oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`160?ooo`030?l0003oool0oooo00@0oooo
00<0o`000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`040000o`3oool0oooo000000@0
oooo00<0003o0?ooo`3oool0;P3oool500000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`3o0?ooo`00403oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
00<0oooo0P00000?0?ooo`030000003o0000oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo04L0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`0000001@3oool00`00
0?l0oooo0?ooo`0^0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000103o
ool200000?l0oooo0@3oool00100oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool03P3oool00`000000o`000?ooo`0:0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`180?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`0;0?ooo`030000
o`3oool0000000D0oooo00<0003o0?ooo`3oool0;`3oool00`000000oooo000000030?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool00100oooo00@000000?ooo`3oool0
00001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?l0000;0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`190?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0;0?ooo`030000o`000000oooo00@0oooo00<0003o0?ooo`3oool0<@3oool20000
00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`004@3oool20000
00T0oooo0`0000050?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0?l0000:
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`19
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0<P3oool00`000000oooo0?ooo`02
0?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`00903oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0080oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0BP3oool01@3o0000oooo0?ooo`3oool0
o`0003d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0
oooo03h0oooo00<000000?ooo`3oool0o`3oool002@0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`020?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo04/0oooo00D0o`000?ooo`3oool0oooo0?l0000m
0?ooo`030000003oool0oooo00X0oooo00<000000000o`3oool0103oool00`000?l0oooo0?ooo`0n
0?ooo`030000003oool0oooo0?l0oooo000T0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0403oool00`000?l0oooo0?ooo`1;0?ooo`040?l0003oool0oooo0?l003l0oooo00<00000
0?ooo`3oool02@3oool00`000000003o0?ooo`040?ooo`030000o`3oool0oooo03h0oooo00<00000
0?ooo`3oool0o`3oool002@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0@0?oo
o`030000o`3oool0oooo04/0oooo00@0o`000?ooo`3oool0o`00?`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0003o00@0oooo00<0003o0?ooo`3oool0?`3oool200000?l0oooo0@3oool0
02@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
04d0oooo00<0o`000?ooo`3o0000?`3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo
0000o`<0oooo00<0003o0?ooo`3oool0?`3oool00`000000oooo0?ooo`3o0?ooo`00903oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0C@3oool00`3o
0000oooo0?l000100?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000o`03
0?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool0o`3oool002@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo04h0oooo00<0o`000?oo
o`3o0000@03oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000?l00`3oool0
0`000?l0oooo0?ooo`0o0?ooo`030000003oool0oooo0?l0oooo000T0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`1?0?ooo`030?l0003oool0oooo
03l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`050000o`3oool0oooo
0?ooo`000?l0@@3oool00`000000oooo0?ooo`3o0?ooo`00903oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0C`3oool00`3o0000oooo0?ooo`100?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0
003o0440oooo00<000000?ooo`3oool0o`3oool002@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo09<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000o`3oool0003o0480oooo00<000000?ooo`3oool0o`3oool002@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo09@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0003o0480
oooo0P00003o0?ooo`40oooo000T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`2D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool00`000?l0oooo0000o`120?ooo`030000003oool0oooo0?l0oooo000T0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`2E0?ooo`050000003o
ool0oooo0?ooo`0000001`3oool00`000?l0oooo0000o`120?ooo`030000003oool0oooo0?l0oooo
000T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`2F0?ooo`040000003oool0oooo000000L0oooo00<0003o0?ooo`000?l0@P3oool00`000000oooo
0?ooo`3o0?ooo`00903oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00d0oooo00<0
003o0?ooo`3oool0UP3oool00`000000oooo000000090?ooo`030000o`3oool0oooo0440oooo00<0
00000?ooo`3oool0o`3oool002@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`08
0?ooo`030?l0003oool0oooo00X0oooo00D0003o0?ooo`3oool0oooo0?l0000?0?ooo`030000o`3o
ool0oooo09L0oooo00<000000?ooo`0000002@3oool00`000?l0oooo0?ooo`110?ooo`030000003o
ool0oooo0?l0oooo000T0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0;0?ooo`040000o`3oool0oooo0?l000l0oooo00<0003o0?ooo`3oool0V03o
ool00`000000oooo0?ooo`080?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0o`3o
ool002@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0
oooo00/0oooo00@0003o0?ooo`3oool0o`003P3oool00`000?l0oooo0?ooo`3X0?ooo`800000o`3o
ool10?ooo`00903oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?l0000>0?ooo`030000o`3oool0oooo0>P0oooo00<00000
0?ooo`3oool0o`3oool002@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o00003P3oool00`000?l0oooo0?ooo`3X0?oo
o`030000003oool0oooo0?l0oooo000T0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o0000oooo00`0oooo00<0003o0?ooo`3o
ool0j@3oool00`000000oooo0?ooo`3o0?ooo`00903oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00X0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030000
o`3oool0oooo0>T0oooo00<000000?ooo`3oool0o`3oool00140oooo0P0000040?ooo`030000003o
ool0oooo0080oooo0`0000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0<0?ooo`030?l000000?l0oooo00`0oooo00<0003o0?ooo`3oool0f`3o
ool3000000@0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo000@0?ooo`040000003oool0
oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030?l000000?l0oooo00/0oooo
00<0003o0?ooo`3oool0f`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`3o0?ooo`00403oool010000000oooo0?ooo`00000;0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00`0oooo00<0o`000?ooo`000?l02`3oool00`000?l0oooo0?ooo`3K0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`800000o`3o
ool10?ooo`00403oool010000000oooo0?ooo`0000090?ooo`8000001@3oool2000000H0oooo00<0
00000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0003o00/0oooo00<0
003o0?ooo`3oool0f`3oool4000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`3o0?ooo`00403oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00@0o`000?ooo`3oool0003o2@3oool00`000?l0oooo0?ooo`3L0?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`00403oool010000000
oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool01@3o0000oooo0?ooo`3o
ool0003o00P0oooo00<0003o0?ooo`3oool0g@3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool00140oooo0P0000090?ooo`<000001@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00<0o`000?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0g`3o
ool2000000@0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo000T0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`3/0?ooo`030000003oool0
oooo0?l0oooo000T0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`3/0?ooo`030000003oool0oooo0?l0oooo000T0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`3]0?ooo`030000003oool0oooo0?l0
oooo000T0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`3o0000oooo
0?ooo`080?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`3]0?ooo`800000o`3oool10?ooo`00903oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0100oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`050000o`3o
ool0oooo0?ooo`000?l0k`3oool00`000000oooo0?ooo`3o0?ooo`00903oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0100oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`050?ooo`040000o`3oool0oooo0000oo00oooo00<000000?ooo`3oool0o`3oool002@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo00D0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0000o`3`0?ooo`030000003oool0oooo0?l0oooo000T
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`000?l0l03oool00`000000oooo0?ooo`0N
0?ooo`D00000g03oool002@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`3_0?oo
o`030000003oool0oooo01X0oooo100000050?ooo`@00000f03oool002@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o
ool0nP3oool00`000000oooo0?ooo`0F0?ooo`@000003@3oool300000=D0oooo000T0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo0?X0oooo0P00000:0?ooo`d00000503ooonl000001T0oooo000T0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool05P3oool01@3o0000oooo0?ooo`3oool0o`000?`0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3c0?ooo`00903oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01H0oooo00D0o`000?ooo`3oool0oooo0?l0003l0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0l`3oool002@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0o`000?d0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`3d0?ooo`00903oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01P0oooo0P3o003m0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0m03oool0
02@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo
0?/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3d0?ooo`00903oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo6@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0?D0oooo000T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
o`3ooolI0?ooo`800000203oool00`000000oooo0?ooo`3e0?ooo`00903oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0?l0oooo6@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0?D0oooo000T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooolI
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0m@3oool002@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3o0?oooaT0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`3f0?ooo`00903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0
oooo6@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?H0oooo000A0?ooo`800000
103oool00`000000oooo0?ooo`030?ooo`<00000103oool01@000000oooo0?ooo`3oool000000?l0
oooo3P3oool3000000@0oooo0P0000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0mP3oool00100oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`05
0000003oool0oooo0?ooo`000000o`3oool=0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0mP3o
ool00100oooo00@000000?ooo`3oool000001`3oool5000000@0oooo0P0000020?ooo`030000003o
ool0oooo0?l0oooo2`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
0000103oool2000000H0oooo00<000000?ooo`3oool0m`3oool00100oooo00@000000?ooo`3oool0
00001`3oool010000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`000000o`3oool>
0?ooo`<000000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0m`3oool00100oooo00@000000?ooo`3oool00000203oool00`000000oooo0000
00050?ooo`050000003oool0oooo0?ooo`000000o`3oool=0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0m`3oool00100oooo00@000000?ooo`3oool000002@3oool2000000D0oooo00D000000?oo
o`3oool0oooo0000003o0?ooo`d0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3h0?ooo`004@3o
ool2000000/0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000?l0oooo
3P3oool3000000@0oooo0P0000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
n03oool002@0oooo00@000000?ooo`3oool00000o`3ooolM0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0n03oool002@0oooo00@000000?ooo`3oool00000o`3ooolM0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0n03oool002@0oooo00@000000?ooo`3oool00000
o`3ooolM0?ooo`800000103oool00`000000oooo0?ooo`3i0?ooo`00903oool010000000oooo0?oo
o`00003o0?oooad0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3i0?ooo`00903o
ool010000000oooo0?ooo`00003o0?oooad0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`3i0?ooo`00903oool010000000oooo0?ooo`00003o0?oooad0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`3j0?ooo`00903oool010000000oooo0?ooo`00003o0?oooad0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3j0?ooo`00903oool00`000000oooo0000
003o0?oooah0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3j0?ooo`00903oool0
0`000000oooo0000003o0?oooah0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3j
0?ooo`00903oool00`000000oooo0000003o0?oooah0oooo00D000000?ooo`3oool0oooo0000003m
0?ooo`00903oool00`000000oooo0000003o0?oooah0oooo0P0000020?ooo`030000003oool0oooo
0?/0oooo000T0?ooo`030000003oool000000?l0oooo7P3oool01@000000oooo0?ooo`3oool00000
0?d0oooo000T0?ooo`030000003oool000000?l0oooo7P3oool010000000oooo0?ooo`00003n0?oo
o`00903oool00`000000oooo0000003o0?oooah0oooo00@000000?ooo`3oool00000oP3oool002@0
oooo0P00003o0?oooal0oooo00@000000?ooo`3oool00000oP3oool002@0oooo0P00003o0?oooal0
oooo00@000000?ooo`3oool00000oP3oool002@0oooo0P00003o0?oooal0oooo00<000000?ooo`00
0000o`3oool002@0oooo0P00003o0?oooal0oooo0`00003o0?ooo`00903oool200000?l0oooo7`3o
ool00`000000oooo0000003o0?ooo`00903oool200000?l0oooo7`3oool00`000000oooo0000003o
0?ooo`00903oool200000?l0oooo7`3oool200000?l0oooo0@3oool00140oooo0P0000040?ooo`03
0000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0?l0oooo2P3oool3000000@0
oooo0P0000040?ooo`8000001@3oool200000?l0oooo0@3oool00100oooo00@000000?ooo`3oool0
00001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0o`3oool;0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00040?ooo`800000o`3oool10?ooo`00403oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0
oooo000@0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool200000?l0
oooo303oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000103oool200000?l0oooo0@3oool00100oooo00@000000?ooo`3oool000001`3oool4
000000D0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00003o0?ooo`L0oooo000@0?ooo`040000003o
ool0oooo000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooo`X0oooo
0P0000040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000o`3oool70?oo
o`004@3oool2000000P0oooo1@0000040?ooo`030000003oool0oooo0?l0oooo2`3oool00`000000
oooo0?ooo`030?ooo`800000103oool200000?l0oooo203oool002@0oooo00<000000?ooo`3oool0
o`3ooooo0?ooob40oooo003o0?ooool0ooooB03oool00?l0ooooo`3ooom80?ooo`00o`3ooooo0?oo
odP0oooo003o0?ooool0ooooB03oool00?l0ooooo`3ooom80?ooo`00\
\>"],
  ImageRangeCache->{{{0, 581}, {170.25, 0}} -> {-0.0545639, -0.0147182, \
0.00363017, 0.00363017}, {{15, 277.375}, {166.188, 4}} -> {-31.0346, \
-0.0596799, 0.860869, 0.00348228}, {{303.562, 565.938}, {166.188, 4}} -> \
{-279.153, -11.8488, 0.860338, 0.696028}}]
}, Closed]],

Cell["\<\
An equilibrium is reached around p=0.0093, and at a deme size of \
70.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mean[
      Table[{AlleleFrequencyMean[\(pop[0.1, 0.01]\)[t]], 
            DemeSize[\(pop[0.1, 0.01]\)[t]]}, {t, 50, 200, 10}] // 
        N]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \({0.09315476190476192`, 70.`}\)], "Output",
  CellLabel->"Out[38]="]
}, Closed]],

Cell[TextData[{
  "The option DemeSize->F is passed to ",
  ButtonBox["NewGametes",
    ButtonData:>{"Simulating individuals: reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ", which changes deme size accordingly.  Note that deme size is assumed to \
remain constant through meiosis and random union, barring a formal doubling \
and halving,  but changes as a result of ",
  ButtonBox["migration",
    ButtonData:>{"Simulating individuals: migration", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text"],

Cell["\<\
When compiled code is used, only certain settings for F can be \
used.\
\>", "Text"],

Cell[TextData[{
  "The logistic model ",
  Cell[BoxData[
      \(TraditionalForm\`f[n, W\&_] = 
        n + r\[VeryThinSpace]\(n(1 - n\/K)\)\)]],
  " should be avoided,because in discrete time, it can lead to negative \
population sizes."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The life cycle", "SubsubsectionIcon",
  CellTags->"Life cycle"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(\(\ \)\(IterateExact[\[Psi], W, {m, Nm}, 
              MigrationOrder \[Rule] 
                UMS]\)\), \(represents\ the\ default\ order\ of\ events\ \
random\ union \[Rule] \(migration \[Rule] \(selection \[Rule] 
                  meiosis . \ \ \n
                      Regulation\ of\ population\ size\ always\ occurs\ \
immediately\ after\ \(\(selection\)\(.\)\)\)\)\)},
          {\(\(\ \)\(IterateExact[\[Psi], W, {m, Nm}, 
              MigrationOrder \[Rule] 
                MUS]\)\), \(\(represents\ migration\)\(\[Rule]\)\(random\ \
union \[Rule] \(selection \[Rule] \(\(meiosis\)\(.\)\)\)\)\(\ \)\)},
          {\(\(\ \)\(IterateExact[\[Psi], W, {m, Nm}, 
              MigrationOrder \[Rule] 
                USM]\)\), \(represents\ random\ union \[Rule] \(selection \
\[Rule] \(migration \[Rule] \(\(meiosis\)\(.\)\)\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}],

Cell["\<\
The default order of events in the life cycle is MigrationOrder\
\[Rule]UMS, representing random union of gametes\[Rule]diploid migration\
\[Rule]selection\[Rule]meiosis.  For a single deme with immigration from a \
population \[Psi]s, this is implemented by:\
\>", "Text"],

Cell[BoxData[
    \(NewGametes[
      MigrateExact[MakeDiploid[HaploidFrequencies[\[Psi], nd]], 
        MakeDiploid[\[Psi]s], {m, Nm}], W]\)], "Input"],

Cell["\<\
In this example, there are 3 loci with 10% selection aaginst '1' \
alleles, balanced by immigration of 2 individuals per generation:\
\>", \
"MathCaption"],

Cell[BoxData[
    \(\[Psi]0 = 
      MakePopulation[3, 0, 100, NumericalModel \[Rule] HaploidIndividuals]; 
    StoreExact[pp[UMS], \[Psi]0, 
      0.9\^Plus @@ \((#1 + #2)\) &, {0.05, 2}, {200, 10}, 
      DemeSize \[Rule] ExponentialF[2, 0, 0.02]];\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[{
    \(\(pt[lc_, i_] := 
        Table[{t, \(AlleleFrequencyTable[\(pp[lc]\)[t]]\)\[LeftDoubleBracket]
              i\[RightDoubleBracket]}, {t, 0, 200, 
            10}];\)\), "\[IndentingNewLine]", 
    \(\(dt[lc_, i_, j_] := 
        Table[{t, \(DisequilibriumTable[\(pp[lc]\)[t]]\)\[LeftDoubleBracket]
              i, j\[RightDoubleBracket]}, {t, 0, 200, 
            10}];\)\), "\[IndentingNewLine]", 
    \(\(gr[tbl_, c_] := 
        ListPlot[tbl, PlotJoined \[Rule] True, 
          PlotStyle \[Rule] c];\)\), "\[IndentingNewLine]", 
    \(\(gr[lc_] := 
        Show[GraphicsArray[{\[IndentingNewLine]Show[gr[pt[lc, 1], Red], 
                gr[pt[lc, 2], Blue], 
                gr[pt[lc, 3], Black]], \[IndentingNewLine]Show[
                gr[dt[lc, 1, 2], Red], gr[dt[lc, 1, 3], Blue], 
                gr[dt[lc, 2, 3], Black]]}]];\)\)}], "Input",
  CellLabel->"In[39]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gr[UMS];\)\)], "Input",
  CellLabel->"In[43]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.0147151 0.840863 [
[.2619 .00222 -6 -9 ]
[.2619 .00222 6 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .0988 -18 -4.5 ]
[.01131 .0988 0 4.5 ]
[.01131 .18289 -18 -4.5 ]
[.01131 .18289 0 4.5 ]
[.01131 .26697 -18 -4.5 ]
[.01131 .26697 0 4.5 ]
[.01131 .35106 -18 -4.5 ]
[.01131 .35106 0 4.5 ]
[.01131 .43515 -18 -4.5 ]
[.01131 .43515 0 4.5 ]
[.01131 .51923 -18 -4.5 ]
[.01131 .51923 0 4.5 ]
[.01131 .60332 -18 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(50)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(100)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(150)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(200)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .0988 m
.03006 .0988 L
s
[(0.1)] .01131 .0988 1 0 Mshowa
.02381 .18289 m
.03006 .18289 L
s
[(0.2)] .01131 .18289 1 0 Mshowa
.02381 .26697 m
.03006 .26697 L
s
[(0.3)] .01131 .26697 1 0 Mshowa
.02381 .35106 m
.03006 .35106 L
s
[(0.4)] .01131 .35106 1 0 Mshowa
.02381 .43515 m
.03006 .43515 L
s
[(0.5)] .01131 .43515 1 0 Mshowa
.02381 .51923 m
.03006 .51923 L
s
[(0.6)] .01131 .51923 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(0.7)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03153 m
.02756 .03153 L
s
.02381 .04835 m
.02756 .04835 L
s
.02381 .06517 m
.02756 .06517 L
s
.02381 .08198 m
.02756 .08198 L
s
.02381 .11562 m
.02756 .11562 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .14925 m
.02756 .14925 L
s
.02381 .16607 m
.02756 .16607 L
s
.02381 .1997 m
.02756 .1997 L
s
.02381 .21652 m
.02756 .21652 L
s
.02381 .23334 m
.02756 .23334 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .28379 m
.02756 .28379 L
s
.02381 .30061 m
.02756 .30061 L
s
.02381 .31743 m
.02756 .31743 L
s
.02381 .33424 m
.02756 .33424 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .38469 m
.02756 .38469 L
s
.02381 .40151 m
.02756 .40151 L
s
.02381 .41833 m
.02756 .41833 L
s
.02381 .45196 m
.02756 .45196 L
s
.02381 .46878 m
.02756 .46878 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .50242 m
.02756 .50242 L
s
.02381 .53605 m
.02756 .53605 L
s
.02381 .55287 m
.02756 .55287 L
s
.02381 .56968 m
.02756 .56968 L
s
.02381 .5865 m
.02756 .5865 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .01472 m
.07143 .2373 L
.11905 .32704 L
.16667 .30301 L
.21429 .18289 L
.2619 .30301 L
.30952 .29912 L
.35714 .44716 L
.40476 .56728 L
.45238 .44716 L
.5 .50722 L
.54762 .36307 L
.59524 .17547 L
.64286 .1631 L
.69048 .24295 L
.7381 .21257 L
.78571 .34859 L
.83333 .22493 L
.88095 .3871 L
.92857 .44716 L
.97619 .36307 L
s
0 0 1 r
.02381 .01472 m
.07143 .13837 L
.11905 .36307 L
.16667 .39911 L
.21429 .15886 L
.2619 .20691 L
.30952 .29912 L
.35714 .47118 L
.40476 .37508 L
.45238 .23094 L
.5 .14685 L
.54762 .1949 L
.59524 .10127 L
.64286 .18783 L
.69048 .13484 L
.7381 .11364 L
.78571 .39805 L
.83333 .24966 L
.88095 .13484 L
.92857 .17088 L
.97619 .25496 L
s
0 0 0 r
.02381 .01472 m
.07143 .17547 L
.11905 .24295 L
.16667 .20691 L
.21429 .27899 L
.2619 .21892 L
.30952 .34859 L
.35714 .45917 L
.40476 .41112 L
.45238 .60332 L
.5 .4832 L
.54762 .27899 L
.59524 .24966 L
.64286 .48461 L
.69048 .57929 L
.7381 .31149 L
.78571 .1631 L
.83333 .18783 L
.88095 .25496 L
.92857 .14685 L
.97619 .18289 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.175786 4.80229 [
[.2619 .16329 -6 -9 ]
[.2619 .16329 6 0 ]
[.5 .16329 -9 -9 ]
[.5 .16329 9 0 ]
[.7381 .16329 -9 -9 ]
[.7381 .16329 9 0 ]
[.97619 .16329 -9 -9 ]
[.97619 .16329 9 0 ]
[.01131 .07974 -30 -4.5 ]
[.01131 .07974 0 4.5 ]
[.01131 .27183 -24 -4.5 ]
[.01131 .27183 0 4.5 ]
[.01131 .36788 -24 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .46392 -24 -4.5 ]
[.01131 .46392 0 4.5 ]
[.01131 .55997 -24 -4.5 ]
[.01131 .55997 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .17579 m
.2619 .18204 L
s
[(50)] .2619 .16329 0 1 Mshowa
.5 .17579 m
.5 .18204 L
s
[(100)] .5 .16329 0 1 Mshowa
.7381 .17579 m
.7381 .18204 L
s
[(150)] .7381 .16329 0 1 Mshowa
.97619 .17579 m
.97619 .18204 L
s
[(200)] .97619 .16329 0 1 Mshowa
.125 Mabswid
.07143 .17579 m
.07143 .17954 L
s
.11905 .17579 m
.11905 .17954 L
s
.16667 .17579 m
.16667 .17954 L
s
.21429 .17579 m
.21429 .17954 L
s
.30952 .17579 m
.30952 .17954 L
s
.35714 .17579 m
.35714 .17954 L
s
.40476 .17579 m
.40476 .17954 L
s
.45238 .17579 m
.45238 .17954 L
s
.54762 .17579 m
.54762 .17954 L
s
.59524 .17579 m
.59524 .17954 L
s
.64286 .17579 m
.64286 .17954 L
s
.69048 .17579 m
.69048 .17954 L
s
.78571 .17579 m
.78571 .17954 L
s
.83333 .17579 m
.83333 .17954 L
s
.88095 .17579 m
.88095 .17954 L
s
.92857 .17579 m
.92857 .17954 L
s
.25 Mabswid
0 .17579 m
1 .17579 L
s
.02381 .07974 m
.03006 .07974 L
s
[(-0.02)] .01131 .07974 1 0 Mshowa
.02381 .27183 m
.03006 .27183 L
s
[(0.02)] .01131 .27183 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.04)] .01131 .36788 1 0 Mshowa
.02381 .46392 m
.03006 .46392 L
s
[(0.06)] .01131 .46392 1 0 Mshowa
.02381 .55997 m
.03006 .55997 L
s
[(0.08)] .01131 .55997 1 0 Mshowa
.125 Mabswid
.02381 .10375 m
.02756 .10375 L
s
.02381 .12776 m
.02756 .12776 L
s
.02381 .15177 m
.02756 .15177 L
s
.02381 .1998 m
.02756 .1998 L
s
.02381 .22381 m
.02756 .22381 L
s
.02381 .24782 m
.02756 .24782 L
s
.02381 .29584 m
.02756 .29584 L
s
.02381 .31985 m
.02756 .31985 L
s
.02381 .34387 m
.02756 .34387 L
s
.02381 .39189 m
.02756 .39189 L
s
.02381 .4159 m
.02756 .4159 L
s
.02381 .43991 m
.02756 .43991 L
s
.02381 .48793 m
.02756 .48793 L
s
.02381 .51195 m
.02756 .51195 L
s
.02381 .53596 m
.02756 .53596 L
s
.02381 .05573 m
.02756 .05573 L
s
.02381 .03172 m
.02756 .03172 L
s
.02381 .00771 m
.02756 .00771 L
s
.02381 .58398 m
.02756 .58398 L
s
.02381 .60799 m
.02756 .60799 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .17579 m
.07143 .48779 L
.11905 .0525 L
.16667 .17777 L
.21429 .35674 L
.2619 .48997 L
.30952 .33495 L
.35714 .2772 L
.40476 .12607 L
.45238 .29709 L
.5 .42336 L
.54762 .43927 L
.59524 .36657 L
.64286 .21373 L
.69048 .33487 L
.7381 .39925 L
.78571 .08197 L
.83333 .1937 L
.88095 .42435 L
.92857 .19766 L
.97619 .2951 L
s
0 0 1 r
.02381 .17579 m
.07143 .50254 L
.11905 .24141 L
.16667 .14198 L
.21429 .21754 L
.2619 .53571 L
.30952 .1663 L
.35714 .52179 L
.40476 .05846 L
.45238 .16187 L
.5 .04753 L
.54762 .09823 L
.59524 .20214 L
.64286 .26854 L
.69048 .12309 L
.7381 .41611 L
.78571 .26433 L
.83333 .21162 L
.88095 .60332 L
.92857 .13005 L
.97619 .2593 L
s
0 0 0 r
.02381 .17579 m
.07143 .32546 L
.11905 .11514 L
.16667 .01472 L
.21429 .40049 L
.2619 .53173 L
.30952 .453 L
.35714 .03062 L
.40476 .02665 L
.45238 .41242 L
.5 .09724 L
.54762 .40447 L
.59524 .3223 L
.64286 .11676 L
.69048 .26527 L
.7381 .33179 L
.78571 .42876 L
.83333 .32546 L
.88095 .39452 L
.92857 .312 L
.97619 .38458 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[43]:=",
  ImageSize->{592, 174.188},
  ImageMargins->{{1, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009@0000[R000`400?l00000o`00003oo`3ooooo
0?oooe80oooo003o0?ooool0ooooDP3oool00?l0ooooo`3ooomB0?ooo`00o`3ooooo0?oooe80oooo
003o0?ooool0ooooDP3oool00?l0ooooo`3ooomB0?ooo`00FP3oool3000000@0oooo0P00000_0?oo
o`<00000103oool2000000@0oooo0P00000/0?ooo`<000000`3oool3000000@0oooo0P00000/0?oo
o`D000000`3oool2000000@0oooo0P00003o0?ooocT0oooo001I0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`00000_0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`00
00000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02X0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?l0oooo
>03oool005d0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000/0?oo
o`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00003o0?ooocP0oooo001M0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000;03oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0;03oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`3o0?ooocH0oooo001I0?ooo`@000000`3oool010000000oooo0?oo
o`00000_0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`00000/0?ooo`040000003oool0oooo0?ooo`@000000`3oool010000000oooo0?ooo`00
000[0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000?l0oooo>03oool005T0oooo00<000000?ooo`3oool0103oool010000000
oooo0?ooo`00000^0?ooo`800000103oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000002/0oooo0P0000030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000
:`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`00003o0?ooocP0oooo001I0?ooo`D000000`3oool200000300oooo00<000000?oo
o`3oool00`3oool2000000@0oooo0P00000]0?ooo`040000003oool0oooo0?ooo`D000000`3oool2
000002d0oooo0`0000040?ooo`800000103oool200000?l0oooo>@3oool00?l0ooooo`3ooomB0?oo
o`00903oool00`000000oooo0?ooo`3o0?ooobl0oooo00<000000?ooo`3oool0n03oool002@0oooo
00<000000?ooo`3oool0o`3oool_0?ooo`030000003oool0oooo0?P0oooo000T0?ooo`030000003o
ool0oooo0?l0oooo;`3oool200000?T0oooo000T0?ooo`030000003oool0oooo0?l0oooo;`3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0=H0oooo000N0?ooooX00000?@3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo0=H0oooo000T0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01h0
oooo0P00003H0?ooo`00903oool00`000000003o0?ooo`3o0?ooobl0oooo00<000000?ooo`3oool0
7P3oool200000380oooo1P00002P0?ooo`00903oool200000?l0oooo<03oool2000001h0oooo00<0
00000?ooo`000000;03oool6000000D0oooo00<000000?ooo`3oool0WP3oool002@0oooo0P00003o
0?oooc00oooo00<000000?ooo`3oool07@3oool010000000oooo0?ooo`00000[0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0WP3oool002@0oooo0P0000000`000?l0oooo0?ooo`3o
0?ooobd0oooo00<000000?ooo`3oool0703oool01@000000oooo0?ooo`3oool0000002/0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`2N0?ooo`00903oool00`000000o`000000003o
0?ooobl0oooo00<000000?ooo`3oool0703oool01@000000oooo0?ooo`3oool0000002/0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`2N0?ooo`00903oool010000000o`0000000000
0?oo0?ooobh0oooo00<000000?ooo`3oool0703oool01@000000oooo0?ooo`3oool0000002/0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo08L0oooo
000T0?ooo`<0000000<0003o0?ooo`3oool0o`3oool/0?ooo`030000003oool0oooo01@0oooo00<0
o`000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo08L0oooo000T
0?ooo`040000003oool0o`0000000?l0oooo;P3oool2000001D0oooo00<0o`000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0B0?ooo`030000o`3oool0003o08P0oooo000T0?ooo`050000003oool0
o`00000000000?l0o`3oool]0?ooo`030000003oool0oooo01@0oooo0P3o00040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`030000o`00
0000oooo01<0oooo00@0003o0?ooo`3oool0003oQ`3oool002@0oooo00D000000?ooo`3o00000000
0000o`3o0?ooobd0oooo00<000000?ooo`3oool0503oool20?l000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo00<0003o0000003oool0
4P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo08@0oooo000T0?ooo`80000000@0
oooo0000003oool0003oo`3ooolC0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000
0P3oool5000000@0oooo00<000000?ooo`3oool0503oool20?l000<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo00<0003o0000003oool0
4P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo08<0oooo000T0?ooo`060000003o
ool0oooo0?l000000000003oo`3ooolB0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01@0oooo00<0
o`000?ooo`3o00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool02@3oool00`000?l000000?ooo`0B0?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool0PP3oool002@0oooo00H000000?ooo`3oool0o`00000000000?oo0?ooo`/0oooo
1@0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00H0o`000?ooo`3oool0o`000?ooo`00
00080?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool00`000?l000000000
o`0A0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0P@3oool002@0oooo00L00000
0?ooo`3oool0o`000000003oool0003o0?l0oooo4@3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool3000001<0oooo00H0o`000?oo
o`3oool0o`000?ooo`0000080?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3o
ool00`000?l0oooo0000000A0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0>@3o
ool00`3o0000oooo0?ooo`140?ooo`00903oool2000000050?ooo`3o0000oooo000000000?l0o`3o
oolA0?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3oool01@3o0000oooo0?ooo`3oool0
000000T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`050000o`3oool0
oooo000000000?l03`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo03P0oooo00<0
o`000?ooo`3oool0A03oool002@0oooo00P000000?ooo`3oool0oooo0?l000000000oooo0000ool0
oooo403oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo00D0o`000?ooo`3oool0oooo
000000090?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool01@000?l0oooo
0?ooo`000000003o00l0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0g0?ooo`80
o`00A@3oool00140oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`080000
003oool0oooo0?ooo`3o000000000?ooo`000?oo0?oooa40oooo0P00000:0?ooo`8000000`3oool3
000000D0oooo00<000000?ooo`3oool04`3oool01@3o0000oooo0?ooo`3oool0000000T0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`090?ooo`050000o`3oool0oooo000000000?l0
3P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo03H0oooo0P3o00150?ooo`00403o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00P000000?ooo`3oool0
oooo0?l0003oool000000000ool0oooo:P3oool00`000000oooo0?ooo`0C0?ooo`060?l0003oool0
oooo0000003oool0o`00203oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00T0oooo
00H0003o0?ooo`3oool000000?ooo`000?l=0?ooo`030000o`3oool0oooo0080oooo00<000000?oo
o`3oool0203oool00`000?l0oooo0?ooo`0d0?ooo`030?l0003oool0o`0004D0oooo000@0?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool200000080oooo00D0o`000?oo
o`000000oooo0000o`3o0?ooobT0oooo0P00000D0?ooo`060?l0003oool0oooo0000003oool0o`00
203oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00T0oooo00H0003o0?ooo`3oool0
00000?ooo`000?l<0?ooo`030000o`3oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`0d0?ooo`040?l0003oool0oooo0?l004@0oooo000@0?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool0103oool02@000000oooo0?ooo`3oool0o`000?ooo`000000
oooo0000o`250?ooo`030000o`3oool0oooo0:00oooo00<000000?ooo`3oool04`3oool00`3o0000
oooo000000030?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`090?ooo`040000o`3oool0oooo00000080oooo00<0003o0?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool0<`3oool0103o
0000oooo0?ooo`3o00140?ooo`00403oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool01@3o000000000?ooo`3oool0003o08@0oooo00<0
003o0?ooo`3oool0X03oool00`000000oooo0?ooo`0C0?ooo`030?l0003oool0000000<0oooo00<0
o`000?ooo`3oool01P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00T0oooo00@0
003o0?ooo`3oool000000P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00<0oooo
00<000000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0c0?ooo`050?l0003oool0oooo0?ooo`3o
0000@`3oool00100oooo00@000000?ooo`3oool00000203oool2000000H0oooo00<000000?ooo`3o
ool00P3oool01@3o0000oooo0000003oool0003o08<0oooo00<0003o0?ooo`000?l0X@3oool00`00
0000oooo0?ooo`0B0?ooo`030?l0003oool0000000@0oooo00<0o`000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00T0oooo00@0003o0?ooo`3oool000000`3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo00<000000?ooo`0000002`3oool0
0`000?l0oooo0?ooo`0b0?ooo`050?l0003oool0oooo0?ooo`3o0000@`3oool00140oooo0P00000:
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@3o0000oooo0000003o
ool0003o08<0oooo00<0003o0?ooo`000?l0803oool20000ogl0oooo00<000000?ooo`3oool04P3o
ool00`3o0000oooo000000050?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`090?ooo`050000o`3oool0oooo0?ooo`0000000P3oool00`000?l0oooo
0?ooo`070?ooo`030000o`3oool0oooo00<0oooo00<000000?ooo`0000002`3oool00`000?l0oooo
0?ooo`0A0?ooo`030000003oool0oooo01h0oooo00D0o`000?ooo`3oool0oooo0?l000130?ooo`00
903oool2000000<0oooo00<0o`000?ooo`0000000P3oool00`000?l0oooo0?ooo`1o0?ooo`050000
o`3oool0oooo0?ooo`000?l07@3oool20000o`030?ooo`000?l0oooo07h0oooo00<000000?ooo`3o
ool04P3oool00`3o0000oooo000000050?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`090?ooo`050000o`3oool0oooo0?ooo`0000000`3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<000000?ooo`0000002`3oool00`00
0?l0oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool04P3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo0400oooo000T0?ooo`030000003oool0oooo00<0
oooo00D0o`000?ooo`000000oooo0000o`210?ooo`050000o`3oool0oooo0?ooo`000?l06P3oool3
0000o`<0oooo00<0003o0?ooo`3oool0O@3oool2000001<0oooo00<0o`000000003oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool0
0`000?l0oooo0?l000020?ooo`050000003oool0oooo0?ooo`000?l01`3oool00`000?l0oooo0?oo
o`040?ooo`030000003oool0000000`0oooo00<0003o0?ooo`3oool0403oool2000000X0oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0400oooo000T
0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`0000000P3oool00`000?l0oooo0?ooo`1m
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool05@3oool20000o`H0oooo00<0003o
0?ooo`3oool0O@3oool00`000000oooo0?ooo`0B0?ooo`030?l000000000oooo00H0oooo00<0o`00
0?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`<00000103oool200000100oooo00<00000
0?ooo`3oool02@3oool00`000?l0oooo0?l000020?ooo`030000003oool0oooo0080oooo00<0003o
0?ooo`3oool00`3oool010000?l000000000000000040?ooo`<000000`3oool2000000L0oooo00<0
003o0?ooo`3oool03`3oool00`000000oooo000000090?ooo`80003o0P3oool3000000<0oooo0`00
00040?ooo`8000000P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01X0oooo00<0
003o0?ooo`000000100000030?ooo`800000103oool2000001<0oooo000T0?ooo`030000003oool0
oooo00<0oooo00<0o`000?ooo`0000000P3oool00`000?l0oooo0?ooo`1m0?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool04P3oool20000o`T0oooo00<0003o0?ooo`3oool0O03oool0
0`000000oooo0?ooo`0B0?ooo`030?l000000000oooo00H0oooo00<0o`000?ooo`3oool0103oool0
0`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`00000?0?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3o00000P3oool00`000000oooo
0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`000000103oool2000000050?oo
o`000000oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo00h0
oooo00<000000?ooo`0000002@3oool20000o`<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3o00001P3oool00`3o0000oooo0?ooo`0J
0?ooo`040000o`3oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0100oooo000T0?ooo`800000103oool01P3o0000oooo
0?ooo`000000oooo0000ogh0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0A0?oo
o`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0803oool20000oeX0oooo00<000000?oo
o`3oool04P3oool00`3o000000000?ooo`070?ooo`040?l0003oool0oooo0000o`<0oooo00<00000
0?ooo`3oool03@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool02@3oool01P000?l0o`000?ooo`3o0000oooo000000@0oooo00<0003o0?ooo`3o
ool00P3oool010000?l0oooo0?ooo`0000040?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000001`3oool00`000?l0oooo0?ooo`0>0?ooo`040000003oool0oooo000000P0oooo
00<0003o0?ooo`000?l00P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3o00001`3oool00`3o0000oooo0?ooo`0I0?ooo`80003o0P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool0
02@0oooo00<000000?ooo`3oool00`3oool0103o0000oooo0?ooo`0000020?ooo`030000o`3oool0
oooo07/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0
oooo00T0oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0000o`1I0?ooo`030000003oool0
oooo0180oooo00<0o`000000003oool01`3oool0103o0000oooo0?ooo`000?l30?ooo`030000003o
ool0oooo00d0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00T0oooo00H0003o0?l0003oool0o`000?ooo`0000050?ooo`050000o`3oool0oooo
0?ooo`000?l00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080000000D0oooo
0000003oool0oooo000000080?ooo`030000o`3oool0oooo00d0oooo00@000000?ooo`3oool00000
1`3oool010000?l0oooo0?ooo`000?l20?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?l000070?ooo`030?l0003oool0oooo01T0oooo0P000?l30?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0100oooo000T0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`0000000P3oool0
0`000?l0oooo0?ooo`1j0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo01l0oooo00D0003o0?ooo`3oool0oooo0000
o`1H0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01`3oool01@3o0000oooo0000
o`3oool0003o0080oooo00<000000?ooo`3oool02@3oool4000000<0oooo00@000000?ooo`3oool0
00003`3oool00`000000oooo0?ooo`090?ooo`060000o`3o0000oooo0?l0003oool000001@3oool0
1@000?l0oooo0?ooo`3oool0003o0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`02000000050?ooo`000000oooo0?ooo`000000203oool00`000?l0oooo0?ooo`0=0?ooo`040000
003oool0oooo000000L0oooo00@0003o0?ooo`3oool0003o0P3oool010000000oooo0?ooo`3oool4
000000<0oooo00H000000?ooo`3oool000000?ooo`3o00070?ooo`030?l0003oool0oooo01T0oooo
0P000?l01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`00000B0?ooo`00903oool00`000000oooo0?ooo`040?ooo`030?l0003oool00000
0080oooo00<0003o0?ooo`3oool0I`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo
00P0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo
01l0oooo00<0003o0?ooo`3oool00P3oool20000o`H0oooo0P00001>0?ooo`8000004P3oool00`3o
000000000?ooo`090?ooo`070?l000000?l0oooo0?ooo`000?l0oooo0000000;0?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`090?ooo`070000
o`3oool0oooo0?ooo`3o0000oooo000000050?ooo`030000o`3oool0003o0080oooo0P0000040?oo
o`030000003oool0oooo0080000000D0oooo0000003oool0oooo000000090?ooo`030000o`3oool0
oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`050000o`3oool0
oooo0000o`3oool00P0000030?ooo`030000003oool0oooo00@0oooo00H000000?ooo`3oool00000
0?ooo`3o00080?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`000?l00`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool0
02@0oooo0P0000050?ooo`040?l0003oool0oooo00000080oooo00<0003o0?ooo`3oool0IP3oool2
0000oa00oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<000000?ooo`000000C@3oool00`000000oooo0?ooo`0A0?ooo`030?l000000000
oooo00T0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0000000/0oooo1@0000030?ooo`800000
403oool00`000000oooo0?ooo`090?ooo`070000o`3oool0oooo0?ooo`3o0000oooo000000050?oo
o`030000o`3oool0003o00<0oooo00<000000?ooo`3oool00P3oool3000000040?ooo`000000oooo
0?ooo`8000002P3oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00@000000?ooo`3oool0oooo
1@0000030?ooo`80000000<0oooo0?l0003oool0203oool00`3o0000oooo0?ooo`0G0?ooo`040000
o`3oool0oooo0000o`<00000103oool2000000@0oooo0P00000C0?ooo`00903oool00`000000oooo
0?ooo`040?ooo`040?l0003oool0oooo00000080oooo00<0003o0?ooo`3oool0I@3oool010000?l0
oooo0?ooo`000?l>0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool01P3oool01@00
0?l0oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0A
0?ooo`030?l000000000oooo00T0oooo00<0003o0?ooo`3oool00P3oool00`000?l000000?ooo`0T
0?ooo`030000003oool0oooo00T0oooo00L0003o0?ooo`3oool0oooo0?l0003oool0000000H0oooo
00<0003o0?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000h0oooo00<0003o0?ooo`3o
ool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D0003o0?ooo`3o
ool0oooo0000o`0A0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool05P3oool01000
0?l0oooo0?ooo`000?lR0?ooo`00903oool00`000000oooo0?ooo`050?ooo`030?l0003oool00000
0080oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`130?ooo`050000o`3oool0oooo
0?ooo`000?l03@3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00T0oooo00<0003o
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo00L0oooo0P000?l0
0`3oool000000?ooo`030?ooo`800000BP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00P0oooo00<0003o0?ooo`3o00000`3oool00`000?l000000?ooo`0L0?ooo`030000o`3oool0
oooo00D0oooo00<000000?ooo`3oool0203oool00`3o0000003o0?ooo`020?ooo`030?l0003oool0
000000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0
oooo01H0oooo00D0003o0?ooo`3oool0oooo0000o`0Q0?ooo`00903oool00`000000oooo0?ooo`05
0?ooo`060?l0003oool0oooo0000003oool0003o8@3oool20000od<0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0
0P3o00050?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool2000001<0oooo
00<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`030000o`3oool0o`0000@0oooo
00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo
00<0003o0?ooo`3oool00`3oool00`3o000000000?ooo`0>0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0303oool00`000?l0oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo
00D000000?ooo`3oool0oooo0000o`050?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`0F0?ooo`050000o`3oool0oooo0?ooo`000?l08@3oool002@0
oooo0P0000060?ooo`060?l0003oool0oooo0000003oool0003o8@3oool00`000?l0oooo0000o`11
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0=
0?ooo`050000o`3o0000o`000?ooo`3o00001@3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo00L0oooo00@000000?ooo`00000000004@3oool00`000?l0oooo0?ooo`0:0?ooo`030000
00000?l0oooo00H0oooo00<000000?ooo`3oool0@@3ooolT000000030000o`000000o`0000D00000
00<0003o0000000000006P0000000`000?l000000000000@000000030000o`000000000000<00000
00<0o`00000000000000900000000`000?l000000000000C000000030000o`000000000000<00000
00<0003o0000000000003P0000000`3o0000000000000009000000030?l000000000000001D00000
00D0003o00000000000000000000o`0>000001<0oooo000T0?ooo`030000003oool0oooo00D0oooo
00@0o`000?ooo`3oool000000P3oool00`000?l0oooo0?ooo`0M0?ooo`050000o`3oool0oooo0?oo
o`000?l0@03oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool02`3oool30?l000030?ooo`000?l0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`0C
0?ooo`030000o`3oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000o`3o
ool0oooo00/0oooo00<000000?ooo`000?l01`3oool2000004H0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000H0oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`090?ooo`030000o`3oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000060?oo
o`050?l000000?l0oooo0?ooo`0000000P3oool00`3o000000000?ooo`050?ooo`030000003oool0
oooo00H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00@0003o0?ooo`3oool000001`3oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo0000o`<0oooo00<000000?ooo`000?l0203oool00`000000oooo0?ooo`050?oo
o`040?l0003oool0oooo000000P0oooo00<0o`000?ooo`0000002`3oool00`000000oooo0?ooo`07
0?ooo`030000o`000000oooo0080oooo00<0003o0?ooo`3oool0103oool00`000000oooo0?ooo`0G
0?ooo`004@3oool2000000@0oooo00@000000?ooo`3oool0oooo1@0000040?ooo`030000003oool0
oooo00D0oooo00L0o`000?ooo`3oool0oooo0000003oool0003o01l0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0l0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`080?ooo`<0o`001@3oool01`000?l0oooo0?ooo`3oool0o`000?oo
o`000?l0503oool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo0P00000=0?oo
o`030000o`3oool0oooo00X0oooo00@000000?ooo`3oool0003o2@3oool00`000000oooo0?ooo`13
0?ooo`030000o`000000oooo0140oooo00<000000?ooo`3oool01`3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<000000000o`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00@0oooo00<000000?ooo`3oool0203oool00`3o0000003o0?ooo`040?ooo`030?l00000
0000oooo00h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000o`060?ooo`030000
o`3oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0
003oool0oooo01@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000
003oool0oooo01L0oooo000@0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`060?ooo`060?l0003oool0oooo0000003oool0003o7`3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo03/0oooo00<0003o0?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo0P3o00080?ooo`060000o`3oool0
oooo0?ooo`3o0000003o5P3oool00`000?l0oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
0P00000;0?ooo`030000o`3oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000o`090?ooo`03
0000003oool0oooo0480oooo00<0003o0000003oool0403oool00`000000o`000?ooo`070?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000000003o0?ooo`0I0?ooo`03
0000o`3oool0003o00D0oooo00<000000?ooo`3oool0203oool00`3o0000003o0?ooo`050?ooo`03
0?l000000000oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000o`060?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool07@3oool00100oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`040?ooo`8000001`3oool01P3o0000oooo0?ooo`000000oooo
0000oal0oooo00<0003o0?l0003oool0103oool00`000?l0oooo0?ooo`0i0?ooo`030000o`3oool0
oooo00/0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00P0oooo00D0003o0?ooo`3oool0003o0?l0000F0?ooo`030000o`3oool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000o`3oool0oooo00X0oooo00<0
00000?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`030000003oool0oooo0440oooo0P00
000A0?ooo`030000003o0000oooo00L0oooo00<0003o0?ooo`3oool00`3oool01`3o0000oooo0?oo
o`3oool000000?ooo`000?l06@3oool00`000?l0oooo0000o`050?ooo`030000003oool0oooo00L0
oooo00<0o`000?ooo`000?l01P3oool00`3o000000000?ooo`0=0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00<000000000o`3oool01@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00/0
oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01d0
oooo000@0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`060?l0003oool0oooo0?ooo`000000003o7`3oool00`000?l0o`000?ooo`05
0?ooo`030000o`3oool0oooo03P0oooo00<0003o0?ooo`3oool0303oool010000?l0oooo0?ooo`00
0?l:0?ooo`030?l0003oool0oooo00P0oooo00D0003o0?ooo`000?l0oooo0?l0000F0?ooo`030000
o`3oool0oooo00@0oooo00<000000?ooo`3oool02@3oool2000000L0oooo00<0003o0?ooo`3oool0
2P3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo04/0oooo00<000000000o`000000
403oool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00D0o`000?ooo`3oool0
oooo000000020?ooo`030000o`3oool0oooo01H0oooo00<0003o0?ooo`000?l01@3oool00`000000
oooo0?ooo`070?ooo`030?l0003oool0003o00H0oooo00<0o`000000003oool0303oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<0003o0?ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`0M0?ooo`00403oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo00<000000000
o`3oool0703oool010000?l0o`000?ooo`3o00060?ooo`030000o`3oool0oooo03H0oooo00<0003o
0?ooo`3oool03P3oool00`000?l0oooo0000o`090?ooo`030?l0003oool0oooo00X0oooo00D0003o
0?ooo`3oool0oooo0?l0000E0?ooo`030000o`3oool0oooo00@0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00X0oooo00<000000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`1:0?ooo`03000000000?l000000100oooo00<000000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`040?ooo`050?l0003oool0oooo0?ooo`0000000P3oool00`000?l0oooo
0?ooo`0F0?ooo`030000o`3oool0003o00D0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo
0000o`070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo
0?ooo`0B0?ooo`030000o`3oool0o`0000D0oooo00<0003o0?ooo`3oool0703oool00100oooo00@0
00000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo01/0oooo00@0003o0?l0003o
ool0o`001`3oool00`000?l0oooo0?ooo`0d0?ooo`030000o`3oool0oooo0100oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<0003o0?oo
o`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo04X0oooo00<000000000
o`0000003`3oool00`000000o`000?ooo`060?ooo`030000o`3oool0oooo00D0oooo00D0o`000?oo
o`3oool0oooo000000030?ooo`030000o`3oool0oooo01D0oooo00<0003o0?ooo`000?l01@3oool0
0`000000oooo0?ooo`060?ooo`040?l0003oool0oooo0000o`L0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00<0003o0?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000o`3oool0000000L0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3o00001@3o
ool00`000?l0oooo0?ooo`0L0?ooo`004@3oool2000000T0oooo0`0000050?ooo`030000003oool0
oooo00L0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`040000o`3o0000
oooo0?l000P0oooo00<0003o0?ooo`3oool0<`3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003o
ool0oooo00l0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`030?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`030000003o
ool0oooo00L0oooo00<0003o0?ooo`3oool0B@3oool010000000003o0?ooo`00000>0?ooo`030000
003o0000oooo00H0oooo00<0003o0?ooo`3oool01P3oool0103o0000oooo0?ooo`0000030?ooo`03
0000o`3oool0oooo01D0oooo00<0003o0?ooo`000?l0103oool00`000000oooo0?ooo`070?ooo`04
0?l0003oool0oooo0000o`L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00l0oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`030000o`3oool0000000L0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?oo
o`030?l0003oool0oooo0140oooo00@0003o0?ooo`3o0000o`00103oool00`000?l0oooo0?ooo`0L
0?ooo`00903oool2000000P0oooo00<0o`000?ooo`3oool00P3oool00`000?l000000?ooo`0K0?oo
o`050000o`3oool0oooo0?ooo`3o0000203oool00`000?l0oooo0?ooo`0a0?ooo`030000o`3oool0
oooo01`0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0
oooo0080oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`000?l<0?ooo`030000003o
ool0oooo00L0oooo00<0003o0?ooo`3oool0B@3oool010000000003o0?ooo`00000>0?ooo`030000
003o0000oooo00D0oooo00<0003o0?ooo`3oool01`3oool01@3o0000oooo0?ooo`3oool0000000<0
oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0000o`040?ooo`030000003oool0oooo00L0
oooo00<0o`000?ooo`000?l0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo000000070?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0o`000?ooo`0B0?ooo`040000o`3o0000oooo0?l0
00D0oooo00<0003o0?ooo`3oool06`3oool002@0oooo00<000000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`030?ooo`030000o`000000oooo00l0oooo0P0000090?ooo`050000o`3oool0oooo0?oo
o`3o00002@3oool00`000?l0oooo0?ooo`0`0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo0080oooo00<000000?oo
o`3oool03`3oool00`000000oooo0000o`0<0?ooo`030000003oool0oooo00P0oooo00<0003o0?oo
o`3oool0B03oool010000000003o0?l00000000>0?ooo`030000003o0000oooo00D0oooo00<0003o
0?ooo`3oool01`3oool01@3o0000oooo0?ooo`3oool0000000@0oooo00<0003o0?ooo`3oool04P3o
ool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo
0000o`080?ooo`030000003o0000oooo00/0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0A0?ooo`050000o`3oool0oooo0?ooo`000000103oool01@3o0000oooo0?ooo`3oool0003o
00<0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?l0003oool04P3oool01@000?l0o`000?ooo`3oool0o`0000@0oooo00<0003o
0?ooo`3oool06`3oool002@0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0000000h0oooo00<000000?ooo`000000203oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`0L0?oo
o`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool04@3oool01@000?l0oooo0?ooo`3oool0
00000180oooo00<000000000o`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000o`3oool0
oooo04P0oooo00D000000?ooo`000?l0oooo0000000=0?ooo`030000003o0000oooo00D0oooo00<0
003o0?ooo`3oool01`3oool01@3o0000oooo0?ooo`3oool0000000@0oooo00<0003o0?ooo`3oool0
4P3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<000000?ooo`3oool01P3oool0103o0000
oooo0?ooo`000?l90?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0B0?ooo`040000o`3oool0oooo000000@0oooo0P3o00020?ooo`050000o`3oool0
oooo0?ooo`0000001`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00`0oooo0P00
0?l00`3o0000oooo0?ooo`0A0?ooo`050000o`3o0000oooo0?ooo`3o00001@3oool00`000?l0oooo
0?ooo`0J0?ooo`00903oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`0000003@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo02h0oooo00<0003o0?ooo`3oool0
703oool00`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo00/0oooo0P3o00030?ooo`050000
o`3oool0oooo0?ooo`0000004`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<0003o0?ooo`3oool0A`3oool2000000030000o`3oool0000000`0oooo00<000000?ooo`3o
00001@3oool00`000?l0oooo0?ooo`090?ooo`040?l0003oool0oooo000000@0oooo00<0003o0?oo
o`3oool04P3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<000000?ooo`3oool01P3oool0
103o0000oooo0?ooo`000?l90?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0A0?ooo`030000o`3oool0000000@0oooo00<0o`000?ooo`3o00000P3o
ool01@000?l0oooo0?ooo`3oool0000000L0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0;0?ooo`040000o`3oool0003o0?l001<0oooo00<0003o0?l0003oool00P3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo01X0oooo000T0?ooo`8000002@3oool00`3o0000oooo
0?ooo`020?ooo`040000o`3oool0oooo000000/0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`000000
003o0?ooo`0^0?ooo`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool04`3oool00`3o0000
oooo0?ooo`0:0?ooo`030?l0003oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0000000C0?oo
o`030000o`000000oooo00T0oooo00<000000?ooo`3oool0303oool00`000?l0oooo0?ooo`160?oo
o`050000003oool0003o0?ooo`000000303oool00`000000oooo0?l000050?ooo`030000o`3oool0
oooo00T0oooo00@0o`000?ooo`3oool00000103oool00`000?l0oooo0?ooo`0B0?ooo`050000o`3o
ool0oooo0?ooo`000?l00`3oool00`000000oooo0?ooo`060?ooo`040?l0003oool0oooo0000o`T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180
oooo00<0003o0000003oool00`3oool01@3o0000oooo0?l0003oool0003o00D0oooo00<000000?oo
o`3oool0103oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00H0003o0?oo
o`3oool0003o0?ooo`3o000B0?ooo`030000o`3o0000oooo0080oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0J0?ooo`00903oool00`000000oooo0?ooo`080?ooo`030?l0003oool0
oooo0080oooo00D0003o0?ooo`3oool0oooo000000080?ooo`8000001P3oool00`000000oooo0?oo
o`030?ooo`030?l000000?l0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000000oooo0000
o`0]0?ooo`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?oo
o`070?ooo`80o`000`3oool0103o0000oooo0?ooo`000?l20?ooo`030000003oool0oooo0140oooo
00@0003o0?ooo`3oool000002@3oool00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo04H0
oooo00<000000?ooo`000?l00P3oool00`000000oooo0?ooo`090?ooo`030000003o0000oooo00@0
oooo00<0003o0?ooo`3oool02P3oool0103o0000oooo0?ooo`0000050?ooo`030000o`3oool0oooo
0140oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030000003oool0oooo00D0oooo00D0o`00
0?ooo`3oool0oooo0000o`090?ooo`030000003o0000oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00D0o`000?ooo`3oool0o`00
0000o`050?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo0080oooo00<0003o0?l0003oool04@3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool06@3oool002@0oooo00<0
00000?ooo`3oool0203oool00`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000000
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<0o`000000o`3oool0
1@3oool00`3o0000oooo0?ooo`040?ooo`040000003oool000000000obd0oooo00<0003o0?ooo`3o
ool07@3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo00D0oooo0P3o00050?ooo`07
0?l0003oool0oooo0?ooo`000?l0oooo0000000@0?ooo`040?l0003oool0oooo0000o`80oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo04D0oooo00<0
00000?ooo`000?l00P3oool00`000000oooo0?ooo`090?ooo`030000003o0000oooo00@0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo000000050?ooo`030000o`3oool0oooo0140oooo00D0
003o0?ooo`3oool0oooo0000o`030?ooo`030000003oool0oooo00D0oooo00D0o`000?ooo`3oool0
oooo0000o`090?ooo`030000003o0000oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0C0?ooo`05000000000?l0oooo0?ooo`3o00000`3oool00`3o0000003o0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?l0003oool04@3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool06@3oool002@0oooo00<000000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`0000001@3oool00`00
0000oooo0?ooo`090?ooo`050000003oool0oooo0?l000000?l0203oool00`3o0000oooo0?ooo`02
0?ooo`060000003oool0oooo0000003oool0003o:`3oool00`000?l0oooo0?ooo`0N0?ooo`030?l0
003oool0oooo01H0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`070?l0
003oool0oooo0?ooo`000?l0oooo0000000@0?ooo`030?l0003oool0003o00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo04D0oooo00H000000?oo
o`000?l0o`000?ooo`00000;0?ooo`030000003o0000oooo00<0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo000000050?ooo`030000o`3oool0oooo0140oooo00D0003o0?ooo`3oool0oooo
0000o`030?ooo`030000003oool0oooo00D0oooo00D0o`000?ooo`3oool0oooo0000o`090?ooo`03
0000003o0000oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0003o0080oooo00H0o`000?ooo`3oool0oooo0000o`3o00060?ooo`030000003oool0
oooo00<0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?l0003oool0403oool00`000?l0o`000?ooo`050?ooo`050?l0003oool0
oooo0?ooo`000?l06`3oool002@0oooo0P00000:0?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000`0oooo00D000000?ooo`3oool0o`00
0000o`080?ooo`050?l0003oool0oooo0?ooo`0000000`3oool00`000000oooo0000o`0[0?ooo`03
0000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`020?l000T0
oooo00D0o`000?ooo`3oool0003o0000000@0?ooo`80o`0000<0oooo0000o`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3oool0A03oool20000
00050?ooo`000?l0oooo0?ooo`0000002@3oool00`000000oooo0?l000040?ooo`030000o`3oool0
oooo00`0oooo00@0o`000?ooo`3oool00000103oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo0080oooo00@0003o0?ooo`3oool000001`3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo00L0oooo00<000000?ooo`3o0000203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0180oooo00H000000?ooo`3oool0003o0?ooo`3o00030?ooo`030000o`3o0000oooo
00D0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?l0000@0?ooo`030000o`3o0000oooo
00D0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0H0?ooo`00903oool00`000000
oooo0?ooo`090?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000000
oooo0000000>0?ooo`040000003oool0o`000000o`P0oooo00@0o`000?ooo`3oool000001@3oool0
0`000000oooo0000o`0Z0?ooo`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool0603oool0
0`3o0000oooo0?l0000;0?ooo`050?l0003oool0oooo0000o`000000403oool00`3o0000oooo0000
o`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?oo
o`140?ooo`040000003oool0oooo0000o`80oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?l000040?ooo`030000o`3oool0oooo00`0oooo00@0o`000?ooo`3oool00000103oool00`000?l0
oooo0?ooo`0@0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`0000001`3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo00<000000?ooo`3o0000203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000o`040?oo
o`030000o`3oool0o`0000D0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?l0000@0?oo
o`030000o`3o0000oooo00H0oooo00D0o`000?ooo`3oool0oooo0000o`0J0?ooo`00903oool00`00
0000oooo0?ooo`090?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0003o00T0oooo00<0o`000?ooo`0000001@3oool00`00
0000oooo0000o`0Y0?ooo`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool06@3oool00`3o
0000oooo0?ooo`0:0?ooo`050?l0003oool0oooo0000o`000000403oool00`3o0000oooo0000o`07
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000?l0oooo0?ooo`13
0?ooo`040000003oool0oooo0000o`80oooo00<000000?ooo`3oool01`3oool00`000000oooo0?l0
00040?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`000000103oool00`000?l0oooo0?oo
o`0@0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`0000001`3oool01@3o0000oooo0?oo
o`3oool0003o00X0oooo00<000000?ooo`3o0000203oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0140oooo00D000000?ooo`3oool0oooo0000o`030?ooo`040000o`3oool0oooo0?l0
00H0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?l0000@0?ooo`030000o`3oool0oooo
00H0oooo00D0o`000?ooo`3oool0oooo0000o`0J0?ooo`00903oool00`000000oooo0?ooo`0:0?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0503oool00`000000oooo0000o`090?oo
o`030?l000000000oooo00D0oooo00@000000?ooo`3oool0003o:03oool00`000?l0oooo0?ooo`0N
0?ooo`030?l0003oool0oooo02L0oooo00<0o`000?ooo`000000403oool0103o0000oooo0?ooo`00
0?l80?ooo`040000003oool0oooo000001D0oooo00<0003o0?ooo`3oool0@P3oool010000000oooo
0?ooo`000?l30?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o00000`3oool00`000?l0
oooo0?ooo`0>0?ooo`030?l0003oool0000000@0oooo00<0003o0?ooo`3oool0403oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0000000H0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`090?ooo`030000003o0000oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0A0?ooo`060000003oool0oooo0?ooo`3o0000003o0P3oool010000?l0oooo0?ooo`3o
00060?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3o0000403oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool05`3oool002@0oooo0P00000;
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0000000:
0?ooo`030000003o0000oooo00H0oooo00<000000?ooo`000?l0:03oool00`000?l0oooo0?ooo`0M
0?ooo`040?l0003oool0oooo0?ooo`8000009@3oool0103o0000oooo000000000?l?0?ooo`050?l0
003oool0003o0?ooo`3o0000203oool00`000000oooo0000000E0?ooo`030000o`3oool0oooo02T0
oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`D00000103oool010000000
oooo0?ooo`000?l30?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0o`000`3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0000000D0oooo00<0003o0?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0000000H0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`090?ooo`030000003oool0o`0000L0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00D0o`000?ooo`000?l0oooo0000
o`030?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool02P3oool00`000?l0o`000?oo
o`0?0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool06`3oool002@0oooo00<00000
0?ooo`3oool02`3oool01@3o0000oooo0?ooo`3oool0003o01D0oooo00@0o`000?ooo`000?l00000
203oool00`000000oooo0?l000070?ooo`040000003oool0oooo0000obH0oooo00<0003o0?ooo`3o
ool07P3oool01P3o0000oooo000000000000oooo000002D0oooo00@0o`000?ooo`000000003o3P3o
ool01P3o0000oooo0?ooo`000?l0oooo0?l000T0oooo00<000000?ooo`3oool05@3oool00`000?l0
oooo0?ooo`0W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000o`<0oooo00<000000?ooo`3oool0
1@3oool010000000oooo0?ooo`3o00030?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`00
00001@3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`00
00001P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00T0oooo00<000000?ooo`3o
00001`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0100oooo00D000000?ooo`3o
ool0oooo0?l000030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0:0?ooo`030000o`3oool0o`0000l0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`0K0?ooo`004@3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000D0
oooo00<000000?ooo`3oool02`3oool01@3o0000oooo0?ooo`3oool0003o01D0oooo00@0o`000?oo
o`000?l000001`3oool010000000oooo0?ooo`3o00070?ooo`050000003oool0oooo0?ooo`000?l0
9@3oool00`000?l0oooo0?ooo`0N0?ooo`030?l000000000oooo0080oooo00<000000?ooo`3oool0
903oool00`000000oooo0000o`0>0?ooo`060?l0003oool0oooo0000o`3oool0o`00B`3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103o
ool3000000030000o`3o0000oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?l0
00040?ooo`030000o`3oool0oooo00l0oooo00<0o`000000003oool0103oool00`000?l0oooo0?oo
o`0?0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`0000001@3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00T0oooo00<000000?ooo`3o00001P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0?l000090?ooo`030?l0
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?l0000?0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool06P3oool00100oooo00@000000?ooo`3oool00000
1`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0303oool01@3o0000
oooo0?ooo`3oool0003o01<0oooo00H0o`000?ooo`3oool0003o0?ooo`0000060?ooo`050000003o
ool0oooo0?ooo`3o00001`3oool010000000oooo0?ooo`000?lU0?ooo`030000o`3oool0oooo01d0
oooo0P0000050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`000?l03P3oool00`3o0000
oooo0000o`030?ooo`030?l0003oool0oooo04P0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
o`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o0000103oool00`000?l0oooo0?oo
o`0?0?ooo`030?l000000000oooo00@0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0000000D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`090?ooo`030000003oool0o`0000H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0@0?ooo`050000003oool0oooo0?ooo`3o00002@3oool00`3o0000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00/0oooo00<0003o0?ooo`3o00003P3oool00`3o0000003o0?ooo`090?ooo`030?l0
003oool0oooo01X0oooo000@0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
0P3oool2000000h0oooo00@0o`000?ooo`3oool0003o4`3oool0103o0000oooo0?ooo`000?l20?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?oo
o`050000003oool0oooo0?ooo`000?l08`3oool00`000?l0oooo0?ooo`0L0?ooo`80000000<0o`00
0?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0003o00d0oooo00@0o`00
0?ooo`3oool0003o0`3oool00`3o0000oooo0?ooo`180?ooo`040000003oool0oooo000000P0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo0000o`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o00000`3oool0
0`000?l0oooo0?ooo`0@0?ooo`030?l000000000oooo00@0oooo00<0003o0?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0000000D0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`090?ooo`040000003oool0oooo0?l000D0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`3o00002P3oool00`3o0000oooo
0?ooo`050?ooo`050000003oool0oooo0?ooo`000?l0203oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00/0oooo00<0003o0?ooo`3o00003P3oool00`3o0000003o0?ooo`0:0?ooo`03
0?l0003oool0oooo01T0oooo000@0?ooo`040000003oool0oooo000000T0oooo0P0000050?ooo`03
0000003oool0oooo00d0oooo00@0o`000?ooo`3oool0003o4P3oool0103o0000oooo0?ooo`000?l3
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`3o0000oooo0?ooo`050?ooo`040000003o
ool0oooo0000ob<0oooo00<0003o0?ooo`3oool06`3oool010000000oooo0?ooo`3o00060?ooo`03
0000003oool0oooo0280oooo00D000000?ooo`3o0000oooo0000o`0<0?ooo`040?l0003oool0oooo
0000o`<0oooo00<0o`000?ooo`3oool0B03oool010000000oooo0?ooo`0000080?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000?l0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?l000<0oooo00<0003o
0?ooo`3oool0403oool00`3o0000oooo000000040?ooo`030000o`3oool0oooo00h0oooo00<0003o
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool02@3oool010000000oooo0?ooo`3o00050?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0o`0000/0oooo00<0o`000?ooo`3oool0
1@3oool010000000oooo0?ooo`000?l80?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool02`3oool010000?l0oooo0?ooo`3o000=0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?oo
o`3oool06@3oool00100oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00h0oooo00<0o`000?ooo`000?l04P3oool0103o0000oooo0?ooo`000?l4
0?ooo`030000003oool0000000L0oooo00<0o`000?ooo`3oool01@3oool01@000000oooo0?ooo`3o
ool0003o0280oooo00<0003o0?ooo`3oool06@3oool2000000<0oooo00<0o`000?ooo`3oool0103o
ool00`000000oooo0?ooo`0R0?ooo`050000003oool0o`000?ooo`000?l0303oool00`3o0000oooo
0000o`040?ooo`030?l0003oool0oooo04T0oooo0P00000:0?ooo`8000000`3oool3000000D0oooo
00D000000?ooo`3oool0oooo0000o`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool0o`000`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l000000000oooo00<0oooo00<0003o0?oo
o`3oool03P3oool00`000?l0oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`090?ooo`040000003oool0oooo0?l000D0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`3o00002`3o
ool00`3o0000oooo0?ooo`050?ooo`040000003oool0oooo0000o`P0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0<0?ooo`040000o`3oool0oooo0?l000d0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0H0?ooo`00403oool010000000oooo0?ooo`0000070?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0003o
0180oooo00@0o`000?ooo`3oool0003o1@3oool00`000000oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00D000000?ooo`3oool0oooo0000o`0Q0?ooo`030000o`3oool0oooo01T0oooo00<0
00000?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00D0
00000?ooo`3o0000oooo0000o`0;0?ooo`040?l0003oool0oooo0000o`D0oooo00<0o`000?ooo`3o
ool0H@3oool01@000000oooo0?ooo`3oool0003o00@0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`3o00030?ooo`030000o`3oool0oooo0140oooo00<0o`000000003oool0103oool0
0`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00D0oooo00D000000?ooo`3oool0oooo0?l0
00070?ooo`030000o`3oool0oooo00/0oooo00@000000?ooo`3oool0o`00103oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool0o`003@3oool00`3o0000
oooo0?ooo`050?ooo`030000003oool0003o00P0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0<0?ooo`040000o`3oool0oooo0?l000d0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0H0?ooo`004@3oool2000000T0oooo0`0000050?ooo`800000403oool00`3o0000
oooo0000o`0@0?ooo`050?l0003oool0oooo0?ooo`000?l03`3oool00`3o0000oooo0?ooo`050?oo
o`050000003oool0oooo0?ooo`000?l0803oool00`000?l0oooo0?ooo`0I0?ooo`030000003oool0
oooo0080oooo00<0o`000?ooo`3oool01P3oool00`000000oooo0?ooo`0P0?ooo`060000003oool0
oooo0?ooo`3o0000003o2`3oool0103o0000oooo0?ooo`000?l50?ooo`030?l0003oool0oooo0640
oooo0P0000020?ooo`030000o`3o0000oooo00<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`050?l0003oool0oooo0?ooo`000?l04`3oool00`3o000000000?ooo`040?ooo`030000o`3oool0
oooo00d0oooo00<0003o0?ooo`3oool01@3oool010000000oooo0?ooo`3o00080?ooo`030000o`3o
ool0oooo00/0oooo00@000000?ooo`3oool0o`000`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00d0oooo00D000000?ooo`3oool0oooo0?l0000=0?ooo`030?l0003oool0oooo00H0
oooo00<000000000o`3oool01`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00d0
oooo00<0003o0?ooo`3o0000303oool00`3o0000003o0?ooo`0=0?ooo`030?l0003oool0oooo01L0
oooo000T0?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`000?l0403oool01@3o0000oooo
0?ooo`3oool0003o00l0oooo00<0o`000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0003o
0200oooo00<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo
00H0oooo00<000000?ooo`3oool0803oool01P000000oooo0?ooo`3oool0o`000000o`X0oooo00@0
o`000?ooo`3oool0003o1P3oool00`3o0000oooo0?ooo`1Q0?ooo`030000003oool0oooo0080oooo
00<0003o0?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`050?l0003oool0oooo0?oo
o`000?l04`3oool00`3o000000000?ooo`040?ooo`030000o`3oool0oooo00d0oooo00<0003o0?oo
o`3oool01@3oool010000000oooo0?ooo`3o00080?ooo`030000o`3oool0oooo00/0oooo00@00000
0?ooo`3oool0o`000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00D0
00000?ooo`3oool0oooo0?l0000=0?ooo`030?l0003oool0oooo00L0oooo00<000000000o`3oool0
1@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3o0000
303oool00`3o0000003o0?ooo`0W0?ooo`00903oool00`000000oooo0?ooo`0@0?ooo`030?l00000
0?l0oooo00h0oooo00D0o`000?ooo`3oool0oooo0000o`0A0?ooo`030?l0003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo01P0oooo
00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`060?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`040?l0003oool0oooo0000o`L0
oooo00<0o`000?ooo`3oool0H03oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00@000000?ooo`3oool000000`3oool0103o0000oooo0?ooo`000?lE0?ooo`030000003oool0
oooo00<0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`050?ooo`030000003oool0
o`0000T0oooo00<0003o0?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0o`000080oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`3o0000
3P3oool00`3o0000oooo0?ooo`060?ooo`03000000000?l0oooo00D0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0>0?ooo`040000o`3oool0oooo0?l000/0oooo00<0o`000000o`3o
ool09`3oool002@0oooo00<000000?ooo`3oool0403oool00`3o0000003o0?ooo`0>0?ooo`050?l0
003oool0oooo0?ooo`000?l04@3oool00`3o0000oooo0?ooo`050?ooo`050000003oool0oooo0?oo
o`000?l07P3oool00`000?l0oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<0o`000?oo
o`3oool01P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo00<0o`000000
o`3oool0203oool0103o0000oooo0?ooo`000?l70?ooo`030?l0003oool0oooo0600oooo00<00000
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0000000<0oooo00@0o`00
0?ooo`3oool0003o5@3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo00<0
003o0?ooo`3oool01P3oool00`000000o`000?ooo`090?ooo`030000o`3oool0oooo00/0oooo00D0
00000?ooo`3oool0oooo0?l000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool010000000oooo0?ooo`3o000?0?ooo`030?l0003oool0oooo00L0oooo00<000000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00h0oooo00@0003o0?ooo`3o
ool0o`002`3oool00`3o0000003o0?ooo`0W0?ooo`00903oool00`000000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo00d0oooo00D0o`000?ooo`3oool0oooo0000o`0A0?ooo`030?l0003oool0oooo
00@0oooo00<0o`000000003o00000`3o00000`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0oooo
01T0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool00`3oool00`3o0000003o0?ooo`070?ooo`040?l0003oool0oooo
0000o`P0oooo00<0o`000?ooo`3oool0H03oool00`000000oooo0?ooo`020?ooo`030000o`3oool0
oooo00<0oooo00<000000?ooo`0000000P3oool01@3o0000oooo0?ooo`3oool0003o01D0oooo00<0
00000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo00<0
00000000o`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`3o0000
0P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool0
o`00403oool00`3o0000oooo0?ooo`060?ooo`030000o`000000oooo00@0oooo00D0o`000?ooo`3o
ool0oooo0000o`0A0?ooo`040000o`3oool0oooo0?l000X0oooo00<0o`000?ooo`000?l00`3oool0
0`000000oooo0?ooo`0R0?ooo`00903oool200000180oooo00<0o`000000o`3oool02`3oool20?l0
00@0oooo00<0003o0?ooo`3oool0403oool60?l000030?ooo`000000oooo00<0oooo00<0003o0?oo
o`3oool06`3oool00`000?l0oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<0o`000?oo
o`3oool0203oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00@0oooo00<0003o0?oo
o`3oool01P3oool0103o0000oooo0?ooo`000?l90?ooo`030?l0003oool0oooo05l0oooo0P000003
0?ooo`030000o`3oool0oooo00<0oooo00<000000?ooo`0000000P3oool01@3o0000oooo0?ooo`3o
ool0003o01H0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00H0oooo00<000000000o`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`030000003o
ool0oooo0080oooo00<0o`000?ooo`0000003`3oool00`000000oooo0?ooo`0;0?ooo`050000003o
ool0oooo0?ooo`3o0000403oool00`3o0000oooo0?ooo`060?ooo`030000o`000000oooo00@0oooo
00D0o`000?ooo`3oool0oooo0000o`0A0?ooo`040000o`3oool0oooo0?l000X0oooo00<0o`000?oo
o`000?l00`3oool00`000000oooo0?ooo`0R0?ooo`00903oool00`000000oooo0?ooo`0B0?ooo`03
0000o`3oool0oooo00P0oooo0P3o00060?ooo`030000o`3oool0oooo01P0oooo00D000000?ooo`3o
ool0oooo0000o`0L0?ooo`030000o`3oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`080?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`050?l0003oool0oooo0?ooo`000?l02@3oool00`3o0000oooo0?ooo`1O
0?ooo`030000003oool0oooo0080oooo00<0003o0?l0003oool0103oool01@000000oooo0?ooo`3o
ool0o`0000<0oooo00<0003o0?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00/0oooo00<0003o0?ooo`3oool01@3oool00`000000oooo0000o`0:0?ooo`030000o`3o
ool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`3o000000000?ooo`0?0?ooo`030000003o
ool0oooo00/0oooo00@000000?ooo`3oool0o`004P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0000000@0oooo00D0o`000?ooo`3oool0oooo0000o`0A0?ooo`050000o`3oool0oooo0?oo
o`3o00002@3oool00`3o0000oooo0000o`020?ooo`030000003oool0000002<0oooo000T0?ooo`03
0000003oool0oooo0180oooo00<0003o0?l0003oool01P3oool20?l000L0oooo00<0003o0?ooo`3o
ool06@3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3o
ool06@3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo00P0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00@0o`000?ooo`3o
ool0003o2P3oool00`3o0000oooo0?ooo`1O0?ooo`030000003oool0oooo0080oooo00<0003o0?l0
003oool0103oool01@000000oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3oool0503oool0
0`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0103oool0
103o000000000?ooo`000?l:0?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool0o`00
4P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0000000<0oooo00D0o`000?ooo`3oool0
oooo0000o`0>0?ooo`040000003oool0oooo0000o`<0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000003o0?ooo`020?ooo`040000003oool0oooo00000280oooo000T0?ooo`030000003oool0oooo
0180oooo00<0003o0?l0003oool01@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
01X0oooo00D000000?ooo`3oool0oooo0000o`0K0?ooo`030000o`3oool0oooo01T0oooo00<00000
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool01@3oool00`000?l0o`000?ooo`050?ooo`040?l0003oool0oooo0000o`X0oooo00<0
o`000?ooo`3oool0G`3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00@0
o`000?ooo`3oool0003o5`3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00/0oooo
00<0003o0?ooo`3oool00`3oool01@3o0000oooo0000003oool0003o00X0oooo00<0003o0?ooo`3o
ool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool02P3oool01@000000oooo0?ooo`3oool0o`000180oooo00<0o`000?ooo`3oool01P3oool01P00
0?l0oooo0?ooo`000000oooo0?l000<0oooo00<0003o0?ooo`3oool03@3oool01@000000oooo0?oo
o`3oool0003o0080oooo00<0o`000?ooo`3oool01`3oool01@3o0000003o0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool0803oool002@0oooo0P00000D0?ooo`030000o`3o0000oooo0080oooo
0P3o000:0?ooo`030000o`3oool0oooo01X0oooo00D000000?ooo`3oool0oooo0000o`0J0?ooo`03
0000o`3oool0oooo01X0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`090?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`05
0?l0003oool0oooo0?ooo`000?l02`3oool00`3o0000oooo0?ooo`1N0?ooo`030000003oool0oooo
00<0oooo00<0003o0?ooo`3oool01`3oool0103o0000oooo0?ooo`000?lG0?ooo`030000003o0000
oooo00<0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`020?ooo`060?l0003oool0
oooo0000003oool0003o2@3oool00`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`3o
00004`3oool00`3o0000oooo0?ooo`050?ooo`060000o`3oool0oooo0000003oool0o`000`3oool0
0`000?l0oooo0?ooo`0<0?ooo`030000003oool000000080oooo00@0003o0?ooo`3oool0o`00203o
ool01@3o0000oooo0000o`3oool0000000D0oooo00<000000?ooo`3oool07`3oool002@0oooo00<0
00000?ooo`3oool04`3oool00`000?l0o`000?ooo`020?l000`0oooo00<0003o0?ooo`3oool06P3o
ool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo01L0oooo00<0003o0?ooo`3oool06P3o
ool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo00X0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00@0o`000?ooo`3oool0003o
303oool00`3o0000oooo0?ooo`1N0?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0
1`3oool0103o0000oooo0?ooo`000?lG0?ooo`030000003o0000oooo00<0oooo00<0003o0?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`030?ooo`060?l0003oool0oooo0000003oool0003o2@3oool0
0`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?l0003oool03`3oool0
0`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`3o0000503oool00`3o0000oooo0?oo
o`050?ooo`060000o`3oool0oooo0?ooo`000000o`000`3oool00`000?l0oooo0?ooo`0<0?ooo`06
0000003oool0oooo0000003oool0003o0P3oool00`3o0000oooo0?ooo`060?ooo`050?l0003oool0
003o0?ooo`0000001P3oool00`000000oooo0?ooo`0N0?ooo`00903oool00`000000oooo0?ooo`0C
0?ooo`030000o`3oool0o`0000h0oooo00<0003o0?ooo`3oool06`3oool01@000000oooo0?ooo`3o
ool0003o01T0oooo00<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`070?ooo`030000o`3o
0000oooo00<0oooo00@0o`000?ooo`3oool0003o303oool00`3o0000oooo0?ooo`1N0?ooo`800000
103oool00`000?l0oooo0?ooo`070?ooo`040?l0003oool0oooo0000oaL0oooo00<000000?l0003o
ool00`3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00<0oooo00H0o`000?ooo`3o
ool000000?ooo`000?l90?ooo`030000o`3oool0oooo00d0oooo00<000000?ooo`3oool00P3oool0
0`000000o`000?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo00@0oooo00H0003o0?ooo`3oool0oooo0000
003o00020?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000003o
0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00@0o`000?ooo`000?l000001`3oool00`000000
oooo0?ooo`0N0?ooo`00903oool00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo00d0oooo
00<0003o0?ooo`3oool0703oool01@000000oooo0?ooo`3oool0003o01T0oooo00<0003o0?ooo`3o
ool06@3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo00/0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`070?ooo`030000o`3o0000oooo0080oooo00D0o`000?ooo`3o
ool0oooo0000o`0=0?ooo`030?l0003oool0oooo05d0oooo00<000000?ooo`3oool00`3oool00`00
0?l0o`000?ooo`070?ooo`040?l0003oool0oooo0000oaL0oooo00<000000?l0003oool00`3oool0
0`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000
00020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool03@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0o`0000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`040000003oool0oooo0000o`h0oooo00<000000?ooo`3oool00P3oool00`000000003o
0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00@0o`000?ooo`000?l00000203oool00`000000
oooo0?ooo`0M0?ooo`00903oool2000001@0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0L0?ooo`060000003oool0oooo0?ooo`000?l0o`005`3oool00`000?l0oooo0?ooo`0J0?oo
o`030000003oool0oooo0080oooo00<0o`000?ooo`3oool02`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00L0oooo00<0003o0?l0003oool00P3oool0103o0000oooo0?ooo`000?l>
0?ooo`030?l0003oool0oooo05d0oooo00<000000?ooo`3oool00`3oool00`000?l0o`000?ooo`06
0?ooo`040?l0003oool0oooo0000oaT0oooo00<000000?l0003oool00`3oool00`000?l0oooo0?oo
o`090?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo000000020?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000080
oooo00<0o`000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?oo
o`0000000P3oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`3oool0oooo0?l000070?ooo`030?l0003oool0000000X0oooo00<000000?ooo`3oool0703oool0
02@0oooo00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo
01d0oooo00D000000?ooo`3oool0oooo0000o`0G0?ooo`030000o`3oool0oooo01X0oooo00<00000
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0;0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool01`3oool01@000?l0oooo0?l0003oool0o`0000<0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`140?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000103o
ool3000000@0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`040?l0003o
ool0oooo0000oaT0oooo00<000000?l0003oool00`3oool00`000?l0oooo0?ooo`090?ooo`030000
o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo000000020?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000080oooo00<0o`000?oo
o`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0o`000?oo
o`3oool05P3oool00`3o0000oooo0?ooo`030?ooo`070000o`3oool0oooo0?ooo`3o000000000000
o`0>0?ooo`030000003oool0oooo00@0oooo00D0003o0000003oool0oooo0?l000060?ooo`040?l0
003oool000000000o`X0oooo00<000000?ooo`3oool0703oool00140oooo0P0000040?ooo`030000
003oool0oooo00<0oooo0`0000040?ooo`030000003oool0oooo01@0oooo00<0003o0?ooo`3oool0
303oool00`000?l0oooo0?ooo`0M0?ooo`050000003oool0oooo0?ooo`000?l05`3oool00`000?l0
oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool03@3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo00@0003o0?l0003oool0o`000`3oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo0480oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`040?l0003oool0oooo0000oaT0oooo00<000000?l0003oool0
0`3oool00`000?l0oooo0?ooo`090?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01@000000
oooo0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<0o`000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`020?ooo`070000o`3oool0
oooo0?l0003oool000000000o`0>0?ooo`030000003oool0oooo00D0oooo00D0003o0000003oool0
oooo0?l000050?ooo`040?l0003oool000000000o`/0oooo00<000000?ooo`3oool06`3oool00100
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01@0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0M0?ooo`060000003oool0oooo
0?ooo`000?l0o`005@3oool00`000?l0oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<0
o`000?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo00@0
003o0?l0003oool0o`000P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0480oooo
00@000000?ooo`3oool00000203oool01@000000oooo0?ooo`000000oooo00D00000103oool00`00
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00@0o`000?ooo`3oool0003o6@3oool0
0`000000oooo0?l000030?ooo`030000o`3oool0oooo00T0oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`050000003oool0oooo0?ooo`000?l0203oool00`000?l0oooo0?ooo`0>0?ooo`040000
003oool0oooo000000<0oooo00<0o`000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<0o`000?ooo`3oool06@3oool01@3o0000oooo0?ooo`3oool0003o
0080oooo00@0o`000?ooo`3oool000003@3oool00`000000oooo0?ooo`060?ooo`050000o`000000
oooo0?ooo`3o00001@3oool0103o000000000?ooo`000?l;0?ooo`030000003oool0oooo01/0oooo
000@0?ooo`040000003oool0oooo000000L0oooo1@0000040?ooo`8000005@3oool00`000?l0oooo
0?ooo`0;0?ooo`030000o`3oool0oooo01l0oooo00D000000?ooo`3oool0003o0?l0000E0?ooo`03
0000o`3oool0oooo01X0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool00`000?l0oooo0?l000030?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0@P3oool010000000oooo0?ooo`0000080?oo
o`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`030?ooo`<00000103o
ool00`000?l0oooo0?ooo`050?ooo`040?l0003oool0oooo0000oaT0oooo00<000000?ooo`3o0000
0`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0
oooo000000030?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool03P3oool010000000
oooo0?ooo`0000040?ooo`030?l0003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030?l0003oool0oooo01X0oooo00@0o`000?ooo`3oool0003o0P3oool0
103o0000oooo0?ooo`00000=0?ooo`030000003oool0oooo00H0oooo00D0003o0?ooo`000000oooo
0?l000050?ooo`030?l000000000003o00d0oooo00<000000?ooo`3oool06P3oool00100oooo00@0
00000?ooo`3oool000001`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo01@0
oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0O0?ooo`050000003oool0oooo0?oo
o`000?l05@3oool00`000?l0oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<0o`000?oo
o`3oool03@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00T0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0480oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool0103oool00`000?l0o`000?ooo`050?ooo`040?l0003oool0oooo0000oaT0oooo
00<000000?ooo`3o00000`3oool00`000?l0oooo0?ooo`080?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool01@000000oooo0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool03P3oool01000
0000oooo0?ooo`0000040?ooo`030?l0003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030?l0003oool0oooo01X0oooo00@0o`000?ooo`3oool0003o0P3o
ool01@3o0000oooo0000o`3oool0000000/0oooo00<000000?ooo`3oool01`3oool01@000?l0oooo
0?ooo`000000o`0000D0oooo00<000000?ooo`000?l03P3oool00`000000oooo0?ooo`0I0?ooo`00
403oool010000000oooo0?ooo`0000080?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0200oooo00D000000?ooo`3o
ool0003o0?l0000C0?ooo`030000o`3oool0oooo01X0oooo00<000000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0@@3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P0000050?ooo`030000003o
ool0oooo00@0oooo00<0003o0?l0003oool01@3oool00`3o0000oooo0000o`0J0?ooo`040000003o
ool0oooo0?l000<0oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo0?ooo`3oool0o`0000@0
oooo00D000000?ooo`3oool0oooo0000o`070?ooo`030000o`3oool0oooo00l0oooo00<000000?oo
o`0000001@3oool00`3o0000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0003o0080oooo00D0o`000?oo
o`000?l0oooo0000000;0?ooo`030000003oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0000
00040?ooo`040?l000000000oooo0000o`h0oooo00<000000?ooo`3oool06@3oool00100oooo00@0
00000?ooo`3oool000002@3oool2000000D0oooo00<000000?ooo`3oool05@3oool20000o`/0oooo
00<0003o0?ooo`3oool0803oool01@000000oooo0?ooo`000?l0o`0001<0oooo00<0003o0?ooo`3o
ool06P3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo00l0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0403oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo02P0oooo0P00000:0?ooo`80
00001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0003o0?l0003o
ool01@3oool00`3o0000oooo0000o`0J0?ooo`040000003oool0oooo0?l000<0oooo00<0003o0?oo
o`3oool01`3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<000000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00l0oooo00<000000?ooo`0000001P3oool0
0`3o0000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`3o0000oooo0?oo
o`0N0?ooo`070?l0003oool0003o0?ooo`3o0000oooo0000o`020?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0203oool01P000?l0oooo0?ooo`3oool000000?l000<0oooo00@00000
0?ooo`3oool0003o3`3oool00`000000oooo0?ooo`0H0?ooo`004@3oool2000000/0oooo00<00000
0?ooo`3oool00`3oool2000001P0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0Q
0?ooo`040000003oool0oooo0000oa<0oooo00<0003o0?ooo`3oool06P3oool00`000000oooo0?oo
o`020?ooo`030?l0003oool0oooo00l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0:0?ooo`050000o`3oool0oooo0?ooo`000?l04P3oool00`3o0000oooo0?ooo`0G0?ooo`030?l0
003oool0oooo0440oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0003o01X0oooo00@000000?ooo`3oool0o`000`3oool00`000?l0oooo0?ooo`070?ooo`04
0000o`3oool0oooo0?l000D0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo00l0oooo00<000000?ooo`0000001P3oool00`3o0000oooo0?ooo`0;0?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`3o0000oooo0?ooo`0N0?ooo`060?l0003oool0
003o0?ooo`3o0000003o0`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<0003o0?ooo`3oool00P3oool01@000000oooo0?ooo`000000o`000080oooo00<0003o0?ooo`3o
ool03P3oool00`000000oooo0?ooo`0G0?ooo`00903oool00`000000oooo0?ooo`0H0?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool08P3oool01@000000oooo0?ooo`000?l0o`000140
oooo00<0003o0?ooo`3oool06`3oool01@000000oooo0?ooo`3oool0o`000180oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0:0?ooo`040000o`3oool0oooo0000oa@0oooo00<0o`00
0?ooo`3oool05@3oool00`3o0000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0000o`0K0?ooo`040000003oool0oooo0?l00080oooo00<0
003o0?ooo`3oool01`3oool010000?l0oooo0?ooo`3o00050?ooo`030000003oool0oooo0080oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0000000L0oooo
00<0o`000?ooo`3oool02P3oool010000000oooo0?ooo`0000050?ooo`030?l0003oool0oooo0200
oooo00D0o`000000o`3o0000oooo0000o`030?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`050?l000000000oooo0000003o00000P3oool0
0`000?l0oooo0?ooo`0X0?ooo`00903oool00`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool08P3oool01@000000oooo0?ooo`000?l0o`000140oooo00<0003o
0?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo0100oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`040000o`3oool0oooo0000oa@0oooo00<0
o`000?ooo`3oool05@3oool00`3o0000oooo0?ooo`120?ooo`8000001P3oool00`000?l0oooo0?oo
o`030?ooo`040?l0003oool0oooo0000oa/0oooo00@000000?ooo`3oool0o`000P3oool00`000?l0
oooo0?ooo`070?ooo`040000o`3oool0oooo0?l000D0oooo00<000000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00l0oooo00<000000?ooo`0000001`3oool00`3o
0000oooo0?ooo`0;0?ooo`8000001@3oool00`3o0000oooo0?ooo`0R0?ooo`040000o`3o0000oooo
0000o`@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`090000o`3oool0
oooo0?ooo`3o0000oooo0000003oool0o`000080oooo00<0003o0?ooo`3oool0:03oool002@0oooo
00<000000?ooo`3oool06P3oool20000o`D0oooo00<0003o0?ooo`3oool08`3oool010000000oooo
0000o`3o000A0?ooo`030000o`3oool0oooo01X0oooo00<000000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02`3oool010000?l0
oooo0?ooo`000?lD0?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`050?ooo`030000o`3o0000oooo00<0oooo00@0o`000?ooo`3oool0003o6`3oool0
10000000oooo0?ooo`3o00020?ooo`030000o`3oool0oooo00H0oooo00@0003o0?ooo`3oool0o`00
1@3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
403oool2000000L0oooo00<0o`000?ooo`3oool02`3oool2000000D0oooo00<0o`000?ooo`3oool0
8P3oool00`000?l0o`000000o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0o`0000<0oooo00<0003o0?ooo`3oool0
:03oool002@0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo02<0oooo00D000000?ooo`3oool0003o0?l0000?0?ooo`030000o`3oool0oooo01/0oooo
00D000000?ooo`3oool0oooo0?l0000D0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool02`3oool00`000?l0oooo0000o`0F0?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3o
ool0A03oool00`000000oooo0?ooo`050?ooo`030000o`3o0000oooo00<0oooo00<0o`000?ooo`00
0?l0703oool01`000000oooo0?ooo`3oool0o`000?ooo`000?l0203oool010000?l0oooo0?ooo`3o
00050?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`0@0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?oo
o`030?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`000?l01P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00/0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?l0
00030?ooo`030000o`3oool0oooo02P0oooo000T0?ooo`8000007P3oool01@000?l0oooo0?ooo`3o
ool0003o02H0oooo00@000000?ooo`000?l0o`003`3oool00`000?l0oooo0?ooo`0K0?ooo`050000
003oool0oooo0?ooo`3o0000503oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00/0
oooo00<0003o0?ooo`000?l05P3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo04@0
oooo00<000000?ooo`3oool01@3oool00`000?l0o`000?ooo`030?ooo`030?l0003oool0003o01`0
oooo00D000000?ooo`3oool0oooo0?l000020?ooo`030000o`3oool0oooo00D0oooo00@0003o0?oo
o`3oool0o`001@3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool0403oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo00l0oooo00<0o`00
0?ooo`3oool09@3oool20000o`H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o00000`3oool00`000?l0oooo0?ooo`0X
0?ooo`00903oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0003o02L0oooo00@000000?oo
o`000?l0o`003P3oool00`000?l0oooo0?ooo`0L0?ooo`050000003oool0oooo0?ooo`3o0000503o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00`0oooo0P000?lF0?ooo`030?l0003o
ool0oooo0140oooo00<0o`000?ooo`3oool0A@3oool00`000000oooo0?ooo`060?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`000?l07@3oool010000000oooo0?ooo`3o00020?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3o00001P3oool00`000000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030?l0
003oool0oooo00h0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`060?ooo`050000
003oool0oooo0?ooo`0000003P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0o`0000<0
oooo00<0003o0?ooo`3oool0:03oool002@0oooo00<000000?ooo`3oool07`3oool20000obP0oooo
00@000000?ooo`000?l0o`003@3oool00`000?l0oooo0?ooo`0K0?ooo`050000003oool0oooo0?oo
o`3o00005@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00`0oooo00<0003o0?oo
o`3oool05P3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo04D0oooo0P0000070?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`000?l07@3oool01`000000oooo0?ooo`3oool0
o`000?ooo`000?l01`3oool00`000?l0oooo0?l000060?ooo`030000003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo00d0oooo00<0
o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000
3P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0o`000080oooo00<0003o0?ooo`3oool0
:@3oool002@0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`0V0?ooo`040000003o
ool0003o0?l000`0oooo00<0003o0?ooo`3oool0703oool01@000000oooo0?ooo`3oool0o`0001H0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0=0?ooo`030000o`3oool0oooo01L0
oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`160?ooo`030000003oool0oooo00H0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0000o`0M0?ooo`070000003oool0oooo0?oo
o`3o0000oooo0000o`070?ooo`030000o`3oool0o`0000H0oooo00<000000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`0`0?ooo`030000003oool0000000l0oooo00<0003o0?ooo`3oool00`3oool0
1@3o0000oooo0?ooo`3oool0003o02/0oooo000T0?ooo`800000B`3oool00`000000003o0?l0000<
0?ooo`030000o`3oool0oooo01`0oooo00D000000?ooo`3oool0oooo0?l0000F0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0:03oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo04H0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030?l00000
0?l0oooo01h0oooo00H000000?ooo`3oool0o`000?ooo`000?l70?ooo`030000o`3o0000oooo00H0
oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01d0
oooo0P3o000<0?ooo`030?l0003oool0oooo0340oooo00<000000?ooo`0000003`3oool00`000?l0
oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l0:`3oool002@0oooo00<000000?ooo`3o
ool0BP3oool010000000003o0?ooo`3o000:0?ooo`030000o`3oool0oooo01d0oooo00@000000?oo
o`3oool0o`005`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02T0oooo00<0o`00
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`170?ooo`030000003oool0oooo00H0oooo00<0003o
0?l0003oool00P3oool00`3o0000003o0?ooo`0N0?ooo`060000003oool0oooo0?ooo`3o0000003o
1`3oool00`000?l0o`000?ooo`060?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0O0?ooo`<0o`00203oool00`3o0000oooo0?ooo`0c0?ooo`030000
003oool0oooo00l0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0Y0?ooo`00903o
ool00`000000oooo0?ooo`1:0?ooo`040000003oool0003o0?l000X0oooo00D0003o0?ooo`3oool0
oooo0000000J0?ooo`050000003oool0oooo0?ooo`3o00005`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo02T0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`180?oo
o`030000003oool0oooo00H0oooo00L0003o0?l0003oool0oooo0?l0003oool0003o01l0oooo00H0
00000?ooo`3oool0oooo0?l000000?l60?ooo`030000o`3oool0o`0000L0oooo00<000000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0280oooo0`3o00050?ooo`03
0?l0003oool0oooo04D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0Y0?ooo`00
903oool00`000000oooo0?ooo`1;0?ooo`03000000000?l0o`0000T0oooo00@0003o0?ooo`3oool0
oooo0P00000J0?ooo`050000003oool0oooo0?ooo`3o00005`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo02X0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`180?oo
o`030000003oool0oooo00H0oooo00L0003o0?l0003oool0oooo0?l0003oool0003o0200oooo00H0
00000?ooo`3oool0o`000?ooo`000?l50?ooo`030000o`3o0000oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02D0oooo0`3o00000`3oool0
o`000?ooo`170?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0:@3oool002@0oooo
0P00001<0?ooo`04000000000?l0oooo0?l000P0oooo00H0003o0?ooo`3oool000000?ooo`00000J
0?ooo`040000003oool0oooo0?l001T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0[0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0B@3oool2000000P0oooo00H0
003o0?ooo`3oool0o`000?ooo`000?lP0?ooo`060000003oool0oooo0?ooo`3o0000003o1@3oool0
0`000?l0o`000?ooo`060?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0X0?ooo`030?l0003oool0oooo04L0oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`0Y0?ooo`00903oool00`000000oooo0?ooo`1<0?ooo`03000000000?l0o`00
00L0oooo00@0003o0?ooo`3oool000000`3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0
oooo0?l001T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0]0?ooo`030?l0003o
ool0oooo00H0oooo00<0o`000?ooo`3oool0B@3oool00`000000oooo0?ooo`070?ooo`060000o`3o
ool0oooo0?l0003oool0003o803oool01P000000oooo0?ooo`3oool0o`000000o`D0oooo00<0003o
0?l0003oool01P3oool00`000000oooo0?ooo`060?ooo`050000o`3oool0oooo0?ooo`000?l0M03o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo02T0oooo000A0?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`1<0?ooo`03000000000?l0
o`0000L0oooo00<0003o0?ooo`000000103oool00`000000oooo0?ooo`0F0?ooo`050000003oool0
oooo0?ooo`3o00006@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02h0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`1:0?ooo`030000003oool0oooo00L0oooo00D0
003o0?ooo`3oool0o`000000o`0R0?ooo`050000003oool0oooo0?l000000?l01@3oool00`000?l0
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00D0003o0?ooo`3oool0oooo0000o`1d0?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0:@3oool00100oooo00@000000?ooo`3o
ool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?l000050?ooo`030000o`3oool0000000D0oooo00<000000?ooo`3oool05P3oool0
10000000oooo0?ooo`3o000J0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0;P3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0340oooo0P0000040?ooo`030000003o
ool0oooo00<0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`070?ooo`050000o`3o
0000oooo0?l000000?l08P3oool01@000000oooo0?ooo`3oool0003o00D0oooo00<0003o0?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`050000o`3oool0oooo0?ooo`000?l0M03oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo02T0oooo000@0?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`3oool00P3oool2000004h0oooo00<000000?ooo`3o00001@3oool00`00
0?l000000?ooo`050?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool0o`006P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02l0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`0a0?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool01@000?l0
o`000?ooo`3o0000003o0280oooo00D000000?ooo`3oool0oooo0000o`050?ooo`030000o`3oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool01@000?l0oooo0?ooo`3oool0003o07D0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0Z0?ooo`00403oool010000000oooo0?ooo`00
000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0CP3oool00`000000o`000?oo
o`030?ooo`030000o`000000oooo00H0oooo00<000000?ooo`3oool05P3oool010000000oooo0?oo
o`3o000K0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<03oool0103o0000oooo
0?ooo`3o000d0?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool01@000?l0o`000?oo
o`3o0000003o02<0oooo00@000000?ooo`3oool0003o103oool00`000?l0oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00@0003o0?ooo`3oool0003oMP3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo02X0oooo000@0?ooo`040000003oool0oooo000000L0oooo100000050?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3o00000`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01@0oooo00@000000?ooo`3oool0o`00703oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0340oooo00<0o`000?ooo`3o0000=03oool010000000oooo0?ooo`00
00080?ooo`050000003oool0oooo0000003oool0100000050?ooo`<00000203oool010000?l0oooo
0?l000000?lS0?ooo`050000003oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`050?oo
o`030000003oool0oooo00P0oooo00@0003o0?ooo`3oool0003oMP3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo02X0oooo000@0?ooo`040000003oool0oooo000000L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0o`000080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo00/0oooo00@00000
0?ooo`3oool0o`00703oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03<0oooo00<0
o`000?ooo`3oool0<`3oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003o
ool00000203oool00`000000oooo0?ooo`080?ooo`040000o`3o0000oooo0000ob@0oooo00@00000
0?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00@0
003o0?ooo`3oool0003oMP3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo02X0oooo
000A0?ooo`800000203oool5000000@0oooo0P00001?0?ooo`060000o`000000o`000?ooo`000000
003o2P3oool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo00/0oooo00@000000?ooo`3o
ool0o`00703oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06T0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0203oool00`000?l0o`000000o`0U0?ooo`040000003oool0oooo0000o`80oooo
00<0o`000000o`3oool01@3oool00`000000oooo0?ooo`090?ooo`040000o`3oool0oooo0000ogH0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0Z0?ooo`00903oool00`000000oooo
0?ooo`1?0?ooo`040000003oool000000000o`/0oooo00<000000?ooo`3oool01@3oool00`3o0000
oooo0?l0000<0?ooo`030000003oool0o`0001d0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`1Z0?ooo`8000002P3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo00P0
oooo00<0003o0?l000000?l09@3oool020000000oooo0?ooo`000?l0o`000?ooo`3o0000003o1P3o
ool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0003o07H0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0Z0?ooo`00903oool00`000000oooo0?ooo`1?0?ooo`040000o`000000
o`000000o``0oooo00<000000?ooo`3oool0103oool0103o0000oooo0?ooo`3o000;0?ooo`030000
003oool0o`0001h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`230?ooo`030000
003oool0oooo00P0oooo00<0003o0?l000000?l09P3oool01`000000oooo0000o`3o0000oooo0?l0
00000?l01@3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0003o07H0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`0Z0?ooo`00903oool00`000000oooo0?ooo`1?0?ooo`03
0000o`3oool0003o00d0oooo00<000000?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0o`00
00T0oooo00@000000?ooo`3oool0o`007P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo08<0oooo0P0000090?ooo`030000o`3o0000003o02H0oooo00<000000?ooo`000?l00P3o0000
0`3oool0003o0?ooo`030?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`000?l0MP3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo02X0oooo000T0?ooo`800000D@3oool20000
o`030?l0003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo00H0oooo00<000000?ooo`3o00007`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo08<0oooo00<000000?ooo`3oool0203oool00`000?l0oooo0000o`0V0?oo
o`060000003oool0003o0?ooo`3o0000003o1@3oool00`000000oooo0?ooo`0<0?ooo`030000o`3o
ool0003o07L0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0Z0?ooo`00903oool0
0`000000oooo0?ooo`1@0?ooo`030000o`3oool0o`0000`0oooo00<000000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3o00007`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`0V0?ooo`050000003oool0003o0?ooo`000?l0103oool00`000000oooo0?oo
o`0=0?ooo`030000o`3oool0003o07L0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0Z0?ooo`00903oool00`000000oooo0?ooo`1C0?ooo`030?l0003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<00000
0?ooo`3o00007`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo08@0oooo00<00000
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0V0?ooo`050000003oool0003o0?ooo`000?l00`3o
ool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0003o07L0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0[0?ooo`00903oool00`000000oooo0?ooo`1C0?ooo`030?l0003oool0
oooo00X0oooo00D000000?ooo`3oool0oooo0?l000080?ooo`030?l0003oool0oooo00<0oooo00<0
00000?ooo`3o00008@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo08@0oooo00<0
00000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0V0?ooo`050000003oool0003o0?ooo`000?l0
0`3oool00`000000oooo0?ooo`0>0?ooo`80003oN03oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo02/0oooo000T0?ooo`030000003oool0oooo05<0oooo00<0o`000?ooo`3oool02P3o
ool01@000000oooo0?ooo`3oool0o`0000T0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo
0?l0000Q0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0Q03oool00`000000oooo
0?ooo`0c0?ooo`04000000000?l0oooo0000o`80oooo00<000000?ooo`3oool0403oool00`000?l0
oooo0?ooo`1f0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0:`3oool002@0oooo
0P00001E0?ooo`030?l0003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0?l0000:0?ooo`07
0?l0003oool0oooo0?ooo`000000oooo0?l0000Q0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0Q03oool2000003@0oooo00H000000000o`3oool0003o0?ooo`00000C0?ooo`030000
o`3oool0oooo07H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0[0?ooo`00903o
ool00`000000oooo0?ooo`1D0?ooo`030?l0003oool0oooo00T0oooo00@000000?ooo`3oool0o`00
2`3oool01P3o0000oooo0?ooo`000000oooo0?l002<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`240?ooo`030000003oool0oooo03<0oooo00H000000000o`3oool0003o0?ooo`00
000C0?ooo`030000o`3oool0oooo07H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`0[0?ooo`00903oool00`000000oooo0?ooo`1E0?ooo`030?l0003oool0oooo00T0oooo00<00000
0?ooo`3o0000303oool01@3o0000oooo0000003oool0o`0002<0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`240?ooo`030000003oool0oooo03@0oooo00@000000000o`3oool00000
503oool00`000?l0oooo0?ooo`1f0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
:`3oool002@0oooo00<000000?ooo`3oool0E@3oool00`3o0000oooo0?ooo`090?ooo`030000003o
0000oooo00d0oooo00@0o`000000003oool0o`00903oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo08D0oooo00<000000?ooo`3oool0=03oool010000000003o0?ooo`00002>0?ooo`05
0000o`3oool0oooo0?ooo`000?l0;@3oool002@0oooo0P00001F0?ooo`030?l0003oool0oooo00T0
oooo00<000000?l0003oool03@3oool00`000000o`000?l0000U0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0d0?ooo`03000000000?l0000008l0
oooo00D0003o0?ooo`3oool0oooo0000o`0]0?ooo`004@3oool2000000@0oooo00<000000?ooo`3o
ool00P3oool3000000D0oooo00<000000?ooo`3oool0EP3oool00`3o0000oooo0?ooo`080?ooo`03
0000003o0000oooo00d0oooo00<000000?ooo`3o00009P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo08D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2>0?ooo`05
0000o`3oool0oooo0?ooo`000?l0;@3oool00100oooo00@000000?ooo`3oool000001`3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0EP3oool00`3o0000oooo0?ooo`08
0?ooo`030?l000000000oooo00`0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo08D0oooo0P0000370?ooo`050000o`3oool0oooo0?ooo`000?l0;@3o
ool00100oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0E`3oool00`3o0000oooo0?ooo`070?ooo`030?l000000000oooo00`0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo08D0oooo
00<000000?ooo`3oool0aP3oool010000?l0oooo0?ooo`000?l^0?ooo`00403oool010000000oooo
0?ooo`0000070?ooo`@000001@3oool2000005P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
00000?ooo`0<0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`250?ooo`030000003oool0oooo0<H0oooo00@0003o0?ooo`3oool0003o;P3oool00100
oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
05L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0000000<0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1]0?ooo`800000103oool00`00
0000oooo0?ooo`030?ooo`8000000`3oool3000000D0oooo00<000000?ooo`3oool0aP3oool01000
0?l0oooo0?ooo`000?l^0?ooo`00403oool010000000oooo0?ooo`0000080?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0F03oool00`3o0000oooo0?ooo`050?ooo`040?l0003oool0
oooo000000/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo06`0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`370?ooo`030000o`3oool0003o
02h0oooo000A0?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool0F03oool00`3o0000
oooo0?ooo`040?ooo`050?l0003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0K03oool010000000oooo0?ooo`000008
0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`<00000
a`3oool00`000?l0oooo0000o`0^0?ooo`00903oool2000005X0oooo00<0o`000?ooo`3oool00`3o
ool01@3o0000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo06`0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000020?ooo`<000001@3oool00`000000oooo0?ooo`370?ooo`030000o`3oool0003o
02h0oooo000T0?ooo`030000003oool0oooo05T0oooo00<0o`000?ooo`3oool00`3oool01@3o0000
oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo06`0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`370?ooo`030000
o`3oool0003o02h0oooo000T0?ooo`030000003oool0oooo05T0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06`0oooo00@000000?ooo`3oool00000
203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`370?ooo`030000o`3oool0003o02h0oooo000T0?ooo`030000003oool0oooo05X0
oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06h0oooo0P00000:0?oo
o`8000000`3oool3000000D0oooo00<000000?ooo`3oool0a`3oool00`000?l0oooo0000o`0^0?oo
o`00903oool2000005/0oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool0a`3oool00`000?l0oooo0000o`0^0?ooo`00903oool00`000000
oooo0?ooo`1K0?ooo`030?l0003oool0o`0000H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0a0?ooo`050000003oool0oooo0?ooo`000000R@3oool200000<P0oooo0P000?l_0?oo
o`00903oool00`000000oooo0?ooo`1K0?ooo`030?l0003oool0o`0000H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0a0?ooo`050000003oool0oooo0?ooo`000000R@3oool00`00
0000oooo0?ooo`380?ooo`030000o`3oool0oooo02d0oooo000T0?ooo`030000003oool0oooo05/0
oooo00<0o`000?ooo`3o00001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0
oooo00@000000?ooo`3oool00000R@3oool00`000000oooo0?ooo`380?ooo`030000o`3oool0oooo
02d0oooo000T0?ooo`030000003oool0oooo05`0oooo00<0o`000?ooo`3oool01P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00@000000?ooo`3oool00000R@3oool00`00
0000oooo0?ooo`380?ooo`030000o`3oool0oooo02d0oooo000T0?ooo`800000IP3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo03D0oooo0P00002:0?ooo`030000003oool0oooo0<P0
oooo00<0003o0?ooo`3oool0;@3oool002@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03D0oooo0P00002:0?ooo`030000003oool0oooo0?P0oooo
000T0?ooo`030000003oool0oooo06H0oooo00D000000?ooo`3oool0oooo0000000h0?ooo`030000
003oool0oooo08P0oooo0P00003i0?ooo`00903oool00`000000oooo0?ooo`1V0?ooo`040000003o
ool0oooo00000<@0oooo00<000000?ooo`3oool0n03oool002@0oooo0P00001W0?ooo`040000003o
ool0oooo00000<@0oooo00<000000?ooo`3oool0n03oool00140oooo0P0000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1V0?ooo`030000003o
ool000000?l0oooo`@3oool00100oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo06H0oooo00<000000?ooo`000000o`3oooo10?ooo`00403oool0
10000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0I`3o
ool200000?l0oooo`@3oool00100oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?oo
o`030?ooo`800000J03oool00`000000oooo0?ooo`3o0?oool00oooo000@0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooool0oooo:`3o
ool00100oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0o`3ooooo0?ooob/0oooo000A0?ooo`800000203oool5000000@0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooob/0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3oool[
0?ooo`00o`3ooooo0?oooe80oooo003o0?ooool0ooooDP3oool00?l0ooooo`3ooomB0?ooo`00o`3o
oooo0?oooe80oooo003o0?ooool0ooooDP3oool00001\
\>"],
  ImageRangeCache->{{{0, 591}, {173.188, 0}} -> {-0.0545095, -0.0147151, \
0.00356856, 0.00356856}, {{15.25, 282.125}, {169.062, 4.0625}} -> {-30.7128, \
-0.0825842, 0.844719, 0.00478374}, {{308.812, 575.688}, {169.062, 4.0625}} -> \
{-303.899, -0.0486365, 0.889203, 0.000881724}}]
}, Closed]],

Cell["\<\
MigrationOrder\[Rule]MUS represents haploid migration\[Rule]random \
union of gametes\[Rule]selection\[Rule]meiosis.  For a single deme with \
immigration from a population fixed for '1' alleles, this is implemented \
by:\
\>", "Text"],

Cell[BoxData[
    \(\(\(\ \ \)\(NewGametes[
      MakeDiploid[
        MigrateExact[HaploidFrequencies[\[Psi], nd], \[Psi]s, {m, Nm}]], 
      W]\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(StoreExact[pp[MUS], \[Psi]0, 
        0.9\^Plus @@ \((#1 + #2)\) &, {0.05, 2}, {200, 10}, 
        DemeSize \[Rule] 
          ExponentialF[2, 0, 0.02]];\)\), "\[IndentingNewLine]", 
    \(\(gr[MUS];\)\)}], "Input",
  CellLabel->"In[49]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.0147151 0.784805 [
[.2619 .00222 -6 -9 ]
[.2619 .00222 6 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .0932 -18 -4.5 ]
[.01131 .0932 0 4.5 ]
[.01131 .17168 -18 -4.5 ]
[.01131 .17168 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .32864 -18 -4.5 ]
[.01131 .32864 0 4.5 ]
[.01131 .40712 -18 -4.5 ]
[.01131 .40712 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .56408 -18 -4.5 ]
[.01131 .56408 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(50)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(100)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(150)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(200)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .0932 m
.03006 .0932 L
s
[(0.1)] .01131 .0932 1 0 Mshowa
.02381 .17168 m
.03006 .17168 L
s
[(0.2)] .01131 .17168 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.3)] .01131 .25016 1 0 Mshowa
.02381 .32864 m
.03006 .32864 L
s
[(0.4)] .01131 .32864 1 0 Mshowa
.02381 .40712 m
.03006 .40712 L
s
[(0.5)] .01131 .40712 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.6)] .01131 .4856 1 0 Mshowa
.02381 .56408 m
.03006 .56408 L
s
[(0.7)] .01131 .56408 1 0 Mshowa
.125 Mabswid
.02381 .03041 m
.02756 .03041 L
s
.02381 .04611 m
.02756 .04611 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0775 m
.02756 .0775 L
s
.02381 .10889 m
.02756 .10889 L
s
.02381 .12459 m
.02756 .12459 L
s
.02381 .14028 m
.02756 .14028 L
s
.02381 .15598 m
.02756 .15598 L
s
.02381 .18737 m
.02756 .18737 L
s
.02381 .20307 m
.02756 .20307 L
s
.02381 .21876 m
.02756 .21876 L
s
.02381 .23446 m
.02756 .23446 L
s
.02381 .26585 m
.02756 .26585 L
s
.02381 .28155 m
.02756 .28155 L
s
.02381 .29724 m
.02756 .29724 L
s
.02381 .31294 m
.02756 .31294 L
s
.02381 .34433 m
.02756 .34433 L
s
.02381 .36003 m
.02756 .36003 L
s
.02381 .37573 m
.02756 .37573 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .42281 m
.02756 .42281 L
s
.02381 .43851 m
.02756 .43851 L
s
.02381 .45421 m
.02756 .45421 L
s
.02381 .4699 m
.02756 .4699 L
s
.02381 .50129 m
.02756 .50129 L
s
.02381 .51699 m
.02756 .51699 L
s
.02381 .53269 m
.02756 .53269 L
s
.02381 .54838 m
.02756 .54838 L
s
.02381 .57977 m
.02756 .57977 L
s
.02381 .59547 m
.02756 .59547 L
s
.02381 .61117 m
.02756 .61117 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .01472 m
.07143 .17629 L
.11905 .14167 L
.16667 .11859 L
.21429 .10705 L
.2619 .18783 L
.30952 .13804 L
.35714 .29171 L
.40476 .13013 L
.45238 .18783 L
.5 .21652 L
.54762 .18289 L
.59524 .10441 L
.64286 .234 L
.69048 .60332 L
.7381 .49681 L
.78571 .234 L
.83333 .20531 L
.88095 .28016 L
.92857 .26137 L
.97619 .22246 L
s
0 0 1 r
.02381 .01472 m
.07143 .0955 L
.11905 .15321 L
.16667 .10705 L
.21429 .07242 L
.2619 .02626 L
.30952 .16046 L
.35714 .13013 L
.40476 .13013 L
.45238 .29171 L
.5 .31743 L
.54762 .39591 L
.59524 .30621 L
.64286 .39558 L
.69048 .30325 L
.7381 .45196 L
.78571 .52253 L
.83333 .26137 L
.88095 .22246 L
.92857 .10441 L
.97619 .08396 L
s
0 0 0 r
.02381 .01472 m
.07143 .19938 L
.11905 .30325 L
.16667 .17629 L
.21429 .11859 L
.2619 .02626 L
.30952 .14925 L
.35714 .21092 L
.40476 .17629 L
.45238 .32633 L
.5 .36227 L
.54762 .295 L
.59524 .27258 L
.64286 .39558 L
.69048 .234 L
.7381 .14925 L
.78571 .17629 L
.83333 .17168 L
.88095 .21092 L
.92857 .20531 L
.97619 .16475 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.243046 3.59957 [
[.2619 .23055 -6 -9 ]
[.2619 .23055 6 0 ]
[.5 .23055 -9 -9 ]
[.5 .23055 9 0 ]
[.7381 .23055 -9 -9 ]
[.7381 .23055 9 0 ]
[.97619 .23055 -9 -9 ]
[.97619 .23055 9 0 ]
[.01131 .06307 -30 -4.5 ]
[.01131 .06307 0 4.5 ]
[.01131 .15306 -36 -4.5 ]
[.01131 .15306 0 4.5 ]
[.01131 .33304 -30 -4.5 ]
[.01131 .33304 0 4.5 ]
[.01131 .42302 -24 -4.5 ]
[.01131 .42302 0 4.5 ]
[.01131 .51301 -30 -4.5 ]
[.01131 .51301 0 4.5 ]
[.01131 .603 -18 -4.5 ]
[.01131 .603 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .24305 m
.2619 .2493 L
s
[(50)] .2619 .23055 0 1 Mshowa
.5 .24305 m
.5 .2493 L
s
[(100)] .5 .23055 0 1 Mshowa
.7381 .24305 m
.7381 .2493 L
s
[(150)] .7381 .23055 0 1 Mshowa
.97619 .24305 m
.97619 .2493 L
s
[(200)] .97619 .23055 0 1 Mshowa
.125 Mabswid
.07143 .24305 m
.07143 .2468 L
s
.11905 .24305 m
.11905 .2468 L
s
.16667 .24305 m
.16667 .2468 L
s
.21429 .24305 m
.21429 .2468 L
s
.30952 .24305 m
.30952 .2468 L
s
.35714 .24305 m
.35714 .2468 L
s
.40476 .24305 m
.40476 .2468 L
s
.45238 .24305 m
.45238 .2468 L
s
.54762 .24305 m
.54762 .2468 L
s
.59524 .24305 m
.59524 .2468 L
s
.64286 .24305 m
.64286 .2468 L
s
.69048 .24305 m
.69048 .2468 L
s
.78571 .24305 m
.78571 .2468 L
s
.83333 .24305 m
.83333 .2468 L
s
.88095 .24305 m
.88095 .2468 L
s
.92857 .24305 m
.92857 .2468 L
s
.25 Mabswid
0 .24305 m
1 .24305 L
s
.02381 .06307 m
.03006 .06307 L
s
[(-0.05)] .01131 .06307 1 0 Mshowa
.02381 .15306 m
.03006 .15306 L
s
[(-0.025)] .01131 .15306 1 0 Mshowa
.02381 .33304 m
.03006 .33304 L
s
[(0.025)] .01131 .33304 1 0 Mshowa
.02381 .42302 m
.03006 .42302 L
s
[(0.05)] .01131 .42302 1 0 Mshowa
.02381 .51301 m
.03006 .51301 L
s
[(0.075)] .01131 .51301 1 0 Mshowa
.02381 .603 m
.03006 .603 L
s
[(0.1)] .01131 .603 1 0 Mshowa
.125 Mabswid
.02381 .08107 m
.02756 .08107 L
s
.02381 .09906 m
.02756 .09906 L
s
.02381 .11706 m
.02756 .11706 L
s
.02381 .13506 m
.02756 .13506 L
s
.02381 .17105 m
.02756 .17105 L
s
.02381 .18905 m
.02756 .18905 L
s
.02381 .20705 m
.02756 .20705 L
s
.02381 .22505 m
.02756 .22505 L
s
.02381 .26104 m
.02756 .26104 L
s
.02381 .27904 m
.02756 .27904 L
s
.02381 .29704 m
.02756 .29704 L
s
.02381 .31504 m
.02756 .31504 L
s
.02381 .35103 m
.02756 .35103 L
s
.02381 .36903 m
.02756 .36903 L
s
.02381 .38703 m
.02756 .38703 L
s
.02381 .40503 m
.02756 .40503 L
s
.02381 .44102 m
.02756 .44102 L
s
.02381 .45902 m
.02756 .45902 L
s
.02381 .47702 m
.02756 .47702 L
s
.02381 .49502 m
.02756 .49502 L
s
.02381 .53101 m
.02756 .53101 L
s
.02381 .54901 m
.02756 .54901 L
s
.02381 .56701 m
.02756 .56701 L
s
.02381 .58501 m
.02756 .58501 L
s
.02381 .04507 m
.02756 .04507 L
s
.02381 .02707 m
.02756 .02707 L
s
.02381 .00907 m
.02756 .00907 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .24305 m
.07143 .38052 L
.11905 .46111 L
.16667 .29361 L
.21429 .37262 L
.2619 .28492 L
.30952 .34515 L
.35714 .4295 L
.40476 .43266 L
.45238 .60332 L
.5 .4547 L
.54762 .38464 L
.59524 .2967 L
.64286 .33864 L
.69048 .25648 L
.7381 .34962 L
.78571 .33469 L
.83333 .486 L
.88095 .50693 L
.92857 .16405 L
.97619 .48007 L
s
0 0 1 r
.02381 .24305 m
.07143 .38842 L
.11905 .5093 L
.16667 .41212 L
.21429 .50851 L
.2619 .28492 L
.30952 .40551 L
.35714 .29677 L
.40476 .45479 L
.45238 .46032 L
.5 .50537 L
.54762 .48525 L
.59524 .36676 L
.64286 .28492 L
.69048 .01472 L
.7381 .328 L
.78571 .51641 L
.83333 .37868 L
.88095 .36393 L
.92857 .38166 L
.97619 .43424 L
s
0 0 0 r
.02381 .24305 m
.07143 .42318 L
.11905 .54327 L
.16667 .31573 L
.21429 .42239 L
.2619 .29598 L
.30952 .43979 L
.35714 .32363 L
.40476 .29361 L
.45238 .4295 L
.5 .40178 L
.54762 .33993 L
.59524 .4234 L
.64286 .29598 L
.69048 .24384 L
.7381 .36378 L
.78571 .40106 L
.83333 .22218 L
.88095 .26991 L
.92857 .19386 L
.97619 .50377 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[49]:=",
  ImageSize->{641, 188.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:10000_2000`400?l00000o`00003oo`3ooooo
0?oooh<0oooo003o0?ooool0ooooP`3oool00?l0ooooo`3ooon30?ooo`00o`3ooooo0?oooh<0oooo
003o0?ooool0ooooP`3oool00?l0ooooo`3ooon30?ooo`00o`3ooooo0?oooh<0oooo001Q0?ooo`<0
0000103oool2000003D0oooo0`0000040?ooo`800000103oool200000340oooo0`0000030?ooo`<0
0000103oool200000340oooo1@0000030?ooo`800000103oool200000?l0ooooD`3oool00600oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000003D0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000340oooo00D0
00000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0;`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000o`3ooomB0?ooo`00I03oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000340oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000?l0ooooDP3oool006@0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000a0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0a0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0ooooD03oool00600oooo10000003
0?ooo`040000003oool0oooo000003D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000340oooo00@000000?ooo`3oool0oooo100000030?oo
o`040000003oool0oooo00000300oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000o`3ooomB0?ooo`00H03oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo000003@0oooo0P0000040?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000<03oool2000000<0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`00000`0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000?l0ooooDP3oool00600oooo1@0000030?ooo`80
0000=P3oool00`000000oooo0?ooo`030?ooo`800000103oool200000380oooo00@000000?ooo`3o
ool0oooo1@0000030?ooo`800000<P3oool3000000@0oooo0P0000040?ooo`800000o`3ooomC0?oo
o`009@3oool00`000000oooo0?ooo`3o0?ooool0ooooF`3oool002D0oooo00<000000?ooo`3oool0
o`3ooom>0?ooo`030000003oool0oooo0?l0oooo2P3oool002D0oooo00<000000?ooo`3oool0o`3o
oom>0?ooo`030000003oool0oooo0?l0oooo2P3oool002D0oooo00<000000?ooo`3oool0o`3ooom>
0?ooo`030000003oool0oooo0?l0oooo2P3oool001l0ooooo`00000A000004H0oooo0P00003o0?oo
o`/0oooo000U0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo0:H0oooo00<0003o0?ooo`3oool0H03oool002D0oooo
00<000000000o`3oool0?P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0:H0oooo
00<0003o0?ooo`3oool0H03oool002D0oooo0P00000o0?ooo`030000003oool0oooo0?l0oooo3@3o
ool00`000000oooo0?ooo`2V0?ooo`030000o`3oool0oooo0600oooo000U0?ooo`80000000<0003o
0?ooo`3oool0>`3oool00`000?l000000?ooo`3o0?ooo`h0oooo0P00002W0?ooo`030000o`3oool0
oooo0600oooo000U0?ooo`80000000<0oooo0000o`3oool0>P3oool010000?l000000?ooo`00003o
0?ooo`h0oooo00<000000?ooo`3oool0Y@3oool00`000?l0oooo0000o`1Q0?ooo`009@3oool20000
00030?l000000?l0oooo03T0oooo00D0003o0?ooo`000000oooo0000003o0?ooo`h0oooo00<00000
0?ooo`3oool0Y@3oool00`000?l0oooo0000o`1Q0?ooo`009@3oool01@000000oooo0000003oool0
003o03P0oooo00<0003o0?ooo`0000000P3oool00`000000oooo0?ooo`3o0?ooo``0oooo00<00000
0?ooo`3oool0Y@3oool00`000?l0oooo0000o`1Q0?ooo`009@3oool01@000000oooo0000003oool0
003o03L0oooo00@0003o0?ooo`3oool000000`3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<0
00000?ooo`3oool0Y@3oool00`000?l0oooo0000o`1Q0?ooo`009@3oool3000000030?l0003oool0
003o03D0oooo00@0003o0?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`/0oooo0P00
002V0?ooo`030000o`3oool0003o0640oooo000U0?ooo`040000003oool000000?l00080oooo00<0
003o0?ooo`3oool0<@3oool01@000?l0oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
o`3oool;0?ooo`030000003oool0oooo0:@0oooo00@0003o0?ooo`3oool0003oH@3oool002D0oooo
00@000000?ooo`3oool000000P3oool00`000?l0oooo0?ooo`0`0?ooo`050000o`3oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`3`0?ooo`800000103oool00`000000oooo0?ooo`030?oo
o`8000000`3oool3000000D0oooo00<000000?ooo`3oool0Y03oool010000?l0oooo0?ooo`000?mQ
0?ooo`009@3oool010000000oooo0?ooo`0000030?ooo`030000o`3oool0oooo02h0oooo00<0003o
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0>l0oooo00@00000
0?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`2T0?ooo`050000o`3oool0oooo0?ooo`000?l0H03oool002D0
oooo0P0000000`3oool000000?l000020?ooo`030000o`3oool0oooo02d0oooo00<0003o0?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`030000o`000000oooo0>P0oooo1@0000020?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`02
0?ooo`<00000Y03oool01@000?l0oooo0?ooo`3oool0003o0600oooo000U0?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000?l0oooo0?ooo`0[0?ooo`030000o`3oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`3^0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0:@0
oooo00D0003o0?ooo`3oool0oooo0000o`1P0?ooo`009@3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<0003o0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0kP3oool010000000oooo0?ooo`0000080?ooo`050000003oool0
oooo0000003oool0100000050?ooo`030000003oool0oooo0:@0oooo00D0003o0?ooo`3oool0oooo
0000o`1P0?ooo`009@3oool01P000000oooo0?ooo`3oool000000?l000<0oooo00<0003o0?ooo`3o
ool09`3oool20000o`D0oooo00<000000?ooo`3oool0203oool00`000?l000000?ooo`3^0?ooo`04
0000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`0000080?ooo`030000003o
ool0oooo0:<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1N0?ooo`009@3oool2
00000080oooo00<000000?l0003oool00`3oool00`000?l0oooo0?ooo`0U0?ooo`030000o`3oool0
oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3^0?ooo`8000002P3oool2
00000080oooo1@0000040?ooo`030000003oool0oooo0:<0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`1N0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<0003o0?ooo`3oool08`3oool20000o`L0oooo00<000000?ooo`3oool02P3oool00`00
0?l000000?ooo`3o0?ooo`P0oooo0P00002T0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0G@3oool00180oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0Q0?ooo`03
0000o`3oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000?l000000?ooo`2i0?ooo`80
003oC03oool00`000000oooo0?ooo`2S0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool0G@3oool00140oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00<000000?l0003oool0103oool00`000?l0oooo0?ooo`0N0?ooo`80
003o2@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0;D0oooo0`000?m>0?ooo`03
0000003oool0oooo0:<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1M0?ooo`00
4@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo0`0000020?ooo`03
0000003o0000oooo00@0oooo00<0003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`090?ooo`03
0000003oool0oooo00`0oooo00<0003o0000003oool0/P3oool30000oe40oooo00<000000?ooo`3o
ool0X`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo05d0oooo000A0?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<0003o0?ooo`3oool06`3oool00`000?l0oooo0?ooo`090?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0[`3oool20000oe@0oooo0P00002S0?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0G@3oool00140oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?l0003o
ool0103oool00`000?l0oooo0?ooo`0I0?ooo`80003o303oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0:`0oooo0`000?mF0?ooo`030000003oool0oooo0:80oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`1M0?ooo`004@3oool010000000oooo0?ooo`0000080?ooo`80
00001P3oool00`000000oooo0?ooo`030?ooo`030000003o0000oooo00D0oooo00<0003o0?ooo`3o
ool05`3oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00<0003o0000003o
ool0D@3oool00`3o0000oooo0?ooo`1G0?ooo`030000o`3oool0oooo05L0oooo00<000000?ooo`3o
ool0XP3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo05d0oooo000B0?ooo`800000
2P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?l0003oool0
1P3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo00P0oooo0`3o00000`3oool00000
0?ooo`0A0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0E`3oool00`000?l0oooo
0?ooo`1G0?ooo`030000003oool0oooo0:80oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`1L0?ooo`009@3oool2000000D0oooo00<000000?l0003oool01P3oool00`000?l0oooo0?oo
o`0C0?ooo`030000o`3oool0oooo00@0oooo1@3o00020?ooo`030?l000000000oooo0180oooo00<0
003o0000003oool0C`3oool00`3o0000oooo0?l0001G0?ooo`030000o`3oool0oooo05P0oooo00<0
00000?ooo`3oool0XP3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo05`0oooo000U
0?ooo`030000003oool0oooo00@0oooo00<000000?l0003oool01`3oool00`000?l0oooo0?ooo`0A
0?ooo`040000o`3oool0oooo0?ooo`@0o`00203oool00`000000oooo0?ooo`0A0?ooo`030000o`00
0000oooo04l0oooo00<0o`000?ooo`3o0000E`3oool00`000?l0oooo0?ooo`1H0?ooo`800000XP3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo05`0oooo000U0?ooo`030000003oool0
oooo00@0oooo00<000000?l0003oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0
o`000080o`002`3oool00`000000o`000?ooo`0C0?ooo`030000003oool0oooo04d0oooo00@0o`00
0?ooo`3oool0o`00E`3oool00`000?l0oooo0?ooo`1H0?ooo`030000003oool0oooo0:40oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1L0?ooo`009@3oool00`000000oooo0?ooo`04
0?ooo`030000003o0000oooo00P0oooo00<0003o0?ooo`3oool03P3oool00`000?l0o`000?l0000>
0?ooo`030000003oool0o`0001<0oooo00<0003o0000003oool0C03oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo05<0oooo00<0003o0?ooo`3oool0F@3oool00`000000oooo0?ooo`2Q
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0G03oool002D0oooo0P0000060?oo
o`030000003o0000oooo00P0oooo00<0003o0?ooo`3oool0303oool00`000?l0o`000?ooo`0>0?oo
o`050000003oool0oooo0?ooo`3o00004P3oool00`000?l000000?ooo`1<0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool0D`3oool00`000?l0oooo0?ooo`1I0?ooo`030000003oool0
oooo0:40oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1L0?ooo`009@3oool00`00
0000oooo0?ooo`050?ooo`030000003o0000oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000003o0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool04@3oool00`00
0?l000000?ooo`0<0?ooo`l0003o;`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
0580oooo00<0003o0?ooo`3oool0FP3oool200000:80oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`1L0?ooo`009@3oool00`000000oooo0?ooo`050?ooo`030000003o0000oooo00X0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000003o0?ooo`0?0?ooo`030000003oool0oooo00@0
oooo00<0o`000?ooo`3oool0403oool00`000?l000000?ooo`0;0?ooo`030000o`3oool0oooo00`0
oooo00<0003o0?ooo`3oool0;@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0540
oooo00<0003o0?ooo`3oool0FP3oool00`000000oooo0?ooo`2Q0?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool0F`3oool002D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?l0000;0?ooo`030000o`3oool0oooo00@0oooo0P3o00000`000?l0oooo0?ooo`0>0?ooo`030000
003oool0oooo00D0oooo00<0o`000?ooo`3oool0403oool00`000?l000000?ooo`090?ooo`80003o
3`3oool00`000?l0o`000?ooo`0/0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
D@3oool00`000?l0oooo0?ooo`0k0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000
0P3oool500000080oooo0`0000050?ooo`030000003oool0oooo0:00oooo00<0003o0?ooo`3oool0
203oool00`000?l0oooo0?ooo`1K0?ooo`009@3oool2000000L0oooo00<000000?l0003oool02P3o
ool00`000?l0oooo0?ooo`020?ooo`80o`0000<0oooo0000o`3oool0403oool00`000000oooo0?oo
o`060?ooo`030?l0003oool0oooo0100oooo00<0003o0000003o00001`3oool00`000?l0oooo0?oo
o`0>0?ooo`040?l0003oool0003o0?l002/0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`1@0?ooo`030000o`3oool0oooo03/0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0:00oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?oo
o`1K0?ooo`009@3oool00`000000oooo0?ooo`060?ooo`030000003o0000oooo00/0oooo00@0003o
0?ooo`3o0000o`000P3oool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00<0
o`000?ooo`3oool03`3oool00`000?l000000?l000050?ooo`80003o4@3oool01@3o0000oooo0000
o`3oool0o`0002X0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`1?0?ooo`030000
o`3oool0oooo03@0oooo1@0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0X03oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo05/0oooo000U0?ooo`03
0000003oool0oooo00H0oooo00<000000?l0003oool0303oool01@000?l0oooo0?ooo`3oool0003o
0140oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`000000o`00
00@0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0000o`020?ooo`030?l0003oool0oooo
02H0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`1>0?ooo`030000o`3oool0oooo
03`0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool300000:00oooo00<0003o0?ooo`3oool0203o
ool00`000?l0oooo0?ooo`1K0?ooo`009@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
o`0000X0oooo0P3o0000103oool0003o0?ooo`000?lA0?ooo`030000003oool0oooo00/0oooo00<0
o`000?ooo`3oool03@3oool01@3o0000oooo0000o`000000o`000080oooo00<0003o0?ooo`3oool0
4@3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`3o0000:03oool00`3o0000oooo0?ooo`080?oo
o`030?l0003oool0oooo01l0oooo0P00000]0?ooo`030000o`3oool0oooo03`0oooo00@000000?oo
o`3oool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000
0`0000050?ooo`030000003oool0oooo0:00oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo
0?ooo`1K0?ooo`009@3oool2000000P0oooo00<000000?l0003oool0203oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00l0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`060?l0003oool0oooo0000o`000000o`000P000?lD0?ooo`050?l0003oool0oooo0?oo
o`000?l00P3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?oo
o`3oool07P3oool010000000oooo00000000000[0?ooo`030000o`3oool0oooo03`0oooo00@00000
0?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`00
0000203oool00`000000oooo0?ooo`2P0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3o
ool0FP3oool002D0oooo00<000000?ooo`3oool01`3oool00`000000o`000?ooo`060?ooo`80o`00
5P3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00X0oooo00L0o`000?ooo`3oool0
oooo0000o`3oool0000001H0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0
oooo0280oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0M0?ooo`030000003oool0
oooo0080oooo0P00000X0?ooo`030000o`3oool0oooo03h0oooo0P00000:0?ooo`8000000`3oool3
00000080oooo1@0000040?ooo`030000003oool0oooo09l0oooo00<0003o0?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0c0?ooo`030?l0003oool0oooo02@0oooo000B0?ooo`800000103oool01000
0000oooo0?ooo`3oool5000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?l00005
0?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`08
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`000000503oool00`3o0000oooo0?ooo`03
0?ooo`050000o`3oool0oooo0?ooo`3o00008`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo01d0oooo00<000000?ooo`3oool0103oool2000002H0oooo00<0003o0?ooo`3oool0G@3o
ool00`000000oooo0?ooo`2O0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0<`3o
ool00`3o0000oooo0?ooo`0T0?ooo`004@3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0203oool00`000000o`000?ooo`030?ooo`030?l0
003oool0oooo01H0oooo00<000000?ooo`3oool0403oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0o`000000003oool04P3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0
003oool0oooo01/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0R0?ooo`030000
o`3oool0oooo0100oooo0P00001<0?ooo`800000X03oool00`000?l0oooo0?ooo`0:0?ooo`030000
o`3oool0oooo03<0oooo00<0o`000?ooo`3oool0903oool00140oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00@000000?l0003oool0
oooo0P3o000H0?ooo`030000003oool0oooo0180oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool000000180oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0J0?ooo`030000003oool0oooo00T0oooo0P00000R0?ooo`030000o`3oool0oooo00l0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`2O0?ooo`030000o`3oool0oooo00X0
oooo00<0003o0?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0T0?ooo`004@3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo0`0000080?ooo`040000003oool0o`000?l0
01T0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
00T0oooo00<0o`000000003oool04@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo
01X0oooo00<000000?ooo`3oool02`3oool2000000L0oooo2000000@0?ooo`030000o`3oool0oooo
00l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`2O0?ooo`030000o`3oool0oooo
00X0oooo00<0003o0?ooo`3oool0<`3oool20?l002D0oooo000A0?ooo`040000003oool0oooo0000
00L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3o00006@3oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool02P3oool00`3o0000oooo0000000@0?ooo`030?l0003oool0oooo008000000`3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0H0?ooo`030000003oool0oooo00h0oooo1`0000080?ooo`030000003oool0
oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo09h0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0b0?ooo`030?l0003oool0
o`0002D0oooo000A0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0F0?ooo`040?l0003oool0oooo0?l000d0oooo00@0o`000?ooo`3oool000003`3oool01@3o0000
oooo0000003oool0000000<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0J0?oo
o`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool0603oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`000000oooo0?ooo`1?0?oo
o`800000W`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo0340oooo00<0o`000?oo
o`3o00009@3oool00180oooo0P0000090?ooo`<000001@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?l0000?0?ooo`04
0?l0003oool0oooo000000h0oooo0P0000020?ooo`050000003oool0oooo0?ooo`000?l01`3oool0
0`3o0000oooo0?ooo`0G0?ooo`80o`004`3oool00`3o0000oooo0?ooo`0G0?ooo`030000003oool0
oooo0200oooo0P00000;0?ooo`030000o`3oool0oooo00`0oooo0P00001B0?ooo`030000003oool0
oooo09h0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0a0?ooo`030?l000000000
o`0002D0oooo000U0?ooo`8000002P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
01P0oooo00<0o`000?ooo`3oool03P3oool01@3o0000oooo0?ooo`3oool0000000`0oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0003o00L0oooo0P3o000F0?ooo`030?l0003o
ool0oooo01@0oooo00<0o`000?ooo`3oool05P3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02`3oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo09h0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0a0?ooo`030?l00000
0000o`0002D0oooo000U0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool01`3oool2
000000030?l0003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000o`090?ooo`030?l0003o
ool0oooo0140oooo0P3o000G0?ooo`030?l0003oool0oooo01D0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo00/0oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`0d0?ooo`<00000103oool200000340oooo0`0000040?ooo`800000103o
ool200000240oooo00<0003o0?ooo`3oool02@3oool3000000030000o`3oool0oooo00<00000103o
ool2000002P0oooo0P0000000`3o0000oooo00000004000000<0oooo0P0000040?ooo`800000503o
ool002D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo02/0oooo00D0o`000?ooo`3oool0oooo000000080?ooo`040000003oool0oooo0?l000D0oooo
00D000000?ooo`3oool0oooo0000o`0:0?ooo`80o`00403oool00`3o0000oooo0?ooo`0G0?ooo`03
0?l0003oool0oooo01@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00X0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0c0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000a0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000P0?ooo`030000
o`3oool0oooo00X0oooo00D000000?ooo`000?l0oooo000000030?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0903oool010000000o`000000003o00020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000C0?ooo`00
9@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
:`3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo0?l000060?ooo`040000003oool0oooo0000o``0oooo0P3o000<0?ooo`80o`006`3oool00`3o
0000oooo0?ooo`0C0?ooo`030000003oool0oooo02L0oooo0P0000050?ooo`030000o`3oool0oooo
00T0oooo00<000000?ooo`3oool0E@3oool2000003P0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00000O0?ooo`030000o`3oool0oooo00/0oooo00<000000?ooo`000?l0
1@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02@0oooo00D000000?l0003o
ool000000?l000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`00000C0?ooo`009@3oool2000000/0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P00
00030?ooo`030?l0003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000o`0=0?ooo`030?l0
003oool0oooo00P0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0B0?ooo`030000
003oool0oooo02X0oooo00D000000?ooo`3oool0oooo0000o`0;0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool0=`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000001l0oooo00<0003o0?ooo`3oool02`3oool010000000oooo0?ooo`000?l40?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool08`3oool01P000000o`000?ooo`3oool00000
0?l000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool04@3oool002D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo02d0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0000
00050?ooo`030?l0003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000o`0>0?ooo`80o`00
1`3oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo0180oooo00<000000?ooo`3oool0
7P3oool20?l000/0oooo00@000000?ooo`3oool0003o103oool7000005T0oooo00<000000?ooo`3o
ool0<`3oool4000000<0oooo00@000000?ooo`3oool00000<@3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000007`3oool00`000?l0oooo0?oo
o`0;0?ooo`040000003oool0oooo0000o`@000000`3oool010000000oooo0?ooo`00000U0?ooo`07
0000003o0000oooo0?ooo`000000o`00000000030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0A0?ooo`009@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0;@3oool00`3o0000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool010000000oooo0?oo
o`000?l@0?ooo`80o`000`3oool20?l00200oooo00<0o`000?ooo`3oool0403oool00`000000oooo
0?ooo`0N0?ooo`030?l0003oool0o`0000`0oooo1`00001P0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000`0?ooo`800000103oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000001l0oooo00<0003o0?ooo`3oool02P3oool2
00000080oooo00<0003o0000003oool01@3oool010000000oooo0?ooo`00000@0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3o00000P3oool00`000000o`00000000030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0A0?ooo`00
9@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
;P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00L0oooo00D000000?ooo`3oool0
oooo0000o`0A0?ooo`030?l0003oool0o`000280oooo00<0o`000?ooo`3oool0403oool00`000000
oooo0?ooo`0L0?ooo`80o`000`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo06<0
oooo0P00000d0?ooo`D000000`3oool200000380oooo00<000000?ooo`3oool00`3oool2000000@0
oooo0P00000P0?ooo`030000o`3oool0oooo00/0oooo00@000000?ooo`3oool0003o1@0000030?oo
o`8000004@3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0?l00080oooo00<00000
0?l0003oool00`0000040?ooo`800000103oool2000001@0oooo000U0?ooo`8000003@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo02l0oooo00<0o`000?ooo`3oool02@3oool00`3o
0000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`000?l04P3oool00`3o0000oooo0?ooo`0Q
0?ooo`030?l0003oool0oooo00l0oooo00<000000?ooo`3oool06`3oool20?l000H0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`1S0?ooo`030000003oool0oooo09d0oooo00<0003o
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0I0?ooo`8000004@3oool010000000oooo0?ooo`3o
00020?ooo`030000003o0000oooo02<0oooo000U0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0_0?ooo`030?l0003oool0oooo00T0oooo00<0o`00
0?ooo`3oool0203oool010000000oooo0?ooo`000?lg0?ooo`030?l0003oool0oooo00h0oooo00<0
00000?ooo`3oool06P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo0P00
0?lH0?ooo`80o`00C03oool00`000000oooo0?ooo`2L0?ooo`030000o`3oool0oooo00l0oooo00<0
003o0?ooo`3oool0603oool010000000oooo0?ooo`00000?0?ooo`050000003oool0oooo0?ooo`3o
00000P3oool00`000000o`000?ooo`0S0?ooo`009@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0<03oool00`3o0000oooo0?ooo`080?ooo`030?l0
003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000o`0f0?ooo`030?l0003oool0oooo00d0
oooo00<000000?ooo`3oool06@3oool20?l000X0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0G0?ooo`030?l0003oool0oooo04`0oooo00<000000?ooo`3oool0W03oool00`000?l0
oooo0?ooo`0?0?ooo`030000o`3oool0oooo01P0oooo00D000000?ooo`3oool0oooo0000000>0?oo
o`050000003oool0oooo0?ooo`3o00000`3oool00`000000o`000?ooo`0R0?ooo`009@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0<03oool00`3o
0000oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000o`0f
0?ooo`030?l0003oool0oooo00`0oooo00<000000?ooo`3oool0603oool20?l000d0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003oool0oooo04d0oooo00<00000
0?ooo`3oool0W03oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo01L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`3o0000103o
ool00`000000o`000?ooo`0R0?ooo`009@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0<P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00X0oooo00@000000?ooo`3oool0003o=`3oool00`3o0000oooo0?ooo`0;0?ooo`030000003o
ool0oooo01L0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo01L0oooo00<0o`000?ooo`3oool0B03ooonU000000030000o`00000000000100000000<0
003o000000000000;@0000000`3o0000000000000003000000030?l000000000000000d00000503o
ool002D0oooo0P00000?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0<P3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00X0oooo00@000000?ooo`3oool0003o=`3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool03`3o
ool0103o0000oooo0?ooo`000?lI0?ooo`030?l0003oool0oooo04l0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0000o`090?ooo`030000003oool0oooo00H0oooo00@0003o0?ooo`3oool0
00002`3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo00L0o`000?ooo`3oool000000?ooo`00
0000o`0000P0oooo00<000000?ooo`3oool0603oool00180oooo0P0000040?ooo`030000003oool0
oooo0080oooo0`0000050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0b0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool02`3oool0
1@000000oooo0?ooo`3oool0003o03H0oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?oo
o`0G0?ooo`030?l0003oool0oooo0100oooo0P000?lH0?ooo`80o`00DP3oool00`000000003o0?oo
o`2K0?ooo`030000o`3oool0oooo00L0oooo00<000000?ooo`0000001`3oool00`000?l0oooo0?oo
o`0F0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`030?ooo`030?l0003oool0oooo0080oooo00<000000?l0003oool08P3oool00140oooo00@00000
0?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03@0oooo00<0o`000?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`0<0?ooo`040000003oool0oooo0000ocH0oooo00<0o`000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?l0003o
ool05`3oool00`3o0000oooo0?ooo`1B0?ooo`800000W03oool00`000?l0oooo0?ooo`060?ooo`04
0000003oool0o`00000000L0oooo00<0003o0?ooo`3oool05P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?oo
o`030000003o0000oooo0280oooo000A0?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0=03oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00`0oooo00@000000?oo
o`3oool0003o=P3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo01P0oooo00<0o`00
0?ooo`3oool03P3oool010000?l0oooo0?ooo`3o000F0?ooo`030?l0003oool0oooo05<0oooo0P00
002L0?ooo`030000o`3oool0oooo00D0oooo00D000000?ooo`3oool0o`00000000070?ooo`030000
o`3oool0oooo01H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000000o`000?ooo`0Q0?ooo`004@3o
ool010000000oooo0?ooo`0000090?ooo`8000001@3oool300000100oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0d0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0
3@3oool01@000000oooo0?ooo`3oool0003o03D0oooo00<0o`000?ooo`3oool02@3oool00`000000
oooo0?ooo`0G0?ooo`030?l0003oool0oooo00h0oooo00D0003o0?ooo`3oool0oooo0?l0000E0?oo
o`030?l0003oool0oooo05@0oooo0P0000000`000?l0oooo0?ooo`2I0?ooo`030000o`3oool0oooo
00@0oooo00L000000?ooo`3oool0o`000?ooo`3o0000000000H0oooo00<0003o0?ooo`3oool05@3o
ool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000L0oooo00<0o`000?ooo`3oool0
0`3oool00`000000o`000?ooo`0Q0?ooo`004@3oool010000000oooo0?ooo`00000;0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo03H0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0>0?ooo`040000
003oool0oooo0000ocH0oooo00<0o`000?ooo`3oool0203oool00`000000oooo0?ooo`0G0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo05D0oooo0P0000000`000?l0oooo0?ooo`2I0?ooo`030000o`3oool0oooo00<0
oooo00P000000?ooo`3oool0oooo0?l0003oool0o`00000000L0oooo00<0003o0?ooo`3oool0503o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000H0oooo00<0o`000?ooo`3oool0103o
ool00`000000o`000?ooo`0Q0?ooo`004@3oool010000000oooo0?ooo`0000070?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00h0oooo
00@000000?ooo`3oool0003o=P3oool00`3o0000oooo0?ooo`070?ooo`030000003oool0oooo01P0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00l0
oooo00<0o`000?ooo`3oool0EP3oool00`000000oooo0000002K0?ooo`030000o`3oool0oooo0080
oooo00D000000?ooo`3oool0oooo0?l000030?ooo`030?l000000000oooo00D0oooo00<0003o0?oo
o`3oool0503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000000o`000?ooo`0Q0?ooo`004P3oool2000000T0oooo0`0000050?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0g0?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool03P3oool010000000oooo0?ooo`000?lf0?oo
o`030?l0003oool0oooo00L0oooo00<000000?ooo`3oool0603oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool03@3oool20?l005T0oooo00@000000?oo
o`000000003oV@3oool00`000?l0oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`3o0000103o
ool00`3o000000000?ooo`050?ooo`030000o`3oool0oooo01<0oooo00<000000?ooo`3oool05@3o
ool00`3o0000oooo0?ooo`040?ooo`030000003o0000oooo0240oooo000U0?ooo`8000004`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo03P0oooo00D0o`000?ooo`3oool0oooo0?l0
000A0?ooo`050000003oool0oooo0?ooo`000?l0=@3oool00`3o0000oooo0?ooo`070?ooo`030000
003oool0oooo01P0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00T0oooo0`3o001K0?ooo`<0000000<0003o0?ooo`3oool0U`3oool01@000?l0oooo
0?ooo`3oool0000000@0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000o`3oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`040?ooo`03
0000003o0000oooo0240oooo000U0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0h0?ooo`050?l0003oool0oooo0?ooo`3o00004P3oool010000000
oooo0?ooo`000?le0?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3oool0603oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01@3oool30?l0
05h0oooo00@000000?ooo`3oool00000>03oool00`000?l0oooo0?ooo`1N0?ooo`040000o`3oool0
oooo000000@0oooo00<0o`000?ooo`3oool0103oool00`3o000000000?ooo`040?ooo`030000o`3o
ool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`040?ooo`030000003o
0000oooo0240oooo000U0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0i0?ooo`050?l0003oool0oooo0?ooo`3o00004P3oool010000000oooo0?oo
o`000?lW0?ooo`800000303oool00`3o0000oooo0?ooo`060?ooo`030000003oool0oooo01P0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00<0oooo
0P3o001Q0?ooo`050000003oool0oooo000000000?l0=`3oool00`000?l0oooo0?ooo`1N0?ooo`03
0000o`3oool0000000D0oooo00<0o`000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`03
0000o`3oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`050?ooo`03
0000003o0000oooo0200oooo000U0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0j0?ooo`030?l0003oool0o`0001<0oooo00D000000?ooo`3oool0
oooo0000o`0T0?ooo`80000000<0oooo0000003oool02`3oool00`3o0000oooo0?ooo`060?ooo`03
0000003oool0oooo01P0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0o`000080o`00H`3oool01@000000oooo0?ooo`000000003o03H0oooo00<0o`000000
o`000?l0GP3oool00`000?l0oooo000000050?ooo`030?l0003oool0oooo00H0oooo00<0o`000000
003oool0103oool00`000?l0oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<0o`000?oo
o`3oool01@3oool00`000000o`000?ooo`0P0?ooo`009@3oool2000001D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0o`0001@0oooo00@000000?ooo`3o
ool0003o8P3oool2000000@0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?oo
o`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo06@0oooo0P0000000`3oool000000000o`0O0?ooo`030?l0003oool0oooo
01@0oooo00@0003o000000000?l0o`005@3oool00`000?l0oooo0?ooo`080?ooo`800000<03oool2
0?l000T0oooo00<0003o0000003oool01@3oool00`3o0000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00<0003o0?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0
oooo00H0oooo00<000000?l0003oool0803oool002D0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo03/0oooo00<0o`000?ooo`3o0000503oool01000
0000oooo0?ooo`000?lO0?ooo`<000001P3oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00@0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo0780oooo00H000000?ooo`3oool0oooo000000000?lN0?ooo`030?l0003oool0oooo01<0oooo
00H0o`000000o`000000003o0?ooo`3o000D0?ooo`030000o`3oool0oooo00H0oooo0P0000000`3o
ool000000?ooo`0_0?ooo`030?l0003oool0o`0000L0oooo00<0003o0?ooo`0000001@3oool00`3o
0000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool04@3oool00`00
0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo00H0oooo00<000000?l0003oool0803oool002D0
oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool0000003h0oooo00<0o`000?oo
o`3oool04`3oool01@000000oooo0?ooo`3oool0003o01`0oooo0P0000090?ooo`030000003oool0
oooo00X0oooo00<0o`000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool0LP3oool01P000000oooo0?ooo`3oool000000000oah0oooo
0P3o000D0?ooo`060?l000000000oooo000000000?l0o`004`3oool20000o`L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0/0?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool0
0`000?l0oooo000000050?ooo`030?l0003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool01P3oool0
0`000000o`000?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0E0?ooo`040000003oool0oooo
000003l0oooo00<0o`000?ooo`3oool0503oool00`000000oooo0?ooo`020000oaT0oooo0P00000<
0?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool0103oool00`000000oooo0?ooo`0H
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0LP3oool01P000000oooo0?ooo`3o
ool000000000oad0oooo00@0o`000?ooo`3oool0o`004P3oool0203o0000oooo0000003oool00000
0000o`3oool0o`004P3oool00`000?l0oooo0000o`040?ooo`8000001@3oool00`000000oooo0?oo
o`0/0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0000
00050?ooo`030?l0003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`0@0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool01P3oool00`000000o`000?oo
o`0P0?ooo`009@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0000005H0oooo00<00000
0?ooo`3oool00P3oool20000oaH0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`09
0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo07<0oooo00L000000?ooo`3oool0oooo0000003oool0003o01`0oooo
00@0o`000?ooo`3oool0o`004@3oool02P3o0000oooo0?ooo`000000oooo0000003oool0003o0?oo
o`3o000@0?ooo`040000o`3oool0oooo0000o`80oooo0P0000070?ooo`030000003oool0oooo02/0
oooo00<0o`000?ooo`3oool0103oool0103o0000oooo0?ooo`000?l20?ooo`030000003oool0oooo
0080oooo00<0o`000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0003o0180oooo00<00000
0?ooo`3oool05P3oool00`3o0000oooo0?ooo`060?ooo`030000003o0000oooo0200oooo000U0?oo
o`8000005`3oool00`000000oooo0000001F0?ooo`030000003oool0oooo00@0oooo0P000?lD0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`030?oo
o`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1c0?oo
o`8000000`3oool00`000000003o0?ooo`0K0?ooo`050?l000000000oooo0?ooo`3o0000403oool0
0`3o0000oooo000000030?ooo`05000000000?l0oooo0?ooo`3o00003`3oool01P000?l0oooo0?oo
o`000?l0oooo000000X0oooo00<000000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`050?ooo`05
0?l0003oool0003o0?ooo`0000001@3oool00`3o0000oooo0?ooo`0<0?ooo`050000003oool0oooo
0?ooo`000?l04P3oool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo00L0oooo00<00000
0?l0003oool07`3oool002D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo00D0oooo0P000?lA0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0203oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0003o0?oo
o`3oool0503oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo07<0oooo00<000000?oo
o`3oool00P3oool00`000000003o0?l0000J0?ooo`030?l0003oool000000080oooo00<0o`000?oo
o`3oool03@3oool0103o0000oooo0?ooo`0000030?ooo`05000000000?l0oooo0?ooo`3o00003`3o
ool00`000?l0oooo0?ooo`02000000/0oooo00<000000?ooo`3oool0:@3oool00`3o0000oooo0?oo
o`070?ooo`040000o`3oool0oooo000000@0oooo00<0o`000?ooo`3oool03@3oool00`000000o`00
0?ooo`020?ooo`030000o`3oool0oooo00l0oooo00<000000?ooo`3oool05P3oool00`3o0000oooo
0?ooo`070?ooo`030000003o0000oooo01l0oooo000U0?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00@0
003o0?ooo`3oool000002P3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo05@0oooo
0P0000040?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`D000000P3oool3000000D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0000o`0J0?ooo`040?l0003oool0000000000080
oooo00<0o`000?ooo`3oool0303oool0103o0000oooo0?ooo`0000030?ooo`030000003oool0003o
0080oooo00<0o`000?ooo`3oool02`3oool01P000?l0oooo0?ooo`000000oooo0000o`/0oooo00<0
00000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`070?ooo`040000o`3o0000oooo000000@0oooo
00<0o`000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0003o0100oooo00<000000?ooo`3o
ool05P3oool00`3o0000oooo0?ooo`080?ooo`030000003o0000oooo01l0oooo000U0?ooo`030000
003oool0oooo0700oooo00<000000?ooo`3oool0203oool20000o``0oooo00<000000?ooo`3oool0
3@3oool010000?l0oooo0?ooo`00000;0?ooo`050?l0003oool0oooo0?ooo`000000103oool20000
oaD0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`1C0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0003o01X0
oooo00@0o`000000003oool000000`3oool00`3o0000oooo0?ooo`0:0?ooo`050?l0003oool0oooo
000000000?l0103oool00`000000003o0?ooo`020?ooo`030?l0003oool0oooo00X0oooo00H0003o
0?ooo`3oool000000?ooo`000?l<0?ooo`030000003oool0oooo02L0oooo00<0o`000?ooo`3oool0
1`3oool010000?l0oooo0?ooo`0000040?ooo`030?l0003oool0oooo00l0oooo00D000000?l0003o
ool0oooo0000o`0@0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool0203oool00`00
0000o`000?ooo`0O0?ooo`009@3oool200000780oooo00<000000?ooo`3oool02@3oool20000o`X0
oooo00<000000?ooo`3oool0303oool00`000?l0oooo0000o`020?ooo`030000003oool0oooo00P0
oooo00D0o`000?ooo`3oool0oooo000000040?ooo`030000o`3oool0003o01@0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`1C0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0`00
00030?ooo`03000000000?l0o`0001T0oooo00D0o`000000003oool0oooo000000020?ooo`030?l0
003oool0oooo00X0oooo00D0o`000?ooo`3oool000000000o`040?ooo`03000000000?l0oooo00<0
oooo00<0o`000?ooo`3oool0203oool010000?l0oooo0?ooo`0000030?ooo`030000o`3oool0oooo
00T0oooo00<000000?ooo`3oool09`3oool00`3o0000oooo0?ooo`060?ooo`060000o`3oool0oooo
0?ooo`000000o`000P3oool00`3o0000oooo0?ooo`0A0?ooo`040000003oool0oooo0000oa00oooo
00<000000?ooo`3oool05P3oool00`3o0000oooo0?ooo`080?ooo`030000003o0000oooo01l0oooo
000U0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`060?ooo`030000003oool0oooo00d0oooo00<0003o0?ooo`000?l00P3oool00`000000oooo0?oo
o`080?ooo`040?l0003oool0oooo000000@0oooo00@0003o0?ooo`3oool0003o503oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo05@0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0003o01P0oooo00<0o`000?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0o`0000X0oooo00D0o`000?ooo`3oool000000000o`050?ooo`030000
003oool0003o00<0oooo00<0o`000?ooo`3oool0203oool010000?l0oooo0?ooo`0000030?ooo`03
0000o`3oool0oooo00T0oooo00<000000?ooo`3oool09P3oool00`3o0000oooo0?ooo`070?ooo`04
0000o`3oool0oooo00000080oooo00<0o`000?ooo`3o00004`3oool010000000o`000?ooo`000?l:
0?ooo`80o`00103oool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo00P0oooo00<00000
0?l0003oool07`3oool00180oooo0P0000040?ooo`030000003oool0oooo00<0oooo0`0000040?oo
o`030000003oool0oooo0740oooo00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?oo
o`030000003oool0oooo00d0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`030000003oool0
oooo00L0oooo00@0o`000?ooo`3oool00000103oool010000?l0oooo0?ooo`000?lD0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0E03oool010000000oooo0?ooo`0000080?ooo`06
0000003oool0oooo0000003oool000000`3oool00`000000oooo00000003000000D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0000o`0H0?ooo`030?l0003oool000000080oooo00<00000
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`050?l0003oool0oooo000000000?l01P3o
ool00`000000003o0?ooo`030?ooo`030?l0003oool0oooo00H0oooo00D0003o0?ooo`3oool0oooo
000000030?ooo`030000o`3oool0oooo00X0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00D0003o0?ooo`3oool0oooo000000030?ooo`03
0?l0003oool0oooo0180oooo00D000000?l0003oool0oooo0000o`060?ooo`<0o`0000<0oooo0?l0
003oool00P3oool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo00T0oooo00<000000?l0
003oool07P3oool00140oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0780oooo00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`040?oo
o`030000003oool0oooo00d0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`030000003oool0
oooo00L0oooo00@0o`000?ooo`3oool000000`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1D0?ooo`040000003o
ool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool00000
00P0oooo00<000000?ooo`3oool0103oool00`000000003o0?l0000G0?ooo`030?l0003oool00000
00<0oooo00D000000?ooo`3oool0oooo0?l000080?ooo`060?l0003oool0oooo0?ooo`000000003o
1P3oool00`000000oooo0000o`040?ooo`030?l0003oool0oooo00D0oooo00@0003o0?ooo`3oool0
0000103oool00`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`0000006@3oool01000
0000o`000?ooo`000?l30?ooo`<0o`00103oool01@3o0000oooo0?ooo`3oool0000001T0oooo00<0
o`000?ooo`3oool02@3oool00`000000o`000?ooo`0N0?ooo`004@3oool010000000oooo0?ooo`00
00070?ooo`D00000103oool300000780oooo0P00000<0?ooo`030000o`3oool0oooo00<0oooo00<0
00000?ooo`3oool03@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0000000T0oooo00@0
o`000?ooo`3oool000000`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1E0?ooo`8000002P3oool2000000<0oooo
0`0000020?ooo`D00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0003o01H0oooo
00<0o`000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo
00H0o`000?ooo`3oool000000?ooo`000?l60?ooo`030000003oool0003o00D0oooo00<0o`000?oo
o`3oool0103oool010000?l0oooo0?ooo`0000050?ooo`030000o`3oool0oooo00T0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo000000030?ooo`030?l0003oool0oooo00L0oooo00D0003o
0?ooo`3oool0oooo0000000J0?ooo`040000003o0000oooo0000o`<0o`00203oool0103o0000oooo
0?ooo`00000I0?ooo`030?l0003oool0oooo00T0oooo00<000000?l0003oool07P3oool00140oooo
00@000000?ooo`3oool000001`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
07@0oooo00<000000?ooo`3oool02P3oool01@000?l0oooo0?ooo`3oool000000100oooo00<0003o
0?ooo`3oool00`3oool010000?l0oooo0?ooo`0000080?ooo`030?l0003oool0000000<0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0M03oool2000000D0oooo00<000000?ooo`000?l05P3oool00`3o0000oooo0000
00050?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool01`3o0000oooo0?oo
o`3oool000000?ooo`000?l01`3oool00`000000003o0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo00@0003o0?ooo`3oool000001P3oool00`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo
01/0oooo00@000000?ooo`3oool000000`3oool00`3o0000oooo0?ooo`070?ooo`050000o`3oool0
oooo0?ooo`0000006`3oool00`000000o`000000o`0;0?ooo`040?l0003oool0oooo000001T0oooo
00<0o`000?ooo`3oool02@3oool00`000000o`000?ooo`0N0?ooo`004@3oool010000000oooo0?oo
o`0000080?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0M@3oool2000000/0oooo
00<0003o0?ooo`000000403oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0000000P0oooo
00<0o`000?ooo`0000000`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00l0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1e0?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`000?l0o`005@3oool00`3o0000oooo000000050?ooo`030000003oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03000000000?l0oooo00L0
oooo00<000000?ooo`000?l01@3oool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo0000
00H0oooo00<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3o00002@3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo
01T0oooo00@000000?ooo`3oool0003o2P3oool00`3o0000oooo0000000I0?ooo`030?l0003oool0
oooo00X0oooo00<000000?l0003oool07P3oool00140oooo00@000000?ooo`3oool000002@3oool2
000000D0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`080?ooo`030000o`3oool0
00000100oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo000000090?ooo`050?l000000000
oooo0?ooo`000?l01`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool0M@3oool00`000000oooo0?ooo`050?ooo`030000003oool0003o01D0oooo00<0
o`000?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o0000
0`3oool00`000000oooo0000o`080?ooo`030000003oool0003o00D0oooo00D0o`000?ooo`3oool0
oooo0000o`020?ooo`030000003oool0oooo00H0oooo00<0003o0?ooo`3oool02@3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo00<000000?l0003oool01`3oool00`000?l0
oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo00@000000?ooo`3oool0003o2`3oool00`3o
000000000?ooo`0H0?ooo`030?l0003oool0oooo00X0oooo00<000000?l0003oool07P3oool00180
oooo0P00000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0N03oool2000000T0
oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0000000P0
oooo00D000000?ooo`3oool0oooo0000o`070?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`1e0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`000?l0503oool0103o0000oooo0?ooo`0000060?ooo`030000003oool0oooo0080oooo00@0o`00
0?ooo`3oool0o`00103oool00`000000oooo0000o`090?ooo`030000003oool0003o00D0oooo00@0
o`000?ooo`3oool0003o0P3oool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo00X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo
00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`80000000<0003o0?ooo`3oool0
2@3oool00`3o000000000?ooo`0B0?ooo`<0003o0`3oool00`3o0000oooo0?ooo`0:0?ooo`030000
003o0000oooo01h0oooo000U0?ooo`800000N`3oool00`000000oooo0?ooo`050?ooo`0300000000
0?l0oooo00l0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo000000080?ooo`040000003o
ool0oooo0000o`T0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo07D0oooo00<000000?ooo`3oool01@3oool010000000oooo0000o`3o000C0?ooo`03
0?l0003oool0000000P0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?l000030?ooo`04
0000003oool0oooo0000o`T0oooo00<000000?ooo`000?l01P3oool00`3o0000003o0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00D0oooo00<0o`000000003oool01P3oool00`000?l0oooo0?ooo`020?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?oo
o`<0003o0`3oool30000o`030?l0003oool0oooo00/0oooo00<000000?l0003oool07@3oool002D0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`040?ooo`030000003oool0003o00h0
oooo00<0003o0?ooo`3oool02@3oool00`000?l000000?ooo`070?ooo`030000003oool0003o00X0
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo07D0
oooo0P0000060?ooo`040000003oool0oooo0000oa<0oooo00<0o`000?ooo`000000203oool00`00
0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`000?l02P3oool00`00
0000oooo0000o`060?ooo`050?l000000?l0oooo0?ooo`0000002P3oool00`000?l0oooo0?ooo`0:
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo00000007
0?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`08
0?ooo`030000003o0000oooo00`0oooo0`000?l90?ooo`80003o303oool00`000000o`000?ooo`0M
0?ooo`009@3oool00`000000oooo0?ooo`1l0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0
003o00`0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo000000060?ooo`040000003o0000
oooo0000o`X0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo07D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000o`0B0?ooo`040?l0003o
ool0oooo000000P0oooo00<000000?ooo`3oool0203oool00`000000oooo0000o`0;0?ooo`030000
003oool0003o00H0oooo00@0003o0?ooo`3oool000002P3oool00`000?l0oooo0?ooo`0:0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool0103o0000oooo0?ooo`0000050?oo
o`030000o`3oool0oooo00<0oooo00<000000?ooo`3oool07`3oool00`000?l000000?ooo`080?oo
o`030000003o0000oooo00T0oooo0`000?l<0?ooo`040?l0003oool0003o0000o`X0oooo00<00000
0?l0003oool07@3oool002D0oooo00<000000?ooo`3oool0OP3oool00`000000oooo000000040?oo
o`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`000?l000000?ooo`050?oo
o`030000003o0000003o00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo07H0oooo00<000000?ooo`3oool01P3oool010000000oooo0000o`3o000A
0?ooo`040?l0003oool0oooo000000T0oooo00<000000?ooo`3oool01P3oool010000000oooo0?oo
o`000?l;0?ooo`030000003oool0003o00D0oooo00@0003o0?l0003oool000002`3oool00`000?l0
oooo0?ooo`0:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool01@3o0000
oooo0?ooo`3oool0000000D0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`0P0?oo
o`030000o`3oool0000000P0oooo00<000000?l0003oool01`3oool20000o`l0oooo00@0o`000?oo
o`3oool0oooo0`000?l70?ooo`030000003o0000oooo01d0oooo000U0?ooo`800000P03oool00`00
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0303oool00`00
0?l0oooo000000050?ooo`030000003o0000003o00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo07H0oooo00<000000?ooo`3oool01P3oool01000
0000oooo0?ooo`000?lA0?ooo`040?l0003oool0oooo000000T0oooo00<000000?ooo`3oool01P3o
ool010000000oooo0?ooo`000?l;0?ooo`030000003oool0003o00D0oooo00@0003o0?ooo`3o0000
00002`3oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo008000001@3oool010000000
oooo0?ooo`3o00070?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`040?ooo`030000003o0000oooo01d0oooo000U0?ooo`030000003oool0oooo08H0
oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0=0?ooo`030000o`000000oooo00@0
oooo00<000000000o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool0MP3oool2000000L0oooo00D000000?ooo`3oool0003o0?l0000@0?oo
o`030?l0003oool0000000/0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000?l<
0?ooo`030000003oool0003o00<0oooo00D0003o0?ooo`3oool0o`000000000<0?ooo`030000o`3o
ool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`030?l0003o
ool0oooo00@0oooo00@000000?ooo`3oool0003o1@3oool00`000000oooo0?ooo`0Q0?ooo`050000
o`3oool0oooo0?ooo`000000103oool010000000oooo0?ooo`3o00060?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030000003o0000oooo
01d0oooo000U0?ooo`030000003oool0oooo08L0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`0>0?ooo`030000o`000000oooo00<0oooo00@000000?ooo`000?l0o`003@3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0MP3oool00`00
0000oooo0?ooo`070?ooo`040000003oool0003o0?l000l0oooo00@0o`000?ooo`3oool000002`3o
ool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0000o`d0oooo00<000000?ooo`000?l0
0`3oool01@000?l0oooo0?ooo`000000o`0000`0oooo00<0003o0?ooo`3oool02P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool010000000
oooo0?ooo`000?l40?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`000000oooo0?ooo`0L
0?ooo`009@3oool00`000000oooo0?ooo`280?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool03`3oool00`000?l000000?ooo`020?ooo`04000000000?l0oooo0?l000d0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo07H0oooo00<00000
0?ooo`3oool01`3oool01@000000oooo0?ooo`000?l0o`0000h0oooo00@0o`000?ooo`3oool00000
303oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000o`d0oooo00H000000?ooo`3o
ool0003o0?ooo`000?l30?ooo`030000003oool0o`0000/0oooo00<0003o0?ooo`3oool02`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0
0`000000003o0?ooo`040?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool00`3oool0
10000000oooo0?ooo`0000030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo00<000000?l0003oool0703o
ool002D0oooo0P0000290?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0403oool0
0`000?l000000?ooo`020?ooo`04000000000?l0oooo0?l000d0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo07L0oooo00<000000?ooo`3oool01`3o
ool01P000000oooo0?ooo`000?l0oooo0?l000d0oooo00@0o`000?ooo`3oool00000303oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000?l03P3oool01@000000oooo0000o`3o
ool0003o0080oooo00@000000?ooo`3oool0o`00303oool00`000?l0oooo0?ooo`0:0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000
00000?l0oooo00<0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`040?ooo`800000
103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`020?ooo`030000003o0000oooo01`0oooo000U0?ooo`030000003o
ool0oooo08T0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0A0?ooo`050000003o
ool0oooo000000000?l00P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1g0?ooo`030000003oool0oooo00P0oooo
00D000000?ooo`000?l0oooo0?l0000<0?ooo`050?l0003oool0oooo0?ooo`0000003@3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<0003o0?ooo`3oool0303oool01@000000oooo0000o`3o
ool0003o0080oooo00D000000?ooo`3oool0oooo0?l0000;0?ooo`030000o`3oool0oooo00X0oooo
00<000000?ooo`3oool0303oool2000000T0oooo00<0o`000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo
0?ooo`090?ooo`060000o`3oool0oooo0?ooo`000000o`007@3oool002D0oooo00<000000?ooo`3o
ool0R@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0180oooo00D0003o0000003o
ool000000000o`020?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo07L0oooo0P0000090?ooo`060000003oool0oooo
0000o`3oool0o`002`3oool0103o0000oooo0?ooo`00000>0?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000?l0oooo0?ooo`0<0?ooo`040000003oool0oooo0000o`<0oooo00D000000?oo
o`3oool0oooo0?l0000;0?ooo`030000o`3oool0oooo00/0oooo00<000000?ooo`3oool02@3oool2
000000X0oooo00<0o`000?ooo`3oool0203oool00`000?l000000?ooo`030?ooo`030000003oool0
oooo02@0oooo00<0003o0?ooo`3oool02P3oool01@3o0000oooo0?ooo`3oool0003o0140oooo00<0
o`000?ooo`3oool02P3oool01@000?l0oooo0?ooo`000000o`0001d0oooo000U0?ooo`030000003o
ool0oooo08X0oooo00D0003o0?ooo`3oool0oooo0000o`0E0?ooo`030000003oool0000000<0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0M`3oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000o`3o
ool0o`002`3oool0103o0000oooo0?ooo`0000040?ooo`030000o`3oool0oooo00L0oooo00@00000
0?ooo`3oool000000`3oool00`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0
00000?ooo`3oool01`3oool2000000/0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0000
00020?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool02P3oool0103o0000oooo0?oo
o`000?lA0?ooo`030?l0003oool0oooo00`0oooo00@0003o0?ooo`000000o`007@3oool002D0oooo
0P00002<0?ooo`030000o`3oool0003o01H0oooo0P0000001@000?l0oooo0?ooo`3oool0o`0000h0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo05h0
oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<000001@3oool00`000000
oooo0?ooo`080?ooo`070000003oool0oooo0?ooo`000?l0oooo0?l0000:0?ooo`040?l0003oool0
oooo000000@0oooo00<0003o0?ooo`3oool0203oool00`000000oooo000000030?ooo`030000o`3o
ool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`800000303o
ool00`3o0000oooo0?ooo`090?ooo`070000o`3oool0oooo0?ooo`000000oooo0000000W0?ooo`03
0000o`3oool0oooo00X0oooo00@0o`000?ooo`3oool0003o4@3oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`000000o`0001d0oooo000U0?ooo`030000003oool0oooo08/0oooo00<0003o0?ooo`00
0?l05`3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo05h0oooo00@000000?ooo`3o
ool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`090?ooo`060000003oool0oooo0000o`3oool0o`002@3oool01@3o0000
oooo0?ooo`3oool0000000<0oooo00<0003o0?ooo`000?l02@3oool00`000000oooo000000030?oo
o`030000o`3oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000070?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00`0oooo00<0o`000?ooo`3oool02@3oool01`000?l0oooo0?ooo`3oool000000?ooo`000000
:03oool00`000?l0oooo0?ooo`090?ooo`040?l0003oool0oooo0000oa40oooo00<0o`000?ooo`3o
ool03P3oool00`000?l000000?l0000L0?ooo`004P3oool2000000@0oooo00<000000?ooo`3oool0
0P3oool3000000D0oooo00<000000?ooo`3oool0S03oool00`000?l0oooo0?ooo`0L0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo05h0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo0080oooo0`0000090?ooo`040000003oool0oooo0000o`80oooo00<0o`00
0?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0000000<0oooo00<0003o0?ooo`000?l02P3o
ool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo00l0oooo00@000000?ooo`3oool00000
203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00/0oooo00@000000?ooo`3oool0
oooo0P00000>0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool00P3oool00`000000
oooo0?ooo`0W0?ooo`030000o`3oool0oooo00X0oooo00<0o`000000o`3oool04@3oool00`3o0000
oooo0?ooo`0?0?ooo`030000003o0000oooo01/0oooo000A0?ooo`040000003oool0oooo000000L0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0:/0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool0GP3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000?l0
0P3oool00`3o0000oooo0?ooo`050?ooo`040?l0003oool0oooo000000<0oooo00D0003o0?ooo`3o
ool0oooo0000o`0>0?ooo`030000o`3oool0oooo00l0oooo00<000000?ooo`0000002@3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00X0oooo00@000000?ooo`00000000003`3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo02d0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000003o0?ooo`0A0?ooo`030?l0003oool0oooo00l0oooo00<000000000o`3oool06`3oool0
0140oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0:/0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool0GP3oool010000000oooo0?ooo`0000080?ooo`050000003o
ool0oooo0000003oool0100000050?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool0
003o0P3oool00`3o0000oooo0?ooo`040?ooo`050?l0003oool0oooo0?ooo`0000000`3oool01@00
0?l0oooo0?ooo`3oool0003o00d0oooo00<0003o0?ooo`3oool0403oool00`000000oooo0000000:
0?ooo`L0o`000`3oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0]0?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0000o`3oool04@3oool00`3o0000oooo0?ooo`0?0?ooo`030000003o0000003o01/0oooo000A0?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool300000:/0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0GP3oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool0
0000203oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0000o`<0oooo00<0o`000?oo
o`3oool00`3oool01@3o0000oooo0?ooo`3oool000000080oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0140oooo0P00000A0?ooo`<0o`0000<0003o
0?l0003o0000703oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo02l0oooo00<0003o
0?ooo`3oool02@3oool00`000?l0o`000?ooo`0A0?ooo`030?l0003oool0oooo00l0oooo00@00000
0?l0003oool0003o6P3oool00140oooo00@000000?ooo`3oool000001`3oool4000000D0oooo00<0
00000?ooo`3oool0Z`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`1O0?ooo`8000002P3oool200000080oooo1@00
00040?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000o`020?ooo`030?l0
003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo000000020?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0A0?ooo`030000003oool0oooo01@0
oooo00<0003o0?l0003oool06P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo02l0
oooo00<0003o0?ooo`3oool02@3oool00`000?l0o`000?ooo`0@0?ooo`030?l0003oool0oooo0100
oooo00<000000?l0003oool06`3oool00140oooo00@000000?ooo`3oool000001`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0:/0oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0N@3oool2000000`0
oooo00@000000?ooo`3oool0003o0`3oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo
00000080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0
oooo02P0oooo00<0003o0?l0003oool06@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo02l0oooo00<0003o0?ooo`3oool02@3oool00`000?l0o`000?ooo`0@0?ooo`030?l0003oool0
oooo0100oooo00<000000?l0003oool06`3oool00180oooo0P0000080?ooo`D00000103oool00`00
0000oooo0?ooo`2[0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo07T0oooo00<000000?ooo`3oool02`3oool01@00
0000oooo0?ooo`3oool0003o0080oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`040000003o
ool0oooo0000o`L0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0Y0?ooo`030000
o`3oool0o`0001T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0`0?ooo`030000
o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0o`00403oool00`3o0000oooo0?ooo`0A0?ooo`03
0000003o0000oooo01X0oooo000U0?ooo`800000[@3oool00`3o0000oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1i0?ooo`030000
003oool0oooo00`0oooo00@000000?ooo`3oool0003o0`3oool0103o0000oooo0?ooo`3o00030?oo
o`030000003oool0003o00T0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0Z0?oo
o`030000o`3o0000oooo01L0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0a0?oo
o`030000o`3oool0oooo00L0oooo00@0003o0?ooo`3oool0o`00403oool00`3o0000oooo0?ooo`0A
0?ooo`030000003o0000oooo01X0oooo000U0?ooo`030000003oool0oooo0:`0oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool0N@3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo0000o`@0oooo00<0o`00
0?ooo`3o00000`3oool00`000000oooo0000o`090?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`3oool0:P3oool40000oaD0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0b
0?ooo`030000o`3oool0oooo00L0oooo00@0003o0?ooo`3oool0o`00403oool00`3o0000oooo0?oo
o`0A0?ooo`030000003o0000oooo01X0oooo000U0?ooo`030000003oool0oooo0:`0oooo00<0o`00
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0N@3oool2000000d0oooo00D000000?ooo`3oool0oooo0000o`030?ooo`80o`00103o
ool00`000000003o0?ooo`0:0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0;03o
ool00`3o0000oooo0000o`050000o`l0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0b0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0=0?ooo`030?l0003oool0oooo0140oooo00<000000?l0003oool06P3oool002D0oooo00<00000
0?ooo`3oool0[03oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo00d0oooo00@00000
0?ooo`3oool0003o103oool01`3o0000oooo0?ooo`3oool000000?ooo`000?l02`3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo02`0oooo00<0o`000?ooo`3oool01@3oool40000o`X0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0b0?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0140
oooo00<000000?l0003oool06P3oool002D0oooo0P00002]0?ooo`030?l0003oool0oooo00l0oooo
00D0003o0?ooo`3oool0oooo0?l0000=0?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3o
ool03@3oool01@000000oooo0?ooo`3oool0003o00L0oooo00<000000?ooo`000?l02`3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02d0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0=03oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0303oool00`3o
0000oooo0?ooo`0B0?ooo`030000003o0000oooo01X0oooo000U0?ooo`030000003oool0oooo0:`0
oooo00<0o`000?ooo`3oool03`3oool01@000?l0oooo0?ooo`3oool0o`0000d0oooo00<0003o0?oo
o`3oool0NP3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000?l01`3oool0
0`000000003o0?ooo`0<0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0;@3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0d0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo01<0oooo00<000000?ooo`3oool06@3oool0
02D0oooo00<000000?ooo`3oool0[03oool00`3o0000oooo0?ooo`0?0?ooo`050000o`3oool0oooo
0?ooo`3o00003@3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo00h0oooo00@00000
0?ooo`3oool0003o1`3oool00`000000003o0?ooo`0<0?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool0;P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0e0?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo01<0oooo00<0
00000?l0003oool06@3oool002D0oooo00<000000?ooo`3oool0[03oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0o`0000h0oooo00<0003o0?ooo`3oool0NP3oool2000000l0oooo00D00000
0?ooo`3oool0oooo0000o`060?ooo`030000003oool0oooo00d0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo03D0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool04`3o
ool00`000000o`000?ooo`0I0?ooo`009@3oool200000:h0oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?l0000>0?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool03`3oool0
10000000oooo0?ooo`000?l50?ooo`03000000000?l0oooo00h0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo00`0oooo0P000?l30?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool0=P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0C0?ooo`030000003o
0000oooo01T0oooo000U0?ooo`030000003oool0oooo0:d0oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?l0000=0?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool03`3oool0
10000000oooo0?ooo`000?l50?ooo`030000003oool0oooo00l0oooo00D0003o0?ooo`3oool0oooo
0000o`0a0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3o00003@3oool20000ocT0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`80o`002`3oool00`3o0000oooo
0?ooo`0C0?ooo`030000003oool0oooo01T0oooo000U0?ooo`030000003oool0oooo0:d0oooo00<0
o`000?ooo`3oool0403oool00`000?l0o`000?ooo`0<0?ooo`030000o`3oool0oooo07/0oooo00<0
00000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0003o00@0oooo00<000000?ooo`3oool0
3`3oool01@000?l0oooo0?ooo`3oool0003o0380oooo00<0o`000?ooo`3oool03P3oool00`000?l0
o`000?ooo`090?ooo`<0003o>`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00P0
oooo0`3o00080?ooo`030?l0003oool0oooo01<0oooo00<000000?ooo`3oool06@3oool002D0oooo
00<000000?ooo`3oool0[@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00/0oooo
00<0003o0?ooo`3oool0N`3oool200000140oooo00@000000?ooo`3oool0003o0`3oool00`000?l0
00000?ooo`0A0?ooo`040000o`3oool0oooo0000oc80oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`060?ooo`80003o?P3oool01@000?l0oooo0?ooo`3oool0003o00h0oooo0P3o0005
0?ooo`030?l0003oool0oooo01@0oooo00<000000?ooo`3oool06@3oool002D0oooo00<000000?oo
o`3oool0[@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?oo
o`3oool0N`3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000?l00P3oool0
0`000?l000000?ooo`0A0?ooo`040000o`3oool0oooo0000oc80oooo00<0o`000?ooo`3oool03P3o
ool00`3o0000oooo0000o`050?ooo`80003o@@3oool010000?l0oooo0?ooo`000?l@0?ooo`80o`00
0`3oool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo01P0oooo000U0?ooo`800000[P3o
ool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0003o00`0oooo00<0003o0?ooo`3oool0G03o
ool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo00<000000?ooo`3oool00P3o
ool3000000D0oooo00<000000?ooo`3oool04@3oool01`000000oooo0?ooo`000?l0oooo0000o`00
0000503oool00`000?l0oooo0000o`0c0?ooo`030?l0003oool0oooo00d0oooo00D0o`000?ooo`3o
ool0003o0?ooo`030000od<0oooo00@0003o0?ooo`3oool0003o4P3oool40?l001L0oooo00<00000
0?ooo`3oool0603oool00180oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000050?oo
o`030000003oool0oooo0:d0oooo00<0o`000?ooo`3oool0403oool0103o0000oooo0?ooo`000?l:
0?ooo`030000o`3oool0oooo05`0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0140oooo00L000000?ooo`3oool0003o0?ooo`000?l0000001@0oooo0P000?ld
0?ooo`030?l0003oool0oooo00d0oooo00D0o`000?ooo`3oool0oooo0000o`160?ooo`030000o`3o
ool0003o01H0oooo00<0o`000?ooo`3oool05@3oool00`000000oooo0?ooo`0H0?ooo`004@3oool0
10000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`2^0?ooo`030?l0003oool0oooo00l0oooo00@0o`000?ooo`3oool0003o2P3oool00`000?l0
oooo0?ooo`1L0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool0
1`000000oooo0?ooo`3oool0003o0?ooo`0000005@3oool00`000?l0oooo0?ooo`0b0?ooo`030?l0
003oool0oooo00`0oooo00<0o`000?ooo`3oool0B@3oool00`000?l0oooo0000o`190?ooo`004@3o
ool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`2^0?ooo`030?l0003oool0oooo00l0oooo00D0o`000?ooo`3oool0oooo0000o`090?oo
o`030000o`3oool0oooo05`0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool300000180oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo00`0oooo00<0
o`000?ooo`3oool0BP3oool20000odT0oooo000A0?ooo`040000003oool0oooo000000L0oooo1000
00050?ooo`<00000[P3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1L0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo00000003000000D0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04T0oooo00<0o`000?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`1:0?ooo`030000o`3oool0oooo04P0oooo000A0?ooo`040000
003oool0oooo000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2^0?ooo`03
0?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo05`0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`0B0?ooo`050000003o
ool0oooo0?ooo`000000C03oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo09H0oooo
000A0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`2^0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo05d0oooo0P00000:0?ooo`8000000P3oool5000000030?oo
o`000000000000<00000103oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo000004`0
oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`2F0?ooo`004P3oool2000000X0oooo
0P0000050?ooo`030000003oool0oooo0:h0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0O@3oool00`000000oooo
0?ooo`0C0?ooo`040000003oool0oooo000004d0oooo00<0o`000?ooo`3oool02@3oool00`3o0000
oooo0?ooo`2F0?ooo`009@3oool200000:l0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0O@3oool2000001D0oooo
00<000000?ooo`000000C@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo09L0oooo
000U0?ooo`030000003oool0oooo0:h0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0O@3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0000004d0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?oo
o`2G0?ooo`009@3oool00`000000oooo0?ooo`2_0?ooo`030?l0003oool0oooo00`0oooo00<0o`00
0?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool0003o07l0oooo00<000000?ooo`3oool0503o
ool2000004h0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`2G0?ooo`009@3oool0
0`000000oooo0?ooo`2_0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool0
10000?l0oooo0?ooo`000?mo0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0C@3o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo09P0oooo000U0?ooo`800000/03oool0
0`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`000?l0P03oool2
000006H0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`2H0?ooo`009@3oool00`00
0000oooo0?ooo`2_0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool20000
oh00oooo00<000000?ooo`3oool0I@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
09P0oooo000U0?ooo`030000003oool0oooo0:l0oooo00<0o`000?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo07h0oooo00<000000?ooo`3oool0IP3oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0oooo09T0oooo000U0?ooo`030000003oool0oooo0:l0oooo
00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`2>0?ooo`030000003oool0oooo06H0oooo
00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`2I0?ooo`009@3oool00`000000oooo0?oo
o`2_0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0S`3oool00`000000oooo0?oo
o`1V0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0V@3oool002D0oooo0P00002`
0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0S`3oool2000006L0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`2J0?ooo`009@3oool00`000000oooo0?ooo`2`0?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0T03oool00`000000oooo0?ooo`1W0?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0VP3oool002D0oooo00<000000?ooo`3o
ool0/03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0900oooo00<000000?ooo`3o
ool0I`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo09X0oooo000U0?ooo`030000
003oool0oooo0;00oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`2A0?ooo`030000
003oool0oooo06L0oooo00D0o`000?ooo`3oool0oooo0?l0002M0?ooo`009@3oool200000;40oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`2A0?ooo`800000J03oool01@3o0000oooo
0?ooo`3oool0o`0009d0oooo000U0?ooo`030000003oool0oooo0;00oooo00<0o`000?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`2B0?ooo`030000003oool0oooo06P0oooo00@0o`000?ooo`3oool0
o`00W@3oool00180oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2`0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
O`3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0
J03oool00`3o0000oooo0?l0002N0?ooo`004@3oool010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0/03oool00`3o0000oooo0?ooo`050?ooo`030?l0
003oool0oooo07h0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo06P0oooo00<0o`000?ooo`3o0000WP3oool00140oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`030?ooo`<00000/@3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo07l0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo06T0oooo0P3o002N0?ooo`004@3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0/@3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo07l0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`04
0?ooo`<00000J@3oool00`3o0000oooo0?ooo`2M0?ooo`004@3oool010000000oooo0?ooo`00000;
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0/@3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo0800oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0?l0oooo2P3oool00140oooo00@000000?ooo`3oool000001`3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0/@3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo0800oooo00@000000?ooo`3oool00000203oool2000000H0
oooo00<000000?ooo`3oool0o`3oool:0?ooo`004P3oool2000000P0oooo1@0000040?ooo`800000
/P3oool01@3o0000oooo0?ooo`3oool0o`0008@0oooo0P00000:0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0o`3oool:0?ooo`009@3oool00`000000oooo0?ooo`2a0?ooo`050?l0
003oool0oooo0?ooo`3o0000U`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo000U0?ooo`030000
003oool0oooo0;40oooo00@0o`000?ooo`3oool0o`00o`3ooonU0?ooo`009@3oool00`000000oooo
0?ooo`2a0?ooo`040?l0003oool0oooo0?l00?l0ooooY@3oool002D0oooo00<000000?ooo`3oool0
/P3oool00`3o0000oooo0?l0003o0?ooojD0oooo000U0?ooo`800000/`3oool20?l00?l0ooooYP3o
ool002D0oooo00<000000?ooo`3oool0/P3oool20?l00?l0ooooYP3oool002D0oooo00<000000?oo
o`3oool0/P3oool00`3o0000oooo0?ooo`3o0?ooojD0oooo000U0?ooo`030000003oool0oooo0?l0
ooooo`3ooomK0?ooo`009@3oool200000?l0ooooo`3ooomL0?ooo`009@3oool00`000000oooo0?oo
o`3o0?ooool0ooooF`3oool002D0oooo00<000000?ooo`3oool0o`3ooooo0?oooe/0oooo003o0?oo
ool0ooooP`3oool00?l0ooooo`3ooon30?ooo`00o`3ooooo0?oooh<0oooo003o0?ooool0ooooP`3o
ool00?l0ooooo`3ooon30?ooo`00\
\>"],
  ImageRangeCache->{{{0, 640}, {187.562, 0}} -> {-0.0544303, -0.0147182, \
0.0032951, 0.0032951}, {{16.5, 305.5}, {183.062, 4.4375}} -> {-29.3077, \
-0.0849305, 0.773386, 0.00469261}, {{334.438, 623.438}, {183.062, 4.4375}} -> \
{-310.252, -0.0843508, 0.830439, 0.00109859}}]
}, Closed]],

Cell["\<\
With strong selection (s=10% on each of 3 loci), this leads to a \
substantially higher equilibrium frequency than \
MigrationOrder\[Rule]UMS.\
\>", "Text"],

Cell["\<\
MigrationOrder\[Rule]USM represents random union of \
gametes\[Rule]selection\[Rule]diploid migration\[Rule]meiosis.  For a single \
deme with immigration from a population fixed for '1' alleles, this is \
implemented by:\
\>", "Text"],

Cell[BoxData[
    \(MigrateExact[
      NewGametes[MakeDiploid[HaploidFrequencies[\[Psi], nd]], 
        W], \[Psi]s, {m, Nm}]\)], "Input"],

Cell["\<\
Note that this really implements random union of \
gametes\[Rule]selection\[Rule]meiosis\[Rule]haploid migration.  However, the \
two are equivalent, since migration is a linear process.  With strong \
selection (s=10% on each of 3 loci), this leads to a slightly higher \
equilibrium frequency than MigrationOrder\[Rule]MUS, and stronger \
disequilibrium.  This is because the final step was migration, rather than \
selection:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(StoreExact[pp[USM], \[Psi]0, 
        0.9\^Plus @@ \((#1 + #2)\) &, {0.05, 2}, {200, 10}, 
        DemeSize \[Rule] ExponentialF[2, 0, 0.02]];\)\), "\n", 
    \(\(gr[USM];\)\)}], "Input",
  CellLabel->"In[51]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.0147151 0.633881 [
[.2619 .00222 -6 -9 ]
[.2619 .00222 6 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .14149 -18 -4.5 ]
[.01131 .14149 0 4.5 ]
[.01131 .26827 -18 -4.5 ]
[.01131 .26827 0 4.5 ]
[.01131 .39504 -18 -4.5 ]
[.01131 .39504 0 4.5 ]
[.01131 .52182 -18 -4.5 ]
[.01131 .52182 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(50)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(100)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(150)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(200)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .14149 m
.03006 .14149 L
s
[(0.2)] .01131 .14149 1 0 Mshowa
.02381 .26827 m
.03006 .26827 L
s
[(0.4)] .01131 .26827 1 0 Mshowa
.02381 .39504 m
.03006 .39504 L
s
[(0.6)] .01131 .39504 1 0 Mshowa
.02381 .52182 m
.03006 .52182 L
s
[(0.8)] .01131 .52182 1 0 Mshowa
.125 Mabswid
.02381 .04641 m
.02756 .04641 L
s
.02381 .0781 m
.02756 .0781 L
s
.02381 .1098 m
.02756 .1098 L
s
.02381 .17319 m
.02756 .17319 L
s
.02381 .20488 m
.02756 .20488 L
s
.02381 .23657 m
.02756 .23657 L
s
.02381 .29996 m
.02756 .29996 L
s
.02381 .33166 m
.02756 .33166 L
s
.02381 .36335 m
.02756 .36335 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45843 m
.02756 .45843 L
s
.02381 .49013 m
.02756 .49013 L
s
.02381 .55351 m
.02756 .55351 L
s
.02381 .58521 m
.02756 .58521 L
s
.02381 .6169 m
.02756 .6169 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .01472 m
.07143 .13244 L
.11905 .12338 L
.16667 .03283 L
.21429 .22299 L
.2619 .17771 L
.30952 .07065 L
.35714 .04188 L
.40476 .09861 L
.45238 .25016 L
.5 .27732 L
.54762 .20488 L
.59524 .19582 L
.64286 .22912 L
.69048 .33166 L
.7381 .3503 L
.78571 .52182 L
.83333 .55804 L
.88095 .53673 L
.92857 .55804 L
.97619 .60332 L
s
0 0 1 r
.02381 .01472 m
.07143 .08716 L
.11905 .04188 L
.16667 .13244 L
.21429 .31354 L
.2619 .25921 L
.30952 .16386 L
.35714 .20488 L
.40476 .21047 L
.45238 .27732 L
.5 .26827 L
.54762 .31354 L
.59524 .25016 L
.64286 .18251 L
.69048 .25016 L
.7381 .17319 L
.78571 .19582 L
.83333 .31354 L
.88095 .36894 L
.92857 .25016 L
.97619 .33166 L
s
0 0 0 r
.02381 .01472 m
.07143 .0781 L
.11905 .05094 L
.16667 .03283 L
.21429 .15055 L
.2619 .0781 L
.30952 .08929 L
.35714 .15055 L
.40476 .06132 L
.45238 .20488 L
.5 .34977 L
.54762 .4041 L
.59524 .25016 L
.64286 .17319 L
.69048 .17771 L
.7381 .22912 L
.78571 .35882 L
.83333 .28638 L
.88095 .38759 L
.92857 .38599 L
.97619 .36788 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.195202 3.06828 [
[.2619 .1827 -6 -9 ]
[.2619 .1827 6 0 ]
[.5 .1827 -9 -9 ]
[.5 .1827 9 0 ]
[.7381 .1827 -9 -9 ]
[.7381 .1827 9 0 ]
[.97619 .1827 -9 -9 ]
[.97619 .1827 9 0 ]
[.01131 .04179 -30 -4.5 ]
[.01131 .04179 0 4.5 ]
[.01131 .34862 -24 -4.5 ]
[.01131 .34862 0 4.5 ]
[.01131 .50203 -18 -4.5 ]
[.01131 .50203 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .1952 m
.2619 .20145 L
s
[(50)] .2619 .1827 0 1 Mshowa
.5 .1952 m
.5 .20145 L
s
[(100)] .5 .1827 0 1 Mshowa
.7381 .1952 m
.7381 .20145 L
s
[(150)] .7381 .1827 0 1 Mshowa
.97619 .1952 m
.97619 .20145 L
s
[(200)] .97619 .1827 0 1 Mshowa
.125 Mabswid
.07143 .1952 m
.07143 .19895 L
s
.11905 .1952 m
.11905 .19895 L
s
.16667 .1952 m
.16667 .19895 L
s
.21429 .1952 m
.21429 .19895 L
s
.30952 .1952 m
.30952 .19895 L
s
.35714 .1952 m
.35714 .19895 L
s
.40476 .1952 m
.40476 .19895 L
s
.45238 .1952 m
.45238 .19895 L
s
.54762 .1952 m
.54762 .19895 L
s
.59524 .1952 m
.59524 .19895 L
s
.64286 .1952 m
.64286 .19895 L
s
.69048 .1952 m
.69048 .19895 L
s
.78571 .1952 m
.78571 .19895 L
s
.83333 .1952 m
.83333 .19895 L
s
.88095 .1952 m
.88095 .19895 L
s
.92857 .1952 m
.92857 .19895 L
s
.25 Mabswid
0 .1952 m
1 .1952 L
s
.02381 .04179 m
.03006 .04179 L
s
[(-0.05)] .01131 .04179 1 0 Mshowa
.02381 .34862 m
.03006 .34862 L
s
[(0.05)] .01131 .34862 1 0 Mshowa
.02381 .50203 m
.03006 .50203 L
s
[(0.1)] .01131 .50203 1 0 Mshowa
.125 Mabswid
.02381 .07247 m
.02756 .07247 L
s
.02381 .10315 m
.02756 .10315 L
s
.02381 .13384 m
.02756 .13384 L
s
.02381 .16452 m
.02756 .16452 L
s
.02381 .22589 m
.02756 .22589 L
s
.02381 .25657 m
.02756 .25657 L
s
.02381 .28725 m
.02756 .28725 L
s
.02381 .31793 m
.02756 .31793 L
s
.02381 .3793 m
.02756 .3793 L
s
.02381 .40998 m
.02756 .40998 L
s
.02381 .44066 m
.02756 .44066 L
s
.02381 .47135 m
.02756 .47135 L
s
.02381 .01111 m
.02756 .01111 L
s
.02381 .53271 m
.02756 .53271 L
s
.02381 .5634 m
.02756 .5634 L
s
.02381 .59408 m
.02756 .59408 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .1952 m
.07143 .30701 L
.11905 .17233 L
.16667 .26762 L
.21429 .33559 L
.2619 .24221 L
.30952 .31373 L
.35714 .24412 L
.40476 .34269 L
.45238 .38324 L
.5 .30193 L
.54762 .42199 L
.59524 .17614 L
.64286 .60332 L
.69048 .41754 L
.7381 .28679 L
.78571 .1952 L
.83333 .3159 L
.88095 .36491 L
.92857 .13803 L
.97619 .30637 L
s
0 0 1 r
.02381 .1952 m
.07143 .2708 L
.11905 .25365 L
.16667 .2816 L
.21429 .28731 L
.2619 .3375 L
.30952 .25447 L
.35714 .21108 L
.40476 .25649 L
.45238 .4709 L
.5 .26953 L
.54762 .28858 L
.59524 .44295 L
.64286 .38983 L
.69048 .28414 L
.7381 .3703 L
.78571 .26635 L
.83333 .11897 L
.88095 .01472 L
.92857 .18885 L
.97619 .31908 L
s
0 0 0 r
.02381 .1952 m
.07143 .3375 L
.11905 .18758 L
.16667 .26762 L
.21429 .23649 L
.2619 .25301 L
.30952 .38377 L
.35714 .21744 L
.40476 .26187 L
.45238 .38641 L
.5 .3375 L
.54762 .18313 L
.59524 .16598 L
.64286 .40128 L
.69048 .34258 L
.7381 .38983 L
.78571 .24602 L
.83333 .09991 L
.88095 .04165 L
.92857 .36291 L
.97619 .2619 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[51]:=",
  ImageSize->{731, 215.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;K0000eb000`400?l00000o`00003oo`3ooooo
0?ooomd0oooo003o0?ooool0oooog@3oool00?l0ooooo`3ooooM0?ooo`00o`3ooooo0?ooomd0oooo
003o0?ooool0oooog@3oool00?l0ooooo`3ooooM0?ooo`00o`3ooooo0?ooomd0oooo001^0?ooo`<0
0000103oool2000003l0oooo0`0000040?ooo`800000103oool2000003/0oooo0`0000030?ooo`<0
0000103oool2000003/0oooo1@0000030?ooo`800000103oool200000?l0ooooPP3oool006d0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000003l0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003/0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0>@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000o`3ooon10?ooo`00L@3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000003/0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000?l0ooooP@3oool00740oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000k0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0k0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0ooooO`3oool006d0oooo10000003
0?ooo`040000003oool0oooo000003l0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000003/0oooo00@000000?ooo`3oool0oooo100000030?oo
o`040000003oool0oooo000003X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000o`3ooon10?ooo`00K@3oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo000003h0oooo0P0000040?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000>P3oool2000000<0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000?l0ooooP@3oool006d0oooo1@0000030?ooo`80
0000@03oool00`000000oooo0?ooo`030?ooo`800000103oool2000003`0oooo00@000000?ooo`3o
ool0oooo1@0000030?ooo`800000?03oool3000000@0oooo0P0000040?ooo`800000o`3ooon20?oo
o`00o`3ooonP0?ooo`030000003oool0oooo0?l0oooo>P3oool002P0oooo00<000000?ooo`3oool0
o`3ooome0?ooo`030000003oool0oooo0?l0oooo>P3oool002P0oooo00<000000?ooo`3oool0o`3o
oome0?ooo`030000003oool0oooo0?l0oooo>P3oool002P0oooo00<000000?ooo`3oool0o`3ooome
0?ooo`030000003oool0oooo0?l0oooo>P3oool002P0oooo00<000000?ooo`3oool0o`3ooome0?oo
o`800000o`3ooolk0?ooo`008@3ooooo000003/00000A03oool00`000000oooo0?ooo`3o0?ooo`03
0000o`3oool0oooo03L0oooo000X0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0?l0oooo00<0003o0?ooo`3oool0
=`3oool002P0oooo0P0000190?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0oP3o
ool20000ocT0oooo000X0?ooo`030000003o000000000?l0ooooM@3oool00`000000oooo0?ooo`3n
0?ooo`030000o`3oool0003o03P0oooo000X0?ooo`040000003o0000003o00000?l0ooooM03oool0
0`000000oooo0?ooo`3m0?ooo`040000o`3oool0oooo0000ocP0oooo000X0?ooo`040000003oool0
o`0000000?l0ooooFP3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`00
00060?ooo`030000003oool0oooo0?d0oooo00@0003o0?ooo`3oool0003o>03oool002P0oooo00D0
00000?ooo`3o0000oooo0000000W0?ooo`800000o`3oool_0?ooo`040000003oool0oooo000000P0
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0o@3oool010000?l0oooo0?ooo`000?lh0?ooo`00:03oool01P000000oooo0?ooo`3o
0000003o000002<0oooo0`0000000`3oool000000?ooo`3o0?ooobL0oooo1@0000020?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0?`0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0e0?oo
o`00:03oool01`000000oooo0?ooo`3o0000oooo0000o`000000803oool2000000<0oooo0P3o0000
0`000000oooo0?ooo`3o0?ooob`0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo00<0oooo0`00003l0?ooo`060000o`3oool0oooo0000003o
ool0003o=`3oool002P0oooo00@000000?ooo`3oool0o`000P3oool00`000000oooo0?ooo`0D0?oo
o`80003o1@3oool3000000D0oooo00<0o`000?ooo`000000>@3oool20?l00?80oooo00@000000?oo
o`3oool00000203oool01@000000oooo0?ooo`000000oooo00@000001P3oool00`000000oooo0?oo
o`3k0?ooo`070000o`3oool0oooo0?ooo`000000oooo0000o`0g0?ooo`00:03oool200000080oooo
00@0o`000?ooo`000?l00000503oool00`000?l0oooo0000o`030?ooo`8000001`3oool0103o0000
oooo0?ooo`00000g0?ooo`80o`0000<0oooo0?l0003oool0l@3oool010000000oooo0?ooo`000008
0?ooo`060000003oool0oooo0000003oool000002@3oool00`000000oooo0?ooo`3k0?ooo`030000
o`3oool0oooo008000000P3oool00`000?l0oooo0?ooo`0d0?ooo`00:03oool01@000000oooo0?oo
o`3oool0o`000080oooo00<0003o0000003oool04@3oool010000?l0oooo0?ooo`3oool3000000T0
oooo00D0o`000?ooo`3oool0o`000000000e0?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool0l03oool2000000X0oooo0P0000020?ooo`D000001@3oool00`000000oooo0?ooo`3j0?oo
o`060000o`3oool0oooo0000003oool000000P3oool00`000?l0oooo0?ooo`0d0?ooo`00:03oool0
0`000000oooo0?ooo`020?ooo`050?l0003oool0oooo0000o`000000403oool00`000?l0oooo0?oo
o`02000000030000o`3oool0oooo00P0oooo00H0o`000?ooo`3oool0oooo0?l00000000c0?ooo`80
o`001P3oool00`3o0000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0nP3oool00`000?l0
oooo000000030?ooo`030000003oool0003o03H0oooo000X0?ooo`030000003oool0oooo0080oooo
00D0o`000?ooo`3oool0003o0000000?0?ooo`040000o`3oool00000000000<0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`020?ooo`030?l000000000oooo02l0oooo0P3o00090?oo
o`030?l0003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`3i0?ooo`030000o`3oool00000
00@0oooo00<000000?ooo`000?l0=P3oool002P0oooo00<000000?ooo`3oool00P3oool01P3o0000
oooo0?ooo`3oool0003o000000d0oooo00<0003o0000000000001@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000000003oool0;P3oool00`3o0000oooo0?ooo`0:
0?ooo`030?l0003oool0oooo0?l0oooo203oool00`000000oooo0?ooo`3i0?ooo`030000o`000000
oooo00@0oooo00@000000?ooo`3oool0003o=@3oool002P0oooo00<000000?ooo`3oool00`3oool0
1P3o0000oooo0?ooo`000?l0oooo000000/0oooo0P0000080?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool0103oool00`3o000000000?ooo`0/0?ooo`80o`003P3oool00`3o0000oooo
0?ooo`070?ooo`030000003oool0oooo0?`0oooo00<000000?ooo`3oool0n03oool00`000?l0oooo
000000050?ooo`040000003oool0oooo0000ocD0oooo000X0?ooo`030000003oool0oooo00<0oooo
00L0o`000?ooo`3oool0oooo0000o`3oool0000000T0oooo00<000000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`000000:P3oool20?l0
0100oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo
0?P0oooo00<0003o0000003oool01@3oool010000000oooo0?ooo`000?le0?ooo`00:03oool00`00
0000oooo0?ooo`040?ooo`060?l0003oool0oooo0?ooo`000?l000001`3oool2000000`0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`030?l000000000oooo02P0oooo00<0
o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`050?ooo`030000003oool000000?d0oooo0P00
003i0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0003o=@3oool002P0oooo00<0
00000?ooo`3oool0103oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000000103oool200000003
0000o`3oool0oooo00`0oooo00D0003o0?ooo`3oool0oooo0?l000080?ooo`030?l0003oool00000
02L0oooo00<0o`000?ooo`3oool04`3oool00`3o0000oooo0?ooo`040?ooo`030000003oool00000
0?d0oooo00<000000?ooo`3oool0m`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo
0?ooo`000?l0=03oool002P0oooo00<000000?ooo`3oool01@3oool0203o0000oooo0?ooo`3oool0
003o0?ooo`000000oooo0P0000000`3oool0003o0?ooo`0>0?ooo`040000o`3oool0oooo0?l000T0
oooo00<0o`000?ooo`0000009`3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0080
oooo00@000000?ooo`3oool00000o@3oool00`000000oooo0?ooo`3f0?ooo`03000000000?l0oooo
00P0oooo00@000000?ooo`3oool0003o=03oool002P0oooo0P0000060?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`0000000P3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0o`00
00T0oooo00<0o`000?ooo`000000603oool3000000/0oooo00<0o`000?ooo`3oool05P3oool01@3o
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0nP3oool00`000000oooo0?ooo`3f
0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0003o=03oool002P0oooo00<00000
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l04P3o
ool00`000?l0o`000?ooo`0:0?ooo`030?l0003oool0000001L0oooo00<000000?ooo`3oool01000
00070?ooo`030?l0003oool0oooo01L0oooo00<0o`000?ooo`000000103oool00`000000oooo0?oo
o`3j0?ooo`030000003oool0oooo0?D0oooo00<000000000o`3oool02@3oool01@000000oooo0?oo
o`3oool0003o03<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0000o`0D0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`0000005P3o
ool00`000000oooo0?ooo`050?ooo`<000000`3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003o
ool0000000@0oooo00<000000?ooo`3oool0nP3oool00`000000oooo0?ooo`3d0?ooo`0300000000
0?l0oooo00X0oooo00D000000?ooo`3oool0oooo0000o`0c0?ooo`00:03oool00`000000oooo0?oo
o`060?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool04P3oool00`3o0000003o0?oo
o`0:0?ooo`040?l0003oool0oooo000001@0oooo00<000000?ooo`3oool02@3oool4000001/0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3i0?ooo`030000003oool0oooo0?<0oooo
00<000000?ooo`000?l02`3oool01@000000oooo0?ooo`3oool0003o03<0oooo000X0?ooo`030000
003oool0oooo00L0oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo0000o`0:0?ooo`040?l0
003oool0oooo000001@0oooo00<000000?ooo`3oool02`3oool0103o0000oooo00000000000H0?oo
o`030000003oool0o`0000D0oooo00<000000?ooo`3oool0n@3oool00`000000oooo0?ooo`3b0?oo
o`030000003oool0003o00`0oooo00D000000?ooo`3oool0oooo0000o`0c0?ooo`00:03oool00`00
0000oooo0?ooo`070?ooo`030?l0003oool0oooo01H0oooo00@0o`000?ooo`3oool0003o2`3oool0
103o0000oooo0?ooo`00000B0?ooo`030000003oool0oooo00`0oooo00@0o`000?ooo`3oool00000
603oool010000000oooo0?ooo`3o00040?ooo`030000003oool0oooo0?T0oooo00<000000?ooo`3o
ool0l@3oool010000000oooo0?ooo`000?l<0?ooo`030000003oool0oooo0080oooo00<0003o0?oo
o`3oool0<03oool002P0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0F0?ooo`05
0?l0003oool0oooo0?ooo`000?l02P3oool0103o0000oooo0?ooo`00000A0?ooo`030000003oool0
oooo00d0oooo00D0o`000?ooo`3oool0oooo0000000F0?ooo`030000003oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool00`000000oooo0?ooo`3h0?ooo`800000lP3oool00`000000oooo0000
o`0>0?ooo`050000003oool0oooo0?ooo`000?l0<P3oool002P0oooo00<000000?ooo`3oool0203o
ool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0203o
ool0103o0000oooo0?ooo`00000A0?ooo`030000003oool0oooo00`0oooo00<0o`000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00D0o`000?ooo`3oool0
oooo0000003j0?ooo`030000003oool0oooo0?00oooo00@000000?ooo`3oool0003o3P3oool01@00
0000oooo0?ooo`3oool0003o0380oooo000X0?ooo`030000003oool0oooo00P0oooo00<0o`000?oo
o`3oool04`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00L0oooo00D0o`000?oo
o`3oool0oooo0000000?0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool0103oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo0000
003j0?ooo`030000003oool0oooo0?00oooo00@000000?ooo`3oool0003o3P3oool01@000000oooo
0?ooo`3oool0003o0380oooo000X0?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool0
4P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00P0oooo00@0o`000?ooo`3oool0
00003P3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3o
ool0m`3oool00`000000oooo0?ooo`3`0?ooo`030000003oool0003o00l0oooo00<000000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0_0?ooo`00:03oool2000000X0oooo00<0o`000?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00D0o`000?ooo`3oool0
oooo0000000=0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool01P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo00D0o`000?ooo`3oool0oooo0000003i0?oo
o`030000003oool0oooo0>l0oooo00@000000?ooo`3oool0003o3`3oool00`000000oooo0?ooo`02
0?ooo`030000o`3oool0oooo02l0oooo000X0?ooo`030000003oool0oooo00T0oooo00<0o`000?oo
o`3oool04@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00D0o`000?oo
o`3oool0oooo0000000<0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool0203oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00D0o`000?ooo`3oool0oooo0000
003i0?ooo`030000003oool0oooo0>l0oooo00<000000?ooo`000?l0403oool00`000000oooo0?oo
o`020?ooo`030000o`3oool0oooo02l0oooo000X0?ooo`030000003oool0oooo00X0oooo00<0o`00
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00D0o`00
0?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool00P3o
ool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo0>l0oooo00<000000?ooo`000?l0403o
ool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo02l0oooo000X0?ooo`030000003oool0
oooo00X0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00H0oooo00D0o`000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00d0oooo00<0
o`000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00D0
o`000?ooo`3oool0oooo0000003h0?ooo`030000003oool0oooo0>h0oooo00<000000?ooo`000?l0
4P3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo02h0oooo000X0?ooo`030000003o
ool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool30?l000`0oooo00<0003o0?ooo`3oool01P3o
ool01@3o0000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool01@3o0000oooo
0?ooo`3oool000000?P0oooo00<000000?ooo`3oool0kP3oool00`000000oooo0000o`0B0?ooo`03
0000003oool0oooo0080oooo00<0003o0?ooo`3oool0;P3oool002P0oooo00<000000?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`060?ooo`D0o`00403oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030?l0
003oool0oooo0080oooo00<000000?ooo`3oool0m@3oool00`000000oooo0?ooo`3^0?ooo`030000
003oool0003o0180oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0^0?ooo`00:03o
ool00`000000oooo0?ooo`0;0?ooo`040?l0003oool0oooo0?ooo`D0o`005@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0;0?ooo`050?l0003oool0oooo0?ooo`000000m`3oool200000>h0oooo00<000000?ooo`00
0?l04`3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo02d0oooo000X0?ooo`030000
003oool0oooo00`0oooo0`3o000K0?ooo`030000o`3oool0oooo00D0oooo00D0o`000?ooo`3oool0
oooo000000060?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool03`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00D0o`000?ooo`3oool0oooo0000003g0?oo
o`030000003oool0oooo0>d0oooo00<000000?ooo`000?l04`3oool00`000000oooo0?ooo`030?oo
o`050000o`3oool0oooo0?ooo`3o0000:`3oool001@0oooo0P0000040?ooo`040000003oool0oooo
0?ooo`D000001@3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<0o`00
0?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<0o`00
0?ooo`3oool00P3oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo0>d0oooo00<00000
0?ooo`000?l04`3oool00`000000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o0000:`3o
ool001<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo02X0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0A0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool01@3o0000oooo0?ooo`3oool000000?H0
oooo00<000000?ooo`3oool0k03oool00`000000oooo0000o`0D0?ooo`030000003oool0oooo00<0
oooo00D0003o0?ooo`3oool0oooo0?l0000[0?ooo`004`3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00D0oooo0`00000[0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool00`3oool010000000oooo0?ooo`00000A0?ooo`030?l0003oool0oooo01<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`050?l0003oool0oooo0?ooo`000000mP3o
ool00`000000oooo0?ooo`3/0?ooo`030000003oool0003o01D0oooo00<000000?ooo`3oool00`3o
ool01@000?l0oooo0?l0003oool0o`0002X0oooo000C0?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool00P3oool010000000oooo0?ooo`00000A0?ooo`030?l0003oool0oooo01@0
oooo00@000000?ooo`3oool000004@3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo
0?<0oooo00<000000?ooo`3oool0k03oool00`000000oooo0000o`0E0?ooo`030000003oool0oooo
00<0oooo00D0003o0?ooo`3o0000oooo0?l0000Z0?ooo`004`3oool010000000oooo0?ooo`000007
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0[0?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0000000A0?ooo`030?l0003o
ool0oooo01H0oooo00<000000?ooo`0000004P3oool01@3o0000oooo0?ooo`3oool000000?D0oooo
00<000000?ooo`3oool0?`3oool3000000@0oooo0P00000l0?ooo`<00000103oool2000000@0oooo
0P00000i0?ooo`<000000`3oool3000000@0oooo0P00000@0?ooo`030000003oool0003o01H0oooo
00<000000?ooo`3oool00`3oool01@000?l0oooo0?l0003oool0o`0000@0oooo1@0000030?ooo`80
0000103oool2000001H0oooo000C0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`030000003oool0oooo02/0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<0o`000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0A0?ooo`050?l0003oool0oooo0?ooo`000000m@3oool00`000000oooo0?ooo`0n
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000l0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000i0?oo
o`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`000?l05P3oool00`000000oooo0?ooo`030?ooo`030000o`3o
ool0o`000080oooo00<0o`000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000005@3oool001@0oooo0P0000090?ooo`<0
00001P3oool00`000000oooo0?ooo`0/0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool05@3oool00`3o0000oooo0?ooo`0/0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3o
ool0lP3oool00`000000oooo0?ooo`120?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000>@3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool03@3oool00`000000oooo0000o`0F0?ooo`030000003oool0oooo00@0oooo
00D0003o0?l0003oool0oooo0?l000050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000E0?ooo`00:03oool00`000000oooo0?ooo`0/0?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`0]0?oo
o`050?l0003oool0oooo0?ooo`000000m03oool2000004<0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000D0?ooo`8000008`3oool00`000000oooo0?ooo`050?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0303oool00`000000oooo0000o`0G0?oo
o`030000003oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0?l000060?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01<0oooo
000X0?ooo`030000003oool0oooo02`0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`0C0?ooo`030?l0003oool0oooo02h0oooo00D0o`000?ooo`3oool0oooo0000003d0?ooo`030000
003oool0oooo03h0oooo100000030?ooo`040000003oool0oooo000003`0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000140oooo0`000000
0`3oool000000?ooo`0R0?ooo`040000003oool0oooo0?ooo`@000000`3oool010000000oooo0?oo
o`00000>0?ooo`030000003oool0003o01L0oooo00<000000?ooo`3oool0103oool00`000?l0oooo
0?ooo`020?ooo`040?l0003oool0oooo000000<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo01<0oooo000X0?ooo`030000003oool0oooo
02d0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo
00X0oooo0P000?lR0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool0l@3oool00`00
0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo0280oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`00000k0?ooo`800000103oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000l0oooo0P0000040?ooo`030000003oool0oooo0200oooo0P0000030?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0000o`0H0?ooo`03
0000003oool0oooo00<0oooo00<0o`000000o`3oool00P3oool0103o0000oooo0?ooo`0000030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0C0?ooo`00:03oool00`000000oooo0?ooo`0]0?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0003o0280oooo00D0o`00
0?ooo`3oool0oooo0000003c0?ooo`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool08P3o
ool5000000<0oooo0P00000m0?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`8000003P3o
ool2000000H0oooo00<000000?ooo`3oool08@3oool010000000oooo0?ooo`3oool5000000<0oooo
0P00000>0?ooo`030000003oool0003o01T0oooo00<000000?ooo`3oool00`3oool00`3o0000003o
0?ooo`020?ooo`040?l0003oool0oooo0?ooo`<00000103oool2000000@0oooo0P00000F0?ooo`00
:03oool00`000000oooo0?ooo`0]0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0:0?ooo`050000o`3oool0oooo0?ooo`000?l08@3oool01@3o0000
oooo0?ooo`3oool000000?<0oooo00<000000?ooo`3oool0603oool00`3o0000oooo0?l000230?oo
o`<00000203oool00`3o000000000?ooo`0m0?ooo`030000003oool0003o01T0oooo00<000000?oo
o`3oool00`3oool00`3o0000003o0?ooo`020?ooo`030?l0003oool0oooo02H0oooo000X0?ooo`80
0000;P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0k0?ooo`T000005@3oool20000oiD0oooo00<000000?ooo`3o
ool0603oool00`3o0000oooo0?l000210?ooo`8000002`3oool00`3o000000000?ooo`0m0?ooo`03
0000003oool0003o01T0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0000o`040?ooo`03
0?l0003oool0oooo02D0oooo000X0?ooo`030000003oool0oooo02h0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0N0?ooo`050?l0003oool0oooo0?ooo`000000?@3oool00`000000
oooo0?ooo`060?ooo`L000003P3oool010000?l0oooo0000o`000?nC0?ooo`030000003oool0oooo
01P0oooo00@0o`000?ooo`3oool0o`00O`3oool00`000000oooo0?ooo`0;0?ooo`030?l000000000
oooo03`0oooo00<000000?ooo`000?l06P3oool00`000000oooo0?ooo`020?ooo`040?l0003oool0
oooo0000o`<0oooo00<0o`000?ooo`3oool09@3oool002P0oooo00<000000?ooo`3oool0;P3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01d0oooo00D0o`000?ooo`3oool0oooo0000
000l0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`020?ooo`80003oT@3oool00`000000oooo0?ooo`0G0?ooo`050?l0003oool000000?ooo`3o0000
O`3oool00`000000oooo0?ooo`0:0?ooo`80o`0000<000000?ooo`3oool0>`3oool00`000000oooo
0000o`0J0?ooo`030000003oool0oooo0080oooo00@0o`000?ooo`3oool0003o0`3oool00`3o0000
oooo0?ooo`0U0?ooo`00:03oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00L0oooo
0P000?lM0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool0>03oool00`000000oooo
0000o`0?0?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool01@3oool30000ohh0oooo
00<000000?ooo`3oool05`3oool00`3o0000oooo000000020?ooo`030?l0003oool0oooo07`0oooo
00<000000?ooo`3oool02P3oool20?l000030000003oool0oooo03/0oooo00<000000?ooo`000?l0
6P3oool00`000000oooo0?ooo`020?ooo`040?l0003oool0oooo0000o`@0oooo00<0o`000?ooo`3o
ool0903oool002P0oooo00<000000?ooo`3oool0;P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`090?ooo`030000
o`3oool0oooo01X0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0003o0100oooo00<000000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`80003o
Q@3ooolQ000000030?l00000000000000080000000<0o`00000000000000R@0000000`3o00000000
0?l0000g000000030?l000000000000000@0000000<0003o0000000000007P0000001@3o00000000
000000000000003o00<0000000<0o`000000000000003`00000E0?ooo`00:03oool00`000000oooo
0?ooo`0_0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool06P3oool01@3o0000oooo
0?ooo`3oool0000003T0oooo00D000000?ooo`000?l0oooo0000o`0@0?ooo`030000003oool0oooo
00H0oooo00<0003o0?ooo`3oool02`3oool20000ohX0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`080?ooo`080?l0003oool000000000003oool000000?ooo`3o000:0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool2000000`0oooo00@0o`000000003o0000
00002`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0003o00L0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?l000<0oooo00<000000000
o`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo000X0?ooo`03
0000003oool0oooo02l0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0I0?ooo`03
0?l0003oool0oooo0080oooo00<000000?ooo`3oool0=P3oool00`000000003o0?ooo`020?ooo`03
0000o`3oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0=0?ooo`80
003oR03oool00`000000003o0?ooo`0F0?ooo`030?l0003oool000000080oooo00<000000?ooo`3o
00009P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool0103o0000oooo0?l00000000X0?ooo`030000003oool0oooo00X0oooo00<0o`000?oo
o`3o00000`3oool00`000000oooo0000o`0L0?ooo`040000003oool0oooo0?l000@0oooo00D0003o
0?ooo`3oool0oooo0?l000090?ooo`030000003oool0oooo01X0oooo000X0?ooo`030000003oool0
oooo02l0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0
oooo0080oooo00<000000?ooo`3oool0:03oool40?l000T0oooo00<000000000o`3oool0103oool0
0`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0403oool0
0`000?l0oooo0?ooo`250?ooo`80000000<0003o0?ooo`3oool0503oool00`3o0000oooo00000003
0?ooo`030000003oool0o`0007X0oooo00<000000?ooo`3oool02`3oool01@3o0000oooo0?ooo`3o
0000000003D0oooo00<0o`000?ooo`3o00000P3oool00`000000oooo0000o`0M0?ooo`040000003o
ool0oooo0?l000D0oooo00D0003o0?ooo`3oool0oooo0?l0000U0?ooo`00:03oool00`000000oooo
0?ooo`0_0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0603oool01@3o0000oooo
0?ooo`3oool0000002D0oooo1@3o00040?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`00
0?l01@3oool00`000?l0oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`000?l04`3oool00`00
0?l0oooo0?ooo`250?ooo`80000000<0003o0?ooo`3oool04`3oool00`3o0000oooo000000040?oo
o`030000003oool0o`0007X0oooo00<000000?ooo`3oool02`3oool01@3o0000oooo0?ooo`3o0000
000003@0oooo00@0o`000?ooo`3oool0o`000P3oool00`000000oooo0000o`0M0?ooo`040000003o
ool0oooo0?l000D0oooo00D0003o0?ooo`3oool0oooo0?l0000U0?ooo`00:03oool00`000000oooo
0?ooo`0`0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo
0?ooo`020?ooo`030000003oool0oooo01d0oooo1@3o000:0?ooo`030?l0003oool0oooo00@0oooo
00<000000000o`3oool01P3oool00`000?l0oooo0?ooo`0?0?ooo`040000003oool0oooo0000oa@0
oooo00<0003o0?ooo`3oool0Q03oool2000000030?l000000?l0oooo01<0oooo00<0o`000?ooo`00
00001@3oool00`000000oooo0?l000100?ooo`<0003o=P3oool00`000000oooo0?ooo`0;0?ooo`06
0?l0003oool0oooo0?l0003oool00000<`3oool02@3o0000oooo0?ooo`3oool0o`000?ooo`000000
oooo0000o`0M0?ooo`040000003oool0oooo0?l000D0oooo00D0003o0?ooo`3oool0oooo0?l0000U
0?ooo`00:03oool200000340oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool04P3oool50000oa@0oooo00<0o`000?oo
o`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`<0o`00403oool20?l000<0oooo00<000000000
o`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`03000000000?l0oooo01@0oooo00<0003o0?oo
o`3oool0Q03oool010000000oooo000000000?lD0?ooo`030?l0003oool0000000H0oooo00<00000
0?l0003oool0?P3oool01@000?l0oooo0?ooo`3oool0003o03@0oooo00<000000?ooo`3oool0303o
ool01P3o0000oooo0?ooo`3o0000oooo00000380oooo00<0o`000?ooo`3oool00P3oool0103o0000
00000?ooo`000?lN0?ooo`030000003oool0o`0000L0oooo00D0003o0?ooo`3oool0oooo0?l0000T
0?ooo`00:03oool00`000000oooo0?ooo`0`0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo01P0oooo1`000?l>0?oo
o`050?l0003oool0oooo0?ooo`000000703oool00`3o0000oooo0?ooo`0B0?ooo`050?l0003oool0
00000?ooo`000?l02@3oool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<0
003o0?ooo`3oool0Q03oool01@000000oooo0000003o0000003o0180oooo00<0o`000?ooo`000000
1`3oool00`000000oooo0?l0000m0?ooo`030000o`3oool0oooo0080000000<0oooo0000o`3oool0
<P3oool00`000000oooo0?ooo`0<0?ooo`060?l0003oool0oooo0?l0003oool00000<P3oool00`3o
0000oooo0?ooo`030?ooo`030000003oool0003o01l0oooo00<000000?l0003oool01P3oool01@00
0?l0oooo0?ooo`3oool0o`0002@0oooo000X0?ooo`030000003oool0oooo0300oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0100oooo00<0003o0?oo
o`3oool07`3oool40000o`X0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?oo
o`030?l0003oool0oooo01@0oooo00<0o`00000000000?l02`3oool00`000?l0oooo0?ooo`0>0?oo
o`030000o`000000oooo01D0oooo00<0003o0?ooo`3oool0P`3oool01P000000oooo0000003o0000
oooo0000oa40oooo00<0o`000?ooo`000000203oool00`000000oooo0?l0000k0?ooo`090000o`3o
ool0oooo0?ooo`000000oooo0000003oool0003o0380oooo00<000000?ooo`3oool02`3oool01`3o
0000oooo0?ooo`3oool0o`000?ooo`000000<@3oool00`3o0000oooo0?ooo`040?ooo`030000003o
ool0003o01l0oooo00<000000?l0003oool01`3oool010000?l0oooo0?ooo`3o000T0?ooo`00:03o
ool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo
0?l0000B0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`020?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool05@3oool00`000000003o
0?l0000<0?ooo`030000o`3oool0oooo00`0oooo00@0003o0?ooo`3oool000005@3oool00`000?l0
oooo0?ooo`230?ooo`80000000@0oooo0000003o0000003o4@3oool00`3o0000oooo000000090?oo
o`030000003o0000oooo03T0oooo00<0003o0?ooo`3oool00P3oool01P000000oooo0?ooo`000000
oooo0000oc00oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`020?ooo`030?l00000
0000oooo0300oooo00<0o`000?ooo`3oool00`3oool00`000000o`000000o`0P0?ooo`030000003o
0000oooo00L0oooo00D0003o0?ooo`3oool0oooo0?l0000S0?ooo`00:03oool00`000000oooo0?oo
o`0a0?ooo`030000o`3oool0oooo00@0oooo00@0o`000?ooo`3oool0o`004`3oool00`000?l0oooo
0?ooo`0T0?ooo`030000o`3oool0oooo00P0oooo00D0o`000?ooo`3oool0oooo0000000I0?ooo`03
0?l0003oool0oooo01D0oooo00@000000?ooo`3oool0o`00303oool00`000?l0oooo0?ooo`0;0?oo
o`050000o`3oool0oooo0?ooo`0000005@3oool00`000?l0oooo0?ooo`220?ooo`070000003oool0
oooo0000003o0000oooo0000o`0?0?ooo`030?l0003oool0000000X0oooo00<000000?ooo`3o0000
>03oool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`000?l0
;`3oool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`000000
;`3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0003o0200oooo00<000000?l0003oool0
1`3oool01@000?l0oooo0?ooo`3oool0o`0002<0oooo000X0?ooo`030000003oool0oooo0340oooo
00<0003o0?ooo`3oool01@3oool20?l001<0oooo00<0003o0?ooo`3oool09P3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool05@3oool00`3o0000oooo
0?ooo`0E0?ooo`03000000000?l0oooo0080oooo0P3o000:0?ooo`030000o`3oool0oooo00X0oooo
00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`0B0?ooo`030000o`3oool0oooo0880oooo
00L000000?ooo`3oool000000?l0003oool0003o00l0oooo00<0o`000?ooo`0000002`3oool00`00
0000o`000?ooo`0f0?ooo`030000o`3oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0000o`0^0?ooo`030000003oool0oooo00`0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0000000_0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`000?l0803oool00`00
0000oooo0?ooo`080?ooo`040000o`3oool0oooo0?l002<0oooo000X0?ooo`030000003oool0oooo
0380oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo
02L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo
01D0oooo00<0o`000?ooo`3oool0503oool00`000000003o0?ooo`050?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`050?ooo`030000003oool0oooo
0140oooo00<0003o0?ooo`3oool0PP3oool020000000oooo0?ooo`3oool000000?l0003oool0003o
3P3oool00`3o0000oooo0000000;0?ooo`030000003oool0o`0003D0oooo00<0003o0?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0003o02`0oooo00<000000?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0000002h0oooo00<0o`000?ooo`3oool0
103oool01@000000oooo0000o`3oool0o`0001l0oooo00<000000?ooo`3oool0203oool010000?l0
oooo0?ooo`3o000S0?ooo`00:03oool00`000000oooo0?ooo`0b0?ooo`030000o`3oool0oooo01P0
oooo00<0003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`070?ooo`050?l0003oool0oooo0?oo
o`0000005P3oool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo00H0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<000000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`210?ooo`060000003oool0oooo0?ooo`000000o`000P3o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0000000d0oooo00<000000?l0003oool0403o
ool300000200oooo00<0003o0?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`80000000<0
003o0?ooo`3oool0:@3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`000000;P3oool00`3o0000oooo0?ooo`040?ooo`050000003oool0003o0?ooo`3o0000
7`3oool00`000000oooo0?ooo`080?ooo`050000o`3oool0oooo0?ooo`3o00008P3oool002P0oooo
00<000000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool0oooo02T0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo
00<0o`000?ooo`3oool05@3oool00`000000003o0?ooo`080?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`030000003oool0oooo0100oooo
00<0003o0?ooo`3oool0P@3oool02@000000oooo0?ooo`3oool000000?ooo`3o0000oooo0000o`0<
0?ooo`030?l0003oool0000000h0oooo00<000000?l0003oool03P3oool010000000oooo0?ooo`3o
ool3000000T0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`050?ooo`030000003o
ool0oooo00P0oooo00<000000000o`3oool0:@3oool00`000000oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`000000;@3oool00`3o0000oooo0?ooo`050?ooo`050000003o
ool0003o0?ooo`3o00007`3oool00`3o000000000?ooo`090?ooo`040000o`3oool0oooo0?l00280
oooo000X0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3oool05`3oool00`000?l0oooo
0?ooo`0[0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo
0?ooo`0B0?ooo`030?l0003oool0oooo01@0oooo00<000000000o`3oool02@3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02@3oool00`000000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0800oooo00<000000?ooo`3oool00P3oool01@000000o`00
0?ooo`3oool0003o00/0oooo00<0o`000?ooo`0000003P3oool00`000000o`000?ooo`0<0?ooo`80
00001`3oool3000000H0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`060?ooo`03
0000003oool0o`0000T0oooo00<000000000o`3oool09`3oool00`000000oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00<0oooo00@0o`000?ooo`3oool00000;03oool00`3o0000oooo0?ooo`040?oo
o`030000003oool0003o00<0oooo00<0o`000?ooo`3oool0703oool00`3o000000000?ooo`090?oo
o`040000o`3oool0oooo0?l00280oooo000X0?ooo`800000=03oool00`000?l0oooo0?ooo`0F0?oo
o`030000o`3oool0oooo02/0oooo00<0003o0?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0
000001<0oooo00<0o`000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0:0?ooo`030000003oool0
oooo0100oooo00<0003o0?ooo`3oool0P03oool00`000000oooo0?ooo`020?ooo`050000003o0000
oooo0?ooo`000?l02P3oool0103o0000oooo0?ooo`00000?0?ooo`030000003o0000oooo00X0oooo
00<000000?ooo`3oool02P3oool300000080oooo00<0o`000?ooo`3o00003`3oool00`000?l0oooo
0?ooo`070?ooo`030000003oool0o`0000X0oooo00<000000000o`3oool09P3oool00`000000oooo
0?ooo`0=0?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3oool00000:`3oool00`3o0000
oooo0?ooo`050?ooo`030000003oool0003o00<0oooo00<0o`000?ooo`3oool06`3oool00`3o0000
oooo0000000;0?ooo`040000o`3oool0oooo0?l00240oooo000X0?ooo`030000003oool0oooo03<0
oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`0]0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo01@0
oooo00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`090?ooo`050000o`3oool0oooo0?oo
o`000?l03@3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0800oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?l000020?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`0000004@3oool00`000000oooo0?ooo`070?ooo`800000403oool300000080oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`070?ooo`050000003oool0o`000?ooo`3o00002P3oool0
0`000000003o0?ooo`0U0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool00`3oool0
103o0000oooo0?ooo`00000[0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`000?l0103o
ool00`3o0000oooo0?ooo`0J0?ooo`030?l0003oool0000000/0oooo00@0003o0?ooo`3oool0o`00
8@3oool002P0oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3o
ool0oooo02h0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<0o`000?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00P0oooo00D0003o0?ooo`3oool0oooo0000o`0=0?ooo`030000003oool0oooo0140oooo
00<0003o0?ooo`3oool0O`3oool00`000000oooo0?ooo`030?ooo`030000003o0000oooo0080oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo000000040?ooo`<0003o2P3oool00`000000o`00
0?ooo`050?ooo`8000004`3oool01@3o0000oooo0000003oool0o`0000`0oooo00<0003o0?ooo`3o
ool0203oool01@000000o`000?ooo`3oool0o`0000/0oooo00<000000000o`3oool08`3oool00`00
0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`000000:P3oool00`3o
0000oooo0?ooo`060?ooo`03000000000?l0oooo00@0oooo00<0o`000?ooo`3oool06P3oool00`3o
0000oooo0000000;0?ooo`040000o`3oool0oooo0?l00240oooo000X0?ooo`030000003oool0oooo
03<0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`0`0?ooo`030000o`3oool0oooo
00@0oooo00D0o`000?ooo`3oool0oooo0000000@0?ooo`030?l0003oool0oooo01D0oooo00<00000
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0003o00l0oooo00<00000
0?ooo`3oool0403oool00`000?l0oooo0?ooo`1o0?ooo`800000103oool00`000000oooo0?l00002
0?ooo`030000o`3oool0oooo00D0oooo00D0o`000?ooo`3oool000000?ooo`030000o`<0oooo0P00
0?l90?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0000
00020?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`000000o`000?oo
o`020?ooo`030?l0003oool0oooo00T0oooo00<000000000o`3oool08P3oool00`000000oooo0?oo
o`0=0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`000000:P3oool00`3o0000oooo0?oo
o`050?ooo`030000003oool0003o00H0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0000
000<0?ooo`030000o`3oool0o`000240oooo000X0?ooo`030000003oool0oooo03@0oooo00<0003o
0?ooo`3oool04`3oool00`000?l0oooo0?ooo`0`0?ooo`030000o`3oool0oooo00@0oooo0P3o0003
0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool0503oool00`000000oooo0?ooo`0?
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool0F03oool00`000000oooo0?ooo`03
0?ooo`030000003oool0o`0000<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo00000002
0000o`P0oooo0P000?l70?ooo`040000003o0000oooo0?ooo`8000005@3oool01@3o0000oooo0?oo
o`3oool000000080oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030000
003o0000oooo00<0oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00d0oooo00<0o`000?ooo`3oool01@3oool0103o0000oooo0?ooo`00000X0?ooo`03
0?l0003oool0oooo00H0oooo00<000000?ooo`000?l01P3oool00`3o0000oooo0?ooo`0H0?ooo`04
0?l0003oool0oooo000000`0oooo00@0003o0?ooo`3oool0o`000`3oool00`000000oooo0?ooo`0J
0?ooo`00:03oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo0180oooo00<0003o0?oo
o`3oool0<P3oool00`000?l0oooo0?ooo`050?ooo`80o`0000<0oooo0000003oool03@3oool00`3o
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool0F03oool00`00
0000oooo0?ooo`040?ooo`030000003o0000oooo0080oooo00<0003o0?ooo`3oool00`3oool30000
o`030000003oool0oooo00X0oooo0P000?l60?ooo`030000003oool0000001L0oooo00D0o`000?oo
o`3oool0oooo000000020?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool02@3oool0
0`000000oooo0?ooo`040?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00D0oooo00@0o`000?ooo`3oool00000:03o
ool00`3o0000oooo0?ooo`060?ooo`03000000000?l0oooo00H0oooo00<0o`000?ooo`3oool0603o
ool01@3o0000oooo0?ooo`3oool0000000/0oooo00@0003o0?ooo`3oool0o`000`3oool00`000000
oooo0?ooo`0J0?ooo`00:03oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo0180oooo
00<0003o0?ooo`3oool0<`3oool00`000?l0oooo0?ooo`060?ooo`030?l000000000oooo00d0oooo
00<0o`000?ooo`3oool0503oool00`000?l000000?ooo`0A0?ooo`030?l0003oool0oooo01X0oooo
00<000000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0Q0?ooo`030000o`3oool0003o05T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?l000030?ooo`030000o`3oool0003o0080003o
00@0o`000?ooo`3oool000003P3oool00`000?l0oooo0?ooo`040?ooo`030000003oool0oooo01D0
oooo00<0o`000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0o`0000L0oooo00<0003o0?oo
o`3oool02@3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo00X0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00D0oooo00@0o`000?oo
o`3oool000009`3oool00`3o0000oooo0?ooo`060?ooo`030000003oool0003o00P0oooo00<0o`00
0?ooo`3oool05`3oool01@3o0000oooo0?ooo`3oool0000000`0oooo00<0003o0?ooo`3o00000P3o
ool00`000000oooo0?ooo`0K0?ooo`00503oool2000000@0oooo00<000000?ooo`3oool00`3oool3
000000D0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0
oooo03@0oooo00<0003o0?ooo`3oool01`3oool00`3o000000000?ooo`0;0?ooo`030?l0003oool0
oooo01@0oooo00<0003o0000003oool04P3oool00`3o0000oooo0?ooo`0J0?ooo`030000003oool0
oooo0140oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0000o`1I0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3o0000103oool01`000?l0oooo0?ooo`3oool0o`000?ooo`000000
403oool20000o`@0oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`3o00001@3oool00`000?l0oooo0?ooo`090?ooo`030?l000000000oooo00H0
oooo00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`0H0?ooo`<0003o103oool00`000000
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00D0oooo00@0o`000?ooo`3oool000009`3oool00`3o
0000oooo0?ooo`060?ooo`030000003oool0003o00P0oooo00<0o`000?ooo`3oool05`3oool01@3o
0000oooo0?ooo`3oool0000000`0oooo00H0003o0?ooo`3oool0o`000?ooo`00000M0?ooo`004`3o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
=@3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo03D0oooo00<0003o0?ooo`3oool0
1`3oool00`000000o`000?l000090?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`000000
4`3oool00`3o0000oooo0?ooo`0K0?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3oool0
8@3oool010000?l0oooo0?ooo`000?mH0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
00001`3oool00`3o0000oooo0000000B0?ooo`80003o0`3oool00`3o0000oooo0?ooo`0C0?ooo`03
0?l0003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0?l000050?ooo`030000o`3oool0oooo
00P0oooo00<0o`000000003oool01`3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo
01P0oooo00<0003o0?ooo`3oool00`000?l00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00H0oooo00@0o`000?ooo`3oool000009P3oool00`3o0000oooo0?ooo`070?ooo`03000000000?l0
oooo00T0oooo00<0o`000?ooo`3oool05P3oool01@3o0000oooo0?ooo`3oool0000000d0oooo00@0
003o0?ooo`3o000000007P3oool001<0oooo00@000000?ooo`3oool000001`3oool5000000D0oooo
00<000000?ooo`3oool0=@3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo03L0oooo
00<0003o0?ooo`3oool01P3oool010000000oooo0?ooo`3o00080?ooo`030?l0003oool0oooo01@0
oooo00<0003o0?ooo`000000503oool00`3o0000oooo0?ooo`0J0?ooo`030000003oool0oooo0140
oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo05D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?l000060?ooo`040?l0003oool0oooo0000
01@0oooo0P000?l20?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool01@3oool01@00
0000oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3oool02@3oool00`3o000000000?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0000003oool0603oool00`000?l0oooo0?ooo`03
0?ooo`03000000000?l0003o00h0oooo00<0o`000?ooo`3oool01P3oool01@3o0000oooo0?ooo`3o
ool0000002D0oooo00<0o`000?ooo`3oool01P3oool00`000000oooo0000o`0:0?ooo`030?l0003o
ool0oooo01D0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`040000o`3o
ool0o`00000001h0oooo000C0?ooo`040000003oool0oooo000000L0oooo00@000000?ooo`3oool0
00001P3oool3000003D0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0i0?ooo`03
0000o`3oool0oooo00H0oooo00<000000?ooo`3oool00P3o00001P3oool0003o0000o`000?l0oooo
0?l001H0oooo00<0003o0?ooo`0000005@3oool00`3o0000oooo0?ooo`0J0?ooo`030000003oool0
oooo0140oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo05D0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`3o00050?ooo`030?l0003o
ool0000001L0oooo1@000?lA0?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`3o0000oooo0000o`0;0?ooo`030?l0003oool0000000T0oooo00<0o`000?ooo`3oool0203o
ool00`000?l000000?ooo`0G0?ooo`030000o`3oool0oooo00@0oooo00<000000?ooo`3oool00`00
0?l;0?ooo`030?l0003oool0oooo00H0oooo00D0o`000?ooo`3oool0oooo0000000T0?ooo`030?l0
003oool0oooo00L0oooo00<000000000o`3oool02P3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0
003oool0oooo0080oooo00<000000?ooo`3oool02`3oool010000?l0oooo0000003o000N0?ooo`00
4`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0000000H0oooo00<000000?ooo`3o
ool0=@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo03X0oooo00<0003o0?ooo`3o
ool01P3oool00`000000003o0000o`030000o`050?l0003oool0oooo0000o`3o00005@3oool01000
0?l0oooo0?ooo`00000F0?ooo`030?l0003oool0oooo01X0oooo00<000000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0E03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0o`0000D0oooo00<0o`000?ooo`0000006P3oool0
0`3o0000oooo0000o`060000o`X0oooo00<0o`000?ooo`3oool01P3oool00`000000oooo0?ooo`03
0?ooo`030?l000000?l0oooo00T0oooo00@0o`000?ooo`3oool000002P3oool00`3o0000oooo0?oo
o`080?ooo`030000003oool0oooo01H0oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`<0003o203oool00`3o0000oooo0?ooo`070?ooo`040?l0003oool0oooo000001D0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`070?ooo`03000000000?l0oooo00/0oooo
00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo
00<0003o0000003o00007P3oool001<0oooo00@000000?ooo`3oool000002@3oool2000000H0oooo
00<000000?ooo`3oool0=P3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo03`0oooo
00@0003o0?ooo`3oool0oooo10000?l00`000000oooo0?ooo`040?ooo`040?l0003oool0o`000000
oa@0oooo00D0003o0?ooo`3oool0oooo0000000F0?ooo`030?l0003oool0oooo01X0oooo00<00000
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool0E03oool2000000L0oooo00<000000?ooo`3o0000103oool0103o0000oooo0?ooo`00
000K0?ooo`030?l0003oool0oooo00D0oooo0`000?l60?ooo`030?l0003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0000000/0oooo00<0
o`000?ooo`3oool0203oool00`000?l000000?ooo`0F0?ooo`030000o`3oool0oooo00<0oooo00<0
00000?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00L0oooo00@0
o`000?ooo`3oool000005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00L0oooo
00<000000?ooo`000?l0303oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo00<0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?l0000N0?ooo`00503oool2000000/0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0f0?ooo`030000o`3oool0oooo00X0oooo00<0
003o0?ooo`3oool0?P3oool30000o`D0oooo00<000000?ooo`3oool0103oool0103o0000oooo0?oo
o`000?lC0?ooo`040000o`3oool0oooo000001P0oooo00<0o`000?ooo`3oool06@3oool00`000000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`1C0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0o`000`3oool0103o
0000oooo0?ooo`00000K0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<0003o0?l0003oool0203oool0
103o0000oooo0?ooo`00000<0?ooo`030?l0003oool0oooo00L0oooo00<0003o0000003oool05P3o
ool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`070?ooo`040?l0003oool0oooo000001@0oooo00<0003o0?ooo`000?l0
303oool00`3o0000oooo0?ooo`070?ooo`03000000000?l0oooo00d0oooo00<0o`000?ooo`3oool0
4`3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o0000
7P3oool002P0oooo00<000000?ooo`3oool0=P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3o
ool0oooo04L0oooo00<000000?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`050000o`3o
ool0oooo0?ooo`000000603oool00`3o0000oooo0?ooo`0J0?ooo`030000003oool0oooo0140oooo
00<0003o0?ooo`3oool06`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo05<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?l000030?ooo`030?l0003oool0000001d0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00P0oooo
00D000000?ooo`3oool0oooo0000o`020?ooo`030?l0003oool0oooo00D0oooo00D0o`000?ooo`3o
ool0oooo0000000<0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`0000005@3oool00`00
0?l0oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`080?ooo`050?l0003oool0oooo0?ooo`0000004`3oool00`000?l0oooo0000o`0;
0?ooo`030?l0003oool0oooo00P0oooo00<000000000o`3oool03@3oool00`3o0000oooo0?ooo`0B
0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool01@000000oooo0000o`3o
ool0o`0001d0oooo000X0?ooo`030000003oool0oooo03L0oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`180?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo01/0oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`1B0?ooo`030000003oool0oooo00L0oooo00H000000?ooo`3oool0o`000?oo
o`3o00020?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool01`3oool01@000?l0oooo
0?ooo`3oool0o`0000`0oooo00<000000?ooo`000?l00`3oool00`3o0000oooo0?ooo`050?ooo`04
0?l0003oool0oooo000000h0oooo00<0o`000?ooo`3oool01`3oool00`000?l000000?ooo`0D0?oo
o`030000o`3oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00P0oooo00D0o`000?ooo`3oool0oooo0000000B0?ooo`050000o`3oool0
oooo0?ooo`000?l02P3oool00`3o0000oooo0?ooo`070?ooo`03000000000?l0oooo00h0oooo00<0
o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00D0
00000?ooo`000?l0oooo0?l0000M0?ooo`00:03oool00`000000oooo0?ooo`0g0?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool0BP3oool00`000000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00/0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`030?l0003o
ool0oooo01X0oooo00<000000?ooo`3oool04@3oool010000?l0oooo0?ooo`00000H0?ooo`030000
o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0D@3oool00`000000oooo0?ooo`070?ooo`060000
003oool0oooo0?l0003oool0o`000P3oool00`000000oooo0?ooo`0L0?ooo`030?l0003oool0oooo
00P0oooo00@0003o0?ooo`3oool0o`00303oool00`000000oooo0000o`040?ooo`030?l0003oool0
oooo00<0oooo00D0o`000?ooo`3oool0oooo0000000>0?ooo`030?l0003oool0oooo00L0oooo00<0
003o0000003oool0503oool00`000?l0oooo0?l000030?ooo`030000003oool0oooo00T0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`080?ooo`050?l0003oool0oooo0?ooo`000000
4P3oool01@000?l0oooo0?ooo`3oool0003o00X0oooo00<0o`000?ooo`3oool01`3oool00`000000
003o0?ooo`0?0?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0103oool00`000000
oooo0?ooo`090?ooo`060000003oool0oooo0?ooo`000?l0o`007@3oool002P0oooo00<000000?oo
o`3oool0=`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo04X0oooo00<000000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0080oooo00<000000?oo
o`3oool06@3oool00`3o0000oooo0?ooo`0I0?ooo`030000003oool0oooo0140oooo00@0003o0?oo
o`3oool00000603oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0540oooo00<00000
0?ooo`3oool0203oool01`000000oooo0?l0003oool0o`000?ooo`000000803oool00`3o0000oooo
0?ooo`080?ooo`030000o`3o0000oooo00d0oooo00<000000?ooo`3oool0103oool01@3o0000oooo
0?ooo`3oool0o`0000@0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0000001@0oooo00<0003o0?ooo`3o00000P3oool00`000000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool01@3o0000oooo0?ooo`3oool00000
0140oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00P0oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo
00@0oooo00<000000?ooo`3oool02@3oool01`000000oooo0?ooo`3oool0003o0?ooo`3o0000703o
ool002P0oooo00<000000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo04/0oooo00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0
oooo00<0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0I0?ooo`030000003oool0
oooo0140oooo00D0003o0?ooo`000000oooo0000000G0?ooo`030000o`3oool0oooo00X0oooo00<0
003o0?ooo`3oool0D03oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo0?l00080oooo
00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00`0oooo
00<000000?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<000000?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0000001@0oooo00H0003o0?l0003o
ool0o`000?ooo`00000=0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0203oool0
1@3o0000oooo0?ooo`3oool000000140oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00L0oooo00<000000000o`3oool04@3oool00`3o0000oooo0?oo
o`0@0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`030000o`3oool0o`0001`0oooo000X0?ooo`030000003oool0oooo03P0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1=0?ooo`030000003oool0oooo00/0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo01/0oooo00<0o`00
0?ooo`3oool06@3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000001H0oooo00<0
003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`1@0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`000?l0303oool00`000?l000000?ooo`060?ooo`030?l0003oool0o`0000@0oooo00<0
00000?ooo`3oool03`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0000001<0oooo00L0
003o0?ooo`3o0000oooo0?l0003oool0000000d0oooo00D0003o0?ooo`3oool0oooo0?l0000;0?oo
o`030?l0003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?oo
o`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool06`3oool002P0oooo0P00000i0?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0CP3oool00`000000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000000oooo0?ooo`0K0?ooo`03
0?l0003oool0oooo01T0oooo00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3oool00000
01D0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`1?0?ooo`030000003oool0oooo
00T0oooo00D000000?ooo`3oool0oooo0000000S0?ooo`030?l0003oool0oooo00H0oooo00@0o`00
0?ooo`3oool0003o2P3oool010000?l0oooo0?ooo`0000070?ooo`030?l0003oool0oooo00<0oooo
00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool000000180oooo
00H0003o0?l0003oool0oooo0?l00000000>0?ooo`050000o`3oool0oooo0?ooo`3o0000303oool0
1@3o0000oooo0?ooo`3oool0000000l0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0?0?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000o`3oool0oooo01/0oooo000X0?ooo`030000003oool0oooo03P0oooo00D0003o
0?ooo`3oool0oooo0000o`1A0?ooo`030000003oool0oooo00d0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`040?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool0603o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0003o0080oooo00<000000?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo04h0oooo0P00000:0?ooo`050000003o
ool0oooo0?ooo`000000903oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool01`3oool010000?l0oooo0?ooo`00000=0?ooo`030000003oool0oooo0100
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0000000B0?ooo`030000o`3oool0oooo0080
oooo00<000000?ooo`3oool03@3oool010000?l0oooo0?ooo`3o000<0?ooo`050?l0003oool0oooo
0?ooo`0000003`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`030?l0003oool0oooo00h0oooo00<0o`00
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0003o
0?ooo`3oool06`3oool002P0oooo00<000000?ooo`3oool0>03oool010000?l0oooo0?ooo`000?mC
0?ooo`030000003oool0oooo00d0oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`030000003o
ool0oooo01`0oooo00<0o`000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`040000003o
ool0oooo0000o`<0oooo00<000000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0>0?ooo`030000
o`3oool0oooo04h0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000002@0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0000000B0?ooo`030000o`3oool0oooo0080
oooo00<000000?ooo`3oool03@3oool010000?l0oooo0?ooo`3o000<0?ooo`050?l0003oool0oooo
0?ooo`0000003P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool01`3oool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo00d0oooo00<0o`00
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0003o
0?ooo`3oool06P3oool002P0oooo00<000000?ooo`3oool0>@3oool20000oe@0oooo00<000000?oo
o`3oool03P3oool00`000?l0oooo0000o`070?ooo`030000003oool0oooo01d0oooo00<0o`000?oo
o`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo0000o`<0oooo00<00000
0?ooo`3oool0403oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo04d0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0000000V0?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo00@0oooo00@0003o
0?ooo`3oool00000403oool00`000?l0oooo0?ooo`020?ooo`030000003oool0o`0000h0oooo00@0
003o0?ooo`3oool0o`00303oool01@3o0000oooo0?ooo`3oool0000000h0oooo00<0003o0?ooo`3o
ool0203oool01@000?l0oooo0?ooo`3oool0o`0000X0oooo00<000000?ooo`3oool05@3oool00`3o
0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0S0?ooo`00:03oool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo05<0
oooo00<000000?ooo`3oool03`3oool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo01h0
oooo00<0o`000?ooo`3oool06@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080
oooo00D0003o0?ooo`3oool0oooo0000000A0?ooo`030000o`3oool0oooo0100oooo00<0003o0?oo
o`3oool0C@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000002L0oooo00D0o`000?oo
o`3oool0oooo0?l000080?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<0o`000?ooo`3oool0103oool0
10000?l0oooo0?ooo`00000@0?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`3o00003P3o
ool010000?l0oooo0?ooo`3o000<0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0:0?ooo`040000o`3oool0oooo0?l000T0oooo00<000000?ooo`3o
ool05`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0S0?ooo`00:03oool00`000000oooo0?ooo`2@0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`0I0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool000000140
oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`1<0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`0000009`3oool0103o0000oooo0?ooo`3o000:0?ooo`040000o`3oool0oooo
0000o`L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0C0?ooo`030?l0003oool0
oooo00@0oooo00@0003o0?ooo`3oool000003P3oool00`3o0000003o0?ooo`030?ooo`030000003o
ool0o`0000l0oooo00<0003o0?l0003oool0303oool00`3o0000oooo0?ooo`020?ooo`030000003o
ool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool010000?l0oooo0?ooo`3o00090?ooo`030000
003oool0oooo01P0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0903oool002P0oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`3oool0603o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo
0000000?0?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool0C03oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo02L0oooo00<0o`000?ooo`3o00002`3oool00`000?l0oooo
0000o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0503oool00`3o0000oooo
0?ooo`040?ooo`040000o`3oool0oooo000000h0oooo00<0o`000000o`3oool00P3oool01@000000
oooo0?ooo`3oool0o`0000h0oooo00<0003o0?l0003oool0303oool00`3o0000oooo0?ooo`020?oo
o`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool0303oool00`000?l0o`000?ooo`080?oo
o`030000o`000000oooo01X0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool002P0oooo00<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`3o
ool06@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00@0003o0?ooo`3o
ool000003`3oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo04/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01D0oooo00<0o`000?oo
o`3oool00`3oool010000?l0oooo0?ooo`00000=0?ooo`030?l000000?l0oooo00<0oooo00D00000
0?ooo`3oool0oooo0?l0000>0?ooo`030000o`3o0000oooo00`0oooo00<0o`000?ooo`3oool00P3o
ool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo00`0oooo00<0003o0?l0003oool0203o
ool00`000000oooo0?ooo`0K0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo000X0?ooo`030000003oool0
oooo0940oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Q0?ooo`030?l0003oool0
oooo01P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`040000o`3oool0
oooo000000d0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`0`0?ooo`800000103o
ool00`000000oooo0?ooo`030?ooo`8000000`3oool3000000H0oooo00<000000?ooo`3oool0CP3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool00`3o
ool01@000?l0oooo0?ooo`3oool0000000`0oooo00<0o`000000o`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool03@3oool00`3o0000003o
0?ooo`070?ooo`030000o`000000oooo01d0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09@3oool002P0oooo00<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0280oooo00<0
o`000?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<0
003o0?ooo`0000003@3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo02l0oooo00@0
00000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool05`3oool20?l000@0oooo00@0003o0?ooo`3oool000002`3oool00`3o0000oooo0000o`03
0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<0o`000000o`3oool01`3oool00`000?l000000?ooo`0N
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02@3oool01@000000oooo0?ooo`3o
ool0000002P0oooo000X0?ooo`800000TP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo02<0oooo0P3o000I0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool0
0`000?l0oooo0000000<0?ooo`030000o`3oool0oooo01H0oooo00<0003o0?ooo`3oool0;P3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
0`3oool3000004l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`050?l0
003oool0oooo0?ooo`000?l00P3oool00`000000oooo0?ooo`080?ooo`040?l0003oool0oooo0000
o`80oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0;0?ooo`030?l000000?l0oooo
00d0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo0P0000060?ooo`030?l0003oool0003o00H0oooo00<0003o0000003oool0803oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000X
0?ooo`00:03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool09@3oool30?l001H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?oo
o`030000o`000000oooo00X0oooo00<0003o0?ooo`3oool0B03oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06P3oool0103o0000oooo0?oo
o`000?l30?ooo`030000003oool0oooo00L0oooo00H0o`000?ooo`3oool0003o0?ooo`0000080?oo
o`030?l0003oool0oooo00X0oooo00<0o`000?ooo`000?l03@3oool00`3o0000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool010000000oooo0?ooo`000004
0?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool00`000?l000000?ooo`0Q0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool02@3oool010000000oooo0?ooo`00000Y0?ooo`00:03o
ool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0:@3o
ool20?l001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000o`00
0000oooo00T0oooo00<0003o0?ooo`3oool0B03oool010000000oooo0?ooo`0000080?ooo`050000
003oool0oooo0000003oool0100000060?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0K0?ooo`030?l0003oool0003o00<0oooo00<000000?ooo`3o
ool01P3oool01P3o0000oooo0?ooo`000?l0oooo000000T0oooo00<0o`000?ooo`3oool02P3oool0
0`3o0000oooo0000o`0=0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0?l0
00030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`0000008`3oool01@3o0000oooo0?oo
o`3oool0o`0000/0oooo00@000000?ooo`3oool00000:@3oool002P0oooo00<000000?ooo`3oool0
TP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02/0oooo0`3o000B0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`070?ooo`030000
o`3oool0oooo04T0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo
000000T0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01d0oooo00<0o`000000o`3oool00`3oool00`000000oooo0?ooo`050?ooo`050?l0003oool0
oooo0000o`0000002`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0003o00d0oooo00<0
o`000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`3o00040?ooo`060000o`3oool0oooo0?ooo`00
0?l000009@3oool0103o0000oooo0?ooo`3o000<0?ooo`800000:P3oool002P0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02h0oooo0P3o000@0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`070?oo
o`030000o`3oool0oooo04X0oooo0P00000:0?ooo`8000000P3oool5000000D0oooo00<000000?oo
o`3oool0D03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo00<0o`000000
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`050?l0003oool0oooo0?ooo`000000303oool0
0`3o0000oooo0?ooo`090?ooo`030?l0003oool0003o00d0oooo00<0o`000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<000000?ooo`3oool01P3oool0
0`000000o`000?ooo`040?ooo`060000o`3oool0oooo0?ooo`000?l000009P3oool20?l000d0oooo
0P00000Z0?ooo`00:03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0<@3oool30?l000h0oooo00@000000?ooo`3oool000005@3oool00`000000oooo
0?ooo`060?ooo`030000o`3oool0oooo06@0oooo00<000000?ooo`3oool0D@3oool01@000000oooo
0?ooo`3oool000000240oooo00D0003o0?l0003oool0oooo000000060?ooo`050?l0003oool0oooo
000000000?l03@3oool00`3o0000oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`000?l0303o
ool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00D0003o0?ooo`000?l0oooo
0000000W0?ooo`030?l0003oool0oooo00/0oooo00<000000?ooo`3oool0:@3oool002P0oooo00<0
00000?ooo`3oool0T`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03@0oooo00<0
o`000?ooo`3oool02`3oool010000000oooo0?ooo`00000E0?ooo`03000000000?l0oooo00D0oooo
00<0003o0?ooo`3oool0I@3oool00`000000oooo0?ooo`1A0?ooo`050000003oool0oooo0?ooo`00
00008@3oool00`000?l0oooo0?l000020?ooo`030000003oool0oooo0080oooo00D0o`000?ooo`3o
ool000000000o`0>0?ooo`030?l0003oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo0000o`0<
0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`030000003oool0oooo00T0oooo00<0o`000000003oool0103oool010000?l0oooo0000o`00
001R0?ooo`00:03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0=03oool00`3o0000oooo0?ooo`0;0?ooo`030000003oool0000001L0oooo00<00000
0000o`3oool0103oool00`000?l0oooo0?ooo`1U0?ooo`030000003oool0oooo0540oooo00@00000
0?ooo`3oool000008P3oool01P000?l0oooo0?ooo`3o0000oooo000000@0oooo00D0o`000?ooo`00
0000oooo0000o`0>0?ooo`030?l0003oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo0000o`0<
0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030000003oool0oooo00T0oooo00@0o`000?ooo`3oool000001@3oool00`000?l0oooo0000
001R0?ooo`00:03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0=03oool00`3o0000oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`000?l00`3oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`0000008`3oool01@000?l0oooo0?ooo`3o0000000000<0oooo00<0o`000?ooo`0000000P3o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool01@000?l0oooo0?ooo`3oool0000000`0oooo00D0o`000?ooo`3oool0oooo000000060?ooo`03
0000003oool0oooo0600oooo000X0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0f0?ooo`030?l0003oool0oooo02D0oooo00<000000?ooo`000?l0
0P3oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`000000
8`3oool02P000?l0oooo0?ooo`3oool0o`000000003oool0o`000?ooo`0000030?ooo`030000o`3o
ool0oooo00d0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool00`3oool010000000oooo0?ooo`000?l40?ooo`030000
003oool0oooo00T0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0640oooo000X0?ooo`800000V03oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo03H0oooo00<0o`000?ooo`3oool09@3oool01P000000oooo0?ooo`000?l0oooo0000ofP0
oooo0P00001C0?ooo`800000903oool00`000?l0oooo0?ooo`020?ooo`040000003oool0o`000000
00<0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`030?ooo`040000003oool0oooo
0000o`<0oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`000000H`3oool002P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo03H0oooo00<0o`000?ooo`3oool09P3oool010000000oooo0?ooo`00
0?lL0?ooo`800000B`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0280oooo00<0
003o0?ooo`3oool00P3oool00`000000o`00000000040?ooo`030000o`3oool0oooo00l0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool00`3oool00`000000oooo0000o`030?ooo`030000003oool0oooo00/0oooo00<0
o`000?ooo`3oool01@3oool010000000oooo0?ooo`00001S0?ooo`00:03oool00`000000oooo0?oo
o`2H0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?oo
o`0U0?ooo`030000003oool0oooo01X0oooo0`00001=0?ooo`030000003oool0oooo07P0oooo00<0
003o0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00l0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool00`3oool00`000000oooo0000o`020?ooo`030000003oool0oooo00/0oooo00<0
o`000?ooo`3oool01`3oool2000006@0oooo000X0?ooo`030000003oool0oooo09T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo02H0oooo00<00000
0?ooo`3oool05`3oool200000500oooo00<000000?ooo`3oool0N@3oool00`000?l0oooo0?ooo`08
0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool00`3oool01@000000003o0?ooo`3o
ool0000000h0oooo00<0o`000?ooo`3oool0203oool00`000000oooo0?ooo`1R0?ooo`00:03oool0
0`000000oooo0?ooo`2J0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0>03oool0
0`3o0000oooo0?ooo`0V0?ooo`030000003oool0oooo01@0oooo0`00001B0?ooo`030000003oool0
oooo07T0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00@0oooo00<000000?ooo`0000003`3oool00`3o0000oooo0?ooo`1]0?ooo`00:03oool00`00
0000oooo0?ooo`2K0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0>@3oool00`3o
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0140oooo0P00001E0?ooo`030000003oool0oooo
07T0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00<0oooo00<0003o0000000000003`3oool00`3o0000oooo0?ooo`1^0?ooo`00:03oool00`000000
oooo0?ooo`2L0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>P3oool00`3o0000
oooo0?ooo`0V0?ooo`030000003oool0oooo00h0oooo0`00001G0?ooo`030000003oool0oooo07T0
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0B0?ooo`050?l0003oool0oooo0?oo
o`3o0000203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`000000403oool00`3o0000oooo0?ooo`1^0?ooo`00503oool2000000@0oooo00<000000?ooo`3o
ool00P3oool3000000H0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03X0oooo00<0o`000?ooo`3oool09`3oool@000005X0oooo00<000000?ooo`3o
ool0NP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0180oooo00D0o`000?ooo`3o
ool0oooo0?l000080?ooo`030000o`3oool0oooo00P0oooo00D0o`000?ooo`3oool0oooo0000o`0C
0?ooo`030?l0003oool0oooo06h0oooo000C0?ooo`040000003oool0oooo000000L0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo0940oooo00<000000?ooo`3oool0NP3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01<0oooo00@0o`000?ooo`3oool0o`00
2@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0003o01<0oooo00<0o`000?ooo`3oool0
K`3oool001<0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`3oool0WP3oool01@000000oooo0?ooo`3oool0000003h0oooo00<0o`000?oo
o`3oool0T03oool2000007/0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0D0?oo
o`040?l0003oool0oooo0?l000T0oooo00<0003o0?ooo`3oool0203oool00`3o0000003o0?ooo`0C
0?ooo`030?l0003oool0oooo06l0oooo000C0?ooo`040000003oool0oooo000000L0oooo10000006
0?ooo`<00000W`3oool010000000oooo0?ooo`00000n0?ooo`030?l0003oool0oooo0900oooo00<0
00000?ooo`3oool0NP3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01D0oooo00<0
o`000?ooo`3o00002@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo01<0oooo00<0
o`000?ooo`3oool0K`3oool001<0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0:00oooo0P00000o0?ooo`030?l0003oool0oooo0900oooo00<0
00000?ooo`3oool0NP3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01D0oooo0P3o
000:0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?l0003oool04`3oool00`3o0000oooo0?oo
o`1`0?ooo`004`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0X@3oool00`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo0900oooo00<0
00000?ooo`3oool0N`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01D0oooo0P3o
000;0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?l0003oool04`3oool00`3o0000oooo0?oo
o`1`0?ooo`00503oool2000000X0oooo0P0000060?ooo`030000003oool0oooo0>80oooo00<0o`00
0?ooo`3oool0S`3oool00`000000oooo0?ooo`1k0?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool05`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3o0000503oool00`3o0000oooo0?ooo`1`0?ooo`00:03oool00`000000oooo0?ooo`3R0?oo
o`030?l0003oool0oooo08l0oooo00<000000?ooo`3oool0N`3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool0103oool010000?l0oooo0?ooo`3o000C
0?ooo`030?l0003oool0oooo0740oooo000X0?ooo`030000003oool0oooo0>80oooo00<0o`000?oo
o`3oool0S`3oool00`000000oooo0?ooo`1k0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0903oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00004`3oool0
0`3o0000oooo0?ooo`1a0?ooo`00:03oool00`000000oooo0?ooo`3S0?ooo`030?l0003oool0oooo
08h0oooo00<000000?ooo`3oool0N`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
02@0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0140oooo00<0o`00
0?ooo`3oool0L@3oool002P0oooo00<000000?ooo`3oool0h`3oool00`3o0000oooo0?ooo`2>0?oo
o`030000003oool0oooo07`0oooo00D0003o0?ooo`3oool0oooo0000o`0W0?ooo`040000o`3oool0
oooo0000o`H0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`1a0?ooo`00:03oool0
0`000000oooo0?ooo`3S0?ooo`030?l0003oool0oooo08h0oooo0P00001m0?ooo`050000o`3oool0
oooo0?ooo`000?l0:03oool20000o`L0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?oo
o`1b0?ooo`00:03oool00`000000oooo0?ooo`3S0?ooo`030?l0003oool0oooo08h0oooo00<00000
0?ooo`3oool0O03oool01@000?l0oooo0?ooo`3oool0003o02P0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo0780oooo000X0?ooo`800000i@3oool0
0`3o0000oooo0?ooo`2=0?ooo`030000003oool0oooo07`0oooo00D0003o0?ooo`3oool0oooo0000
o`0a0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool0LP3oool002P0oooo00<00000
0?ooo`3oool0i03oool00`3o0000oooo0?ooo`2=0?ooo`030000003oool0oooo07d0oooo00@0003o
0?ooo`3oool0003o<@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo07<0oooo000X
0?ooo`030000003oool0oooo0>@0oooo00<0o`000?ooo`3oool0S@3oool00`000000oooo0?ooo`1m
0?ooo`030000o`3oool0003o0380oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`1c
0?ooo`00:03oool00`000000oooo0?ooo`3U0?ooo`030?l0003oool0oooo08`0oooo00<000000?oo
o`3oool0O@3oool00`000?l0oooo0000o`0b0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?oo
o`3oool0L`3oool002P0oooo00<000000?ooo`3oool0i@3oool00`3o0000oooo0?ooo`2<0?ooo`03
0000003oool0oooo07d0oooo00<0003o0?ooo`000?l0<P3oool00`3o0000oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo07<0oooo000X0?ooo`030000003oool0oooo0>D0oooo00<0o`000?ooo`3oool0
S03oool00`000000oooo0?ooo`1m0?ooo`030000o`3oool0003o0380oooo00<0o`000?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`1d0?ooo`00:03oool00`000000oooo0?ooo`3U0?ooo`030?l0003o
ool0oooo08`0oooo00<000000?ooo`3oool0OP3oool00`000?l0oooo0?ooo`0a0?ooo`030?l0003o
ool0oooo00d0oooo00<0o`000?ooo`3oool0M03oool002P0oooo00<000000?ooo`3oool0iP3oool0
0`3o0000oooo0?ooo`2;0?ooo`800000O`3oool00`000?l0oooo0?ooo`0b0?ooo`030?l0003oool0
oooo00`0oooo00<0o`000?ooo`3oool0M03oool002P0oooo00<000000?ooo`3oool0iP3oool00`3o
0000oooo0?ooo`2;0?ooo`030000003oool0oooo0;<0oooo00<0o`000?ooo`3oool0303oool00`3o
0000oooo0?ooo`1d0?ooo`00:03oool00`000000oooo0?ooo`3V0?ooo`030?l0003oool0oooo08/0
oooo00<000000?ooo`3oool0/`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo07D0
oooo000X0?ooo`800000i`3oool00`3o0000oooo0?ooo`2;0?ooo`030000003oool0oooo0;<0oooo
00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`1e0?ooo`00:03oool00`000000oooo0?oo
o`3W0?ooo`030?l0003oool0oooo08X0oooo00<000000?ooo`3oool0/`3oool00`3o0000oooo0?oo
o`0;0?ooo`030?l0003oool0oooo07D0oooo000X0?ooo`030000003oool0oooo0>L0oooo00<0o`00
0?ooo`3oool0RP3oool00`000000oooo0?ooo`2c0?ooo`030?l0003oool0oooo00/0oooo00<0o`00
0?ooo`3oool0M@3oool002P0oooo00<000000?ooo`3oool0i`3oool00`3o0000oooo0?ooo`2:0?oo
o`030000003oool0oooo0;<0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`1f0?oo
o`00:03oool00`000000oooo0?ooo`3X0?ooo`030?l0003oool0oooo07D0oooo0P0000040?ooo`03
0000003oool0oooo0080oooo0`0000060?ooo`030000003oool0oooo0;<0oooo00<0o`000?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`1f0?ooo`00:03oool00`000000oooo0?ooo`3X0?ooo`030?l0
003oool0oooo07@0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0;<0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`1f0?ooo`00
:03oool00`000000oooo0?ooo`3X0?ooo`030?l0003oool0oooo07@0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;@0oooo00<0o`000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`1g0?ooo`00:03oool00`000000oooo0?ooo`3X0?ooo`030?l0
003oool0oooo07@0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`050?ooo`<0
0000]03oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo07L0oooo000X0?ooo`030000
003oool0oooo0>T0oooo00<0o`000?ooo`3oool0L`3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0]03oool00`3o0000oooo0?ooo`080?ooo`03
0?l0003oool0oooo07L0oooo000X0?ooo`030000003oool0oooo0>T0oooo00<0o`000?ooo`3oool0
L`3oool010000000oooo0?ooo`0000080?ooo`8000001`3oool00`000000oooo0?ooo`2d0?ooo`03
0?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0M`3oool002P0oooo0P00003Z0?ooo`030?l0
003oool0oooo07@0oooo0P00000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
]03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo07P0oooo000X0?ooo`030000003o
ool0oooo0>X0oooo00<0o`000?ooo`3oool0Q`3oool00`000000oooo0?ooo`2d0?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool0N03oool002P0oooo00<000000?ooo`3oool0jP3oool0
0`3o0000oooo0?ooo`270?ooo`030000003oool0oooo0;@0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`1h0?ooo`00:03oool00`000000oooo0?ooo`3Z0?ooo`030?l0003oool0oooo
08L0oooo00<000000?ooo`3oool0]03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
07P0oooo000X0?ooo`030000003oool0oooo0>X0oooo00<0o`000?ooo`3oool0Q`3oool00`000000
oooo0?ooo`2d0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0N@3oool002P0oooo
00<000000?ooo`3oool0j`3oool00`3o0000oooo0?ooo`260?ooo`030000003oool0oooo0;D0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`1i0?ooo`00:03oool00`000000oooo0?oo
o`3[0?ooo`030?l0003oool0oooo08H0oooo0P00002f0?ooo`030?l0003oool0oooo00D0oooo00<0
o`000?ooo`3oool0N@3oool001@0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`000006
0?ooo`030000003oool0oooo0>/0oooo00<0o`000?ooo`3oool0QP3oool00`000000oooo0?ooo`2e
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0NP3oool001<0oooo00@000000?oo
o`3oool000001`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0k03o
ool00`3o0000oooo0?ooo`250?ooo`030000003oool0oooo0;D0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`1j0?ooo`004`3oool010000000oooo0?ooo`0000070?ooo`050000003o
ool0oooo0?ooo`0000001@3oool300000>`0oooo0P3o00260?ooo`030000003oool0oooo0;D0oooo
00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`1j0?ooo`004`3oool010000000oooo0?oo
o`0000080?ooo`<000001P3oool00`000000oooo0?ooo`3^0?ooo`030?l0003oool0oooo08<0oooo
00<000000?ooo`3oool0]@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo07X0oooo
000C0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000050?ooo`03
0000003oool0oooo0>l0oooo00<0o`000?ooo`3oool0PP3oool00`000000oooo0?ooo`2e0?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0N`3oool001<0oooo00@000000?ooo`3oool0
00001`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0l03oool00`3o
0000oooo0?ooo`210?ooo`030000003oool0oooo0;D0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`1k0?ooo`00503oool2000000T0oooo0`0000060?ooo`030000003oool0oooo0?40
oooo0P3o00210?ooo`030000003oool0oooo0;D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`1k0?ooo`00:03oool00`000000oooo0?ooo`3c0?ooo`030?l0003oool0oooo01<0oooo
0`3o001X0?ooo`030000003oool0oooo0;H0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`1k0?ooo`00:03oool00`000000oooo0?ooo`3d0?ooo`030?l0003oool0oooo0100oooo0P3o
00030?ooo`80o`00IP3oool200000;L0oooo00D0o`000?ooo`3oool0oooo0?l0001n0?ooo`00:03o
ool00`000000oooo0?ooo`3e0?ooo`030?l0003oool0oooo00d0oooo0P3o00070?ooo`80o`00I03o
ool00`000000oooo0?ooo`2f0?ooo`050?l0003oool0oooo0?ooo`3o0000OP3oool002P0oooo00<0
00000?ooo`3oool0mP3oool20?l000X0oooo0`3o000;0?ooo`<0o`00H@3oool00`000000oooo0?oo
o`2f0?ooo`050?l0003oool0oooo0?ooo`3o0000OP3oool002P0oooo00<000000?ooo`3oool0n03o
ool00`3o0000oooo0?ooo`050?ooo`80o`004@3oool20?l005l0oooo00<000000?ooo`3oool0]P3o
ool01@3o0000oooo0?ooo`3oool0o`0007h0oooo000X0?ooo`800000nP3oool00`3o0000oooo0?oo
o`020?ooo`80o`005@3oool20?l005d0oooo00<000000?ooo`3oool0]P3oool0103o0000oooo0?oo
o`3o001o0?ooo`00:03oool00`000000oooo0?ooo`3j0?ooo`040?l0003oool0o`000?l001T0oooo
0P3o001K0?ooo`030000003oool0oooo0;H0oooo00@0o`000?ooo`3oool0o`00O`3oool002P0oooo
00<000000?ooo`3oool0n`3oool00`3o0000oooo0?ooo`0K0?ooo`80o`00F@3oool00`000000oooo
0?ooo`2f0?ooo`040?l0003oool0oooo0?l007l0oooo000X0?ooo`030000003oool0oooo0?l0oooo
703oool00`3o0000oooo0?ooo`1F0?ooo`030000003oool0oooo0;H0oooo00<0o`000?ooo`3o0000
P03oool002P0oooo00<000000?ooo`3oool0o`3ooolM0?ooo`030?l0003oool0oooo05D0oooo00<0
00000?ooo`3oool0]`3oool20?l00800oooo000X0?ooo`030000003oool0oooo0?l0oooo7P3oool0
0`3o0000oooo0?ooo`1D0?ooo`800000^03oool20?l00800oooo000X0?ooo`030000003oool0oooo
0?l0oooo7`3oool00`3o0000oooo0?ooo`1C0?ooo`030000003oool0oooo0;L0oooo0P3o00200?oo
o`00:03oool00`000000oooo0?ooo`3o0?ooob00oooo00<0o`000?ooo`3oool0DP3oool00`000000
oooo0?ooo`2g0?ooo`030?l0003oool0oooo07l0oooo000X0?ooo`030000003oool0oooo0?l0oooo
8@3oool00`3o0000oooo0?ooo`1A0?ooo`030000003oool0oooo0;L0oooo00<0o`000?ooo`3oool0
O`3oool002P0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`030?l0003oool0oooo0500oooo00<0
00000?ooo`3oool0o`3ooolj0?ooo`00:03oool200000?l0oooo903oool00`3o0000oooo0?ooo`1?
0?ooo`030000003oool0oooo0?l0oooo>P3oool002P0oooo00<000000?ooo`3oool0o`3ooolT0?oo
o`030?l0003oool0oooo04h0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooobD0oooo00<0o`000?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?ooocX0
oooo000X0?ooo`030000003oool0oooo0?l0oooo9P3oool00`3o0000oooo0?ooo`1<0?ooo`030000
003oool0oooo0?l0oooo>P3oool002P0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030?l0003o
ool0oooo0?l0ooooR03oool002P0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`030?l0003oool0
oooo0?l0ooooQ`3oool002P0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`030?l0003oool0oooo
0?l0ooooQP3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oook80oooo000X0?ooo`030000
003oool0oooo0?l0ooooo`3ooonb0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooool0oooo/P3o
ool002P0oooo0P00003o0?ooool0oooo/`3oool002P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ok80oooo003o0?ooool0oooog@3oool00?l0ooooo`3ooooM0?ooo`00o`3ooooo0?ooomd0oooo003o
0?ooool0oooog@3oool00?l0ooooo`3ooooM0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 730}, {214.062, 0}} -> {-0.0538194, -0.0147182, \
0.00288718, 0.00288718}, {{18.625, 348.5}, {208.938, 5.0625}} -> {-27.1285, \
-0.0946588, 0.669012, 0.00502581}, {{381.438, 711.312}, {208.938, 5.0625}} -> \
{-289.238, -0.0786546, 0.696612, 0.00108113}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{901, 692},
WindowMargins->{{30, Automatic}, {Automatic, 1}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "IterateExact"->{
    Cell[2044, 64, 1018, 22, 70, "DefinitionBox",
      CellTags->{"IterateExact", "StoreExact"}],
    Cell[79662, 1759, 652, 12, 70, "DefinitionBox",
      CellTags->"IterateExact"]},
  "StoreExact"->{
    Cell[2044, 64, 1018, 22, 70, "DefinitionBox",
      CellTags->{"IterateExact", "StoreExact"}]},
  "Immigration"->{
    Cell[79578, 1756, 81, 1, 20, "SubsubsectionIcon",
      CellTags->"Immigration"]},
  "DemeSize"->{
    Cell[82613, 1825, 845, 16, 108, "DefinitionBox",
      CellTags->{"DemeSize", "PowerF", "ExponentialF"}]},
  "PowerF"->{
    Cell[82613, 1825, 845, 16, 108, "DefinitionBox",
      CellTags->{"DemeSize", "PowerF", "ExponentialF"}]},
  "ExponentialF"->{
    Cell[82613, 1825, 845, 16, 108, "DefinitionBox",
      CellTags->{"DemeSize", "PowerF", "ExponentialF"}]},
  "Life cycle"->{
    Cell[145762, 3181, 69, 1, 20, "SubsubsectionIcon",
      CellTags->"Life cycle"]},
  "MigrationOrder"->{
    Cell[145834, 3184, 1008, 18, 90, "DefinitionBox",
      CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}]},
  "UMS"->{
    Cell[145834, 3184, 1008, 18, 90, "DefinitionBox",
      CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}]},
  "MUS"->{
    Cell[145834, 3184, 1008, 18, 90, "DefinitionBox",
      CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}]},
  "USM"->{
    Cell[145834, 3184, 1008, 18, 90, "DefinitionBox",
      CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"IterateExact", 510142, 10947},
  {"StoreExact", 510345, 10952},
  {"Immigration", 510464, 10955},
  {"DemeSize", 510567, 10958},
  {"PowerF", 510692, 10961},
  {"ExponentialF", 510823, 10964},
  {"Life cycle", 510952, 10967},
  {"MigrationOrder", 511061, 10970},
  {"UMS", 511185, 10973},
  {"MUS", 511309, 10976},
  {"USM", 511433, 10979}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 44, 0, 36, "SubsectionIcon"],
Cell[1786, 53, 82, 1, 28, "MathCaption"],
Cell[1871, 56, 103, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[1999, 62, 42, 0, 24, "SubsubsectionIcon"],
Cell[2044, 64, 1018, 22, 70, "DefinitionBox",
  CellTags->{"IterateExact", "StoreExact"}],
Cell[3065, 88, 123, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3213, 95, 546, 14, 72, "Input"],
Cell[3762, 111, 25100, 715, 184, 8609, 506, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[28877, 829, 98, 3, 28, "MathCaption"],
Cell[28978, 834, 129, 3, 27, "Input"],

Cell[CellGroupData[{
Cell[29132, 841, 65, 2, 27, "Input"],
Cell[29200, 845, 76, 2, 20, "Print"],
Cell[29279, 849, 20241, 286, 1361, "Print"]
}, Closed]],
Cell[49535, 1138, 102, 3, 18, "Text"],
Cell[49640, 1143, 142, 3, 22, "Text"],
Cell[49785, 1148, 71, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[49881, 1152, 329, 7, 42, "Input"],
Cell[50213, 1161, 29316, 589, 184, 3815, 269, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[79578, 1756, 81, 1, 20, "SubsubsectionIcon",
  CellTags->"Immigration"],
Cell[79662, 1759, 652, 12, 70, "DefinitionBox",
  CellTags->"IterateExact"],
Cell[80317, 1773, 72, 0, 28, "MathCaption"],
Cell[80392, 1775, 167, 4, 27, "Input"],
Cell[80562, 1781, 118, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[80705, 1788, 210, 5, 43, "Input"],
Cell[80918, 1795, 1597, 22, 111, "Output"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[82564, 1823, 46, 0, 24, "SubsubsectionIcon"],
Cell[82613, 1825, 845, 16, 108, "DefinitionBox",
  CellTags->{"DemeSize", "PowerF", "ExponentialF"}],
Cell[83461, 1843, 58, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[83544, 1847, 148, 3, 27, "Input"],
Cell[83695, 1852, 1006, 14, 72, "Output"]
}, Closed]],
Cell[84716, 1869, 377, 10, 20, "Text"],
Cell[85096, 1881, 188, 4, 22, "Text"],
Cell[85287, 1887, 246, 5, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[85558, 1896, 828, 16, 87, "Input"],
Cell[86389, 1914, 58019, 1214, 178, 7710, 588, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[144423, 3131, 94, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[144542, 3138, 200, 5, 27, "Input"],
Cell[144745, 3145, 87, 2, 20, "Output"]
}, Closed]],
Cell[144847, 3150, 528, 12, 38, "Text"],
Cell[145378, 3164, 94, 3, 22, "Text"],
Cell[145475, 3169, 250, 7, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145762, 3181, 69, 1, 20, "SubsubsectionIcon",
  CellTags->"Life cycle"],
Cell[145834, 3184, 1008, 18, 90, "DefinitionBox",
  CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}],
Cell[146845, 3204, 283, 5, 36, "Text"],
Cell[147131, 3211, 152, 3, 27, "Input"],
Cell[147286, 3216, 165, 4, 28, "MathCaption"],
Cell[147454, 3222, 287, 6, 42, "Input"],
Cell[147744, 3230, 901, 18, 102, "Input"],

Cell[CellGroupData[{
Cell[148670, 3252, 70, 2, 27, "Input"],
Cell[148743, 3256, 105350, 1812, 181, 8701, 614, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[254108, 5071, 245, 5, 32, "Text"],
Cell[254356, 5078, 162, 4, 27, "Input"],

Cell[CellGroupData[{
Cell[254543, 5086, 263, 6, 43, "Input"],
Cell[254809, 5094, 89555, 1648, 195, 9128, 650, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[344379, 6745, 166, 4, 18, "Text"],
Cell[344548, 6751, 245, 5, 36, "Text"],
Cell[344796, 6758, 139, 3, 27, "Input"],
Cell[344938, 6763, 452, 8, 50, "Text"],

Cell[CellGroupData[{
Cell[345415, 6775, 235, 5, 43, "Input"],
Cell[345653, 6782, 93142, 1595, 222, 7511, 533, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

