(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11213,        304]*)
(*NotebookOutlinePosition[     12717,        351]*)
(*  CellTagsIndexPosition[     12535,        342]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Avoid integer parameters", "SubsectionIcon",
  CellTags->"Avoid integers"],

Cell["\<\
  If IterateExact[] is called with integer parameters, the Kernel \
may crash, since it will calculate extremely long rational numbers.  Use \
either Compiled\[Rule]True (which forces numerical approximation) or real \
arguments.\
\>", "Text",
  CellDingbat->"\[FivePointedStar]"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Redefining fitness functions", "SubsectionIcon",
  CellTags->{"pitfall", "Redefining fitness"}],

Cell["\<\
  If GameteTable[] (perhaps via NewGametes[]) is called with a \
fitness function W, the result is stored as GameteTable[n,W].  If the \
function W is then redefined, the old values are still used - which can be \
extremely confusing.  \
\>", "Text",
  CellDingbat->"\[FivePointedStar]"],

Cell["\<\
The same problem arises with compiled versions of IterateExact, \
when using AlleleFrequencies.  This is because compiled code specific to each \
fitness function is stored.  Again, it is essential to give distinct names to \
the functions.\
\>", "Text",
  CellTags->"AlleleFrequencies"],

Cell["\<\
Here W is defined to give selection against heterozygotes.  The \
result is stored in GameteTable[3,W]: \
\>", "MathCaption"],

Cell[BoxData[
    \(W[i_, j_, h_] := 0.9\^h; GameteTable[3, W]; \)], "Input",
  CellLabel->"In[8]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(?? GameteTable\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    StyleBox[
      \(GameteTable[3, \ W]\  = 
        \ {{{1, \ 0, \ 0, \ 0}, \ {0.45, \ 0.45, \ 0, \ 0}, 
            \ {0.2025, \ 0.405, \ 0.2025, \ 0}, 
            \ {0.091125, \ 0.273375, \ 0.273375, \ 0.091125}}, 
          \ {{0.45, \ 0.45, \ 0, \ 0}, 
            \ {0.135, \ 0.6033333333333334, \ 0.135, \ 0}, 
            \ {0.030375, \ 0.3911249999999999, \ 0.3911249999999999, \ 
              0.030375}, \ {0, \ 0.2025, \ 0.405, \ 0.2025}}, 
          \ {{0.2025, \ 0.405, \ 0.2025, \ 0}, 
            \ {0.030375, \ 0.3911249999999999, \ 0.3911249999999999, \ 
              0.030375}, \ {0, \ 0.135, \ 0.6033333333333334, \ 0.135}, 
            \ {0, \ 0, \ 0.45, \ 0.45}}, 
          \ {{0.091125, \ 0.273375, \ 0.273375, \ 0.091125}, 
            \ {0, \ 0.2025, \ 0.405, \ 0.2025}, \ {0, \ 0, \ 0.45, \ 0.45}, 
            \ {0, \ 0, \ 0, \ 1}}}\),
      ShowStringCharacters->True,
      NumberMarks->True]], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Closed]],

Cell["If W is redefined, the same old result is still used:", "MathCaption"],

Cell[BoxData[
    \(W[i_, j_, h_] := 0.8\^h; GameteTable[3, W]; \)], "Input",
  CellLabel->"In[10]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(?? GameteTable\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    StyleBox[
      \(GameteTable[3, \ W]\  = 
        \ {{{1, \ 0, \ 0, \ 0}, \ {0.45, \ 0.45, \ 0, \ 0}, 
            \ {0.2025, \ 0.405, \ 0.2025, \ 0}, 
            \ {0.091125, \ 0.273375, \ 0.273375, \ 0.091125}}, 
          \ {{0.45, \ 0.45, \ 0, \ 0}, 
            \ {0.135, \ 0.6033333333333334, \ 0.135, \ 0}, 
            \ {0.030375, \ 0.3911249999999999, \ 0.3911249999999999, \ 
              0.030375}, \ {0, \ 0.2025, \ 0.405, \ 0.2025}}, 
          \ {{0.2025, \ 0.405, \ 0.2025, \ 0}, 
            \ {0.030375, \ 0.3911249999999999, \ 0.3911249999999999, \ 
              0.030375}, \ {0, \ 0.135, \ 0.6033333333333334, \ 0.135}, 
            \ {0, \ 0, \ 0.45, \ 0.45}}, 
          \ {{0.091125, \ 0.273375, \ 0.273375, \ 0.091125}, 
            \ {0, \ 0.2025, \ 0.405, \ 0.2025}, \ {0, \ 0, \ 0.45, \ 0.45}, 
            \ {0, \ 0, \ 0, \ 1}}}\),
      ShowStringCharacters->True,
      NumberMarks->True]], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Closed]],

Cell["\<\
There are two ways round this problem.  First, the function can be \
stored as a a pure function.  The distinct form is then used in storage:\
\>",
   "Text",
  CellDingbat->"\[FivePointedStar]"],

Cell[BoxData[
    \(W = 0.8\^#3&; GameteTable[3, W]; \)], "Input",
  CellLabel->"In[14]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(?? GameteTable\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    StyleBox[
      \(GameteTable[3, \ 0.8^#3]\  = 
        \ {{{\((0.8^#3)\)[0, \ 0, \ 0], \ 0, \ 0, \ 0}, 
            \ {\((0.8^#3)\)[0, \ 1, \ 1]/2, \ \((0.8^#3)\)[0, \ 1, \ 1]/2, \ 
              0, \ 0}, 
            \ {\((0.8^#3)\)[0, \ 2, \ 2]/4, \ \((0.8^#3)\)[0, \ 2, \ 2]/2, \ 
              \((0.8^#3)\)[0, \ 2, \ 2]/4, \ 0}, 
            \ {\((0.8^#3)\)[0, \ 3, \ 3]/8, \ 
              \((3*\((0.8^#3)\)[0, \ 3, \ 3])\)/8, \ 
              \((3*\((0.8^#3)\)[0, \ 3, \ 3])\)/8, \ 
              \((0.8^#3)\)[0, \ 3, \ 3]/8}}, 
          \ {{\((0.8^#3)\)[1, \ 0, \ 1]/2, \ \((0.8^#3)\)[1, \ 0, \ 1]/2, \ 
              0, \ 0}, 
            \ {\((0.8^#3)\)[1, \ 1, \ 2]/6, \ 
              \((4*\((0.8^#3)\)[1, \ 1, \ 0]\  + \ 
                    4*\((0.8^#3)\)[1, \ 1, \ 2])\)/12, \ 
              \((0.8^#3)\)[1, \ 1, \ 2]/6, \ 0}, 
            \ {\((0.8^#3)\)[1, \ 2, \ 3]/24, \ 
              \((8*\((0.8^#3)\)[1, \ 2, \ 1]\  + \ 
                    3*\((0.8^#3)\)[1, \ 2, \ 3])\)/24, \ 
              \((8*\((0.8^#3)\)[1, \ 2, \ 1]\  + \ 
                    3*\((0.8^#3)\)[1, \ 2, \ 3])\)/24, \ 
              \((0.8^#3)\)[1, \ 2, \ 3]/24}, 
            \ {0, \ \((0.8^#3)\)[1, \ 3, \ 2]/4, \ 
              \((0.8^#3)\)[1, \ 3, \ 2]/2, \ \((0.8^#3)\)[1, \ 3, \ 2]/4}}, 
          \ {{\((0.8^#3)\)[2, \ 0, \ 2]/4, \ \((0.8^#3)\)[2, \ 0, \ 2]/2, \ 
              \((0.8^#3)\)[2, \ 0, \ 2]/4, \ 0}, 
            \ {\((0.8^#3)\)[2, \ 1, \ 3]/24, \ 
              \((8*\((0.8^#3)\)[2, \ 1, \ 1]\  + \ 
                    3*\((0.8^#3)\)[2, \ 1, \ 3])\)/24, \ 
              \((8*\((0.8^#3)\)[2, \ 1, \ 1]\  + \ 
                    3*\((0.8^#3)\)[2, \ 1, \ 3])\)/24, \ 
              \((0.8^#3)\)[2, \ 1, \ 3]/24}, 
            \ {0, \ \((0.8^#3)\)[2, \ 2, \ 2]/6, \ 
              \((16*\((0.8^#3)\)[2, \ 2, \ 0]\  + \ 
                    16*\((0.8^#3)\)[2, \ 2, \ 2])\)/48, \ 
              \((0.8^#3)\)[2, \ 2, \ 2]/6}, 
            \ {0, \ 0, \ \((0.8^#3)\)[2, \ 3, \ 1]/2, \ 
              \((0.8^#3)\)[2, \ 3, \ 1]/2}}, 
          \ {{\((0.8^#3)\)[3, \ 0, \ 3]/8, \ 
              \((3*\((0.8^#3)\)[3, \ 0, \ 3])\)/8, \ 
              \((3*\((0.8^#3)\)[3, \ 0, \ 3])\)/8, \ 
              \((0.8^#3)\)[3, \ 0, \ 3]/8}, 
            \ {0, \ \((0.8^#3)\)[3, \ 1, \ 2]/4, \ 
              \((0.8^#3)\)[3, \ 1, \ 2]/2, \ \((0.8^#3)\)[3, \ 1, \ 2]/4}, 
            \ {0, \ 0, \ \((0.8^#3)\)[3, \ 2, \ 1]/2, \ 
              \((0.8^#3)\)[3, \ 2, \ 1]/2}, 
            \ {0, \ 0, \ 0, \ \((0.8^#3)\)[3, \ 3, \ 0]}}}\),
      ShowStringCharacters->True,
      NumberMarks->True]], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Closed]],

Cell[TextData[{
  "This is clumsy, especially when using a spatial model, in which fitness \
must be a function of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(W[d]\)[i, j, h]\)]],
  ".  "
}], "Text"],

Cell["\<\
A better approach is to use distinct names for the fitnesses:\
\>", \
"MathCaption"],

Cell[BoxData[
    \(\(hetW[s_]\)[_, _, h_] := \((1 - s)\)\^h; GameteTable[3, hetW[0.3]]; 
    \)], "Input",
  CellLabel->"In[16]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(?? GameteTable\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    StyleBox[
      \(GameteTable[3, \ hetW[0.3]]\  = 
        \ {{{1, \ 0, \ 0, \ 0}, 
            \ {0.3499999999999999, \ 0.3499999999999999, \ 0, \ 0}, 
            \ {0.1224999999999999, \ 0.2449999999999999, \ 
              0.1224999999999999, \ 0}, 
            \ {0.04287499999999998, \ 0.1286249999999999, \ 
              0.1286249999999999, \ 0.04287499999999998}}, 
          \ {{0.35, \ 0.35, \ 0, \ 0}, 
            \ {0.08166666666666666, \ 0.4966666666666666, \ 
              0.08166666666666666, \ 0}, 
            \ {0.01429166666666666, \ 0.2762083333333333, \ 
              0.2762083333333333, \ 0.01429166666666666}, 
            \ {0, \ 0.1224999999999999, \ 0.2449999999999999, \ 
              0.1224999999999999}}, 
          \ {{0.1224999999999999, \ 0.2449999999999999, \ 0.1224999999999999, 
              \ 0}, \ {0.01429166666666666, \ 0.2762083333333333, \ 
              0.2762083333333333, \ 0.01429166666666666}, 
            \ {0, \ 0.08166666666666666, \ 0.4966666666666666, \ 
              0.08166666666666666}, \ {0, \ 0, \ 0.35, \ 0.35}}, 
          \ {{0.04287499999999998, \ 0.1286249999999999, \ 
              0.1286249999999999, \ 0.04287499999999998}, 
            \ {0, \ 0.1224999999999999, \ 0.2449999999999999, \ 
              0.1224999999999999}, 
            \ {0, \ 0, \ 0.3499999999999999, \ 0.3499999999999999}, 
            \ {0, \ 0, \ 0, \ 1}}}\),
      ShowStringCharacters->True,
      NumberMarks->True]], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Other forms of migration", "SubsectionIcon"],

Cell[TextData[{
  "It is assumed that a constant fraction of  individuals migrate.  It is \
awkward to implement other forms of migration, though there are some ",
  ButtonBox["notes",
    ButtonData:>{"Allele frequencies: migration", "Constant numbers"},
    ButtonStyle->"AddOnsLink"],
  " on how to allow a constant ",
  StyleBox["number",
    FontSlant->"Italic"],
  " to migrate into a single deme."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{526, 699},
WindowMargins->{{Automatic, -5}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Avoid integers"->{
    Cell[1739, 51, 80, 1, 36, "SubsectionIcon",
      CellTags->"Avoid integers"]},
  "pitfall"->{
    Cell[2149, 65, 101, 1, 36, "SubsectionIcon",
      CellTags->{"pitfall", "Redefining fitness"}]},
  "Redefining fitness"->{
    Cell[2149, 65, 101, 1, 36, "SubsectionIcon",
      CellTags->{"pitfall", "Redefining fitness"}]},
  "AlleleFrequencies"->{
    Cell[2553, 76, 297, 6, 50, "Text",
      CellTags->"AlleleFrequencies"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Avoid integers", 12078, 326},
  {"pitfall", 12177, 329},
  {"Redefining fitness", 12305, 332},
  {"AlleleFrequencies", 12432, 335}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 80, 1, 36, "SubsectionIcon",
  CellTags->"Avoid integers"],
Cell[1822, 54, 290, 6, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2149, 65, 101, 1, 36, "SubsectionIcon",
  CellTags->{"pitfall", "Redefining fitness"}],
Cell[2253, 68, 297, 6, 50, "Text"],
Cell[2553, 76, 297, 6, 50, "Text",
  CellTags->"AlleleFrequencies"],
Cell[2853, 84, 135, 3, 42, "MathCaption"],
Cell[2991, 89, 101, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[3117, 95, 71, 2, 27, "Input"],
Cell[3191, 99, 1003, 20, 125, "Print"]
}, Closed]],
Cell[4209, 122, 76, 0, 18, "MathCaption"],
Cell[4288, 124, 102, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[4415, 130, 72, 2, 27, "Input"],
Cell[4490, 134, 1003, 20, 125, "Print"]
}, Closed]],
Cell[5508, 157, 205, 5, 32, "Text"],
Cell[5716, 164, 91, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[5832, 170, 72, 2, 27, "Input"],
Cell[5907, 174, 2670, 52, 275, "Print"]
}, Closed]],
Cell[8592, 229, 210, 6, 32, "Text"],
Cell[8805, 237, 94, 3, 28, "MathCaption"],
Cell[8902, 242, 132, 3, 28, "Input"],

Cell[CellGroupData[{
Cell[9059, 249, 72, 2, 27, "Input"],
Cell[9134, 253, 1545, 30, 185, "Print"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10728, 289, 50, 0, 36, "SubsectionIcon"],
Cell[10781, 291, 416, 10, 52, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

