(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    105525,       2389]*)
(*NotebookOutlinePosition[    177305,       4965]*)
(*  CellTagsIndexPosition[    177168,       4957]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Stability", "SubsectionIcon"],

Cell["\<\
The stability of an equilibrium is given by the eigenvalues of the \
stability matrix.  This is the matrix of derivatives of the new values with \
respect to the old values.  \
\>", "Text"],

Cell["\<\
The stability matrix can also be calculated for populations which \
are not at equilibrium.  For example, it might be used to calculate the \
distribution of fluctuations caused by random drift, or the sensitivity of \
the outcome to initial conditions.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(StabilityDirect[HaploidFrequencies[\[Psi], n], W, 
              m]\), \(gives\ the\ derivative\ of\ {\(\[Psi]\^*\), \(n\^*\)}\ \
wrt\ \[Psi], n, \ 
            by\ direct\ differentiation\ of\ \(\(IterateExact[]\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->"StabilityDirect"]], "DefinitionBox",
  CellTags->"StabilityDirect"],

Cell[TextData[{
  "StabilityDirect[] can take all the options of IterateExact[].  However, \
RandomDrift->True and Compiled\[Rule]True cannot be used, since algebraic \
derivatives are taken.   For a single deme, generates one number, whilst for \
a stepping-stone model, generates an array ",
  Cell[BoxData[
      \(n\_d\[Times]n\_d\)]],
  "."
}], "Text"],

Cell["This loads the package. ", "MathCaption",
  CellTags->{"S5.24.1", "1.4"}],

Cell[BoxData[
    \(\(<< NumericalModels`ExactModel`;\)\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
This defines a fitness with heterozygote advantage s at two loci, \
and with epistasis \[Epsilon] favouring genotypes {0,0} and {1,1}:\
\>", \
"MathCaption"],

Cell[BoxData[
    \(\(\(w[s_, \[Epsilon]_, epi]\)[x_, y_] := 
        1 + s*CountHeterozygotes[x, 
              y] + \[Epsilon] \((x\[LeftDoubleBracket]1\[RightDoubleBracket] \
+ y\[LeftDoubleBracket]1\[RightDoubleBracket] - 
                1)\) \((x\[LeftDoubleBracket]2\[RightDoubleBracket] + 
                y\[LeftDoubleBracket]2\[RightDoubleBracket] - 
                1)\);\)\)], "Input",
  CellLabel->"In[2]:="],

Cell["The individual fitnesses are:", "MathCaption"],

Cell[BoxData[GridBox[{
        {" ", \(\(Q\_2\) Q\_2\), \(\(Q\_2\) P\_2\), \(\(P\_2\) P\_2\)},
        {\(\(Q\_1\) Q\_1\), \(1 + \[Epsilon]\), \(1 + 
            s\), \(1 - \[Epsilon]\)},
        {\(\(Q\_1\) P\_1\), \(1 + s\), \(1 + 2  s\), \(1 + s\)},
        {\(\(P\_1\) P\_1\), \(1 - \[Epsilon]\), \(1 + 
            s\), \(1 + \[Epsilon]\)}
        },
      GridFrame->True,
      RowLines->True,
      ColumnLines->True]], "DisplayMath"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MeanW[MakeDiploid[MakePopulation[2, {p1, p2}]], 
      w[0.15, 0.3, epi]]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(1.3`\ \((1 - p1)\)\^2\ \((1 - p2)\)\^2 + 
      2.3`\ \((1 - p1)\)\ p1\ \((1 - p2)\)\^2 + 
      0.7`\ p1\^2\ \((1 - p2)\)\^2 + 
      2.3`\ \((1 - p1)\)\^2\ \((1 - p2)\)\ p2 + 
      5.2`\ \((1 - p1)\)\ p1\ \((1 - p2)\)\ p2 + 
      2.3`\ p1\^2\ \((1 - p2)\)\ p2 + 0.7`\ \((1 - p1)\)\^2\ p2\^2 + 
      2.3`\ \((1 - p1)\)\ p1\ p2\^2 + 1.3`\ p1\^2\ p2\^2\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[TextData[{
  "This shows the mean fitness as a function of allele frequencies (i.e. the \
",
  StyleBox["adaptive landscape",
    FontSlant->"Italic"],
  "):"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(wb = 
      MeanW[MakeDiploid[MakePopulation[2, {p1, p2}]], w[0.15, 0.3, epi]]; 
    ContourPlot[wb, {p1, 0, 1}, {p2, 0, 1}];\)], "Input",
  CellLabel->"In[13]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.21154 -0.0125 -9 -9 ]
[.21154 -0.0125 9 0 ]
[.40385 -0.0125 -9 -9 ]
[.40385 -0.0125 9 0 ]
[.59615 -0.0125 -9 -9 ]
[.59615 -0.0125 9 0 ]
[.78846 -0.0125 -9 -9 ]
[.78846 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -18 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -18 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -18 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -18 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(0.2)] .21154 -0.0125 0 1 Mshowa
.40385 0 m
.40385 .00625 L
s
[(0.4)] .40385 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(0.6)] .59615 -0.0125 0 1 Mshowa
.78846 0 m
.78846 .00625 L
s
[(0.8)] .78846 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.5 0 m
.5 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0.2)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(0.4)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(0.6)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(0.8)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(1)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .25962 m
.00375 .25962 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .45192 m
.00375 .45192 L
s
0 .5 m
.00375 .5 L
s
0 .54808 m
.00375 .54808 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .74038 m
.00375 .74038 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.21154 .99375 m
.21154 1 L
s
.40385 .99375 m
.40385 1 L
s
.59615 .99375 m
.59615 1 L
s
.78846 .99375 m
.78846 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.25962 .99625 m
.25962 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.45192 .99625 m
.45192 1 L
s
.5 .99625 m
.5 1 L
s
.54808 .99625 m
.54808 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.74038 .99625 m
.74038 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .5 m
1 .5 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.8 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.7 g
.01923 .38371 m
.08791 .40417 L
.15659 .42541 L
.17359 .43132 L
.22527 .44802 L
.29396 .47325 L
.35442 .5 L
.36264 .50393 L
.43132 .55169 L
.44831 .56868 L
.49607 .63736 L
.5 .64558 L
.52675 .70604 L
.55198 .77473 L
.56868 .82641 L
.57459 .84341 L
.59583 .91209 L
.61629 .98077 L
.01923 .98077 L
F
0 g
.01923 .38371 m
.08791 .40417 L
.15659 .42541 L
.17359 .43132 L
.22527 .44802 L
.29396 .47325 L
.35442 .5 L
.36264 .50393 L
.43132 .55169 L
.44831 .56868 L
.49607 .63736 L
.5 .64558 L
.52675 .70604 L
.55198 .77473 L
.56868 .82641 L
.57459 .84341 L
.59583 .91209 L
.61629 .98077 L
s
.6 g
.01923 .48236 m
.05584 .5 L
.08791 .51665 L
.15659 .5557 L
.17721 .56868 L
.22527 .60169 L
.27057 .63736 L
.29396 .65793 L
.34207 .70604 L
.36264 .72943 L
.39831 .77473 L
.43132 .82279 L
.4443 .84341 L
.48335 .91209 L
.5 .94416 L
.51764 .98077 L
.01923 .98077 L
F
0 g
.01923 .48236 m
.05584 .5 L
.08791 .51665 L
.15659 .5557 L
.17721 .56868 L
.22527 .60169 L
.27057 .63736 L
.29396 .65793 L
.34207 .70604 L
.36264 .72943 L
.39831 .77473 L
.43132 .82279 L
.4443 .84341 L
.48335 .91209 L
.5 .94416 L
.51764 .98077 L
s
.5 g
.01923 .57163 m
.08791 .61577 L
.11847 .63736 L
.15659 .66632 L
.20398 .70604 L
.22527 .72545 L
.27455 .77473 L
.29396 .79602 L
.33368 .84341 L
.36264 .88153 L
.38423 .91209 L
.42837 .98077 L
.01923 .98077 L
F
0 g
.01923 .57163 m
.08791 .61577 L
.11847 .63736 L
.15659 .66632 L
.20398 .70604 L
.22527 .72545 L
.27455 .77473 L
.29396 .79602 L
.33368 .84341 L
.36264 .88153 L
.38423 .91209 L
.42837 .98077 L
s
.4 g
.01923 .65379 m
.08791 .70538 L
.08874 .70604 L
.15659 .76415 L
.16799 .77473 L
.22527 .83201 L
.23585 .84341 L
.29396 .91126 L
.29462 .91209 L
.34621 .98077 L
.01923 .98077 L
F
0 g
.01923 .65379 m
.08791 .70538 L
.08874 .70604 L
.15659 .76415 L
.16799 .77473 L
.22527 .83201 L
.23585 .84341 L
.29396 .91126 L
.29462 .91209 L
.34621 .98077 L
s
.9 g
.01923 .27191 m
.08791 .2708 L
.15659 .25858 L
.21714 .22527 L
.22527 .21714 L
.25858 .15659 L
.2708 .08791 L
.27191 .01923 L
.01923 .01923 L
F
0 g
.01923 .27191 m
.08791 .2708 L
.15659 .25858 L
.21714 .22527 L
.22527 .21714 L
.25858 .15659 L
.2708 .08791 L
.27191 .01923 L
s
.3 g
.01923 .73029 m
.07301 .77473 L
.08791 .7878 L
.14718 .84341 L
.15659 .85282 L
.2122 .91209 L
.22527 .92699 L
.26971 .98077 L
.01923 .98077 L
F
0 g
.01923 .73029 m
.07301 .77473 L
.08791 .7878 L
.14718 .84341 L
.15659 .85282 L
.2122 .91209 L
.22527 .92699 L
.26971 .98077 L
s
.2 g
.01923 .80217 m
.06551 .84341 L
.08791 .86452 L
.13548 .91209 L
.15659 .93449 L
.19783 .98077 L
.01923 .98077 L
F
0 g
.01923 .80217 m
.06551 .84341 L
.08791 .86452 L
.13548 .91209 L
.15659 .93449 L
.19783 .98077 L
s
1 g
.01923 .13967 m
.08791 .09711 L
.09711 .08791 L
.13967 .01923 L
.01923 .01923 L
F
0 g
.01923 .13967 m
.08791 .09711 L
.09711 .08791 L
.13967 .01923 L
s
.1 g
.01923 .87018 m
.06343 .91209 L
.08791 .93657 L
.12982 .98077 L
.01923 .98077 L
F
0 g
.01923 .87018 m
.06343 .91209 L
.08791 .93657 L
.12982 .98077 L
s
.01923 .93487 m
.06513 .98077 L
.01923 .98077 L
F
.01923 .93487 m
.06513 .98077 L
s
.7 g
.98077 .61629 m
.91209 .59583 L
.84341 .57459 L
.82641 .56868 L
.77473 .55198 L
.70604 .52675 L
.64558 .5 L
.63736 .49607 L
.56868 .44831 L
.55169 .43132 L
.50393 .36264 L
.5 .35442 L
.47325 .29396 L
.44802 .22527 L
.43132 .17359 L
.42541 .15659 L
.40417 .08791 L
.38371 .01923 L
.98077 .01923 L
F
0 g
.98077 .61629 m
.91209 .59583 L
.84341 .57459 L
.82641 .56868 L
.77473 .55198 L
.70604 .52675 L
.64558 .5 L
.63736 .49607 L
.56868 .44831 L
.55169 .43132 L
.50393 .36264 L
.5 .35442 L
.47325 .29396 L
.44802 .22527 L
.43132 .17359 L
.42541 .15659 L
.40417 .08791 L
.38371 .01923 L
s
.6 g
.98077 .51764 m
.94416 .5 L
.91209 .48335 L
.84341 .4443 L
.82279 .43132 L
.77473 .39831 L
.72943 .36264 L
.70604 .34207 L
.65793 .29396 L
.63736 .27057 L
.60169 .22527 L
.56868 .17721 L
.5557 .15659 L
.51665 .08791 L
.5 .05584 L
.48236 .01923 L
.98077 .01923 L
F
0 g
.98077 .51764 m
.94416 .5 L
.91209 .48335 L
.84341 .4443 L
.82279 .43132 L
.77473 .39831 L
.72943 .36264 L
.70604 .34207 L
.65793 .29396 L
.63736 .27057 L
.60169 .22527 L
.56868 .17721 L
.5557 .15659 L
.51665 .08791 L
.5 .05584 L
.48236 .01923 L
s
.5 g
.98077 .42837 m
.91209 .38423 L
.88153 .36264 L
.84341 .33368 L
.79602 .29396 L
.77473 .27455 L
.72545 .22527 L
.70604 .20398 L
.66632 .15659 L
.63736 .11847 L
.61577 .08791 L
.57163 .01923 L
.98077 .01923 L
F
0 g
.98077 .42837 m
.91209 .38423 L
.88153 .36264 L
.84341 .33368 L
.79602 .29396 L
.77473 .27455 L
.72545 .22527 L
.70604 .20398 L
.66632 .15659 L
.63736 .11847 L
.61577 .08791 L
.57163 .01923 L
s
.4 g
.98077 .34621 m
.91209 .29462 L
.91126 .29396 L
.84341 .23585 L
.83201 .22527 L
.77473 .16799 L
.76415 .15659 L
.70604 .08874 L
.70538 .08791 L
.65379 .01923 L
.98077 .01923 L
F
0 g
.98077 .34621 m
.91209 .29462 L
.91126 .29396 L
.84341 .23585 L
.83201 .22527 L
.77473 .16799 L
.76415 .15659 L
.70604 .08874 L
.70538 .08791 L
.65379 .01923 L
s
.9 g
.98077 .72809 m
.91209 .7292 L
.84341 .74142 L
.78286 .77473 L
.77473 .78286 L
.74142 .84341 L
.7292 .91209 L
.72809 .98077 L
.98077 .98077 L
F
0 g
.98077 .72809 m
.91209 .7292 L
.84341 .74142 L
.78286 .77473 L
.77473 .78286 L
.74142 .84341 L
.7292 .91209 L
.72809 .98077 L
s
.3 g
.98077 .26971 m
.92699 .22527 L
.91209 .2122 L
.85282 .15659 L
.84341 .14718 L
.7878 .08791 L
.77473 .07301 L
.73029 .01923 L
.98077 .01923 L
F
0 g
.98077 .26971 m
.92699 .22527 L
.91209 .2122 L
.85282 .15659 L
.84341 .14718 L
.7878 .08791 L
.77473 .07301 L
.73029 .01923 L
s
.2 g
.98077 .19783 m
.93449 .15659 L
.91209 .13548 L
.86452 .08791 L
.84341 .06551 L
.80217 .01923 L
.98077 .01923 L
F
0 g
.98077 .19783 m
.93449 .15659 L
.91209 .13548 L
.86452 .08791 L
.84341 .06551 L
.80217 .01923 L
s
1 g
.98077 .86033 m
.91209 .90289 L
.90289 .91209 L
.86033 .98077 L
.98077 .98077 L
F
0 g
.98077 .86033 m
.91209 .90289 L
.90289 .91209 L
.86033 .98077 L
s
.1 g
.98077 .12982 m
.93657 .08791 L
.91209 .06343 L
.87018 .01923 L
.98077 .01923 L
F
0 g
.98077 .12982 m
.93657 .08791 L
.91209 .06343 L
.87018 .01923 L
s
.98077 .06513 m
.93487 .01923 L
.98077 .01923 L
F
.98077 .06513 m
.93487 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[13]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`006@3oool2000002/0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D00000903oool2
000000@0oooo00<000000?ooo`3oool00`3oool3000002@0oooo0P0000040?ooo`030000003oool0
oooo0080oooo0`00000U0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<00000:P3oool3
000000H0oooo000H0?ooo`040000003oool0oooo000002T0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000S0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool08P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000008`3oool0
10000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000:P3oool00`000000oooo
0?ooo`050?ooo`00603oool010000000oooo0?ooo`00000Y0?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool08`3oool010000000oooo0?ooo`0000070?ooo`D000008`3oool01000
0000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000008`3oool010000000oooo0?oo
o`0000070?ooo`050000003oool0oooo0?ooo`000000:P3oool00`000000oooo0?ooo`050?ooo`00
603oool010000000oooo0?ooo`00000Y0?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool08P3oool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo000002@0oooo00@0
00000?ooo`3oool000001`3oool4000002@0oooo00@000000?ooo`3oool00000203oool3000002/0
oooo00<000000?ooo`3oool01@3oool001P0oooo00@000000?ooo`3oool00000:@3oool010000000
oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000008`3oool010000000oooo0?ooo`00
00080?ooo`030000003oool0000002@0oooo00@000000?ooo`3oool000001`3oool00`000000oooo
0?ooo`0U0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000Z0?oo
o`030000003oool0oooo00D0oooo000H0?ooo`040000003oool0oooo000002T0oooo00@000000?oo
o`3oool000001`3oool01@000000oooo0?ooo`3oool0000002<0oooo00@000000?ooo`3oool00000
2@3oool2000002@0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0T0?ooo`04
0000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000Y0?ooo`8000001`3oool0
01T0oooo0P00000[0?ooo`8000002@3oool3000002D0oooo0P00000;0?ooo`030000003oool0oooo
02<0oooo0P00000:0?ooo`8000009@3oool2000000T0oooo0`00000[0?ooo`030000003oool0oooo
00D0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000E0?oo
ool000002`0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool00P3oool100000040oooo000>0?ooo`8000001@3oool00`000000oooo0?oo
o`3o0?ooo`L0oooo0@0000010?ooo`003@3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0?l0oooo1`3oool100000040oooo000=0?ooo`040000003oool0oooo000000@0oooo0P00
000S0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00d0oooo0P0000010?ooo`003@3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0280oooo00<000000>KViP3Vi^H0803Vi^H00`000000c<c<0<c<
c00K0<c<c0030000002c/k<0/k>c01L0/k>c00<0000009VIV@2IVIT05@2IVIT00`000000Ogmo07mo
O`0B07moO`030000001VIVH0IVIV0180IVIV00<0000004a<C01<C4`0401<C4`00`000000<c<c03<c
<`0?03<c<`030000000I6AT06ATI00h06ATI300000050?ooo`4000000@3oool000d0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0Q0?ooo`030000003Vi^H0i^KV0240i^KV00<0
00000<c<c03<c<`06`3<c<`00`000000/k>c0;>c/`0H0;>c/`030000002IVIT0VIVI01D0VIVI00<0
000007moO`1oOgl04P1oOgl00`000000IVIV06IVIP0B06IVIP030000001<C4`0C4a<0100C4a<00<0
000003<c<`0c<c<03`0c<c<00`0000006ATI01TI6@0>01TI6@/000001@3oool100000040oooo000=
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool08@3oool00`000000i^KV0>KV
iP0Q0>KViP030000003<c<`0c<c<01`0c<c<00<000000;>c/`2c/k<05`2c/k<00`000000VIVI09VI
V@0E09VIV@030000001oOgl0Ogmo01<0Ogmo00<0000006IVIP1VIVH04P1VIVH00`000000C4a<04a<
C00@04a<C0030000000c<c<0<c<c00l0<c<c00<0000001TI6@0I6AT03P0I6AT:000000D0oooo0@00
00010?ooo`003P3oool2000000D0oooo00<000000?ooo`3oool0803oool00`000000i^KV0>KViP0R
0>KViP030000003<c<`0c<c<01`0c<c<00<000000;>c/`2c/k<0602c/k<00`000000VIVI09VIV@0E
09VIV@030000001oOgl0Ogmo01<0Ogmo00<0000006IVIP1VIVH04P1VIVH00`000000C4a<04a<C00@
04a<C0030000000c<c<0<c<c00l0<c<c00<0000001TI6@0I6AT03P0I6AT9000000D0oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`0O0?ooo`030000003Vi^H0i^KV02<0i^KV00<000000<c<
c03<c<`0703<c<`00`000000/k>c0;>c/`0H0;>c/`030000002IVIT0VIVI01H0VIVI00<0000007mo
O`1oOgl04P1oOgl00`000000IVIV06IVIP0C06IVIP030000001<C4`0C4a<0100C4a<00<0000003<c
<`0c<c<03`0c<c<00`0000006ATI01TI6@0>01TI6@P000001@3oool100000040oooo000E0?ooo`03
0000003oool0oooo01l0oooo00<000000>KViP3Vi^H08`3Vi^H00`000000c<c<0<c<c00L0<c<c003
0000002c/k<0/k>c01T0/k>c00<0000009VIV@2IVIT05@2IVIT00`000000Ogmo07moO`0C07moO`03
0000001VIVH0IVIV0180IVIV00<0000004a<C01<C4`04@1<C4`00`000000<c<c03<c<`0?03<c<`03
0000000I6AT06ATI00h06ATI1`0000050?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
7P3oool00`000000i^KV0>KViP0T0>KViP030000003<c<`0c<c<01d0c<c<00<000000;>c/`2c/k<0
602c/k<00`000000VIVI09VIV@0F09VIV@030000001oOgl0Ogmo01<0Ogmo00<0000006IVIP1VIVH0
4P1VIVH00`000000C4a<04a<C00A04a<C0030000000c<c<0<c<c00l0<c<c00<0000001TI6@0I6AT0
3P0I6AT6000000D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0N0?ooo`030000003V
i^H0i^KV02@0i^KV00<000000<c<c03<c<`07@3<c<`00`000000/k>c0;>c/`0I0;>c/`030000002I
VIT0VIVI01D0VIVI00<0000007moO`1oOgl0501oOgl00`000000IVIV06IVIP0B06IVIP030000001<
C4`0C4a<0100C4a<00<0000003<c<`0c<c<0400c<c<00`0000006ATI01TI6@0>01TI6@D000001@3o
ool100000040oooo000E0?ooo`030000003oool0oooo01d0oooo00<000000>KViP3Vi^H09@3Vi^H0
0`000000c<c<0<c<c00M0<c<c0030000002c/k<0/k>c01T0/k>c00<0000009VIV@2IVIT05P2IVIT0
0`000000Ogmo07moO`0C07moO`030000001VIVH0IVIV01<0IVIV00<0000004a<C01<C4`0401<C4`0
0`000000<c<c03<c<`0@03<c<`030000000I6AT06ATI00h06ATI100000050?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0703oool00`000000i^KV0>KViP0V0>KViP030000003<c<`0c<c<
01h0c<c<00<000000;>c/`2c/k<06@2c/k<00`000000VIVI09VIV@0F09VIV@030000001oOgl0Ogmo
01<0Ogmo00<0000006IVIP1VIVH04`1VIVH00`000000C4a<04a<C00@04a<C0030000000c<c<0<c<c
0100<c<c00<0000001TI6@0I6AT03P0I6AT3000000D0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`0L0?ooo`030000003Vi^H0i^KV02H0i^KV00<000000<c<c03<c<`07P3<c<`00`000000
/k>c0;>c/`0I0;>c/`030000002IVIT0VIVI01H0VIVI00<0000007moO`1oOgl0501oOgl00`000000
IVIV06IVIP0B06IVIP030000001<C4`0C4a<0140C4a<00<0000003<c<`0c<c<0400c<c<00`000000
6ATI01TI6@0>01TI6@8000001@3oool100000040oooo000E0?ooo`030000003oool0oooo01/0oooo
00<000000>KViP3Vi^H09`3Vi^H00`000000c<c<0<c<c00N0<c<c0030000002c/k<0/k>c01X0/k>c
00<0000009VIV@2IVIT05P2IVIT00`000000Ogmo07moO`0C07moO`030000001VIVH0IVIV01<0IVIV
00<0000004a<C01<C4`04@1<C4`00`000000<c<c03<c<`0@03<c<`030000000I6AT06ATI00h06ATI
00<000000?ooo`3oool00`3oool100000040oooo000E0?ooo`800000703oool00`000000i^KV0>KV
iP0W0>KViP030000003<c<`0c<c<01h0c<c<00<000000;>c/`2c/k<06P2c/k<00`000000VIVI09VI
V@0F09VIV@030000001oOgl0Ogmo01@0Ogmo00<0000006IVIP1VIVH04`1VIVH00`000000C4a<04a<
C00A04a<C0030000000c<c<0<c<c0100<c<c00<0000001TI6@0I6AT03P0I6AT010000000oooo0?oo
o`3oool200000040oooo000E0?ooo`030000003oool0oooo01X0oooo00<000000>KViP3Vi^H0:03V
i^H00`000000c<c<0<c<c00O0<c<c0030000002c/k<0/k>c01X0/k>c00<0000009VIV@2IVIT05P2I
VIT00`000000Ogmo07moO`0D07moO`030000001VIVH0IVIV01<0IVIV00<0000004a<C01<C4`0401<
C4`00`000000<c<c03<c<`0A03<c<`030000000I6AT06ATI00d06ATI1@3oool100000040oooo000E
0?ooo`030000003oool0oooo01X0oooo00<000000>KViP3Vi^H0:03Vi^H00`000000c<c<0<c<c00O
0<c<c0030000002c/k<0/k>c01X0/k>c00<0000009VIV@2IVIT05P2IVIT00`000000Ogmo07moO`0E
07moO`030000001VIVH0IVIV01<0IVIV00<0000004a<C01<C4`0401<C4`00`000000<c<c03<c<`0A
03<c<`030000000I6AT06ATI00`06ATI1@3oool100000040oooo000E0?ooo`030000003oool0oooo
01T0oooo00<000000>KViP3Vi^H0:@3Vi^H00`000000c<c<0<c<c00O0<c<c0030000002c/k<0/k>c
01X0/k>c00<0000009VIV@2IVIT05`2IVIT00`000000Ogmo07moO`0D07moO`030000001VIVH0IVIV
01<0IVIV00<0000004a<C01<C4`04@1<C4`00`000000<c<c03<c<`0A03<c<`030000000I6AT06ATI
00/06ATI1@3oool100000040oooo000E0?ooo`030000003oool0oooo01P0oooo00<000000>KViP3V
i^H0:P3Vi^H00`000000c<c<0<c<c00O0<c<c0030000002c/k<0/k>c01/0/k>c00<0000009VIV@2I
VIT05`2IVIT00`000000Ogmo07moO`0D07moO`030000001VIVH0IVIV01<0IVIV00<0000004a<C01<
C4`04@1<C4`00`000000<c<c03<c<`0A03<c<`030000000I6AT06ATI00X06ATI1@3oool100000040
oooo000E0?ooo`030000003oool0oooo01P0oooo00<000000>KViP3Vi^H0:P3Vi^H00`000000c<c<
0<c<c00P0<c<c0030000002c/k<0/k>c01X0/k>c00<0000009VIV@2IVIT05`2IVIT00`000000Ogmo
07moO`0E07moO`030000001VIVH0IVIV01<0IVIV00<0000004a<C01<C4`04@1<C4`00`000000<c<c
03<c<`0A03<c<`030000000I6AT06ATI00T06ATI1@3oool100000040oooo000E0?ooo`030000003o
ool0oooo01H0oooo0P00000]0>KViP030000003<c<`0c<c<0200c<c<00<000000;>c/`2c/k<06`2c
/k<00`000000VIVI09VIV@0G09VIV@030000001oOgl0Ogmo01D0Ogmo00<0000006IVIP1VIVH04`1V
IVH00`000000C4a<04a<C00A04a<C08000004P0c<c<00`0000006ATI01TI6@0801TI6@D0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`0E0?ooo`030000003Vi^H0i^KV02d0i^KV00<00000
0<c<c03<c<`0803<c<`00`000000/k>c0;>c/`0K0;>c/`030000002IVIT0VIVI01L0VIVI00<00000
07moO`1oOgl05@1oOgl00`000000IVIV06IVIP0D06IVIP030000001<C4`0C4a<0180C4a<00<00000
03<c<`0c<c<0400c<c<00`0000006ATI01TI6@0701TI6@D0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`0C0?ooo`800000<03Vi^H00`000000c<c<0<c<c00Q0<c<c0030000002c/k<0/k>c
01/0/k>c00<0000009VIV@2IVIT05`2IVIT00`000000Ogmo07moO`0E07moO`030000001VIVH0IVIV
01@0IVIV00<0000004a<C01<C4`04P1<C4`00`000000<c<c03<c<`0@03<c<`030000000I6AT06ATI
00H06ATI1@3oool100000040oooo000E0?ooo`030000003oool0oooo0180oooo00<000000>KViP3V
i^H0;`3Vi^H00`000000c<c<0<c<c00R0<c<c0030000002c/k<0/k>c01/0/k>c00<0000009VIV@2I
VIT0602IVIT00`000000Ogmo07moO`0E07moO`030000001VIVH0IVIV01@0IVIV00<0000004a<C01<
C4`04P1<C4`00`000000<c<c03<c<`0@03<c<`030000000I6AT06ATI00D06ATI1@3oool100000040
oooo000E0?ooo`030000003oool0oooo0100oooo0P00000b0>KViP030000003<c<`0c<c<0280c<c<
00<000000;>c/`2c/k<0702c/k<00`000000VIVI09VIV@0H09VIV@030000001oOgl0Ogmo01D0Ogmo
00<0000006IVIP1VIVH0501VIVH00`000000C4a<04a<C00B04a<C0030000000c<c<0<c<c0100<c<c
00<0000001TI6@0I6AT0100I6AT50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool03P3o
ool2000003@0i^KV00<000000<c<c03<c<`08`3<c<`00`000000/k>c0;>c/`0L0;>c/`030000002I
VIT0VIVI01L0VIVI00<0000007moO`1oOgl05P1oOgl00`000000IVIV06IVIP0D06IVIP030000001<
C4`0C4a<0180C4a<00<0000003<c<`0c<c<0400c<c<00`0000006ATI01TI6@0301TI6@D0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`0=0?ooo`030000003Vi^H0i^KV03@0i^KV00<00000
0<c<c03<c<`08`3<c<`00`000000/k>c0;>c/`0L0;>c/`030000002IVIT0VIVI01P0VIVI00<00000
07moO`1oOgl05P1oOgl00`000000IVIV06IVIP0D06IVIP030000001<C4`0C4a<0180C4a<00<00000
03<c<`0c<c<0400c<c<00`0000006ATI01TI6@0201TI6@D0oooo0@0000010?ooo`005@3oool20000
00`0oooo0P00000g0>KViP030000003<c<`0c<c<02<0c<c<00<000000;>c/`2c/k<07@2c/k<00`00
0000VIVI09VIV@0H09VIV@030000001oOgl0Ogmo01H0Ogmo00<0000006IVIP1VIVH0501VIVH00`00
0000C4a<04a<C00B04a<C0030000000c<c<0<c<c0100<c<c00@0000001TI6@0I6AT06ATI103oool2
00000040oooo000E0?ooo`030000003oool0oooo00T0oooo0P00000h0>KViP030000003<c<`0c<c<
02D0c<c<00<000000;>c/`2c/k<0702c/k<00`000000VIVI09VIV@0I09VIV@030000001oOgl0Ogmo
01H0Ogmo00<0000006IVIP1VIVH0501VIVH00`000000C4a<04a<C00B04a<C0030000000c<c<0<c<c
0100<c<c00<0000001TI6@0I6AT01@3oool100000040oooo000E0?ooo`030000003oool0oooo00P0
oooo00<000000>KViP3Vi^H0>03Vi^H00`000000c<c<0<c<c00U0<c<c0030000002c/k<0/k>c01d0
/k>c00<0000009VIV@2IVIT0602IVIT00`000000Ogmo07moO`0G07moO`030000001VIVH0IVIV01@0
IVIV00<0000004a<C01<C4`04P1<C4`00`000000<c<c03<c<`0@03<c<`030000000I6AT0oooo00@0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`060?ooo`800000>`3Vi^H00`000000c<c<
0<c<c00U0<c<c0030000002c/k<0/k>c01d0/k>c00<0000009VIV@2IVIT06@2IVIT00`000000Ogmo
07moO`0F07moO`030000001VIVH0IVIV01D0IVIV00<0000004a<C01<C4`04P1<C4`00`000000<c<c
03<c<`0@03<c<`030000003oool0oooo00<0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`040?ooo`800000?@3Vi^H00`000000c<c<0<c<c00V0<c<c0030000002c/k<0/k>c01d0/k>c00<0
000009VIV@2IVIT06@2IVIT00`000000Ogmo07moO`0F07moO`030000001VIVH0IVIV01D0IVIV00<0
000004a<C01<C4`04P1<C4`00`000000<c<c03<c<`0@03<c<`030000003oool0oooo0080oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003Vi^H0i^KV03`0i^KV00<00000
0<c<c03<c<`09`3<c<`00`000000/k>c0;>c/`0M0;>c/`030000002IVIT0VIVI01X0VIVI00<00000
07moO`1oOgl05P1oOgl00`000000IVIV06IVIP0E06IVIP030000001<C4`0C4a<0180C4a<00<00000
03<c<`0c<c<03`0c<c<50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3oool00`00
0000i^KV0>KViP0m0>KViP030000003<c<`0c<c<02L0c<c<00<000000;>c/`2c/k<07P2c/k<00`00
0000VIVI09VIV@0J09VIV@030000001oOgl0Ogmo01H0Ogmo00<0000006IVIP1VIVH05@1VIVH00`00
0000C4a<04a<C00B04a<C0030000000c<c<0<c<c00h0<c<c1@3oool100000040oooo000E0?ooo`03
0000003oool0oooo0080oooo@03Vi^H00`000000c<c<0<c<c00X0<c<c0030000002c/k<0/k>c01h0
/k>c00<0000009VIV@2IVIT06@2IVIT00`000000Ogmo07moO`0G07moO`030000001VIVH0IVIV01D0
IVIV00<0000004a<C01<C4`04P1<C4`00`000000<c<c03<c<`0=03<c<`D0oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`020?oood00i^KV00<000000<c<c03<c<`0:03<c<`00`000000/k>c
0;>c/`0N0;>c/`030000002IVIT0VIVI01X0VIVI00<0000007moO`1oOgl05`1oOgl00`000000IVIV
06IVIP0E06IVIP030000001<C4`0C4a<0180C4a<00<0000003<c<`0c<c<0300c<c<50?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool00P3ooom00>KViP030000003<c<`0c<c<02P0c<c<00<0
00000;>c/`2c/k<07`2c/k<00`000000VIVI09VIV@0J09VIV@030000001oOgl0Ogmo01L0Ogmo00<0
000006IVIP1VIVH0501VIVH00`000000C4a<04a<C00C04a<C0030000000c<c<0<c<c00/0<c<c1@3o
ool100000040oooo000E0?ooo`030000003oool0oooo0080oooo?`3Vi^H00`000000c<c<0<c<c00Z
0<c<c0030000002c/k<0/k>c01h0/k>c00<0000009VIV@2IVIT06`2IVIT00`000000Ogmo07moO`0G
07moO`030000001VIVH0IVIV01@0IVIV00<0000004a<C01<C4`04`1<C4`00`000000<c<c03<c<`0:
03<c<`D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooocl0i^KV00<000000<c<
c03<c<`0:P3<c<`00`000000/k>c0;>c/`0O0;>c/`030000002IVIT0VIVI01/0VIVI00<0000007mo
O`1oOgl05`1oOgl00`000000IVIV06IVIP0D06IVIP800000501<C4`2000000X0<c<c1@3oool10000
0040oooo000E0?ooo`030000003oool0oooo0080oooo?`3Vi^H00`000000c<c<0<c<c00Z0<c<c003
0000002c/k<0/k>c01l0/k>c00<0000009VIV@2IVIT06`2IVIT00`000000Ogmo07moO`0H07moO`03
0000001VIVH0IVIV01D0IVIV00<0000004a<C01<C4`04`1<C4`00`000000<c<c03<c<`0703<c<`D0
oooo0@0000010?ooo`005@3oool2000000<0oooo?P3Vi^H00`000000c<c<0<c<c00[0<c<c0030000
002c/k<0/k>c0200/k>c00<0000009VIV@2IVIT06`2IVIT00`000000Ogmo07moO`0H07moO`030000
001VIVH0IVIV01D0IVIV00<0000004a<C01<C4`04`1<C4`00`000000<c<c03<c<`0603<c<`@0oooo
0P0000010?ooo`005@3oool00`000000oooo0?ooo`020?oooch0i^KV00<000000<c<c03<c<`0;03<
c<`00`000000/k>c0;>c/`0P0;>c/`030000002IVIT0VIVI01/0VIVI00<0000007moO`1oOgl0601o
Ogl00`000000IVIV06IVIP0E06IVIP030000001<C4`0C4a<01<0C4a<00<0000003<c<`0c<c<01@0c
<c<50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooolm0>KViP030000003<c<`0
c<c<02d0c<c<00<000000;>c/`2c/k<08@2c/k<00`000000VIVI09VIV@0K09VIV@030000001oOgl0
Ogmo01P0Ogmo00<0000006IVIP1VIVH05@1VIVH00`000000C4a<04a<C00C04a<C0030000000c<c<0
<c<c00@0<c<c1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo?@3Vi^H00`00
0000c<c<0<c<c00]0<c<c0030000002c/k<0/k>c0280/k>c00<0000009VIV@2IVIT06P2IVIT00`00
0000Ogmo07moO`0I07moO`030000001VIVH0IVIV01D0IVIV00<0000004a<C01<C4`04`1<C4`00`00
0000<c<c03<c<`0303<c<`D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?oooc`0
i^KV00<000000<c<c03<c<`0;`3<c<`00`000000/k>c0;>c/`0Q0;>c/`030000002IVIT0VIVI01/0
VIVI00<0000007moO`1oOgl06@1oOgl00`000000IVIV06IVIP0E06IVIP030000001<C4`0C4a<01<0
C4a<00<0000003<c<`0c<c<00P0c<c<50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
0P3oooll0>KViP030000003<c<`0c<c<02l0c<c<00<000000;>c/`2c/k<08P2c/k<00`000000VIVI
09VIV@0K09VIV@030000001oOgl0Ogmo01T0Ogmo00<0000006IVIP1VIVH05@1VIVH00`000000C4a<
04a<C00C04a<C0040000000c<c<0<c<c03<c<`D0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`020?oooc/0i^KV00<000000<c<c03<c<`0<03<c<`00`000000/k>c0;>c/`0S0;>c/`030000
002IVIT0VIVI01/0VIVI00<0000007moO`1oOgl06@1oOgl00`000000IVIV06IVIP0E06IVIP030000
001<C4`0C4a<01<0C4a<00<0000003<c<`0c<c<01@3oool100000040oooo000E0?ooo`030000003o
ool0oooo0080oooo>`3Vi^H00`000000c<c<0<c<c00a0<c<c0030000002c/k<0/k>c0280/k>c00<0
000009VIV@2IVIT0702IVIT00`000000Ogmo07moO`0I07moO`030000001VIVH0IVIV01D0IVIV00<0
000004a<C01<C4`04`1<C4`00`000000<c<c0?ooo`040?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool00P3ooolj0>KViP030000003<c<`0c<c<0380c<c<00<000000;>c/`2c/k<08`2c/k<0
0`000000VIVI09VIV@0K09VIV@030000001oOgl0Ogmo01X0Ogmo00<0000006IVIP1VIVH05@1VIVH0
0`000000C4a<04a<C00C04a<C0030000003oool0oooo00<0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`020?ooocX0i^KV00<000000<c<c03<c<`0<P3<c<`00`000000/k>c0;>c/`0T0;>c
/`030000002IVIT0VIVI01/0VIVI00<0000007moO`1oOgl06P1oOgl00`000000IVIV06IVIP0E06IV
IP030000001<C4`0C4a<01<0C4a<00<000000?ooo`3oool00P3oool100000040oooo00020?ooo`80
0000103oool010000000oooo0?ooo`3oool5000000@0oooo00<000000?ooo`3oool00P3oooli0>KV
iP030000003<c<`0c<c<03@0c<c<00<000000;>c/`2c/k<0902c/k<00`000000VIVI09VIV@0K09VI
V@030000001oOgl0Ogmo01X0Ogmo00<0000006IVIP1VIVH05@1VIVH00`000000C4a<04a<C00B04a<
C0D0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00P3oooli0>KViP030000003<c<`0c<c<03@0c<c<00<00000
0;>c/`2c/k<0902c/k<00`000000VIVI09VIV@0L09VIV@030000001oOgl0Ogmo01X0Ogmo00<00000
06IVIP1VIVH05@1VIVH00`000000C4a<04a<C00A04a<C0D0oooo0@0000010?ooo`0000D0oooo0000
003oool0oooo000000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3ooolh
0>KViP030000003<c<`0c<c<03D0c<c<00<000000;>c/`2c/k<09@2c/k<00`000000VIVI09VIV@0L
09VIV@030000001oOgl0Ogmo01X0Ogmo00<0000006IVIP1VIVH05@1VIVH00`000000C4a<04a<C00@
04a<C0D0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo0000000:0?ooo`030000003oool0
oooo00<0oooo0P0000030?ooocP0i^KV00<000000<c<c03<c<`0=P3<c<`00`000000/k>c0;>c/`0U
0;>c/`030000002IVIT0VIVI01`0VIVI00<0000007moO`1oOgl06P1oOgl00`000000IVIV06IVIP0E
06IVIP800000401<C4`40?ooo`8000000@3oool000050?ooo`000000oooo0?ooo`0000001`3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3ooolf0>KViP800000>@3<
c<`00`000000/k>c0;>c/`0U0;>c/`030000002IVIT0VIVI01d0VIVI00<0000007moO`1oOgl06P1o
Ogl00`000000IVIV06IVIP0F06IVIP030000001<C4`0C4a<00d0C4a<1@3oool100000040oooo0000
1@3oool000000?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo0080oooo=@3Vi^H00`000000c<c<0<c<c00i0<c<c0030000002c/k<0/k>c02H0/k>c
00<0000009VIV@2IVIT07@2IVIT00`000000Ogmo07moO`0J07moO`030000001VIVH0IVIV01H0IVIV
00<0000004a<C01<C4`0301<C4`50?ooo`4000000@3oool00080oooo0P0000090?ooo`<000001@3o
ool00`000000oooo0?ooo`020?oooc<0i^KV0P00000m0<c<c0030000002c/k<0/k>c02H0/k>c00<0
000009VIV@2IVIT07@2IVIT2000001/0Ogmo00<0000006IVIP1VIVH05P1VIVH2000000`0C4a<1@3o
ool100000040oooo000E0?ooo`030000003oool0oooo0080oooo<@3Vi^H2000003l0c<c<00<00000
0;>c/`2c/k<09P2c/k<00`000000VIVI09VIV@0O09VIV@030000001oOgl0Ogmo01T0Ogmo00<00000
06IVIP1VIVH05`1VIVH00`000000C4a<04a<C00904a<C0D0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`020?oooc00i^KV00<000000<c<c03<c<`0@03<c<`00`000000/k>c0;>c/`0V0;>c
/`030000002IVIT0VIVI01l0VIVI00<0000007moO`1oOgl06@1oOgl00`000000IVIV06IVIP0G06IV
IP030000001<C4`0C4a<00P0C4a<1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080
oooo;P3Vi^H2000004<0c<c<00<000000;>c/`2c/k<09`2c/k<00`000000VIVI09VIV@0O09VIV@03
0000001oOgl0Ogmo01T0Ogmo0P00000H06IVIP030000001<C4`0C4a<00L0C4a<1@3oool100000040
oooo000E0?ooo`030000003oool0oooo0080oooo;03Vi^H2000004D0c<c<00<000000;>c/`2c/k<0
:02c/k<00`000000VIVI09VIV@0O09VIV@030000001oOgl0Ogmo01X0Ogmo00<0000006IVIP1VIVH0
5P1VIVH00`000000C4a<04a<C00604a<C0D0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`020?ooobX0i^KV0P0000180<c<c0030000002c/k<0/k>c02L0/k>c00<0000009VIV@2IVIT0802I
VIT00`000000Ogmo07moO`0J07moO`030000001VIVH0IVIV01H0IVIV00<0000004a<C01<C4`01@1<
C4`50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooolX0>KViP800000BP3<c<`0
0`000000/k>c0;>c/`0X0;>c/`030000002IVIT0VIVI0200VIVI00<0000007moO`1oOgl06P1oOgl0
0`000000IVIV06IVIP0F06IVIP8000001@1<C4`50?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool00P3ooolW0>KViP030000003<c<`0c<c<04X0c<c<00<000000;>c/`2c/k<0:@2c/k<00`00
0000VIVI09VIV@0P09VIV@030000001oOgl0Ogmo01X0Ogmo00<0000006IVIP1VIVH05`1VIVH00`00
0000C4a<04a<C00204a<C0D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooobD0
i^KV0P00001>0<c<c0030000002c/k<0/k>c02T0/k>c00<0000009VIV@2IVIT0802IVIT00`000000
Ogmo07moO`0J07moO`800000601VIVH010000000C4a<04a<C01<C4`50?ooo`4000000@3oool001D0
oooo0P0000030?ooob40i^KV1000001@0<c<c0030000002c/k<0/k>c02T0/k>c00<0000009VIV@2I
VIT08@2IVIT00`000000Ogmo07moO`0K07moO`030000001VIVH0IVIV01H0IVIV00<0000004a<C01<
C4`0103oool200000040oooo000E0?ooo`030000003oool0oooo0080oooo6`3Vi^H6000005@0c<c<
00<000000;>c/`2c/k<0:P2c/k<00`000000VIVI09VIV@0Q09VIV@030000001oOgl0Ogmo01/0Ogmo
00<0000006IVIP1VIVH05P1VIVH00`000000C4a<0?ooo`040?ooo`4000000@3oool001D0oooo00<0
00000?ooo`3oool00P3ooolE0>KViPH00000F`3<c<`00`000000/k>c0;>c/`0Z0;>c/`030000002I
VIT0VIVI0240VIVI00<0000007moO`1oOgl06`1oOgl00`000000IVIV06IVIP0F06IVIP030000003o
ool0oooo00<0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`T0i^KV3000001Q
0<c<c0030000002c/k<0/k>c02/0/k>c00<0000009VIV@2IVIT08@2IVIT00`000000Ogmo07moO`0K
07moO`030000001VIVH0IVIV01H0IVIV00<000000?ooo`3oool00P3oool100000040oooo000E0?oo
o`030000003oool0oooo0080oooo2@00001]0<c<c0030000002c/k<0/k>c02`0/k>c00<0000009VI
V@2IVIT08@2IVIT00`000000Ogmo07moO`0K07moO`8000005P1VIVH50?ooo`4000000@3oool001D0
oooo00<000000?ooo`3oool00P3ooomg0<c<c0030000002c/k<0/k>c02`0/k>c00<0000009VIV@2I
VIT08@2IVIT00`000000Ogmo07moO`0L07moO`030000001VIVH0IVIV01<0IVIV1@3oool100000040
oooo000E0?ooo`030000003oool0oooo0080ooooM`3<c<`00`000000/k>c0;>c/`0]0;>c/`030000
002IVIT0VIVI0240VIVI00<0000007moO`1oOgl0701oOgl00`000000IVIV06IVIP0B06IVIPD0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooogL0c<c<00<000000;>c/`2c/k<0;P2c
/k<00`000000VIVI09VIV@0Q09VIV@030000001oOgl0Ogmo01`0Ogmo00<0000006IVIP1VIVH04@1V
IVH50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooomh0<c<c0030000002c/k<0
/k>c02h0/k>c00<0000009VIV@2IVIT08@2IVIT00`000000Ogmo07moO`0L07moO`030000001VIVH0
IVIV0100IVIV1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080ooooN03<c<`00`00
0000/k>c0;>c/`0_0;>c/`030000002IVIT0VIVI0240VIVI0P00000M07moO`030000001VIVH0IVIV
00l0IVIV1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080ooooN03<c<`00`000000
/k>c0;>c/`0_0;>c/`030000002IVIT0VIVI02<0VIVI00<0000007moO`1oOgl06P1oOgl200000100
IVIV1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080ooooN@3<c<`00`000000/k>c
0;>c/`0_0;>c/`030000002IVIT0VIVI02<0VIVI00<0000007moO`1oOgl06`1oOgl00`000000IVIV
06IVIP0=06IVIPD0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooogT0c<c<00<0
00000;>c/`2c/k<0<02c/k<00`000000VIVI09VIV@0S09VIV@030000001oOgl0Ogmo01/0Ogmo00<0
000006IVIP1VIVH0301VIVH50?ooo`4000000@3oool001D0oooo0P0000030?ooogX0c<c<00<00000
0;>c/`2c/k<0<02c/k<00`000000VIVI09VIV@0S09VIV@030000001oOgl0Ogmo01/0Ogmo0P00000<
06IVIP@0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooogX0c<c<00<000000;>c
/`2c/k<0<@2c/k<00`000000VIVI09VIV@0S09VIV@8000007@1oOgl00`000000IVIV06IVIP0906IV
IPD0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooog/0c<c<00<000000;>c/`2c
/k<0<@2c/k<00`000000VIVI09VIV@0T09VIV@030000001oOgl0Ogmo01/0Ogmo0P00000906IVIPD0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooog/0c<c<00<000000;>c/`2c/k<0
<P2c/k<00`000000VIVI09VIV@0T09VIV@030000001oOgl0Ogmo01`0Ogmo00<0000006IVIP1VIVH0
1P1VIVH50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3oooml0<c<c0030000002c
/k<0/k>c0380/k>c00<0000009VIV@2IVIT0902IVIT00`000000Ogmo07moO`0L07moO`030000001V
IVH0IVIV00D0IVIV1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080ooooO03<c<`0
0`000000/k>c0;>c/`0c0;>c/`030000002IVIT0VIVI02@0VIVI00<0000007moO`1oOgl0701oOgl2
000000D0IVIV1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080ooooO@3<c<`00`00
0000/k>c0;>c/`0c0;>c/`030000002IVIT0VIVI02@0VIVI00<0000007moO`1oOgl07@1oOgl00`00
0000IVIV06IVIP0206IVIPD0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooogd0
c<c<00<000000;>c/`2c/k<0=02c/k<00`000000VIVI09VIV@0T09VIV@8000007P1oOgl200000080
IVIV1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080ooooOP3<c<`00`000000/k>c
0;>c/`0d0;>c/`030000002IVIT0VIVI02D0VIVI00<0000007moO`1oOgl07@1oOgl00`000000IVIV
0?ooo`040?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooomn0<c<c0030000002c
/k<0/k>c03D0/k>c0P00000V09VIV@030000001oOgl0Ogmo01d0Ogmo00<000000?ooo`3oool00`3o
ool100000040oooo000E0?ooo`030000003oool0oooo0080ooooO`3<c<`00`000000/k>c0;>c/`0f
0;>c/`030000002IVIT0VIVI02@0VIVI00<0000007moO`1oOgl07@1oOgl00`000000oooo0?ooo`02
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooomo0<c<c0030000002c/k<0/k>c
03L0/k>c00<0000009VIV@2IVIT0902IVIT2000001d0Ogmo1@3oool100000040oooo000E0?ooo`03
0000003oool0oooo0080ooooP03<c<`00`000000/k>c0;>c/`0g0;>c/`030000002IVIT0VIVI02D0
VIVI00<0000007moO`1oOgl06P1oOgl50?ooo`4000000@3oool001D0oooo0P0000030?oooh00c<c<
00<000000;>c/`2c/k<0>02c/k<00`000000VIVI09VIV@0U09VIV@030000001oOgl0Ogmo01T0Ogmo
103oool200000040oooo000E0?ooo`030000003oool0oooo0080ooooP@3<c<`00`000000/k>c0;>c
/`0h0;>c/`030000002IVIT0VIVI02D0VIVI00<0000007moO`1oOgl0601oOgl50?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool00P3ooon10<c<c0030000002c/k<0/k>c03T0/k>c0P00000V
09VIV@800000601oOgl50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooon10<c<
c0030000002c/k<0/k>c03/0/k>c00<0000009VIV@2IVIT09@2IVIT00`000000Ogmo07moO`0E07mo
O`D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?oooh80c<c<00<000000;>c/`2c
/k<0>`2c/k<00`000000VIVI09VIV@0U09VIV@8000005@1oOgl50?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool00P3ooon30<c<c0030000002c/k<0/k>c03/0/k>c0P00000W09VIV@800000
4`1oOgl50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooon30<c<c0030000002c
/k<0/k>c03d0/k>c00<0000009VIV@2IVIT09P2IVIT00`000000Ogmo07moO`0@07moO`D0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`<00000P@3<c<`00`000000/k>c0;>c/`0m
0;>c/`030000002IVIT0VIVI02H0VIVI0P00000@07moO`D0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`020?ooo`<0/k>c0`00001o0<c<c0030000002c/k<0/k>c03d0/k>c0P00000X09VI
V@030000001oOgl0Ogmo00d0Ogmo1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080
oooo1P2c/k<3000007`0c<c<00<000000;>c/`2c/k<0?`2c/k<00`000000VIVI09VIV@0V09VIV@80
00003@1oOgl50?ooo`4000000@3oool00080oooo0P0000040?ooo`030000003oool0oooo00<0oooo
0`0000040?ooo`030000003oool0oooo0080oooo2@2c/k<3000007X0c<c<00<000000;>c/`2c/k<0
?`2c/k<00`000000VIVI09VIV@0W09VIV@030000001oOgl0Ogmo00X0Ogmo1@3oool100000040oooo
00001@3oool000000?ooo`3oool0000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo``0/k>c0`00001h0<c<c0030000002c/k<0/k>c03l0/k>c0P00000X09VIV@800000
2P1oOgl50?ooo`4000000@3oool000050?ooo`000000oooo0?ooo`0000001`3oool5000000@0oooo
00<000000?ooo`3oool00P3oool?0;>c/`<00000M@3<c<`00`000000/k>c0;>c/`110;>c/`030000
002IVIT0VIVI02L0VIVI00<0000007moO`1oOgl01`1oOgl50?ooo`4000000@3oool000050?ooo`00
0000oooo0?ooo`0000001`3oool010000000oooo0?ooo`0000050?ooo`8000000`3ooolB0;>c/`<0
0000L`3<c<`00`000000/k>c0;>c/`110;>c/`030000002IVIT0VIVI02L0VIVI0P00000707moO`@0
oooo0P0000010?ooo`0000D0oooo0000003oool0oooo000000080?ooo`030000003oool0000000D0
oooo00<000000?ooo`3oool00P3ooolE0;>c/`<00000L@3<c<`00`000000/k>c0;>c/`110;>c/`80
0000:@2IVIT00`000000Ogmo07moO`0407moO`D0oooo0@0000010?ooo`0000D0oooo0000003oool0
oooo000000090?ooo`8000001@3oool00`000000oooo0?ooo`020?oooaP0/k>c1000001]0<c<c003
0000002c/k<0/k>c04<0/k>c00<0000009VIV@2IVIT09`2IVIT2000000@0Ogmo1@3oool100000040
oooo00020?ooo`8000002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
702c/k<4000006X0c<c<00<000000;>c/`2c/k<0@`2c/k<00`000000VIVI09VIV@0X09VIV@040000
001oOgl0Ogmo07moO`D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooob00/k>c
0`00001X0<c<c0030000002c/k<0/k>c04<0/k>c0P00000Y09VIV@80000000<0Ogmo0?ooo`3oool0
0`3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo8`2c/k<3000006D0c<c<00<0
00000;>c/`2c/k<0A@2c/k<00`000000VIVI09VIV@0X09VIV@030000003oool0oooo00<0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`020?ooobH0/k>c0`00001S0<c<c0030000002c/k<0
/k>c04D0/k>c00<0000009VIV@2IVIT0:02IVIT00`000000oooo0?ooo`020?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool00P3ooolY0;>c/`<00000H@3<c<`2000004H0/k>c0P00000X09VI
V@D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooob`0/k>c0`00001P0<c<c003
0000002c/k<0/k>c04D0/k>c0P00000V09VIV@D0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`020?ooobl0/k>c1000001M0<c<c0030000002c/k<0/k>c04H0/k>c0P00000T09VIV@D0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?oooc<0/k>c0`00001K0<c<c0030000002c
/k<0/k>c04L0/k>c0P00000R09VIV@D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`02
0?ooocH0/k>c0`00001I0<c<c0800000B@2c/k<00`000000VIVI09VIV@0O09VIV@D0oooo0@000001
0?ooo`005@3oool2000000<0oooo>@2c/k<3000005P0c<c<00<000000;>c/`2c/k<0A`2c/k<20000
01l0VIVI103oool200000040oooo000E0?ooo`030000003oool0oooo0080oooo?02c/k<2000005L0
c<c<00<000000;>c/`2c/k<0B02c/k<2000001d0VIVI1@3oool100000040oooo000E0?ooo`030000
003oool0oooo0080oooo?P2c/k<3000005D0c<c<0P00001:0;>c/`030000002IVIT0VIVI01X0VIVI
1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo@@2c/k<3000005@0c<c<00<0
00000;>c/`2c/k<0B02c/k<2000001X0VIVI1@3oool100000040oooo000E0?ooo`030000003oool0
oooo0080ooooA02c/k<2000005<0c<c<0P00001:0;>c/`800000602IVIT50?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool00P3ooom60;>c/`<00000DP3<c<`00`000000/k>c0;>c/`190;>c
/`030000002IVIT0VIVI01D0VIVI1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080
ooooB@2c/k<200000540c<c<00<000000;>c/`2c/k<0B@2c/k<2000001D0VIVI1@3oool100000040
oooo000E0?ooo`030000003oool0oooo0080ooooB`2c/k<200000500c<c<0P00001;0;>c/`800000
4`2IVIT50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3oool2000004/0/k>c0`00
001?0<c<c0030000002c/k<0/k>c04X0/k>c00<0000009VIV@2IVIT0402IVIT50?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool00P3oool209VIV@800000C02c/k<2000004h0c<c<0P00001;
0;>c/`800000402IVIT50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3oool409VI
V@800000C02c/k<2000004h0c<c<00<000000;>c/`2c/k<0BP2c/k<2000000h0VIVI1@3oool10000
0040oooo000E0?ooo`030000003oool0oooo0080oooo1P2IVIT2000004`0/k>c0`00001<0<c<c003
0000002c/k<0/k>c04/0/k>c0`00000;09VIV@D0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`020?ooo`P0VIVI0P00001=0;>c/`800000B`3<c<`2000004h0/k>c0P00000909VIV@D0oooo
0@0000010?ooo`005@3oool2000000<0oooo2P2IVIT2000004d0/k>c0P00001;0<c<c0800000CP2c
/k<2000000L0VIVI103oool200000040oooo000E0?ooo`030000003oool0oooo0080oooo302IVIT0
0`000000/k>c0;>c/`1<0;>c/`800000B`3<c<`2000004h0/k>c0P00000509VIV@D0oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`d0VIVI0P00001>0;>c/`030000003<c<`0c<c<
04X0c<c<0`00001=0;>c/`8000000`2IVIT50?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool00P3oool?09VIV@800000C@2c/k<00`000000c<c<0<c<c01<0<c<c0800000C@2c/k<00`000000
VIVI09VIV@050?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooolA09VIV@030000
002c/k<0/k>c04/0/k>c0P00001>0<c<c0800000C02c/k<2000000D0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`020?oooa80VIVI0P00001=0;>c/`030000003<c<`0c<c<04d0c<c<0`00
001;0;>c/`030000003oool0oooo0080oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`02
0?oooa@0VIVI0P00001<0;>c/`800000D03<c<`2000004T0/k>c1@3oool100000040oooo000E0?oo
o`030000003oool0oooo0080oooo5P2IVIT2000004`0/k>c00<000000<c<c03<c<`0C`3<c<`20000
04L0/k>c1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo602IVIT00`000000
/k>c0;>c/`1:0;>c/`030000003<c<`0c<c<0500c<c<0`0000140;>c/`D0oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`020?oooaT0VIVI0P00001;0;>c/`800000D`3<c<`300000440/k>c
1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo6`2IVIT2000004/0/k>c00<0
00000<c<c03<c<`0D`3<c<`3000003h0/k>c1@3oool100000040oooo000E0?ooo`030000003oool0
oooo0080oooo7@2IVIT2000004X0/k>c0P00001F0<c<c0800000?02c/k<50?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool00P3ooolO09VIV@800000BP2c/k<00`000000c<c<0<c<c01E0<c<
c0<00000>@2c/k<50?ooo`4000000@3oool001D0oooo0P0000030?ooob40VIVI00<000000;>c/`2c
/k<0B02c/k<00`000000c<c<0<c<c01G0<c<c0<00000=P2c/k<40?ooo`8000000@3oool001D0oooo
00<000000?ooo`3oool00P3ooolR09VIV@800000B@2c/k<2000005X0c<c<0`00000c0;>c/`D0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooob@0VIVI0P0000190;>c/`030000003<
c<`0c<c<05X0c<c<0`00000`0;>c/`D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`02
0?ooobH0VIVI0P0000180;>c/`030000003<c<`0c<c<05`0c<c<0`00000]0;>c/`D0oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`020?ooobP0VIVI0P0000170;>c/`030000003<c<`0c<c<
05h0c<c<0`00000Z0;>c/`D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooobX0
VIVI0P0000160;>c/`030000003<c<`0c<c<0600c<c<0`00000W0;>c/`D0oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`020?ooo`800000:P2IVIT00`000000/k>c0;>c/`130;>c/`030000
003<c<`0c<c<06<0c<c<0`00000T0;>c/`D0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`020?ooo`80Ogmo00<0000009VIV@2IVIT0:02IVIT2000004@0/k>c00<000000<c<c03<c<`0I@3<
c<`300000240/k>c1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo0`1oOgl2
000002X0VIVI00<000000;>c/`2c/k<0@P2c/k<00`000000c<c<0<c<c01W0<c<c0<000007P2c/k<5
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3oool507moO`030000002IVIT0VIVI
02P0VIVI0P0000120;>c/`030000003<c<`0c<c<06X0c<c<0`00000K0;>c/`D0oooo0@0000010?oo
o`000P3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3o
ool00P3oool607moO`800000:P2IVIT00`000000/k>c0;>c/`100;>c/`030000003<c<`0c<c<06`0
c<c<0`00000H0;>c/`D0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000070?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`P0Ogmo00<0000009VI
V@2IVIT0:02IVIT00`000000/k>c0;>c/`100;>c/`030000003<c<`0c<c<06h0c<c<0`00000E0;>c
/`D0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`T0Ogmo0P00000Y09VIV@800000@02c/k<0
0`000000c<c<0<c<c01a0<c<c0<000004P2c/k<50?ooo`4000000@3oool000050?ooo`000000oooo
0?ooo`0000001`3oool4000000D0oooo0P0000030?ooo`/0Ogmo00<0000009VIV@2IVIT0:02IVIT0
0`000000/k>c0;>c/`0n0;>c/`030000003<c<`0c<c<07<0c<c<0`00000?0;>c/`@0oooo0P000001
0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool<07moO`800000:@2IVIT2000003l0/k>c00<000000<c<c03<c<`0M@3<c<`3
000000`0/k>c1@3oool100000040oooo00001@3oool000000?ooo`3oool0000000P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`h0Ogmo00<0000009VIV@2IVIT0:02IVIT0
0`000000/k>c0;>c/`0m0;>c/`030000003<c<`0c<c<07L0c<c<100000080;>c/`D0oooo0@000001
0?ooo`000P3oool2000000X0oooo0P0000050?ooo`030000003oool0oooo0080oooo3`1oOgl20000
02T0VIVI00<000000;>c/`2c/k<0?02c/k<00`000000c<c<0<c<c01k0<c<c0@00000102c/k<50?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooolA07moO`030000002IVIT0VIVI02L0
VIVI00<000000;>c/`2c/k<0?02c/k<00`000000c<c<0<c<c01n0<c<c0<0000000<0/k>c0?ooo`3o
ool00`3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo4P1oOgl2000002P0VIVI
00<000000;>c/`2c/k<0?02c/k<00`000000c<c<0<c<c0200<c<c0800000103oool100000040oooo
000E0?ooo`030000003oool0oooo0080oooo501oOgl00`000000VIVI09VIV@0V09VIV@800000?02c
/k<00`000000c<c<0<c<c0210<c<c0D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`02
0?oooaD0Ogmo00<0000009VIV@2IVIT09`2IVIT00`000000/k>c0;>c/`0j0;>c/`030000003<c<`0
c<c<0800c<c<1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo5P1oOgl20000
02P0VIVI00<000000;>c/`2c/k<0>P2c/k<00`000000c<c<0<c<c01o0<c<c0D0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`020?oooaP0Ogmo00<0000009VIV@2IVIT09P2IVIT00`000000
/k>c0;>c/`0i0;>c/`030000003<c<`0c<c<07l0c<c<1@3oool100000040oooo000E0?ooo`030000
003oool0oooo0080oooo6@1oOgl00`000000VIVI09VIV@0V09VIV@030000002c/k<0/k>c03T0/k>c
00<000000<c<c03<c<`0OP3<c<`50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3o
oolJ07moO`8000009`2IVIT2000003X0/k>c00<000000<c<c03<c<`0O@3<c<`50?ooo`4000000@3o
ool001D0oooo0P0000030?oooa`0Ogmo00<0000009VIV@2IVIT09P2IVIT00`000000/k>c0;>c/`0g
0;>c/`030000003<c<`0c<c<07d0c<c<103oool200000040oooo000E0?ooo`030000003oool0oooo
0080oooo7@1oOgl2000002L0VIVI00<000000;>c/`2c/k<0=`2c/k<00`000000c<c<0<c<c01l0<c<
c0D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?oooal0Ogmo00<0000009VIV@2I
VIT09@2IVIT00`000000/k>c0;>c/`0f0;>c/`030000003<c<`0c<c<07`0c<c<1@3oool100000040
oooo000E0?ooo`030000003oool0oooo0080oooo0P00000N07moO`030000002IVIT0VIVI02D0VIVI
00<000000;>c/`2c/k<0=P2c/k<00`000000c<c<0<c<c01k0<c<c0D0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`020?ooo`80IVIV00<0000007moO`1oOgl0701oOgl2000002H0VIVI00<0
00000;>c/`2c/k<0=@2c/k<00`000000c<c<0<c<c01k0<c<c0D0oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`020?ooo`<0IVIV00<0000007moO`1oOgl07@1oOgl00`000000VIVI09VIV@0T
09VIV@030000002c/k<0/k>c03D0/k>c00<000000<c<c03<c<`0NP3<c<`50?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool00P3oool406IVIP8000007P1oOgl2000002D0VIVI00<000000;>c
/`2c/k<0=02c/k<00`000000c<c<0<c<c01j0<c<c0D0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`020?ooo`H0IVIV00<0000007moO`1oOgl07@1oOgl00`000000VIVI09VIV@0S09VIV@03
0000002c/k<0/k>c03<0/k>c00<000000<c<c03<c<`0NP3<c<`50?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool00P3oool706IVIP030000001oOgl0Ogmo01d0Ogmo00<0000009VIV@2IVIT0
8`2IVIT00`000000/k>c0;>c/`0c0;>c/`030000003<c<`0c<c<07T0c<c<1@3oool100000040oooo
000E0?ooo`030000003oool0oooo0080oooo201VIVH00`000000Ogmo07moO`0M07moO`030000002I
VIT0VIVI02<0VIVI00<000000;>c/`2c/k<0<P2c/k<00`000000c<c<0<c<c01i0<c<c0D0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`T0IVIV0P00000N07moO`030000002IVIT0
VIVI02<0VIVI00<000000;>c/`2c/k<0<P2c/k<00`000000c<c<0<c<c01h0<c<c0D0oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`/0IVIV00<0000007moO`1oOgl0701oOgl20000
02@0VIVI00<000000;>c/`2c/k<0<@2c/k<00`000000c<c<0<c<c01h0<c<c0D0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`020?ooo``0IVIV00<0000007moO`1oOgl07@1oOgl00`000000
VIVI09VIV@0R09VIV@030000002c/k<0/k>c0340/k>c00<000000<c<c03<c<`0M`3<c<`50?ooo`40
00000@3oool001D0oooo0P0000030?ooo`d0IVIV0P00000N07moO`030000002IVIT0VIVI0280VIVI
00<000000;>c/`2c/k<0<02c/k<00`000000c<c<0<c<c01g0<c<c0@0oooo0P0000010?ooo`005@3o
ool00`000000oooo0?ooo`020?ooo`l0IVIV00<0000007moO`1oOgl0701oOgl00`000000VIVI09VI
V@0R09VIV@030000002c/k<0/k>c02l0/k>c00<000000<c<c03<c<`0M`3<c<`50?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool00P3oool@06IVIP030000001oOgl0Ogmo01`0Ogmo00<00000
09VIV@2IVIT08P2IVIT00`000000/k>c0;>c/`0_0;>c/`030000003<c<`0c<c<07H0c<c<1@3oool1
00000040oooo000E0?ooo`030000003oool0oooo0080oooo4@1VIVH00`000000Ogmo07moO`0L07mo
O`030000002IVIT0VIVI0280VIVI00<000000;>c/`2c/k<0;P2c/k<00`000000c<c<0<c<c01f0<c<
c0D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?oooa80IVIV0P00000M07moO`80
00008`2IVIT00`000000/k>c0;>c/`0^0;>c/`030000003<c<`0c<c<07D0c<c<1@3oool100000040
oooo000E0?ooo`030000003oool0oooo0080oooo501VIVH00`000000Ogmo07moO`0L07moO`030000
002IVIT0VIVI0200VIVI00<000000;>c/`2c/k<0;P2c/k<00`000000c<c<0<c<c01e0<c<c0D0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?oooaD0IVIV00<0000007moO`1oOgl0701o
Ogl00`000000VIVI09VIV@0P09VIV@030000002c/k<0/k>c02h0/k>c00<000000<c<c03<c<`0M03<
c<`50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooolF06IVIP030000001oOgl0
Ogmo01`0Ogmo00<0000009VIV@2IVIT0802IVIT00`000000/k>c0;>c/`0]0;>c/`030000003<c<`0
c<c<07@0c<c<1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo5`1VIVH00`00
0000Ogmo07moO`0L07moO`030000002IVIT0VIVI0200VIVI00<000000;>c/`2c/k<0;02c/k<00`00
0000c<c<0<c<c01d0<c<c0D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?oooaP0
IVIV0P00000M07moO`030000002IVIT0VIVI0200VIVI00<000000;>c/`2c/k<0;02c/k<00`000000
c<c<0<c<c01c0<c<c0D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`800000
601VIVH00`000000Ogmo07moO`0K07moO`030000002IVIT0VIVI0200VIVI00<000000;>c/`2c/k<0
:`2c/k<00`000000c<c<0<c<c01N0<c<c1H00000103oool100000040oooo000E0?ooo`030000003o
ool0oooo0080oooo0P1<C4`00`000000IVIV06IVIP0F06IVIP030000001oOgl0Ogmo01/0Ogmo00<0
000009VIV@2IVIT07`2IVIT00`000000/k>c0;>c/`0[0;>c/`030000003<c<`0c<c<05P0c<c<1P00
000E0>KViPD0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`<0C4a<00<00000
06IVIP1VIVH05P1VIVH00`000000Ogmo07moO`0K07moO`030000002IVIT0VIVI01l0VIVI00<00000
0;>c/`2c/k<0:`2c/k<00`000000c<c<0<c<c01A0<c<c0H000006`3Vi^H50?ooo`4000000@3oool0
01D0oooo0P0000030?ooo`@0C4a<00<0000006IVIP1VIVH05P1VIVH00`000000Ogmo07moO`0K07mo
O`030000002IVIT0VIVI01l0VIVI00<000000;>c/`2c/k<0:P2c/k<00`000000c<c<0<c<c01=0<c<
c0@000008@3Vi^H40?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool00P3oool504a<C003
0000001VIVH0IVIV01H0IVIV0P00000L07moO`030000002IVIT0VIVI01l0VIVI00<000000;>c/`2c
/k<0:@2c/k<00`000000c<c<0<c<c01;0<c<c08000009@3Vi^H50?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool00P3oool604a<C0030000001VIVH0IVIV01L0IVIV00<0000007moO`1oOgl0
6P1oOgl00`000000VIVI09VIV@0O09VIV@030000002c/k<0/k>c02T0/k>c00<000000<c<c03<c<`0
B@3<c<`00`000000i^KV0>KViP0U0>KViPD0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`020?ooo`L0C4a<0P00000H06IVIP030000001oOgl0Ogmo01X0Ogmo00<0000009VIV@2IVIT07`2I
VIT00`000000/k>c0;>c/`0X0;>c/`030000003<c<`0c<c<04L0c<c<0P00000X0>KViPD0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`T0C4a<00<0000006IVIP1VIVH05P1VIVH0
0`000000Ogmo07moO`0J07moO`030000002IVIT0VIVI01h0VIVI00<000000;>c/`2c/k<0:02c/k<0
0`000000c<c<0<c<c0150<c<c0800000:P3Vi^H50?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool00P3oool:04a<C0030000001VIVH0IVIV01H0IVIV00<0000007moO`1oOgl06P1oOgl00`00
0000VIVI09VIV@0N09VIV@030000002c/k<0/k>c02P0/k>c00<000000<c<c03<c<`0@P3<c<`20000
02`0i^KV1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo2`1<C4`00`000000
IVIV06IVIP0F06IVIP030000001oOgl0Ogmo01X0Ogmo00<0000009VIV@2IVIT07P2IVIT00`000000
/k>c0;>c/`0W0;>c/`030000003<c<`0c<c<0400c<c<0P00000^0>KViPD0oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`020?ooo``0C4a<00<0000006IVIP1VIVH05P1VIVH00`000000Ogmo
07moO`0J07moO`030000002IVIT0VIVI01h0VIVI00<000000;>c/`2c/k<09P2c/k<00`000000c<c<
0<c<c00o0<c<c0030000003Vi^H0i^KV02h0i^KV1@3oool100000040oooo000E0?ooo`030000003o
ool0oooo0080oooo3@1<C4`00`000000IVIV06IVIP0F06IVIP030000001oOgl0Ogmo01X0Ogmo00<0
000009VIV@2IVIT07P2IVIT00`000000/k>c0;>c/`0V0;>c/`030000003<c<`0c<c<03`0c<c<0P00
000a0>KViPD0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`h0C4a<00<00000
06IVIP1VIVH05P1VIVH2000001/0Ogmo00<0000009VIV@2IVIT07P2IVIT00`000000/k>c0;>c/`0U
0;>c/`030000003<c<`0c<c<03/0c<c<00<000000>KViP3Vi^H0<@3Vi^H50?ooo`4000000@3oool0
0080oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo
0080oooo3`1<C4`00`000000IVIV06IVIP0G06IVIP030000001oOgl0Ogmo01P0Ogmo00<0000009VI
V@2IVIT07P2IVIT00`000000/k>c0;>c/`0U0;>c/`030000003<c<`0c<c<03X0c<c<00<000000>KV
iP3Vi^H0<P3Vi^H50?ooo`4000000@3oool000050?ooo`000000oooo0?ooo`0000001`3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool@04a<C0030000001VIVH0
IVIV01L0IVIV00<0000007moO`1oOgl0601oOgl00`000000VIVI09VIV@0N09VIV@030000002c/k<0
/k>c02D0/k>c00<000000<c<c03<c<`0>03<c<`00`000000i^KV0>KViP0c0>KViPD0oooo0@000001
0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`020?oooa40C4a<00<0000006IVIP1VIVH05`1VIVH00`000000Ogmo07mo
O`0H07moO`030000002IVIT0VIVI01h0VIVI00<000000;>c/`2c/k<0902c/k<00`000000c<c<0<c<
c00h0<c<c0030000003Vi^H0i^KV03<0i^KV1@3oool100000040oooo00001@3oool000000?ooo`3o
ool0000000P0oooo0`0000050?ooo`8000000`3ooolB04a<C0800000601VIVH00`000000Ogmo07mo
O`0H07moO`030000002IVIT0VIVI01d0VIVI00<000000;>c/`2c/k<0902c/k<00`000000c<c<0<c<
c00g0<c<c0030000003Vi^H0i^KV03@0i^KV103oool200000040oooo00001@3oool000000?ooo`3o
ool0000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo
501<C4`00`000000IVIV06IVIP0F06IVIP030000001oOgl0Ogmo01P0Ogmo00<0000009VIV@2IVIT0
7@2IVIT00`000000/k>c0;>c/`0T0;>c/`030000003<c<`0c<c<03H0c<c<00<000000>KViP3Vi^H0
=03Vi^H50?ooo`4000000@3oool000050?ooo`000000oooo0?ooo`0000001`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3ooolE04a<C0030000001VIVH0IVIV01H0
IVIV00<0000007moO`1oOgl0601oOgl00`000000VIVI09VIV@0L09VIV@030000002c/k<0/k>c02@0
/k>c00<000000<c<c03<c<`0=@3<c<`00`000000i^KV0>KViP0e0>KViPD0oooo0@0000010?ooo`00
0P3oool2000000T0oooo0`0000050?ooo`030000003oool0oooo0080oooo0P00000D04a<C0030000
001VIVH0IVIV01H0IVIV00<0000007moO`1oOgl05`1oOgl00`000000VIVI09VIV@0M09VIV@030000
002c/k<0/k>c02<0/k>c00<000000<c<c03<c<`0=03<c<`00`000000i^KV0>KViP0f0>KViPD0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`80<c<c00<0000004a<C01<C4`04P1<
C4`00`000000IVIV06IVIP0F06IVIP030000001oOgl0Ogmo01L0Ogmo00<0000009VIV@2IVIT07@2I
VIT00`000000/k>c0;>c/`0S0;>c/`030000003<c<`0c<c<03<0c<c<00<000000>KViP3Vi^H0=P3V
i^H50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3oool303<c<`030000001<C4`0
C4a<0180C4a<00<0000006IVIP1VIVH05P1VIVH00`000000Ogmo07moO`0G07moO`030000002IVIT0
VIVI01`0VIVI00<000000;>c/`2c/k<08`2c/k<00`000000c<c<0<c<c00b0<c<c0030000003Vi^H0
i^KV03L0i^KV1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo100c<c<00`00
0000C4a<04a<C00B04a<C0030000001VIVH0IVIV01H0IVIV00<0000007moO`1oOgl05`1oOgl00`00
0000VIVI09VIV@0L09VIV@030000002c/k<0/k>c0280/k>c00<000000<c<c03<c<`0<P3<c<`00`00
0000i^KV0>KViP0g0>KViPD0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`D0
<c<c00<0000004a<C01<C4`04P1<C4`2000001L0IVIV00<0000007moO`1oOgl05`1oOgl00`000000
VIVI09VIV@0K09VIV@030000002c/k<0/k>c02<0/k>c00<000000<c<c03<c<`0<03<c<`00`000000
i^KV0>KViP0h0>KViPD0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`H0<c<c
00<0000004a<C01<C4`04`1<C4`00`000000IVIV06IVIP0E06IVIP030000001oOgl0Ogmo01L0Ogmo
00<0000009VIV@2IVIT06`2IVIT00`000000/k>c0;>c/`0R0;>c/`030000003<c<`0c<c<0300c<c<
00<000000>KViP3Vi^H0>03Vi^H50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3o
ool703<c<`030000001<C4`0C4a<01<0C4a<00<0000006IVIP1VIVH05@1VIVH00`000000Ogmo07mo
O`0F07moO`030000002IVIT0VIVI01`0VIVI00<000000;>c/`2c/k<08@2c/k<00`000000c<c<0<c<
c00_0<c<c0030000003Vi^H0i^KV03T0i^KV1@3oool100000040oooo000E0?ooo`030000003oool0
oooo0080oooo200c<c<00`000000C4a<04a<C00C04a<C0030000001VIVH0IVIV01D0IVIV00<00000
07moO`1oOgl05P1oOgl00`000000VIVI09VIV@0K09VIV@030000002c/k<0/k>c0280/k>c00<00000
0<c<c03<c<`0;P3<c<`00`000000i^KV0>KViP0i0>KViPD0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`020?ooo`T0<c<c00<0000004a<C01<C4`04`1<C4`00`000000IVIV06IVIP0E06IV
IP030000001oOgl0Ogmo01H0Ogmo00<0000009VIV@2IVIT06`2IVIT00`000000/k>c0;>c/`0Q0;>c
/`030000003<c<`0c<c<02d0c<c<00<000000>KViP3Vi^H0>P3Vi^H50?ooo`4000000@3oool001D0
oooo00<000000?ooo`3oool00P3oool:03<c<`030000001<C4`0C4a<01<0C4a<00<0000006IVIP1V
IVH0501VIVH00`000000Ogmo07moO`0G07moO`030000002IVIT0VIVI01/0VIVI00<000000;>c/`2c
/k<0802c/k<00`000000c<c<0<c<c00/0<c<c0030000003Vi^H0i^KV03/0i^KV1@3oool100000040
oooo000E0?ooo`8000000`3oool;03<c<`030000001<C4`0C4a<01<0C4a<00<0000006IVIP1VIVH0
501VIVH00`000000Ogmo07moO`0G07moO`030000002IVIT0VIVI01/0VIVI00<000000;>c/`2c/k<0
802c/k<00`000000c<c<0<c<c00[0<c<c0030000003Vi^H0i^KV03/0i^KV103oool200000040oooo
000E0?ooo`030000003oool0oooo0080oooo300c<c<00`000000C4a<04a<C00C04a<C0030000001V
IVH0IVIV01@0IVIV00<0000007moO`1oOgl05`1oOgl00`000000VIVI09VIV@0K09VIV@030000002c
/k<0/k>c01l0/k>c00<000000<c<c03<c<`0:P3<c<`00`000000i^KV0>KViP0l0>KViPD0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`d0<c<c00<0000004a<C01<C4`04P1<C4`0
0`000000IVIV06IVIP0D06IVIP030000001oOgl0Ogmo01L0Ogmo00<0000009VIV@2IVIT06`2IVIT0
0`000000/k>c0;>c/`0O0;>c/`030000003<c<`0c<c<02X0c<c<00<000000>KViP3Vi^H0?03Vi^H5
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3oool>03<c<`030000001<C4`0C4a<
0180C4a<00<0000006IVIP1VIVH0501VIVH00`000000Ogmo07moO`0G07moO`030000002IVIT0VIVI
01/0VIVI00<000000;>c/`2c/k<07P2c/k<00`000000c<c<0<c<c00Z0<c<c0030000003Vi^H0i^KV
03`0i^KV1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo3`0c<c<00`000000
C4a<04a<C00B04a<C0030000001VIVH0IVIV01@0IVIV00<0000007moO`1oOgl05`1oOgl00`000000
VIVI09VIV@0J09VIV@030000002c/k<0/k>c01l0/k>c00<000000<c<c03<c<`0:03<c<`00`000000
i^KV0>KViP0m0>KViPD0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?oooa00<c<c
00<0000004a<C01<C4`04@1<C4`00`000000IVIV06IVIP0E06IVIP030000001oOgl0Ogmo01L0Ogmo
00<0000009VIV@2IVIT06P2IVIT00`000000/k>c0;>c/`0N0;>c/`030000003<c<`0c<c<02P0c<c<
00<000000>KViP3Vi^H0?@3Vi^H50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3o
oolA03<c<`030000001<C4`0C4a<0140C4a<00<0000006IVIP1VIVH05@1VIVH00`000000Ogmo07mo
O`0G07moO`030000002IVIT0VIVI01T0VIVI00<000000;>c/`2c/k<07P2c/k<00`000000c<c<0<c<
c00X0<c<c0030000003Vi^H0i^KV03`0i^KV0P0000040?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool00P3ooolB03<c<`030000001<C4`0C4a<0140C4a<00<0000006IVIP1VIVH05@1VIVH0
0`000000Ogmo07moO`0F07moO`030000002IVIT0VIVI01X0VIVI00<000000;>c/`2c/k<07P2c/k<0
0`000000c<c<0<c<c00W0<c<c0030000003Vi^H0i^KV03/0i^KV00<000000?ooo`3oool0103oool1
00000040oooo000E0?ooo`030000003oool0oooo0080oooo00<0000003<c<`0c<c<0400c<c<00`00
0000C4a<04a<C00A04a<C0030000001VIVH0IVIV01D0IVIV00<0000007moO`1oOgl05P1oOgl00`00
0000VIVI09VIV@0I09VIV@030000002c/k<0/k>c01h0/k>c00<000000<c<c03<c<`09`3<c<`00`00
0000i^KV0>KViP0i0>KViP8000001`3oool100000040oooo000E0?ooo`030000003oool0oooo0080
oooo00<06ATI0000000c<c<04@0c<c<00`000000C4a<04a<C00A04a<C0030000001VIVH0IVIV01D0
IVIV00<0000007moO`1oOgl05P1oOgl00`000000VIVI09VIV@0I09VIV@030000002c/k<0/k>c01d0
/k>c00<000000<c<c03<c<`09P3<c<`00`000000i^KV0>KViP0h0>KViP8000002@3oool100000040
oooo000E0?ooo`030000003oool0oooo0080oooo0P0I6AT00`000000<c<c03<c<`0@03<c<`030000
001<C4`0C4a<0140C4a<00<0000006IVIP1VIVH05@1VIVH00`000000Ogmo07moO`0F07moO`030000
002IVIT0VIVI01P0VIVI00<000000;>c/`2c/k<07P2c/k<00`000000c<c<0<c<c00U0<c<c0030000
003Vi^H0i^KV03L0i^KV00<000000?ooo`3oool02@3oool100000040oooo000E0?ooo`030000003o
ool0oooo0080oooo0`0I6AT00`000000<c<c03<c<`0@03<c<`030000001<C4`0C4a<0140C4a<00<0
000006IVIP1VIVH0501VIVH00`000000Ogmo07moO`0G07moO`030000002IVIT0VIVI01P0VIVI00<0
00000;>c/`2c/k<07@2c/k<00`000000c<c<0<c<c00U0<c<c0030000003Vi^H0i^KV03D0i^KV0P00
000<0?ooo`4000000@3oool001D0oooo0P0000030?ooo`@06ATI00<0000003<c<`0c<c<0400c<c<0
0`000000C4a<04a<C00A04a<C0030000001VIVH0IVIV01@0IVIV00<0000007moO`1oOgl05P1oOgl0
0`000000VIVI09VIV@0I09VIV@030000002c/k<0/k>c01`0/k>c00<000000<c<c03<c<`09@3<c<`0
0`000000i^KV0>KViP0c0>KViP8000003@3oool200000040oooo000E0?ooo`030000003oool0oooo
0080oooo1@0I6AT00`000000<c<c03<c<`0@03<c<`030000001<C4`0C4a<0140C4a<00<0000006IV
IP1VIVH0501VIVH00`000000Ogmo07moO`0F07moO`030000002IVIT0VIVI01P0VIVI00<000000;>c
/`2c/k<07@2c/k<00`000000c<c<0<c<c00T0<c<c0030000003Vi^H0i^KV0380i^KV00<000000?oo
o`3oool03P3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo1P0I6AT00`000000
<c<c03<c<`0@03<c<`030000001<C4`0C4a<0140C4a<00<0000006IVIP1VIVH0501VIVH00`000000
Ogmo07moO`0F07moO`030000002IVIT0VIVI01P0VIVI00<000000;>c/`2c/k<0702c/k<00`000000
c<c<0<c<c00S0<c<c0030000003Vi^H0i^KV0340i^KV0P00000A0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool00P3oool701TI6@030000000c<c<0<c<c0100<c<c00<0000004a<C01<C4`0
4@1<C4`00`000000IVIV06IVIP0D06IVIP030000001oOgl0Ogmo01D0Ogmo00<0000009VIV@2IVIT0
602IVIT00`000000/k>c0;>c/`0L0;>c/`030000003<c<`0c<c<02<0c<c<00<000000>KViP3Vi^H0
;`3Vi^H2000001<0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`P06ATI00<0
000003<c<`0c<c<0400c<c<00`000000C4a<04a<C00A04a<C0030000001VIVH0IVIV01@0IVIV00<0
000007moO`1oOgl05@1oOgl00`000000VIVI09VIV@0H09VIV@030000002c/k<0/k>c01`0/k>c00<0
00000<c<c03<c<`08P3<c<`00`000000i^KV0>KViP0^0>KViP030000003oool0oooo01<0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`T06ATI00<0000003<c<`0c<c<0400c<c<0
0`000000C4a<04a<C00A04a<C0030000001VIVH0IVIV01@0IVIV00<0000007moO`1oOgl05@1oOgl0
0`000000VIVI09VIV@0G09VIV@030000002c/k<0/k>c01`0/k>c00<000000<c<c03<c<`08P3<c<`0
0`000000i^KV0>KViP0]0>KViP030000003oool0oooo01@0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`020?ooo`X06ATI00<0000003<c<`0c<c<0400c<c<00`000000C4a<04a<C00A04a<
C0030000001VIVH0IVIV01@0IVIV00<0000007moO`1oOgl0501oOgl00`000000VIVI09VIV@0H09VI
V@030000002c/k<0/k>c01/0/k>c00<000000<c<c03<c<`08P3<c<`00`000000i^KV0>KViP0]0>KV
iP030000003oool0oooo01@0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`/0
6ATI00<0000003<c<`0c<c<0400c<c<00`000000C4a<04a<C00A04a<C0030000001VIVH0IVIV01@0
IVIV00<0000007moO`1oOgl0501oOgl00`000000VIVI09VIV@0G09VIV@030000002c/k<0/k>c01`0
/k>c00<000000<c<c03<c<`0803<c<`00`000000i^KV0>KViP0]0>KViP030000003oool0oooo01D0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo``06ATI00<0000003<c<`0c<c<0
400c<c<00`000000C4a<04a<C00A04a<C0030000001VIVH0IVIV01<0IVIV00<0000007moO`1oOgl0
5@1oOgl00`000000VIVI09VIV@0G09VIV@030000002c/k<0/k>c01/0/k>c00<000000<c<c03<c<`0
803<c<`00`000000i^KV0>KViP0/0>KViP030000003oool0oooo01H0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`020?ooo`d06ATI00<0000003<c<`0c<c<03`0c<c<00`000000C4a<04a<
C00B04a<C0030000001VIVH0IVIV0180IVIV00<0000007moO`1oOgl05@1oOgl00`000000VIVI09VI
V@0G09VIV@030000002c/k<0/k>c01/0/k>c00<000000<c<c03<c<`0803<c<`00`000000i^KV0>KV
iP0/0>KViP030000003oool0oooo01H0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`02
0?ooo`h06ATI00<0000003<c<`0c<c<03`0c<c<00`000000C4a<04a<C00B04a<C0030000001VIVH0
IVIV0180IVIV00<0000007moO`1oOgl05@1oOgl00`000000VIVI09VIV@0G09VIV@030000002c/k<0
/k>c01X0/k>c00<000000<c<c03<c<`0803<c<`00`000000i^KV0>KViP0[0>KViP030000003oool0
oooo01L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`l06ATI00<0000003<c
<`0c<c<03`0c<c<00`000000C4a<04a<C00B04a<C0030000001VIVH0IVIV0180IVIV00<0000007mo
O`1oOgl05@1oOgl00`000000VIVI09VIV@0G09VIV@030000002c/k<0/k>c01X0/k>c00<000000<c<
c03<c<`07`3<c<`00`000000i^KV0>KViP0Z0>KViP030000003oool0oooo01P0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`020?oooa006ATI00<0000003<c<`0c<c<03`0c<c<00`000000
C4a<04a<C00B04a<C0030000001VIVH0IVIV0180IVIV00<0000007moO`1oOgl0501oOgl00`000000
VIVI09VIV@0G09VIV@030000002c/k<0/k>c01X0/k>c00<000000<c<c03<c<`07`3<c<`00`000000
i^KV0>KViP0Z0>KViP030000003oool0oooo01P0oooo0@0000010?ooo`005@3oool2000000<0oooo
4@0I6AT00`000000<c<c03<c<`0?03<c<`030000001<C4`0C4a<0140C4a<00<0000006IVIP1VIVH0
4`1VIVH00`000000Ogmo07moO`0D07moO`030000002IVIT0VIVI01L0VIVI00<000000;>c/`2c/k<0
6@2c/k<00`000000c<c<0<c<c00O0<c<c0030000003Vi^H0i^KV02T0i^KV00<000000?ooo`3oool0
603oool200000040oooo000E0?ooo`030000003oool0oooo0080oooo00<0000001TI6@0I6AT03`0I
6AT00`000000<c<c03<c<`0?03<c<`030000001<C4`0C4a<0140C4a<00<0000006IVIP1VIVH04P1V
IVH00`000000Ogmo07moO`0E07moO`030000002IVIT0VIVI01H0VIVI00<000000;>c/`2c/k<06P2c
/k<00`000000c<c<0<c<c00N0<c<c0030000003Vi^H0i^KV02P0i^KV00<000000?ooo`3oool06P3o
ool100000040oooo000E0?ooo`030000003oool0oooo0080oooo0P00000@01TI6@030000000c<c<0
<c<c00l0<c<c00<0000004a<C01<C4`04P1<C4`00`000000IVIV06IVIP0B06IVIP030000001oOgl0
Ogmo01@0Ogmo00<0000009VIV@2IVIT05`2IVIT00`000000/k>c0;>c/`0I0;>c/`030000003<c<`0
c<c<01h0c<c<00<000000>KViP3Vi^H0:03Vi^H00`000000oooo0?ooo`0J0?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool00P3oool3000001006ATI00<0000003<c<`0c<c<03`0c<c<00`00
0000C4a<04a<C00B04a<C0030000001VIVH0IVIV0180IVIV00<0000007moO`1oOgl0501oOgl00`00
0000VIVI09VIV@0G09VIV@030000002c/k<0/k>c01P0/k>c00<000000<c<c03<c<`07P3<c<`00`00
0000i^KV0>KViP0W0>KViP030000003oool0oooo01/0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`020?ooo`@00000400I6AT00`000000<c<c03<c<`0?03<c<`030000001<C4`0C4a<0180
C4a<00<0000006IVIP1VIVH04P1VIVH00`000000Ogmo07moO`0D07moO`030000002IVIT0VIVI01H0
VIVI00<000000;>c/`2c/k<0602c/k<00`000000c<c<0<c<c00N0<c<c0030000003Vi^H0i^KV02H0
i^KV00<000000?ooo`3oool0703oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo
1@00000@01TI6@030000000c<c<0<c<c00l0<c<c00<0000004a<C01<C4`04@1<C4`00`000000IVIV
06IVIP0B06IVIP030000001oOgl0Ogmo01@0Ogmo00<0000009VIV@2IVIT05`2IVIT00`000000/k>c
0;>c/`0H0;>c/`030000003<c<`0c<c<01d0c<c<00<000000>KViP3Vi^H09P3Vi^H00`000000oooo
0?ooo`0L0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3oool6000001006ATI00<0
000003<c<`0c<c<03`0c<c<00`000000C4a<04a<C00A04a<C0030000001VIVH0IVIV0180IVIV00<0
000007moO`1oOgl0501oOgl00`000000VIVI09VIV@0F09VIV@030000002c/k<0/k>c01P0/k>c00<0
00000<c<c03<c<`07@3<c<`00`000000i^KV0>KViP0U0>KViP030000003oool0oooo01d0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`L00000400I6AT00`000000<c<c03<c<`0?
03<c<`030000001<C4`0C4a<0140C4a<00<0000006IVIP1VIVH04P1VIVH00`000000Ogmo07moO`0D
07moO`030000002IVIT0VIVI01D0VIVI00<000000;>c/`2c/k<0602c/k<00`000000c<c<0<c<c00M
0<c<c0030000003Vi^H0i^KV02@0i^KV00<000000?ooo`3oool07P3oool100000040oooo000E0?oo
o`030000003oool0oooo0080oooo2000000@01TI6@030000000c<c<0<c<c00l0<c<c00<0000004a<
C01<C4`04@1<C4`00`000000IVIV06IVIP0B06IVIP030000001oOgl0Ogmo01<0Ogmo00<0000009VI
V@2IVIT05P2IVIT00`000000/k>c0;>c/`0G0;>c/`030000003<c<`0c<c<01d0c<c<00<000000>KV
iP3Vi^H0903Vi^H00`000000oooo0?ooo`0N0?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool00P3oool9000001006ATI00<0000003<c<`0c<c<03`0c<c<00`000000C4a<04a<C00@04a<C003
0000001VIVH0IVIV01<0IVIV00<0000007moO`1oOgl04`1oOgl00`000000VIVI09VIV@0E09VIV@03
0000002c/k<0/k>c01P0/k>c00<000000<c<c03<c<`0703<c<`00`000000i^KV0>KViP0S0>KViP03
0000003oool0oooo01l0oooo0@0000010?ooo`003@3oool3000000D0oooo00<000000?ooo`3oool0
0P3oool:000001006ATI00<0000003<c<`0c<c<03`0c<c<00`000000C4a<04a<C00@04a<C0030000
001VIVH0IVIV0180IVIV00<0000007moO`1oOgl0501oOgl00`000000VIVI09VIV@0E09VIV@030000
002c/k<0/k>c01L0/k>c00<000000<c<c03<c<`0703<c<`00`000000i^KV0>KViP0R0>KViP030000
003oool0oooo0200oooo0@0000010?ooo`003P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo2`00000@01TI6@030000000c<c<0<c<c00l0<c<c00<0000004a<C01<C4`0401<
C4`00`000000IVIV06IVIP0B06IVIP030000001oOgl0Ogmo01<0Ogmo00<0000009VIV@2IVIT05@2I
VIT00`000000/k>c0;>c/`0G0;>c/`030000003<c<`0c<c<01`0c<c<00<000000>KViP3Vi^H08P3V
i^H00`000000oooo0?ooo`0P0?ooo`4000000@3oool000h0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo``00000400I6AT00`000000<c<c03<c<`0?03<c<`030000001<C4`0
C4a<0100C4a<00<0000006IVIP1VIVH04P1VIVH00`000000Ogmo07moO`0C07moO`030000002IVIT0
VIVI01@0VIVI00<000000;>c/`2c/k<0602c/k<00`000000c<c<0<c<c00K0<c<c0030000003Vi^H0
i^KV0240i^KV00<000000?ooo`3oool08@3oool100000040oooo000>0?ooo`030000003oool0oooo
00@0oooo0P0000030?ooo`d00000400I6AT00`000000<c<c03<c<`0?03<c<`030000001<C4`0C4a<
0100C4a<00<0000006IVIP1VIVH04P1VIVH00`000000Ogmo07moO`0C07moO`030000002IVIT0VIVI
01@0VIVI00<000000;>c/`2c/k<05`2c/k<00`000000c<c<0<c<c00K0<c<c0030000003Vi^H0i^KV
0200i^KV00<000000?ooo`3oool08@3oool200000040oooo000>0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool000d0oooo0P0000060?ooo`030000
003oool0oooo0?l0oooo1`3oool100000040oooo000>0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool00P3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo0@000001
0?ooo`005@3ooooo000000/000000@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.1035, -0.0861209, 0.00391636, \
0.00391636}}]
}, Open  ]],

Cell["This plot assumes linkage equilibrium.", "Text"],

Cell[TextData[{
  "This is the derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`{\(g\_00\%*\), \ \(g\_01\%*\), \(g\_10\%*\), \ \
\(g\_11\%*\), \ \(n\^*\)}\ with\ respect\ to\ {g\_00, \ g\_01, g\_10, \ 
          g\_11, \ n}\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hp = MakePopulation[2, {0.5, 0.5}];\)\), "\[IndentingNewLine]", 
    \(StabilityDirect[hp, w[0.15, 0.3, epi], 0] // MatrixForm\)}], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "0.6391776937618149`", \(-0.10656899810964093`\), \
\(-0.10656899810964099`\), \(-0.4260396975425332`\), "0"},
            {\(-0.10656899810964088`\), 
              "0.508742911153119`", \(-0.2956049149338375`\), \
\(-0.10656899810964088`\), "0"},
            {\(-0.10656899810964088`\), \(-0.29560491493383745`\), 
              "0.508742911153119`", \(-0.10656899810964088`\), "0"},
            {\(-0.4260396975425332`\), \(-0.10656899810964093`\), \
\(-0.10656899810964099`\), "0.6391776937618147`", "0"},
            {"0", "0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[19]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "The deme size is included as an extra variable.  By default, the deme size \
stays the same, and so ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_n\( n\^*\) = 1\ \((lower\ right)\)\)]],
  ".  If DemeSize->F is used to include population regulation, then the last \
row and column are non-trivial, and may affect the overall stability."
}], "Text"],

Cell["\<\
There is an eigenvalue greater than 1, and so the central \
equilibrium {0.5,0.5} is unstable:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues[%] // Chop\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({1.0652173913043481`, 1.`, 0.8043478260869563`, 0.42627599243856334`, 
      0}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["\<\
The eigenvalue of 1 corresponds to the constant deme size.  The \
last eigenvalue,of zero, corresponds to variations in total frequency, which \
is fixed at 1.\
\>", "Text"],

Cell[TextData[{
  "Element {i,j} is the derivative of variable ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " w.r.t. variable ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ".  For example, we can find ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(D[\(g\_00\%*\), g\_01]\)\(:\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(np = 
        IterateExact[HaploidFrequencies[{0.25, g01, 0.25, 0.25}, 100], 
          w[0.15, 0.3, epi], 0];\)\), "\n", 
    \(D[np[\([1, 1]\)], g01] /. g01 -> 0.25\)}], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \(\(-0.10656899810964088`\)\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell["This is the same as element {1,2} in the matrix above.", "Text"],

Cell["\<\
Symbolic expressions can be handled.  These are the equilibria, in \
terms of allele frequencies and linkage disequilibria:\
\>", "MathCaption"],

Cell[BoxData[{
    \(\(pop = 
        HaploidFrequencies[{\((1 - p1)\) \((1 - p2)\) + d, \((1 - p1)\) p2 - 
              d, p1 \((1 - p2)\) - d, p1\ p2 + d}, n];\)\), "\n", 
    \(\(np = \(IterateExact[pop, w[s, \[Epsilon], epi], 0, 
              Linkage \[Rule] \
{r}]\)\[LeftDoubleBracket]1\[RightDoubleBracket] // Simplify;\)\)}], "Input",
  CellLabel->"In[3]:="],

Cell["\<\
Linkage\[Rule]r sets the recombination rate.\
\>", "Text"],

Cell[TextData[{
  "This gives the change in ",
  Cell[BoxData[
      \(TraditionalForm\`p\_1, \ p\_2, \ D\)]],
  ", to first order in s, \[Epsilon], r:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dpop = \(Series[{np\[LeftDoubleBracket]3\[RightDoubleBracket] + 
                    np\[LeftDoubleBracket]4\[RightDoubleBracket] - p1, 
                  np\[LeftDoubleBracket]2\[RightDoubleBracket] + 
                    np\[LeftDoubleBracket]4\[RightDoubleBracket] - p2, 
                  np\[LeftDoubleBracket]4\[RightDoubleBracket] - p1\ p2 - 
                    d} /. {r \[Rule] r*s, \[Epsilon] \[Rule] s*eps}, {s, 0, 
                1}] /. {r \[Rule] r\/s, eps \[Rule] \[Epsilon]\/s} // 
          Normal\) // Simplify\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(dpop\)\" is similar to \
existing symbol \"\!\(pop\)\"."\)], "Message",
  CellLabel->"From In[5]:="],

Cell[BoxData[
    \({d\ \((s - 2\ p2\ s)\) + \((\(-1\) + 
              p1)\)\ p1\ \((\((\(-1\) + 2\ p1)\)\ s + \[Epsilon] - 
              2\ p2\ \[Epsilon])\), 
      d\ \((s - 2\ p1\ s)\) + \((\(-1\) + 
              p2)\)\ p2\ \((\((\(-1\) + 2\ p2)\)\ s + \[Epsilon] - 
              2\ p1\ \[Epsilon])\), \((d + p1\ p2)\)\ \((2 - 3\ p1 + 
              2\ p1\^2 - 3\ p2 + 2\ p2\^2)\)\ s + d\^2\ \[Epsilon] + 
        p1\^2\ p2\^2\ \[Epsilon] - \((d + 
              p1\ p2)\)\ \((2\ d + \((\(-1\) + 2\ p1)\)\ \((\(-1\) + 
                    2\ p2)\))\)\ \[Epsilon] - 
        d\ \((r - 2\ p1\ p2\ \[Epsilon])\)}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[{
  "There are two equilibria at ",
  Cell[BoxData[
      \(TraditionalForm\`p\_1, \ p\_2 = 1\/2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`D = \(\[PlusMinus]\(1\/2\)\) \((\@\(1\/4 + \((r\/\
\[Epsilon])\)\^2\) - r\/\[Epsilon])\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq = 
      Solve[0 == 
            dpop\[LeftDoubleBracket]3\[RightDoubleBracket] /. {p1 \[Rule] 
              1\/2, p2 \[Rule] 1\/2}, d]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \({{d \[Rule] \(\(-2\)\ r - \@\(4\ r\^2 + \[Epsilon]\^2\)\)\/\(4\ \
\[Epsilon]\)}, {d \[Rule] \(\(-2\)\ r + \@\(4\ r\^2 + \[Epsilon]\^2\)\)\/\(4\ \
\[Epsilon]\)}}\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell["\<\
These are the eigenvalues associated with one of these equilibria, \
to leading order in s, \[Epsilon], r:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(sm = 
        StabilityDirect[pop /. {p1 \[Rule] 1\/2, p2 \[Rule] 1\/2}, 
          w[s, \[Epsilon], epi], 0];\)\), "\n", 
    \(\(sm2 = \(Series[
                sm /. {r \[Rule] r*s, \[Epsilon] \[Rule] s*eps}, {s, 0, 
                  1}] /. {r \[Rule] r\/s, eps \[Rule] \[Epsilon]\/s} // 
            Normal\) // Simplify;\)\), "\n", 
    \(ev = 
      Eigenvalues[
        sm2 /. eq\[LeftDoubleBracket]1\[RightDoubleBracket]]\)}], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \({0, 
      1, \(1 - s\)\/2, \(2\ \[Epsilon]\^2 - s\ \[Epsilon]\^2 - \@\(8\ r\^2\ s\
\^2\ \[Epsilon]\^2 + 4\ r\ s\ \[Epsilon]\^4 + s\^2\ \[Epsilon]\^4 + \
\[Epsilon]\^6 + 4\ r\ s\^2\ \[Epsilon]\^2\ \@\(4\ r\^2 + \[Epsilon]\^2\) + 2\ \
s\ \[Epsilon]\^4\ \@\(4\ r\^2 + \[Epsilon]\^2\)\)\)\/\(2\ \[Epsilon]\^2\), \
\(2\ \[Epsilon]\^2 - s\ \[Epsilon]\^2 + \@\(8\ r\^2\ s\^2\ \[Epsilon]\^2 + 4\ \
r\ s\ \[Epsilon]\^4 + s\^2\ \[Epsilon]\^4 + \[Epsilon]\^6 + 4\ r\ s\^2\ \
\[Epsilon]\^2\ \@\(4\ r\^2 + \[Epsilon]\^2\) + 2\ s\ \[Epsilon]\^4\ \@\(4\ \
r\^2 + \[Epsilon]\^2\)\)\)\/\(2\ \[Epsilon]\^2\)}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[TextData[{
  "This is the critical strength of epistasis above which the central \
equilibrium becomes unstable, as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = r\/s\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(soln = 
        Solve[1 \[Equal] 
              ev\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] /. \
{\[Epsilon]\^j_Integer \[Rule] \[Epsilon]2\^\(j/2\), 
              r \[Rule] \[Rho]\ s}, \[Epsilon]2];\)\), "\n", 
    \(Simplify[soln\[LeftDoubleBracket]1\[RightDoubleBracket], 
      s > 0]\)}], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \({\[Epsilon]2 \[Rule] 
        2\/3\ s\^2\ \((2 - 
              4\ \[Rho] + \(4\ \((1 - \[Rho] + \[Rho]\^2)\)\)\/\((8 - 12\ \
\[Rho] + 15\ \[Rho]\^2 + 8\ \[Rho]\^3 + 3\ \[Rho]\^\(3/2\)\ \@\(24 - 39\ \
\[Rho] + 48\ \[Rho]\^2\))\)\^\(1/3\) + \((8 - 12\ \[Rho] + 15\ \[Rho]\^2 + 8\ \
\[Rho]\^3 + 3\ \[Rho]\^\(3/2\)\ \@\(24 - 39\ \[Rho] + 48\ \
\[Rho]\^2\))\)\^\(1/3\))\)}\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(StabilityDirect[{HaploidFrequencies[\[Psi]\_1, 
                  n\_1], \[Ellipsis]}, W, 
              m]\), \(generates\ the\ stability\ matrix\ for\ a\ clinal\ \
model . \ \ This\ is\ in\ block\ form\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[TextData[{
  "With ",
  Cell[BoxData[
      \(TraditionalForm\`n\_g\ genes, \ plus\ deme\ size, \ 
      there\ are\ 2\^n\_g + 
        1\ variables\ for\ each\ deme . \ \ For\ a\ clinal\ model, 
      with\ \(n\_\(\(d\)\(\ \)\)\) demes, \ 
      the\ stability\ matrix\ is\ a\ \((2\^n\_g + 1)\)\[Times]\((2\^n\_g + 
            1)\)\)]],
  " array, with each element being an ",
  Cell[BoxData[
      \(TraditionalForm\`n\_d\[Times]n\_d\ \(\(array\)\(.\)\)\)]]
}], "Text"],

Cell["\<\
In this example, epistatic selection s acts against heterozygotes \
at 3 loci, along a cline with 20 demes:\
\>", "MathCaption"],

Cell[BoxData[{
    \(\(\(\(hetWfull[s_, k_]\)[_]\)[X_, 
          Y_] := \((1 - s)\)\^\(CountHeterozygotes[X, Y]\^k\);\)\), "\n", 
    \(\(pop0 = MakeCline[20, 3, 10];\)\), "\[IndentingNewLine]", 
    \(\(StoreExact[\[Psi], pop0, hetWfull[0.01, 4], 0.5, {500, 100}, 
        Compiled \[Rule] True];\)\)}], "Input",
  CellLabel->"In[14]:="],

Cell[TextData[{
  "Fitness is ",
  Cell[BoxData[
      \(TraditionalForm\`\((1 - s)\)\^\(h\^k\)\)]],
  ", where h is the # of heterozygotes.  For k>1, fitness declines faster \
than multiplicatively with # heterozygotes.  Equilibrium is reached by 500 \
generations."
}], "Text"],

Cell["\<\
This gives the stability matrix, as a 9\[Times]9 array of \
20\[Times]20 arrays:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(sm = 
        StabilityDirect[\[Psi][500], hetWfull[0.01, 4], 0.5];\)\), "\n", 
    \(sm // Dimensions\)}], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \({9, 9, 20, 20}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell[TextData[{
  "For example, this is the array of ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\(\[Psi]\_\(i, 
              000\)\%*\)/\[PartialD]\[Psi]\_\(j, 001\)\)]],
  " (with  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_\(deme, genotype\)\)]],
  "):"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sm\[LeftDoubleBracket]1, 2\[RightDoubleBracket] // 
      MatrixForm\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-0.6618455639126128`\), \(-0.22146132220628675`\), "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0", "0", "0"},
            {\(-0.2176308086693138`\), \(-0.43695799334680796`\), \
\(-0.22027968309277`\), "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0", "0", "0", "0", "0", "0"},
            {
              "0", \(-0.21215909878761563`\), \(-0.4279383697193218`\), \
\(-0.21697462689937086`\), "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0"},
            {"0", 
              "0", \(-0.20352636949762012`\), \(-0.41311695345987387`\), \
\(-0.21123784118373964`\), "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0"},
            {"0", "0", 
              "0", \(-0.19057205727762455`\), \(-0.39063605727940026`\), \
\(-0.2025161900961299`\), "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0"},
            {"0", "0", "0", 
              "0", \(-0.17138940679298817`\), \(-0.3575063439677745`\), \
\(-0.18999211349882844`\), "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0"},
            {"0", "0", "0", "0", 
              "0", \(-0.14300807747818015`\), \(-0.30936634311445815`\), \
\(-0.17268121343335602`\), "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0"},
            {"0", "0", "0", "0", "0", 
              "0", \(-0.1012929377769316`\), \(-0.24101348254673366`\), \
\(-0.14948931515126443`\), "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0"},
            {"0", "0", "0", "0", "0", "0", 
              "0", \(-0.04312849564223692`\), \(-0.1503899319430766`\), \
\(-0.11756182172073593`\), "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", 
              "0.0201034957561875`", \(-0.05438760136174803`\), \
\(-0.07283826602848961`\), "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0.05102819316166165`", 
              "0.005382815689486661`", \(-0.027535266875719448`\), "0", "0", 
              "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0.03915396019597747`", 
              "0.01853575172593669`", \(-0.0036116529994564186`\), "0", "0", 
              "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0.01932399605192466`", "0.013735694914209166`", 
              "0.002196419356720577`", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0.008806090905593167`", "0.008478095434625577`", 
              "0.0023387805036018086`", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0.004570724265960545`", "0.005381810024588595`", 
              "0.0017632585451938492`", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0.0027551939000821975`", "0.0036644277422735517`", 
              "0.0013200710675444042`", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0.0018481511838676936`", "0.0026746049174400004`", 
              "0.001039736474349991`", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0.0013422150480632074`", 
              "0.002090096414938203`", "0.0008773246952194332`", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0.0010467768432232756`", 
              "0.0017583430594591536`", "0.0008029621811292402`"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0.0008797576354312493`", 
              "0.0024107149105838345`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[19]//MatrixForm="]
}, Closed]],

Cell["\<\
Because migration is between nearest neighbours, there are entries \
only along the three diagonals.\
\>", "Text"],

Cell["\<\
These are the eigenvalues.  BlockMatrix[] has been used to collapse \
the 9\[Times]9 array of 20\[Times]20 arrays into a 180\[Times]180 array: \
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev = Eigenvalues[BlockMatrix[sm]] // Chop\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({1.0249821751523753`, 1.02498217515237`, 1.000109345335512`, 
      0.9999999999999993`, 0.9938441702975693`, 0.9834667951218591`, 
      0.9834667951218541`, 0.9755282581475764`, 0.9754372816588975`, 
      0.9754372816588971`, 0.9588818577703923`, 0.9561085406715064`, 
      0.9455032620941832`, 0.9451137346292162`, 0.9451137346292148`, 
      0.9107736398706529`, 0.906401881645021`, 0.9064018816450187`, 
      0.9045084971874737`, 0.8825655028021415`, 0.8560107494814249`, 
      0.8560107494814208`, 0.8535533905932738`, 0.8315703887153579`, 
      0.7965025258479023`, 0.7965025258479019`, 0.7938926261462368`, 
      0.7774225290436341`, 0.7300175130022324`, 0.73001751300223`, 
      0.7269952498697736`, 0.7133343668171526`, 0.6575473561849509`, 
      0.6575473561849428`, 0.6545084971874728`, 0.6454711964476779`, 
      0.581573985533535`, 0.5815739855335315`, 0.5782172325201153`, 
      0.5724558322724033`, 0.517708005879898`, 0.517708005879896`, 
      0.5034840378953207`, 0.5034840378953188`, 0.4999999999999996`, 
      0.4988838357819798`, 0.4931260530715116`, 0.4602210005386569`, 
      0.46022100053865617`, 0.439928550933246`, 0.4399285509332432`, 
      0.4315102731547244`, 0.43151027315472285`, 0.4278464725344017`, 
      0.4256971731119657`, 0.425697173111965`, 0.4249250589561019`, 
      0.4217827674798845`, 0.42072468468814084`, 0.4167309031119273`, 
      0.4167309031119267`, 0.4134831302503513`, 0.3955359706234706`, 
      0.3955359706234699`, 0.3952397873714286`, 0.3739109613389141`, 
      0.36832805518463063`, 0.36832805518462963`, 0.3528314544451211`, 
      0.3499121883743854`, 0.3499121883743835`, 0.34765655386368133`, 
      0.34549150281252583`, 0.3366093617025946`, 0.3366093617025933`, 
      0.31775365073853246`, 0.30467859847702594`, 0.30467859847702494`, 
      0.2876655996685043`, 0.28194873401963916`, 0.27619572997546726`, 
      0.27619572997546704`, 0.27300475013022696`, 0.26872955666411735`, 
      0.26872955666411713`, \(\(0.2524495897963284`\)\(\[InvisibleSpace]\)\) \
+ 0.003308302405930017`\ \[ImaginaryI], \(\(0.2524495897963284`\)\(\
\[InvisibleSpace]\)\) - 0.003308302405930017`\ \[ImaginaryI], 
      0.23176765487997908`, 0.23176765487997866`, 0.2194049483069246`, 
      0.21822982779358083`, 0.21083239963251885`, 0.21083239963251843`, 
      0.2061073738537634`, 0.20384291884917793`, 0.19376108136794237`, 
      0.19376108136794182`, 0.18501565864747127`, 0.16982722187701016`, 
      0.16340497040750804`, 0.1624189154464216`, 0.16241891544642123`, 
      0.15655285844580127`, 0.14724516240545368`, 0.14724516240545346`, 
      0.14644660940672607`, 0.14409925650841854`, 0.13939463291212487`, 
      0.13148586859136988`, 0.1282453702986654`, 0.12704845115023095`, 
      0.12704845115023078`, 0.12086470890546881`, 0.11738764053889165`, 
      0.11068864438757638`, 0.10110100123817607`, 0.09874826135624819`, 
      0.09733447912126787`, 0.09733447912126778`, 0.09549150281252619`, 
      0.09507884695665618`, 0.09507884695665617`, 0.08521801372265513`, 
      0.08229898715740948`, 0.07061757214707179`, 0.06692586072978246`, 
      0.06692586072978236`, 0.06532650519650778`, 0.06463468890726115`, 
      0.058041548834960474`, 0.058041548834960294`, 0.054496737905816016`, 
      0.04954888793563088`, 0.04860007336040574`, 0.04199434572022775`, 
      0.04199434572022762`, \
\(\(0.036394864797784615`\)\(\[InvisibleSpace]\)\) + 
        0.0027626221253890327`\ \[ImaginaryI], \(\(0.036394864797784615`\)\(\
\[InvisibleSpace]\)\) - 0.0027626221253890327`\ \[ImaginaryI], 
      0.03118103937810278`, 0.029105545983618218`, 0.02910554598361803`, 
      0.024471741852423186`, 0.02124566960473642`, 0.021245669604736245`, 
      0.020567337941622476`, 0.019227690119852592`, 0.019204127159865494`, 
      0.012370230594288108`, 0.012370230594287882`, 0.010459122400666694`, 
      0.010416468273512959`, 0.006155829702431066`, 0.005734989881758329`, 
      0.0057349898817581945`, \
\(\(0.004853633915105327`\)\(\[InvisibleSpace]\)\) + 
        0.002951351238230668`\ \[ImaginaryI], \(\(0.004853633915105327`\)\(\
\[InvisibleSpace]\)\) - 
        0.002951351238230668`\ \[ImaginaryI], \(-0.0035757652030282833`\), 
      0.003103647251054699`, 0.0031036472510546603`, 0.0018217957277152457`, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",\

  CellLabel->"Out[20]="]
}, Open  ]],

Cell["\<\
There are two unstable eigenvalues (\[Lambda]=1.025), which \
correspond to a shift apart of the three clines.  The third eigenvalue \
corresponds to a translation of the three clines to left or right, and is \
nearly neutral (\[Lambda]=1.00011).  the discrepancy arises because of end \
effects.  The fourth eigenvalue of 1 coresponds to the assumed constancy of \
deme size.\
\>", "Text"],

Cell["This shows the leading eigenvector:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Partition[\(Eigenvectors[
              BlockMatrix[sm]]\)\[LeftDoubleBracket]1\[RightDoubleBracket], 
          20] // MatrixForm\) // Chop\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0"},
            {"0.0081342783384788`", "0.009373430603221954`", 
              "0.01203550871609583`", "0.016507057848488906`", 
              "0.023398090486147282`", "0.03349095926716476`", 
              "0.04735945115941537`", "0.06396838778129776`", 
              "0.07757901607536724`", "0.07685774839364079`", 
              "0.05701307413889179`", "0.031623510403842904`", 
              "0.014466896873771968`", "0.006196845356740736`", 
              "0.0027142518585016877`", "0.0012646060151268708`", 
              "0.0006372666367599898`", "0.0003543652530154562`", 
              "0.00022623789066635285`", "0.00017611237547684506`"},
            {"0.020667608427614226`", "0.02381605168522284`", 
              "0.030579870889839635`", "0.041941201629857684`", 
              "0.05944996618075717`", "0.08509396939798529`", 
              "0.12033109160956164`", "0.16253114725302542`", 
              "0.19711308855457027`", "0.19528048861085104`", 
              "0.14485905725509882`", "0.08034914751422956`", 
              "0.03675755209175657`", "0.015744970603876512`", 
              "0.006896382475892145`", "0.003213116253164677`", 
              "0.0016191697364305907`", "0.0009003727172202956`", 
              "0.0005748261789966109`", "0.0004474670603230959`"},
            {"0.0006235794358152334`", "0.0008010640696787161`", 
              "0.0012547379702510277`", "0.002256436373198932`", 
              "0.00447772226827081`", "0.009610634334279564`", 
              "0.021941815960232484`", "0.05122444896440786`", 
              "0.11197265791520203`", "0.20187213138830012`", 
              "0.2721382369968511`", "0.27469210462286203`", 
              "0.22649953502897352`", "0.1676905427651033`", 
              "0.1185849286623013`", "0.08284805666477676`", 
              "0.058448259476732656`", "0.042615379604674264`", 
              "0.033189482287403385`", "0.02880188676515729`"},
            {\(-0.0288018867673692`\), \(-0.03318948228994706`\), \
\(-0.042615379607925344`\), \(-0.05844825948115396`\), \
\(-0.08284805667094644`\), \(-0.11858492867088516`\), \(-0.16769054277664436`\
\), \(-0.2264995350433186`\), \(-0.27469210463847255`\), \
\(-0.27213823701124273`\), \(-0.20187213139958926`\), \(-0.11197265792249746`\
\), \(-0.051224448968192435`\), \(-0.021941815961901777`\), \
\(-0.009610634334967305`\), \(-0.0044777222685549985`\), \
\(-0.002256436373321413`\), \(-0.0012547379703081222`\), \
\(-0.0008010640697092255`\), \(-0.0006235794358361977`\)},
            {\(-0.000447467060347285`\), \(-0.0005748261790275176`\), \
\(-0.0009003727172683401`\), \(-0.0016191697365167566`\), \
\(-0.003213116253336525`\), \(-0.006896382476263697`\), \
\(-0.015744970604703985`\), \(-0.03675755209346098`\), \(-0.0803491475170251`\
\), \(-0.1448590572585623`\), \(-0.19528048861500036`\), \
\(-0.19711308855990728`\), \(-0.16253114725872597`\), \
\(-0.1203310916144445`\), \(-0.0850939694016393`\), \
\(-0.05944996618332741`\), \(-0.04194120163163748`\), \(-0.03057987089109719`\
\), \(-0.02381605168616976`\), \(-0.020667608428417153`\)},
            {\(-0.0001761123755039388`\), \(-0.00022623789069760558`\), \
\(-0.0003543652530553818`\), \(-0.0006372666368133804`\), \
\(-0.0012646060151979238`\), \(-0.002714251858589584`\), \
\(-0.006196845356812989`\), \(-0.01446689687361055`\), \
\(-0.03162351040260155`\), \(-0.05701307413533508`\), \
\(-0.0768577483886012`\), \(-0.07757901607148897`\), \
\(-0.06396838777924348`\), \(-0.04735945115832637`\), \(-0.03349095926639714`\
\), \(-0.02339809048548893`\), \(-0.01650705784789939`\), \
\(-0.012035508715565012`\), \(-0.00937343060273631`\), \
\(-0.008134278338017442`\)},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[21]//MatrixForm="]
}, Open  ]],

Cell["\<\
It corresponds to an increase in {0,0,1}, {0,1,0}, {0,1,1} at the \
expense of the complementary genotypes - that is, to a shift to the right for \
clines at the first two loci, and to the left of the cline at the third \
locus. \
\>", "Text"],

Cell["\<\
This shows the nearly neutral eigenvector.  It corresponds to an \
increase in '1' alleles at the expense of '0' alleles - that is, to shifts of \
all the clines to the right.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Partition[\(Eigenvectors[
              BlockMatrix[sm]]\)\[LeftDoubleBracket]3\[RightDoubleBracket], 
          20] // MatrixForm\) // Chop\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.03305776568488083`", "0.03699805787379103`", 
              "0.045541937701169946`", "0.0602226961828173`", 
              "0.08389530294226775`", "0.12138273076624656`", 
              "0.1795115620722131`", "0.262309104326029`", 
              "0.34815622989455813`", "0.35476941757295727`", 
              "0.22701475597836904`", "0.08372565356493712`", 
              "0.019338947178033774`", "0.0035298358279711593`", 
              "0.0006798426672977111`", "0.00016718333275640208`", 
              "0.00005395096834133959`", "0.00002217929750113982`", 
              "0.00001168721429412078`", "8.279525099718935`*^-6"},
            {\(-0.010546380367493531`\), \(-0.011745576872268609`\), \
\(-0.014303425200458925`\), \(-0.018555357802077472`\), \
\(-0.02498864330498347`\), \(-0.03390519251147696`\), \
\(-0.0437614108447894`\), \(-0.04611227677744389`\), \(-0.021089885273632612`\
\), "0.03811118037511858`", "0.08069606757255604`", "0.06705364016789658`", 
              "0.034877775603475034`", "0.014899164568472215`", 
              "0.006329103520298436`", "0.0029207298972003656`", 
              "0.001500890601922556`", "0.0008698276000506608`", 
              "0.0005832133469198898`", "0.00047011501849070035`"},
            {\(-0.010546380366576439`\), \(-0.011745576871303766`\), \
\(-0.014303425199395899`\), \(-0.01855535780086311`\), \
\(-0.024988643303563794`\), \(-0.03390519250981164`\), \
\(-0.043761410842909354`\), \(-0.046112276775598315`\), \
\(-0.021089885272490255`\), "0.03811118037477954`", "0.0806960675710486`", 
              "0.06705364016645546`", "0.034877775602631625`", 
              "0.014899164568064479`", "0.0063291035201039035`", 
              "0.002920729897100704`", "0.001500890601865978`", 
              "0.0008698276000145859`", "0.0005832133468936361`", 
              "0.00047011501846846266`"},
            {\(-0.0004701150184540598`\), \(-0.0005832133468766743`\), \
\(-0.0008698275999913144`\), \(-0.001500890601829503`\), \
\(-0.0029207298970363557`\), \(-0.006329103519978172`\), \
\(-0.014899164567800527`\), \(-0.034877775602085145`\), \
\(-0.06705364016552119`\), \(-0.08069606757007117`\), \(-0.03811118037456006`\
\), "0.021089885271747377`", "0.04611227677439782`", "0.04376141084168602`", 
              "0.03390519250872737`", "0.024988643302638572`", 
              "0.018555357800071906`", "0.014303425198703394`", 
              "0.011745576870675588`", "0.010546380365980596`"},
            {\(-0.010546380370196324`\), \(-0.01174557687511256`\), \
\(-0.014303425203591623`\), \(-0.01855535780565613`\), \
\(-0.024988643309168525`\), \(-0.03390519251638478`\), \
\(-0.04376141085033036`\), \(-0.046112276782883425`\), \
\(-0.021089885276999586`\), "0.03811118037611752`", "0.08069606757699813`", 
              "0.06705364017214394`", "0.03487777560596062`", 
              "0.014899164569673955`", "0.006329103520871731`", 
              "0.002920729897494131`", "0.0015008906020893083`", 
              "0.0008698276001569907`", "0.0005832133469972728`", 
              "0.00047011501855624596`"},
            {\(-0.00047011501854183404`\), \(-0.0005832133469802997`\), \
\(-0.0008698276001337328`\), \(-0.0015008906020528123`\), \
\(-0.0029207298974297884`\), \(-0.006329103520745988`\), \
\(-0.014899164569410036`\), \(-0.03487777560541415`\), \
\(-0.06705364017120928`\), \(-0.08069606757602067`\), \
\(-0.038111180375898224`\), "0.021089885276256555`", "0.046112276781682754`", 
              "0.04376141084910694`", "0.03390519251530054`", 
              "0.02498864330824334`", "0.01855535780486498`", 
              "0.014303425202898953`", "0.011745576874484619`", 
              "0.0105463803696006`"},
            {\(-0.00047011501851960974`\), \(-0.0005832133469540578`\), \
\(-0.000869827600097643`\), \(-0.001500890601996255`\), \
\(-0.0029207298973301142`\), \(-0.006329103520551493`\), \
\(-0.014899164569002294`\), \(-0.03487777560457084`\), \(-0.0670536401697684`\
\), \(-0.08069606757451357`\), \(-0.03811118037555924`\), 
              "0.021089885275114174`", "0.04611227677983728`", 
              "0.04376141084722695`", "0.03390519251363539`", 
              "0.024988643306823474`", "0.018555357803650665`", 
              "0.014303425201836091`", "0.011745576873519691`", 
              "0.010546380368683557`"},
            {\(-8.279525099719577`*^-6\), \(-0.000011687214294123201`\), \
\(-0.000022179297501143738`\), \(-0.00005395096834134718`\), \
\(-0.00016718333275641924`\), \(-0.000679842667297755`\), \
\(-0.0035298358279712756`\), \(-0.019338947178034197`\), \
\(-0.08372565356493704`\), \(-0.22701475597836782`\), \
\(-0.3547694175729545`\), \(-0.3481562298945527`\), \(-0.2623091043260193`\), \
\(-0.17951156207220156`\), \(-0.12138273076623526`\), \
\(-0.0838953029422571`\), \(-0.06022269618280662`\), \
\(-0.04554193770116161`\), \(-0.036998057873784865`\), \
\(-0.03305776568487987`\)},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[22]//MatrixForm="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{864, 688},
WindowMargins->{{Automatic, 40}, {Automatic, 0}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\nThe item above is horizontal 0.5 pt line", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\nThe item above is a ProgramTop line\n", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\nThe item above is a ProgramBottom line\n", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "StabilityDirect"->{
    Cell[2259, 66, 401, 8, 38, "DefinitionBox",
      CellTags->"StabilityDirect"]},
  "S5.24.1"->{
    Cell[3023, 86, 79, 1, 28, "MathCaption",
      CellTags->{"S5.24.1", "1.4"}]},
  "1.4"->{
    Cell[3023, 86, 79, 1, 28, "MathCaption",
      CellTags->{"S5.24.1", "1.4"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"StabilityDirect", 176866, 4944},
  {"S5.24.1", 176966, 4947},
  {"1.4", 177060, 4950}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 35, 0, 36, "SubsectionIcon"],
Cell[1777, 53, 199, 4, 22, "Text"],
Cell[1979, 59, 277, 5, 36, "Text"],
Cell[2259, 66, 401, 8, 38, "DefinitionBox",
  CellTags->"StabilityDirect"],
Cell[2663, 76, 357, 8, 36, "Text"],
Cell[3023, 86, 79, 1, 28, "MathCaption",
  CellTags->{"S5.24.1", "1.4"}],
Cell[3105, 89, 92, 2, 26, "Input"],
Cell[3200, 93, 167, 4, 28, "MathCaption"],
Cell[3370, 99, 421, 8, 26, "Input"],
Cell[3794, 109, 52, 0, 28, "MathCaption"],
Cell[3849, 111, 442, 10, 85, "DisplayMath"],

Cell[CellGroupData[{
Cell[4316, 125, 131, 3, 26, "Input"],
Cell[4450, 130, 413, 8, 39, "Output"]
}, Open  ]],
Cell[4878, 141, 182, 6, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[5085, 151, 183, 4, 42, "Input"],
Cell[5271, 157, 69424, 1541, 294, 10409, 807, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[74710, 1701, 54, 0, 22, "Text"],
Cell[74767, 1703, 262, 7, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[75054, 1714, 188, 3, 42, "Input"],
Cell[75245, 1719, 755, 16, 95, "Output"]
}, Open  ]],
Cell[76015, 1738, 377, 7, 36, "Text"],
Cell[76395, 1747, 125, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[76545, 1754, 80, 2, 26, "Input"],
Cell[76628, 1758, 138, 3, 20, "Output"]
}, Open  ]],
Cell[76781, 1764, 183, 4, 22, "Text"],
Cell[76967, 1770, 318, 10, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[77310, 1784, 228, 5, 42, "Input"],
Cell[77541, 1791, 84, 2, 20, "Output"]
}, Open  ]],
Cell[77640, 1796, 70, 0, 22, "Text"],
Cell[77713, 1798, 154, 3, 28, "MathCaption"],
Cell[77870, 1803, 368, 7, 42, "Input"],
Cell[78241, 1812, 68, 2, 22, "Text"],
Cell[78312, 1816, 171, 5, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[78508, 1825, 585, 9, 56, "Input"],
Cell[79096, 1836, 209, 4, 20, "Message"],
Cell[79308, 1842, 655, 12, 37, "Output"]
}, Open  ]],
Cell[79978, 1857, 276, 8, 52, "MathCaption"],

Cell[CellGroupData[{
Cell[80279, 1869, 196, 5, 41, "Input"],
Cell[80478, 1876, 218, 4, 41, "Output"]
}, Open  ]],
Cell[80711, 1883, 137, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[80873, 1890, 491, 11, 90, "Input"],
Cell[81367, 1903, 649, 10, 93, "Output"]
}, Open  ]],
Cell[82031, 1916, 222, 6, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[82278, 1926, 357, 8, 47, "Input"],
Cell[82638, 1936, 427, 8, 80, "Output"]
}, Open  ]],
Cell[83080, 1947, 321, 6, 37, "DefinitionBox"],
Cell[83404, 1955, 478, 12, 36, "Text"],
Cell[83885, 1969, 138, 3, 28, "MathCaption"],
Cell[84026, 1974, 339, 6, 64, "Input"],
Cell[84368, 1982, 279, 7, 26, "Text"],
Cell[84650, 1991, 111, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[84786, 1998, 164, 4, 42, "Input"],
Cell[84953, 2004, 73, 2, 20, "Output"]
}, Open  ]],
Cell[85041, 2009, 296, 9, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[85362, 2022, 126, 3, 26, "Input"],
Cell[85491, 2027, 4282, 73, 335, "Output"]
}, Closed]],
Cell[89788, 2103, 124, 3, 18, "Text"],
Cell[89915, 2108, 176, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[90116, 2116, 99, 2, 26, "Input"],
Cell[90218, 2120, 4408, 65, 260, "Output"]
}, Open  ]],
Cell[94641, 2188, 400, 7, 36, "Text"],
Cell[95044, 2197, 58, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[95127, 2201, 200, 4, 26, "Input"],
Cell[95330, 2207, 4238, 69, 159, "Output"]
}, Open  ]],
Cell[99583, 2279, 253, 5, 36, "Text"],
Cell[99839, 2286, 199, 4, 22, "Text"],

Cell[CellGroupData[{
Cell[100063, 2294, 200, 4, 26, "Input"],
Cell[100266, 2300, 5231, 85, 165, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

