(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     53794,       1183]*)
(*NotebookOutlinePosition[    125332,       3752]*)
(*  CellTagsIndexPosition[    125254,       3746]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Finding the stability for a cline: a three locus example", \
"SubsectionIcon"],

Cell["This loads the package, as well as the graphics package:", "MathCaption"],

Cell[BoxData[
    \(<< NumericalModels`ExactModel`; << Graphics`;\)], "Input",
  CellLabel->"In[13]:="],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(StabilityK[k, i, h, \[Psi], \[Psi]', 
              W]\), \(gives\ the\ more\ general\ element\ for\ demic\ models \
. \ \ \[Psi]\ must\ have\ the\ form\ SymmetricHaploidFrequencies[{\[Phi]\_0, \
\ \[Ellipsis]}, n\_d]\)},
          {\(StabilityK[k, i, h, \[Psi], W, 
              m]\), \(generates\ an\ n\_d\[Times]
              n\_d\ matrix\ which\ gives\ the\ stability\ for\ a\ stepping\ \
stone\ model . \ \ \[Psi]\ must\ now\ be\ a\ list\ of\ the\ form \
{SymmetricHaploidFrequencies[\[Ellipsis]], \[Ellipsis]}, \ 
            representing\ a\ cline . \ \ Includes\ the\ factor\ 2\/W\&_, \ 
            since\ this\ now\ varies\ across\ \(\(demes\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"StabilityK"],

Cell[TextData[{
  "For a demic model, at equilibrium under migration and selection, the \
derivatives ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_\(\(g'\)[Y]\)\(g\^*\)[X]\)]],
  " that determine the stability matrix depend on the genotype frequencies in \
the deme of interest ",
  Cell[BoxData[
      \(TraditionalForm\`\((g[X] = \(g\^\(\(*\)\(\ \)\)\)[X]\)\)]],
  " at  equilibrium) and in the source deme g'[Y].  (For a single deme, ",
  Cell[BoxData[
      \(TraditionalForm\`StabilityK[k, i, h, \[Psi], W]\)]],
  " \[Congruent] ",
  Cell[BoxData[
      \(TraditionalForm\`StabilityK[k, i, h, \[Psi], \[Psi], W]\)]],
  ").  This allows rather general migration-selection models to be analysed."
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`StabilityK[k, i, h, \[Psi], W, m]\)]],
  " gives the derivatives for a linear stepping-stone model.  By default, \
migration is between nearest-neighbours, and occurs immediately before \
selection on diploids (i.e. MigrationOrder\[Rule]UMS).",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \ \)\(\[Psi]\)\)\)]],
  " must now list genotype frequencies across the cline.   Unlike the \
single-deme case ",
  Cell[BoxData[
      \(TraditionalForm\`\((StabilityK[k, i, h, \[Psi], W]\)\)]],
  "), this now includes the factor ",
  Cell[BoxData[
      \(TraditionalForm\`2\/W\&_\)]],
  ", since this varies across demes.  MigrationOrder can be set to other \
orders of events."
}], "Text"],

Cell[TextData[{
  "This stores a three locus cline across 20 demes, saving values in \
\[Psi][t] at t=0,10,\[Ellipsis],100. Migration is at its maximum ",
  Cell[BoxData[
      \(TraditionalForm\`\((m\)\)]],
  "=50%).  There is an accelerating decline in fitness with more heterozygous \
loci (",
  Cell[BoxData[
      \(TraditionalForm\`W = \((1 - s)\)\^\(h\^4\)\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  "=1%); this should push clines apart, making the symmetric solution \
unstable."
}], "Text"],

Cell[BoxData[{
    \(\(\(\(hetW[s_, k_]\)[_]\)[_, _, 
          h_] := \((1 - s)\)\^\(h\^k\);\)\), "\n", 
    \(\(\[Psi]0 = 
        MakeCline[20, 3, 1, 
          NumericalModel \[Rule] 
            SymmetricHaploidFrequencies];\)\), "\[IndentingNewLine]", 
    \(\(StoreExact[\[Psi], \[Psi]0, hetW[0.01, 4], 0.5, {100, 10}, 
        Compiled \[Rule] True];\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi][100] // MatrixForm\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(SymmetricHaploidFrequencies[{0.9288899442946607`, 
                  0.06973730704575426`, 0.0013679778734190177`, 
                  4.770786166065611`*^-6}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.922434862489034`, 
                  0.07589945244256792`, 0.001659080684621774`, 
                  6.604383776467821`*^-6}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.908817091538568`, 
                  0.0888019075880939`, 0.0023690088379706067`, 
                  0.000011992035367249919`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.8864201176358572`, 
                  0.10971681643421817`, 0.0038360945799158137`, 
                  0.000026971350008715953`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.8522615460465179`, 
                  0.14080102251070534`, 0.006863705472240212`, 
                  0.00007372597053652497`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.801193049531807`, 
                  0.18510994904364275`, 0.013444282880972701`, 
                  0.00025271854357740274`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.7248222882753691`, 
                  0.24529121331859544`, 0.028760734025905104`, 
                  0.0011257643801303534`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.6113216390957789`, 
                  0.3172957190892717`, 0.06542151577063574`, 
                  0.005961126044313614`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.4516513090564137`, 
                  0.3748222594027596`, 0.14407403579709605`, 
                  0.029452395743730514`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.2631623181335865`, 
                  0.3643313242705033`, 0.26501103936837683`, 
                  0.10749531822753325`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.10749531822753336`, 
                  0.26501103936837694`, 0.3643313242705033`, 
                  0.26316231813358637`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.029452395743730538`, 
                  0.14407403579709607`, 0.37482225940275954`, 
                  0.4516513090564138`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.005961126044313618`, 
                  0.06542151577063576`, 0.3172957190892717`, 
                  0.611321639095779`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.0011257643801303536`, 
                  0.028760734025905108`, 0.24529121331859552`, 
                  0.724822288275369`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.0002527185435774027`, 
                  0.0134442828809727`, 0.18510994904364278`, 
                  0.8011930495318071`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.000073725970536525`, 
                  0.006863705472240213`, 0.14080102251070536`, 
                  0.8522615460465179`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.000026971350008715953`, 
                  0.0038360945799158137`, 0.10971681643421818`, 
                  0.8864201176358574`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.000011992035367249917`, 
                  0.002369008837970606`, 0.0888019075880939`, 
                  0.9088170915385682`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{6.604383776467821`*^-6, 
                  0.0016590806846217743`, 0.07589945244256796`, 
                  0.922434862489034`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{4.770786166065615`*^-6, 
                  0.0013679778734190186`, 0.06973730704575429`, 
                  0.9288899442946605`}, 1.`]\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        SymmetricHaploidFrequencies[ {0.92888994429466065, 
          0.06973730704575426, 0.0013679778734190177, 
          4.7707861660656113*^-06}, 1.0], 
        SymmetricHaploidFrequencies[ {0.92243486248903395, 
          0.075899452442567919, 0.001659080684621774, 
          6.6043837764678208*^-06}, 1.0], 
        SymmetricHaploidFrequencies[ {0.90881709153856804, 
          0.088801907588093906, 0.0023690088379706067, 
          1.1992035367249919*^-05}, 1.0], 
        SymmetricHaploidFrequencies[ {0.88642011763585715, 
          0.10971681643421817, 0.0038360945799158137, 
          2.6971350008715953*^-05}, 1.0], 
        SymmetricHaploidFrequencies[ {0.85226154604651794, 
          0.14080102251070534, 0.0068637054722402117, 7.372597053652497*^-05},
           1.0], 
        SymmetricHaploidFrequencies[ {0.80119304953180703, 
          0.18510994904364275, 0.013444282880972701, 0.00025271854357740274}, 
          1.0], 
        SymmetricHaploidFrequencies[ {0.7248222882753691, 0.24529121331859544,
           0.028760734025905104, 0.0011257643801303534}, 1.0], 
        SymmetricHaploidFrequencies[ {0.61132163909577886, 
          0.31729571908927168, 0.065421515770635735, 0.0059611260443136142}, 
          1.0], 
        SymmetricHaploidFrequencies[ {0.45165130905641371, 
          0.37482225940275959, 0.14407403579709605, 0.029452395743730514}, 
          1.0], 
        SymmetricHaploidFrequencies[ {0.26316231813358648, 0.3643313242705033,
           0.26501103936837683, 0.10749531822753325}, 1.0], 
        SymmetricHaploidFrequencies[ {0.10749531822753336, 
          0.26501103936837694, 0.3643313242705033, 0.26316231813358637}, 1.0],
         
        SymmetricHaploidFrequencies[ {0.029452395743730538, 
          0.14407403579709607, 0.37482225940275954, 0.45165130905641382}, 
          1.0], 
        SymmetricHaploidFrequencies[ {0.0059611260443136176, 
          0.065421515770635763, 0.31729571908927168, 0.61132163909577897}, 
          1.0], 
        SymmetricHaploidFrequencies[ {0.0011257643801303536, 
          0.028760734025905108, 0.24529121331859552, 0.72482228827536899}, 
          1.0], 
        SymmetricHaploidFrequencies[ {0.00025271854357740268, 
          0.013444282880972699, 0.18510994904364278, 0.80119304953180714}, 
          1.0], 
        SymmetricHaploidFrequencies[ {7.3725970536524997*^-05, 
          0.0068637054722402134, 0.14080102251070536, 0.85226154604651794}, 
          1.0], 
        SymmetricHaploidFrequencies[ {2.6971350008715953*^-05, 
          0.0038360945799158137, 0.10971681643421818, 0.88642011763585737}, 
          1.0], 
        SymmetricHaploidFrequencies[ {1.1992035367249917*^-05, 
          0.0023690088379706058, 0.088801907588093906, 0.90881709153856816}, 
          1.0], 
        SymmetricHaploidFrequencies[ {6.6043837764678208*^-06, 
          0.0016590806846217743, 0.075899452442567961, 0.92243486248903395}, 
          1.0], 
        SymmetricHaploidFrequencies[ {4.7707861660656147*^-06, 
          0.0013679778734190186, 0.069737307045754288, 0.92888994429466054}, 
          1.0]}]]], "Output",
  CellLabel->"Out[30]//MatrixForm="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[AlleleFrequencyMean[\[Psi][100]], 
        PlotJoined \[Rule] True];\)\)], "Input",
  CellLabel->"In[32]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 0.603178 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13535 -18 -4.5 ]
[.01131 .13535 0 4.5 ]
[.01131 .25599 -18 -4.5 ]
[.01131 .25599 0 4.5 ]
[.01131 .37662 -18 -4.5 ]
[.01131 .37662 0 4.5 ]
[.01131 .49726 -18 -4.5 ]
[.01131 .49726 0 4.5 ]
[.01131 .61789 -6 -4.5 ]
[.01131 .61789 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(10)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(15)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13535 m
.03006 .13535 L
s
[(0.2)] .01131 .13535 1 0 Mshowa
.02381 .25599 m
.03006 .25599 L
s
[(0.4)] .01131 .25599 1 0 Mshowa
.02381 .37662 m
.03006 .37662 L
s
[(0.6)] .01131 .37662 1 0 Mshowa
.02381 .49726 m
.03006 .49726 L
s
[(0.8)] .01131 .49726 1 0 Mshowa
.02381 .61789 m
.03006 .61789 L
s
[(1)] .01131 .61789 1 0 Mshowa
.125 Mabswid
.02381 .04487 m
.02756 .04487 L
s
.02381 .07503 m
.02756 .07503 L
s
.02381 .10519 m
.02756 .10519 L
s
.02381 .16551 m
.02756 .16551 L
s
.02381 .19567 m
.02756 .19567 L
s
.02381 .22583 m
.02756 .22583 L
s
.02381 .28615 m
.02756 .28615 L
s
.02381 .3163 m
.02756 .3163 L
s
.02381 .34646 m
.02756 .34646 L
s
.02381 .40678 m
.02756 .40678 L
s
.02381 .43694 m
.02756 .43694 L
s
.02381 .4671 m
.02756 .4671 L
s
.02381 .52742 m
.02756 .52742 L
s
.02381 .55758 m
.02756 .55758 L
s
.02381 .58773 m
.02756 .58773 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.07143 .02929 m
.11905 .03065 L
.16667 .03353 L
.21429 .03833 L
.2619 .04583 L
.30952 .05749 L
.35714 .07628 L
.40476 .10841 L
.45238 .16578 L
.5 .25937 L
.54762 .37324 L
.59524 .46683 L
.64286 .5242 L
.69048 .55633 L
.7381 .57512 L
.78571 .58678 L
.83333 .59427 L
.88095 .59908 L
.92857 .60196 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[32]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00E@3oool3000003X0oooo0`0000040?ooo`800000=P3oool3000000<0oooo0`00000e0?oo
o`D000000`3oool2000000L0oooo001D0?ooo`050000003oool0oooo0?ooo`000000>P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000003H0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo03<0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000060?ooo`00F03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000060?ooo`00F03oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000=P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo03D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00@0oooo001D0?ooo`@00000>`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000003H0oooo00@000000?ooo`3oool0oooo1000000e0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000060?ooo`00E03oool00`000000oooo
0?ooo`0k0?ooo`800000103oool010000000oooo0?ooo`00000e0?ooo`8000000`3oool00`000000
oooo0?ooo`0f0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000006
0?ooo`00E03oool5000003X0oooo00<000000?ooo`3oool00`3oool2000003L0oooo00@000000?oo
o`3oool0oooo1@00000e0?ooo`<00000103oool2000000L0oooo000H0?ooo`030000003oool0oooo
0?l0oooo1P3oool001P0oooo00<000000?ooo`3oool0o`3oool60?ooo`00603oool00`000000oooo
0?ooo`3o0?ooo`H0oooo000H0?ooo`030000003oool0oooo0?l0oooo1P3oool00180ooooo`00000;
000000@0oooo000H0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0oooo0?l0oooo1P3oool001P0oooo00<000000?ooo`3oool02P3o
oolD00000>L0oooo000H0?ooo`030000003oool0oooo01h0oooo3@00003J0?ooo`00603oool00`00
0000oooo0?ooo`0[0?ooo`T00000d@3oool001P0oooo00<000000?ooo`3oool0=03oool600000</0
oooo000H0?ooo`800000>`3oool500000<H0oooo000H0?ooo`030000003oool0oooo03l0oooo1@00
00310?ooo`00603oool00`000000oooo0?ooo`140?ooo`@00000_@3oool001P0oooo00<000000?oo
o`3oool0B03oool300000;X0oooo000H0?ooo`030000003oool0oooo04/0oooo0`00002g0?ooo`00
603oool00`000000oooo0?ooo`1>0?ooo`<00000]03oool001P0oooo00<000000?ooo`3oool0D@3o
ool200000;80oooo000H0?ooo`030000003oool0oooo05<0oooo0`00002_0?ooo`00603oool20000
05L0oooo0P00002]0?ooo`00603oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0:X0
oooo000H0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0Z@3oool001P0oooo00<0
00000?ooo`3oool0FP3oool200000:T0oooo000H0?ooo`030000003oool0oooo05`0oooo00<00000
0?ooo`3oool0YP3oool001P0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`2U0?oo
o`00603oool00`000000oooo0?ooo`1N0?ooo`800000Y@3oool001P0oooo00<000000?ooo`3oool0
H03oool00`000000oooo0?ooo`2R0?ooo`00603oool200000680oooo00<000000?ooo`3oool0X@3o
ool001P0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`2P0?ooo`00603oool00`00
0000oooo0?ooo`1R0?ooo`030000003oool0oooo0:00oooo000H0?ooo`030000003oool0oooo06<0
oooo00<000000?ooo`3oool0W`3oool001P0oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`2N0?ooo`001@3oool2000000@0oooo00@000000?ooo`3oool0oooo1@0000040?ooo`030000
003oool0oooo06D0oooo00<000000?ooo`3oool0W@3oool000@0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3o
ool0W03oool000@0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo06L0oooo00<000000?ooo`3oool0V`3oool000@0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`030?ooo`<00000J03oool00`000000oooo0?ooo`2J0?ooo`00
103oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`1Y0?ooo`030000003oool0oooo09T0oooo00040?ooo`040000003oool0oooo0000
00L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0V@3oool000D0oooo0P0000090?ooo`<000001@3oool00`000000oooo0?ooo`1Z0?oo
o`030000003oool0oooo09P0oooo000H0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3o
ool0U`3oool001P0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`2F0?ooo`00603o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo09D0oooo000H0?ooo`030000003oool0
oooo06h0oooo00<000000?ooo`3oool0U03oool001P0oooo0P00001`0?ooo`030000003oool0oooo
09<0oooo000H0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0T`3oool001P0oooo
00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`2B0?ooo`00603oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo0980oooo000H0?ooo`030000003oool0oooo0740oooo00<00000
0?ooo`3oool0T@3oool001P0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`2A0?oo
o`00603oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0900oooo000H0?ooo`030000
003oool0oooo0780oooo00<000000?ooo`3oool0T03oool001P0oooo0P00001d0?ooo`030000003o
ool0oooo08l0oooo000H0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0S`3oool0
01P0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`2>0?ooo`00603oool00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo08h0oooo000H0?ooo`030000003oool0oooo07D0oooo
00<000000?ooo`3oool0S@3oool001P0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?oo
o`2<0?ooo`00603oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo08`0oooo000H0?oo
o`030000003oool0oooo07L0oooo00<000000?ooo`3oool0R`3oool001P0oooo0P00001h0?ooo`03
0000003oool0oooo08/0oooo000H0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
RP3oool001P0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`2:0?ooo`00603oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo08T0oooo000H0?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool0R@3oool000D0oooo0P0000040?ooo`030000003oool0oooo00<0
oooo0`0000040?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0R03oool000@0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07X0
oooo00<000000?ooo`3oool0R03oool000@0oooo00@000000?ooo`3oool000001`3oool5000000@0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`270?ooo`00103oool010000000oooo
0?ooo`0000070?ooo`040000003oool0oooo000000D0oooo0`00001k0?ooo`030000003oool0oooo
08L0oooo00040?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`0000001@3oool00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo08H0oooo00040?ooo`040000003oool0oooo0000
00T0oooo0P0000050?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0QP3oool000D0
oooo0P00000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0O@3oool00`000000
oooo0?ooo`250?ooo`00603oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo08D0oooo
000H0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0Q@3oool001P0oooo00<00000
0?ooo`3oool0OP3oool00`000000oooo0?ooo`240?ooo`00603oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo08@0oooo000H0?ooo`800000P03oool00`000000oooo0?ooo`230?ooo`00
603oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo08<0oooo000H0?ooo`030000003o
ool0oooo07l0oooo00<000000?ooo`3oool0P`3oool001P0oooo00<000000?ooo`3oool0P03oool0
0`000000oooo0?ooo`220?ooo`00603oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo
0880oooo000H0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0P@3oool001P0oooo
00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`210?ooo`00603oool00`000000oooo0?oo
o`210?ooo`030000003oool0oooo0840oooo000H0?ooo`800000P`3oool00`000000oooo0?ooo`20
0?ooo`00603oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0800oooo000H0?ooo`03
0000003oool0oooo08<0oooo00<000000?ooo`3oool0O`3oool001P0oooo00<000000?ooo`3oool0
P`3oool00`000000oooo0?ooo`1o0?ooo`00603oool00`000000oooo0?ooo`230?ooo`030000003o
ool0oooo07l0oooo000H0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0OP3oool0
01P0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`1n0?ooo`00603oool00`000000
oooo0?ooo`250?ooo`030000003oool0oooo07d0oooo000H0?ooo`800000QP3oool00`000000oooo
0?ooo`1m0?ooo`00603oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo07d0oooo000H
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0O03oool001P0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`1l0?ooo`00603oool00`000000oooo0?ooo`270?ooo`03
0000003oool0oooo07/0oooo00050?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<00000
1@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo07/0oooo00040?ooo`040000003o
ool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo08L0
oooo00<000000?ooo`3oool0N`3oool000@0oooo00@000000?ooo`3oool000001`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`1j0?oo
o`00103oool010000000oooo0?ooo`0000070?ooo`@000001@3oool3000008P0oooo00<000000?oo
o`3oool0NP3oool000@0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo08T0oooo00<000000?ooo`3oool0N@3oool000@0oooo00@000000?ooo`3o
ool00000203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08T0oooo00<000000?oo
o`3oool0N@3oool000D0oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`2:0?ooo`03
0000003oool0oooo07P0oooo000H0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0
N03oool001P0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`1g0?ooo`00603oool0
0`000000oooo0?ooo`2;0?ooo`030000003oool0oooo07L0oooo000H0?ooo`030000003oool0oooo
08`0oooo00<000000?ooo`3oool0MP3oool001P0oooo0P00002=0?ooo`030000003oool0oooo07H0
oooo000H0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0M@3oool001P0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`1e0?ooo`00603oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo07@0oooo000H0?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool0L`3oool001P0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`1c0?ooo`00
603oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0780oooo000H0?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool0LP3oool001P0oooo0P00002B0?ooo`030000003oool0
oooo0740oooo000H0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0L@3oool001P0
oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`1`0?ooo`00603oool00`000000oooo
0?ooo`2B0?ooo`030000003oool0oooo0700oooo000H0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0K`3oool001P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`1_
0?ooo`00603oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo06h0oooo000H0?ooo`03
0000003oool0oooo09@0oooo00<000000?ooo`3oool0KP3oool001P0oooo0P00002F0?ooo`030000
003oool0oooo06d0oooo000H0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0K@3o
ool001P0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`1/0?ooo`00603oool00`00
0000oooo0?ooo`2G0?ooo`030000003oool0oooo06/0oooo000H0?ooo`030000003oool0oooo09P0
oooo00<000000?ooo`3oool0JP3oool000D0oooo0P0000040?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0J@3oool000@0oooo00@0
00000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0V@3oool00`000000oooo0?ooo`1Y0?ooo`00103oool010000000oooo0?ooo`0000070?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo
06P0oooo00040?ooo`040000003oool0oooo000000P0oooo0`0000050?ooo`<00000V`3oool00`00
0000oooo0?ooo`1W0?ooo`00103oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo06H0oooo00040?oo
o`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo09d0oooo00<000000?ooo`3oool0I@3oool000D0oooo0P0000090?ooo`<000001@3oool0
0`000000oooo0?ooo`2M0?ooo`030000003oool0oooo06D0oooo000H0?ooo`030000003oool0oooo
09h0oooo00<000000?ooo`3oool0I03oool001P0oooo00<000000?ooo`3oool0W`3oool00`000000
oooo0?ooo`1S0?ooo`00603oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo0680oooo
000H0?ooo`030000003oool0oooo0:40oooo0P00001R0?ooo`00603oool200000:@0oooo00<00000
0?ooo`3oool0G`3oool001P0oooo00<000000?ooo`3oool0Y03oool2000005l0oooo000H0?ooo`03
0000003oool0oooo0:H0oooo00<000000?ooo`3oool0G03oool001P0oooo00<000000?ooo`3oool0
Y`3oool2000005`0oooo000H0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0F@3o
ool001P0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`1H0?ooo`00603oool00`00
0000oooo0?ooo`2[0?ooo`800000F03oool001P0oooo00<000000?ooo`3oool0[@3oool00`000000
oooo0?ooo`1E0?ooo`00603oool200000:l0oooo0P00001E0?ooo`00603oool00`000000oooo0?oo
o`2`0?ooo`<00000DP3oool001P0oooo00<000000?ooo`3oool0/`3oool3000004l0oooo000H0?oo
o`030000003oool0oooo0;H0oooo0P00001=0?ooo`00603oool00`000000oooo0?ooo`2h0?ooo`<0
0000BP3oool001P0oooo00<000000?ooo`3oool0^`3oool3000004L0oooo000H0?ooo`030000003o
ool0oooo0;h0oooo100000130?ooo`00603oool00`000000oooo0?ooo`320?ooo`@00000?`3oool0
01P0oooo0P0000370?ooo`D00000>P3oool001P0oooo00<000000?ooo`3oool0b`3oool7000003<0
oooo000H0?ooo`030000003oool0oooo0=80oooo2P00000Y0?ooo`00603oool00`000000oooo0?oo
o`3L0?ooo``000007@3oool001P0oooo00<000000?ooo`3oool0j03ooolC000000X0oooo000@0?oo
o`<000001@3oool00`000000oooo0?ooo`3o0?ooo`H0oooo000A0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0o`3oool60?ooo`004@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0?l0oooo1P3oool00140oooo00<000000?ooo`3oool0103oool300000?l0oooo1P3o
ool00140oooo00<000000?ooo`3oool0o`3oool=0?ooo`00403oool200000?l0oooo3`3oool00140
oooo00<000000?ooo`3oool0o`3oool=0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.9452, -0.0769285, \
0.079108, 0.00624533}}]
}, Open  ]],

Cell[TextData[{
  "First, examine the stability towards concordant fluctuations ",
  Cell[BoxData[
      \(TraditionalForm\`\((p\)\)]],
  "=0):"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(sm = 
        SigmaMatrix[
          StabilityK[#1, #2, #3, \[Psi][100], hetW[0.01, 4], 0.5] &, 0, 
          3];\)\), "\n", 
    \(sm // Dimensions\)}], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \({4, 4, 20, 20}\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell[TextData[{
  "SigmaMatrix[] still produces a 4\[Times]4 matrix, with each element \
corresponding to a pair of genotype classes ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j\)\)]],
  " = 0\[Ellipsis]3).  However, each element is now itself a 20\[Times]20 \
matrix giving the derivatives with respect to fluctuations across the vector \
of 20 demes."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sm\[LeftDoubleBracket]1, 1\[RightDoubleBracket] // 
      MatrixForm\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0.0535971852797231029`", "0.016239842156683184`", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0"},
            {"0.0211041155510841793`", "0.0389547818976196289`", 
              "0.0160382564832684533`", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0.0263153409293186868`", "0.0457443564410925418`", 
              "0.0171859591662084243`", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0.0341385921991251262`", "0.056879870817517899`", 
              "0.0196859832416744069`", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0.0456821984557851035`", 
              "0.0737859782143973497`", "0.0235845078133909824`", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0.0628518115201663718`", 
              "0.0988775776698316732`", "0.0289055855795959981`", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0.088850101686824825`", 
              "0.135941332806424286`", "0.035570663933404405`", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0.128406528788497698`", 
              "0.189502512796117184`", "0.0436920033836666021`", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0.183745673311888975`", 
              "0.257012759261980372`", "0.0546848359929088534`", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0.234970789978566152`", 
              "0.303843618125051895`", "0.0682237784053603846`", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0.23056379647348062`", "0.276118973077355223`", 
              "0.0739121975672681053`", "0", "0", "0", "0", "0", "0", "0", 
              "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0.166925030324204204`", "0.201182413069253263`", 
              "0.0661119650283903848`", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0.105322709384031343`", "0.142308930899995385`", 
              "0.0545739508877231127`", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0.0710999703913096059`", "0.109511297933094976`", 
              "0.0460642845710687431`", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0.0544357255048821109`", "0.0916392172309929264`", 
              "0.0407419730279727687`", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0.0456434617845593848`", "0.0811772744661191048`", 
              "0.0374316959763574752`", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0.040499991692315671`", "0.0747010576176718732`", 
              "0.0353651138725317659`", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0.0373047537290363839`", 
              "0.0706437949114462959`", "0.0341435240483010771`", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0.0352985020791594017`", 
              "0.068241874360011554`", "0.0335694565917546094`"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0.0341109738442041532`", 
              "0.100678976648029072`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[8]//MatrixForm=",
  FontSize->7]
}, Closed]],

Cell["\<\
The eigenvalues can be found by applying BlockMatrix[], which \
collapses the matrix to 80\[Times]80:  \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues[BlockMatrix[sm]] // Chop\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \({1.0000143361900289`, 0.9597420703864987`, 0.9570228294859782`, 
      0.9110731509452868`, 0.8830325319769524`, 0.8319454282355546`, 
      0.7778114943542168`, 0.713691709701286`, 0.64581086038722`, 
      0.5727683324076273`, 0.4991700222376372`, 0.4929493814572072`, 
      0.42774024837641145`, 0.425197764933652`, 0.42073016148402315`, 
      0.413464860566898`, 0.395191602895507`, 0.3738610425040995`, 
      0.35305541671114066`, 0.34761149400704394`, 0.3177126162988579`, 
      0.28769333363160643`, 
      0.28207242659726295`, \(\(0.25237971165530815`\)\(\[InvisibleSpace]\)\) \
+ 0.003315721111005639`\ \[ImaginaryI], \(\(0.25237971165530815`\)\(\
\[InvisibleSpace]\)\) - 0.003315721111005639`\ \[ImaginaryI], 
      0.2195358232721947`, 0.2182242140291242`, 0.20356562937544043`, 
      0.18499184441138655`, 0.16943833367642017`, 0.1634638192472242`, 
      0.15625866846948802`, 0.14375081291480785`, 0.1385801202906311`, 
      0.1303852816220235`, 0.1273502908444664`, 0.12052927997411031`, 
      0.11661409504010263`, 0.11047683073794934`, 0.10072089002348662`, 
      0.09833297790097784`, 0.08487224998431932`, 0.08190406895369427`, 
      0.07055762706390109`, 0.0650639417458258`, 0.06447092725812711`, 
      0.04931971299875674`, 
      0.04836898733532729`, \(\(0.03634644111205593`\)\(\[InvisibleSpace]\)\) \
+ 0.0026858887436242993`\ \[ImaginaryI], \(\(0.03634644111205593`\)\(\
\[InvisibleSpace]\)\) - 0.0026858887436242993`\ \[ImaginaryI], 
      0.03104385297944658`, 0.020414683852067458`, 0.0192719659619824`, 
      0.019158863402701162`, 0.010429243742121556`, 
      0.010388095936983996`, \(\(0.004836247965445302`\)\(\[InvisibleSpace]\)\
\) + 0.0029859889751218953`\ \[ImaginaryI], \(\(0.004836247965445302`\)\(\
\[InvisibleSpace]\)\) - 
        0.0029859889751218953`\ \[ImaginaryI], \(-0.0036120518131521947`\), 
      0.0018209363568406662`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[18]="]
}, Closed]],

Cell[TextData[
"The leading eigenvalue is close to 1 (the error arising from the finite \
number of demes).  It corresponds to neutral shifts to left or right.  All \
other concordant fluctuations decay, more or less rapidly.  Note that some \
perturbations decay immediately (i.e., with \[Lambda]=0), owing to the \
symmetry of the model."], "Text"],

Cell["\<\
Here is the leading concordant eigenvector.  Partition[[ has been \
used to restore the block structure; each column gives the change in each of \
the four genotypic classes across the cline.  This eigenvector corresponds to \
shifts to the left.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Partition[Eigenvectors[BlockMatrix[sm]] // First, 20] // Chop\) // 
        Transpose\) // MatrixForm\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "0.03581633339175724`", \(-0.011461737091345483`\), \
\(-0.00047445784882909286`\), \(-7.748571233845051`*^-6\)},
            {
              "0.039895237623841284`", \(-0.012703347614315852`\), \
\(-0.0005913558618724587`\), \(-0.000011127195278680388`\)},
            {
              "0.048740811603188355`", \(-0.015351601819253198`\), \
\(-0.0008881217302270282`\), \(-0.000021640954747440984`\)},
            {
              "0.06394590717674006`", \(-0.019754647637863297`\), \
\(-0.0015427035298480741`\), \(-0.00005385367360489367`\)},
            {
              "0.0884827606749065`", \(-0.02642029537899555`\), \
\(-0.0030173681469358145`\), \(-0.0001697700971112303`\)},
            {
              "0.12738243472854183`", \(-0.035667309318953934`\), \
\(-0.006560740876651782`\), \(-0.0006982841417240314`\)},
            {
              "0.18778388689580378`", \(-0.045898083203817046`\), \
\(-0.01547941459314078`\), \(-0.003651393504929792`\)},
            {
              "0.2739500237608172`", \(-0.04832160154021571`\), \
\(-0.03629734505762163`\), \(-0.020093183967305386`\)},
            {
              "0.3634284455767355`", \(-0.02219904429652325`\), \
\(-0.06986832968971417`\), \(-0.08722632361802243`\)},
            {"0.37030889977557047`", 
              "0.03962804473315556`", \(-0.08411624678433709`\), \
\(-0.2368442936220255`\)},
            {"0.23684429362202572`", 
              "0.08411624678433756`", \(-0.039628044733154906`\), \
\(-0.37030889977557385`\)},
            {"0.08722632361802266`", "0.06986832968971526`", 
              "0.022199044296524875`", \(-0.36342844557674353`\)},
            {"0.020093183967305656`", "0.03629734505762264`", 
              "0.04832160154021879`", \(-0.2739500237608302`\)},
            {"0.003651393504929935`", "0.015479414593141847`", 
              "0.04589808320382248`", \(-0.18778388689582315`\)},
            {"0.000698284141724096`", "0.006560740876652825`", 
              "0.035667309318962025`", \(-0.12738243472856836`\)},
            {"0.00016977009711128334`", "0.0030173681469367647`", 
              "0.026420295379006094`", \(-0.08848276067493996`\)},
            {"0.00005385367360491798`", "0.001542703529848925`", 
              "0.019754647637876196`", \(-0.06394590717678027`\)},
            {"0.000021640954747465318`", "0.0008881217302278315`", 
              "0.015351601819267613`", \(-0.04874081160323386`\)},
            {"0.000011127195278693481`", "0.0005913558618731349`", 
              "0.012703347614330904`", \(-0.03989523762389079`\)},
            {"7.748571233855922`*^-6", "0.00047445784882973476`", 
              "0.01146173709136217`", \(-0.03581633339180957`\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[19]//MatrixForm="]
}, Closed]],

Cell[TextData[{
  "Now, examine the stability towards discordant fluctuations ",
  Cell[BoxData[
      \(TraditionalForm\`\((p\)\)]],
  "=1):"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(sm = 
        SigmaMatrix[
          StabilityK[#1, #2, #3, \[Psi][100], hetW[0.01, 4], 0.5] &, 1, 
          3];\)\), "\n", 
    \(Eigenvalues[BlockMatrix[sm]] // Chop\)}], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({1.0248852080086985`, 0.9835009139977674`, 0.975516386329671`, 
      0.9451017606174524`, 0.9064026456323176`, 0.8560082192441761`, 
      0.7964999031821466`, 0.7300170596206365`, 0.6575472005785035`, 
      0.5815767547277231`, 0.5175988223287962`, 0.5034875609608082`, 
      0.45995803754069725`, 0.4394311230747253`, 0.43091544568730905`, 
      0.4256613195439834`, 0.4162788975532852`, 0.39511905314924123`, 
      0.36795000393906235`, 0.3498882282320395`, 0.3362929193973678`, 
      0.30438306262108`, 0.27618888739972774`, 0.26846555056087806`, 
      0.23154204990254876`, 0.21080985109906847`, 0.19359405771840116`, 
      0.16228056713966987`, 0.14723198682992159`, 0.12692252673188126`, 
      0.09734121937770884`, 0.09497944847776504`, 0.06685344906137804`, 
      0.058052262757883916`, 0.04194420459041289`, 0.029106108133244088`, 
      0.021223828059986637`, 0.012367012207506642`, 0.005731133596647199`, 
      0.003102328745116996`}\)], "Output",
  CellLabel->"Out[21]="]
}, Closed]],

Cell[TextData[{
  "There is now a single instability, \[Lambda]=1.02489, associated with \
discordant allele frequencies.  The matrix below shows the components ",
  Cell[BoxData[
      \(TraditionalForm\`{e\_\(\(1\)\(\ \)\), e\_2}\)]],
  ", for each of the 20 demes:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Partition[Eigenvectors[BlockMatrix[sm]] // First, 20] // Chop\) // 
        Transpose\) // MatrixForm\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.036596236801650604`", "0.0007378548807109812`"},
            {"0.042133667230818524`", "0.0009568840581135818`"},
            {"0.05402737805071619`", "0.0015197377174097548`"},
            {"0.07400106832484851`", "0.002769662392285047`"},
            {"0.10477811777944805`", "0.0055537546404277275`"},
            {"0.14985701293451875`", "0.012005780736261979`"},
            {"0.21181422131075556`", "0.027534602354544795`"},
            {"0.2860451238320461`", "0.06446216619856489`"},
            {"0.34690013546470055`", "0.14116338870480694`"},
            {"0.34363873949421003`", "0.2547810038260293`"},
            {"0.25478100382602864`", "0.34363873949420676`"},
            {"0.1411633887048051`", "0.34690013546469267`"},
            {"0.06446216619856325`", "0.2860451238320352`"},
            {"0.027534602354543563`", "0.21181422131074343`"},
            {"0.012005780736261122`", "0.14985701293450573`"},
            {"0.005553754640427048`", "0.1047781177794323`"},
            {"0.0027696623922844467`", "0.07400106832483111`"},
            {"0.001519737717409272`", "0.05402737805069763`"},
            {"0.0009568840581131778`", "0.04213366723079979`"},
            {"0.0007378548807106202`", "0.03659623680163225`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[22]//MatrixForm="]
}, Closed]],

Cell[TextData[{
  "The full form of this instability is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{
              FormBox[
                RowBox[{
                  FormBox[\({0, 0, e\_1\),
                    "TraditionalForm"], ",", \(-e\_1\)}],
                "TraditionalForm"], ",", \(e\_2\)}],
            "TraditionalForm"], ",", \(-e\_2\)}], TraditionalForm]]],
  ",0,0},  where the haplotypes are \
{{0,0,0},{0,0,1},{0,1,0},{1,0,0},{0,1,1},{1,0,1},{1,1,0},{1,1,1}}.  This \
corresponds to an increase of genotypes {0,1,0} and {0,1,1} at the expense of \
{1,0,0} and {1,0,1}."
}], "Text"],

Cell[TextData[{
  "In the following section, this instability is confirmed by iterating the \
full system of ",
  Cell[BoxData[
      \(TraditionalForm\`\(2\^n\ \)\)]],
  "genotype frequencies, which shows that the clines do tend to move apart.  \
Note that with stronger selection and weaker epistasis (W = ",
  Cell[BoxData[
      \(TraditionalForm\`\((1 - s)\)\^\(h\^k\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`k = 2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`s = 0.05\)]],
  ", say), linkage disequilibrium holds the clines together."
}], "Text"],

Cell["The full set of eigenvalues is given by:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExactEigenvalues[
        StabilityK[#1, #2, #3, \[Psi][100], hetW[0.01, 4], 0.5] &, 3] // 
      TableForm\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"1.0000143361900289`", "0.9597420703864987`", 
            "0.9570228294859782`", "0.9110731509452868`", 
            "0.8830325319769524`", "0.8319454282355546`", 
            "0.7778114943542168`", "0.713691709701286`", "0.64581086038722`", 
            "0.5727683324076273`", "0.4991700222376372`", 
            "0.4929493814572072`", "0.42774024837641145`", 
            "0.425197764933652`", "0.42073016148402315`", 
            "0.413464860566898`", "0.395191602895507`", "0.3738610425040995`",
             "0.35305541671114066`", "0.34761149400704394`", 
            "0.3177126162988579`", "0.28769333363160643`", 
            "0.28207242659726295`", \(\(\(0.25237971165530815`\)\(\
\[InvisibleSpace]\)\) + 
              0.003315721111005639`\ \[ImaginaryI]\), \
\(\(\(0.25237971165530815`\)\(\[InvisibleSpace]\)\) - 
              0.003315721111005639`\ \[ImaginaryI]\), "0.2195358232721947`", 
            "0.2182242140291242`", "0.20356562937544043`", 
            "0.18499184441138655`", "0.16943833367642017`", 
            "0.1634638192472242`", "0.15625866846948802`", 
            "0.14375081291480785`", "0.1385801202906311`", 
            "0.1303852816220235`", "0.1273502908444664`", 
            "0.12052927997411031`", "0.11661409504010263`", 
            "0.11047683073794934`", "0.10072089002348662`", 
            "0.09833297790097784`", "0.08487224998431932`", 
            "0.08190406895369427`", "0.07055762706390109`", 
            "0.0650639417458258`", "0.06447092725812711`", 
            "0.04931971299875674`", 
            "0.04836898733532729`", \(\(\(0.03634644111205593`\)\(\
\[InvisibleSpace]\)\) + 
              0.0026858887436242993`\ \[ImaginaryI]\), \
\(\(\(0.03634644111205593`\)\(\[InvisibleSpace]\)\) - 
              0.0026858887436242993`\ \[ImaginaryI]\), "0.03104385297944658`",
             "0.020414683852067458`", "0.0192719659619824`", 
            "0.019158863402701162`", "0.010429243742121556`", 
            "0.010388095936983996`", \(\(\(0.004836247965445302`\)\(\
\[InvisibleSpace]\)\) + 
              0.0029859889751218953`\ \[ImaginaryI]\), \
\(\(\(0.004836247965445302`\)\(\[InvisibleSpace]\)\) - 
              0.0029859889751218953`\ \[ImaginaryI]\), \
\(-0.0036120518131521947`\), 
            "0.0018209363568406662`", \(-1.5801125967480155`*^-15\), \
\(\(-3.625160739110173`*^-16\) + 
              1.0669243137632694`*^-15\ \[ImaginaryI]\), \
\(\(-3.625160739110173`*^-16\) - 1.0669243137632694`*^-15\ \[ImaginaryI]\), 
            "1.1044614564514364`*^-16", 
            "1.0713841148096695`*^-16", \(-1.031223266427781`*^-16\), 
            "9.45585048217843`*^-17", "8.423682263466459`*^-17", 
            "8.357723759735335`*^-17", \(-6.728193620461491`*^-17\), \
\(-5.701585534378622`*^-17\), 
            "5.5199322745778096`*^-17", \(-5.3091673636015766`*^-17\), \
\(-4.445080013023006`*^-17\), "4.247610392999612`*^-17", 
            "2.2012403818076216`*^-17", "1.5905079768562756`*^-17", 
            "1.0213683891500168`*^-17", \(-8.346347217286798`*^-18\), 
            "5.0909250963685976`*^-18"},
          {"1.0248852080086985`", "0.9835009139977674`", "0.975516386329671`",
             "0.9451017606174524`", "0.9064026456323176`", 
            "0.8560082192441761`", "0.7964999031821466`", 
            "0.7300170596206365`", "0.6575472005785035`", 
            "0.5815767547277231`", "0.5175988223287962`", 
            "0.5034875609608082`", "0.45995803754069725`", 
            "0.4394311230747253`", "0.43091544568730905`", 
            "0.4256613195439834`", "0.4162788975532852`", 
            "0.39511905314924123`", "0.36795000393906235`", 
            "0.3498882282320395`", "0.3362929193973678`", "0.30438306262108`",
             "0.27618888739972774`", "0.26846555056087806`", 
            "0.23154204990254876`", "0.21080985109906847`", 
            "0.19359405771840116`", "0.16228056713966987`", 
            "0.14723198682992159`", "0.12692252673188126`", 
            "0.09734121937770884`", "0.09497944847776504`", 
            "0.06685344906137804`", "0.058052262757883916`", 
            "0.04194420459041289`", "0.029106108133244088`", 
            "0.021223828059986637`", "0.012367012207506642`", 
            "0.005731133596647199`", 
            "0.003102328745116996`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\
\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\
\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\
\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{1.0000143361900289, 0.95974207038649872, 
        0.95702282948597817, 0.91107315094528685, 0.88303253197695242, 
        0.83194542823555462, 0.77781149435421681, 0.71369170970128604, 
        0.64581086038722002, 0.57276833240762726, 0.49917002223763718, 
        0.49294938145720718, 0.42774024837641145, 0.42519776493365202, 
        0.42073016148402315, 0.41346486056689802, 0.39519160289550698, 
        0.37386104250409952, 0.35305541671114066, 0.34761149400704394, 
        0.31771261629885789, 0.28769333363160643, 0.28207242659726295, 
        Complex[ 0.25237971165530815, 0.0033157211110056389], 
        Complex[ 0.25237971165530815, -0.0033157211110056389], 
        0.2195358232721947, 0.2182242140291242, 0.20356562937544043, 
        0.18499184441138655, 0.16943833367642017, 0.1634638192472242, 
        0.15625866846948802, 0.14375081291480785, 0.1385801202906311, 
        0.13038528162202351, 0.12735029084446639, 0.12052927997411031, 
        0.11661409504010263, 0.11047683073794934, 0.10072089002348662, 
        0.098332977900977836, 0.084872249984319317, 0.081904068953694273, 
        0.070557627063901091, 0.065063941745825804, 0.064470927258127114, 
        0.049319712998756739, 0.048368987335327289, 
        Complex[ 0.036346441112055927, 0.0026858887436242993], 
        Complex[ 0.036346441112055927, -0.0026858887436242993], 
        0.03104385297944658, 0.020414683852067458, 0.019271965961982399, 
        0.019158863402701162, 0.010429243742121556, 0.010388095936983996, 
        Complex[ 0.0048362479654453019, 0.0029859889751218953], 
        Complex[ 
        0.0048362479654453019, -0.0029859889751218953], \
-0.0036120518131521947, 0.0018209363568406662, -1.5801125967480155*^-15, 
        Complex[ -3.625160739110173*^-16, 1.0669243137632694*^-15], 
        Complex[ -3.625160739110173*^-16, -1.0669243137632694*^-15], 
        1.1044614564514364*^-16, 
        1.0713841148096695*^-16, -1.031223266427781*^-16, 
        9.4558504821784304*^-17, 8.4236822634664591*^-17, 
        8.3577237597353348*^-17, -6.7281936204614911*^-17, \
-5.7015855343786218*^-17, 
        5.5199322745778096*^-17, -5.3091673636015766*^-17, \
-4.4450800130230062*^-17, 4.2476103929996119*^-17, 2.2012403818076216*^-17, 
        1.5905079768562756*^-17, 
        1.0213683891500168*^-17, -8.3463472172867985*^-18, 
        5.0909250963685976*^-18}, {1.0248852080086985, 0.9835009139977674, 
        0.97551638632967097, 0.94510176061745244, 0.90640264563231765, 
        0.85600821924417614, 0.79649990318214658, 0.73001705962063645, 
        0.65754720057850347, 0.58157675472772308, 0.51759882232879617, 
        0.50348756096080816, 0.45995803754069725, 0.43943112307472532, 
        0.43091544568730905, 0.4256613195439834, 0.41627889755328518, 
        0.39511905314924123, 0.36795000393906235, 0.34988822823203952, 
        0.33629291939736777, 0.30438306262108, 0.27618888739972774, 
        0.26846555056087806, 0.23154204990254876, 0.21080985109906847, 
        0.19359405771840116, 0.16228056713966987, 0.14723198682992159, 
        0.12692252673188126, 0.097341219377708843, 0.094979448477765044, 
        0.066853449061378037, 0.058052262757883916, 0.041944204590412891, 
        0.029106108133244088, 0.021223828059986637, 0.012367012207506642, 
        0.0057311335966471989, 0.003102328745116996}}]]], "Output",
  CellLabel->"Out[23]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "The rows give eigenvalues for ",
  Cell[BoxData[
      \(TraditionalForm\`p = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`p = 1\)]],
  "."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{993, 683},
WindowMargins->{{66, Automatic}, {Automatic, 0}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\nThe item above is horizontal 0.5 pt line", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\nThe item above is a ProgramTop line\n", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\nThe item above is a ProgramBottom line\n", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "StabilityK"->{
    Cell[2014, 60, 806, 14, 96, "DefinitionBox",
      CellTags->"StabilityK"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"StabilityK", 125148, 3739}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 84, 1, 36, "SubsectionIcon"],
Cell[1826, 54, 79, 0, 28, "MathCaption"],
Cell[1908, 56, 103, 2, 26, "Input"],
Cell[2014, 60, 806, 14, 96, "DefinitionBox",
  CellTags->"StabilityK"],
Cell[2823, 76, 723, 16, 36, "Text"],
Cell[3549, 94, 742, 17, 57, "Text"],
Cell[4294, 113, 524, 14, 40, "Text"],
Cell[4821, 129, 398, 9, 64, "Input"],

Cell[CellGroupData[{
Cell[5244, 142, 83, 2, 26, "Input"],
Cell[5330, 146, 6910, 123, 347, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[12277, 274, 139, 3, 22, "Input"],
Cell[12419, 279, 16624, 390, 184, 3093, 218, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[29058, 672, 163, 5, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[29246, 681, 210, 6, 42, "Input"],
Cell[29459, 689, 73, 2, 20, "Output"]
}, Open  ]],
Cell[29547, 694, 372, 8, 36, "Text"],

Cell[CellGroupData[{
Cell[29944, 706, 126, 3, 26, "Input"],
Cell[30073, 711, 4255, 67, 217, "Output"]
}, Closed]],
Cell[34343, 781, 134, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[34502, 788, 94, 2, 26, "Input"],
Cell[34599, 792, 2010, 31, 95, "Output"]
}, Closed]],
Cell[36624, 826, 350, 5, 32, "Text"],
Cell[36977, 833, 270, 5, 36, "Text"],

Cell[CellGroupData[{
Cell[37272, 842, 163, 3, 26, "Input"],
Cell[37438, 847, 2892, 56, 341, "Output"]
}, Closed]],
Cell[40345, 906, 161, 5, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[40531, 915, 230, 6, 42, "Input"],
Cell[40764, 923, 1015, 15, 65, "Output"]
}, Closed]],
Cell[41794, 941, 287, 6, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[42106, 951, 163, 3, 26, "Input"],
Cell[42272, 956, 1436, 25, 335, "Output"]
}, Closed]],
Cell[43723, 984, 645, 17, 32, "Text"],
Cell[44371, 1003, 581, 16, 40, "Text"],
Cell[44955, 1021, 63, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[45043, 1025, 165, 4, 26, "Input"],
Cell[45211, 1031, 8371, 138, 49, "Output"]
}, Open  ]],
Cell[53597, 1172, 181, 8, 22, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

