(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     21201,        604]*)
(*NotebookOutlinePosition[     22247,        639]*)
(*  CellTagsIndexPosition[     22170,        633]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Setting up a symmetric cline", "SubsectionIcon"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< NumericalModels`ExactModel`;\)\)], "Input",
  CellLabel->"In[37]:="],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(DoubleCline[\[Psi], True, 
              NumericalModel \[Rule] 
                SymmetricHaploidFrequencies]\), \(takes\ the\ cline\ \[Psi]\ \
to\ represent\ the\ left\ half\ of\ a\ symmetric\ cline\ with\ an\ even\ #\ \
of\ demes, \ \(\(and\)\(\ \)\(adds\)\(\ \)\(the\)\(\ \)\(right\)\(\ \
\)\(\(half\)\(.\)\)\(\ \)\)\)},
          {\(DoubleCline[\[Psi], False, 
              NumericalModel \[Rule] 
                SymmetricHaploidFrequencies]\), \(takes\ the\ cline\ \[Psi]\ \
to\ represent\ the\ left\ half\ of\ a\ symmetric\ cline\ with\ an\ odd\ #\ of\
\ demes, \ \(\(and\)\(\ \)\(adds\)\(\ \)\(the\)\(\ \)\(right\)\(\ \
\)\(\(half\)\(.\)\)\(\ \)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"DoubleCline"],

Cell["\<\
This is a symmetrical cline with an even number of haploid demes:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pop = 
      MakeCline[6, 3, 10, 1, 
        NumericalModel \[Rule] SymmetricHaploidFrequencies]; 
    pop // MatrixForm\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(SymmetricHaploidFrequencies[{1, 0, 0, 0}, 10]\)},
            {\(SymmetricHaploidFrequencies[{64\/125, 48\/125, 12\/125, 
                  1\/125}, 10]\)},
            {\(SymmetricHaploidFrequencies[{27\/125, 54\/125, 36\/125, 
                  8\/125}, 10]\)},
            {\(SymmetricHaploidFrequencies[{8\/125, 36\/125, 54\/125, 
                  27\/125}, 10]\)},
            {\(SymmetricHaploidFrequencies[{1\/125, 12\/125, 48\/125, 
                  64\/125}, 10]\)},
            {\(SymmetricHaploidFrequencies[{0, 0, 0, 1}, 10]\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        SymmetricHaploidFrequencies[ {1, 0, 0, 0}, 10], 
        SymmetricHaploidFrequencies[ {
          Rational[ 64, 125], 
          Rational[ 48, 125], 
          Rational[ 12, 125], 
          Rational[ 1, 125]}, 10], 
        SymmetricHaploidFrequencies[ {
          Rational[ 27, 125], 
          Rational[ 54, 125], 
          Rational[ 36, 125], 
          Rational[ 8, 125]}, 10], 
        SymmetricHaploidFrequencies[ {
          Rational[ 8, 125], 
          Rational[ 36, 125], 
          Rational[ 54, 125], 
          Rational[ 27, 125]}, 10], 
        SymmetricHaploidFrequencies[ {
          Rational[ 1, 125], 
          Rational[ 12, 125], 
          Rational[ 48, 125], 
          Rational[ 64, 125]}, 10], 
        SymmetricHaploidFrequencies[ {0, 0, 0, 1}, 10]}]]], "Output",
  CellLabel->"Out[28]//MatrixForm="]
}, Closed]],

Cell["This is the left half of the cline:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(popLeft = Take[pop, 3]; popLeft // MatrixForm\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(SymmetricHaploidFrequencies[{1, 0, 0, 0}, 10]\)},
            {\(SymmetricHaploidFrequencies[{64\/125, 48\/125, 12\/125, 
                  1\/125}, 10]\)},
            {\(SymmetricHaploidFrequencies[{27\/125, 54\/125, 36\/125, 
                  8\/125}, 10]\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        SymmetricHaploidFrequencies[ {1, 0, 0, 0}, 10], 
        SymmetricHaploidFrequencies[ {
          Rational[ 64, 125], 
          Rational[ 48, 125], 
          Rational[ 12, 125], 
          Rational[ 1, 125]}, 10], 
        SymmetricHaploidFrequencies[ {
          Rational[ 27, 125], 
          Rational[ 54, 125], 
          Rational[ 36, 125], 
          Rational[ 8, 125]}, 10]}]]], "Output",
  CellLabel->"Out[29]//MatrixForm="]
}, Closed]],

Cell["This reconstructs the whole cline:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DoubleCline[popLeft, True] // MatrixForm\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(SymmetricHaploidFrequencies[{1, 0, 0, 0}, 10]\)},
            {\(SymmetricHaploidFrequencies[{64\/125, 48\/125, 12\/125, 
                  1\/125}, 10]\)},
            {\(SymmetricHaploidFrequencies[{27\/125, 54\/125, 36\/125, 
                  8\/125}, 10]\)},
            {\(SymmetricHaploidFrequencies[{8\/125, 36\/125, 54\/125, 
                  27\/125}, 10]\)},
            {\(SymmetricHaploidFrequencies[{1\/125, 12\/125, 48\/125, 
                  64\/125}, 10]\)},
            {\(SymmetricHaploidFrequencies[{0, 0, 0, 1}, 10]\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        SymmetricHaploidFrequencies[ {1, 0, 0, 0}, 10], 
        SymmetricHaploidFrequencies[ {
          Rational[ 64, 125], 
          Rational[ 48, 125], 
          Rational[ 12, 125], 
          Rational[ 1, 125]}, 10], 
        SymmetricHaploidFrequencies[ {
          Rational[ 27, 125], 
          Rational[ 54, 125], 
          Rational[ 36, 125], 
          Rational[ 8, 125]}, 10], 
        SymmetricHaploidFrequencies[ {
          Rational[ 8, 125], 
          Rational[ 36, 125], 
          Rational[ 54, 125], 
          Rational[ 27, 125]}, 10], 
        SymmetricHaploidFrequencies[ {
          Rational[ 1, 125], 
          Rational[ 12, 125], 
          Rational[ 48, 125], 
          Rational[ 64, 125]}, 10], 
        SymmetricHaploidFrequencies[ {0, 0, 0, 1}, 10]}]]], "Output",
  CellLabel->"Out[30]//MatrixForm="]
}, Closed]],

Cell["This is a symmetrical cline with an odd number of demes:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pop = MakeCline[7, 3, 10, 1]; pop // MatrixForm\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(HaploidFrequencies[{1, 0, 0, 0, 0, 0, 0, 0}, 10]\)},
            {\(HaploidFrequencies[{125\/216, 25\/216, 25\/216, 5\/216, 
                  25\/216, 5\/216, 5\/216, 1\/216}, 10]\)},
            {\(HaploidFrequencies[{8\/27, 4\/27, 4\/27, 2\/27, 4\/27, 2\/27, 
                  2\/27, 1\/27}, 10]\)},
            {\(HaploidFrequencies[{1\/8, 1\/8, 1\/8, 1\/8, 1\/8, 1\/8, 1\/8, 
                  1\/8}, 10]\)},
            {\(HaploidFrequencies[{1\/27, 2\/27, 2\/27, 4\/27, 2\/27, 4\/27, 
                  4\/27, 8\/27}, 10]\)},
            {\(HaploidFrequencies[{1\/216, 5\/216, 5\/216, 25\/216, 5\/216, 
                  25\/216, 25\/216, 125\/216}, 10]\)},
            {\(HaploidFrequencies[{0, 0, 0, 0, 0, 0, 0, 1}, 10]\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        HaploidFrequencies[ {1, 0, 0, 0, 0, 0, 0, 0}, 10], 
        HaploidFrequencies[ {
          Rational[ 125, 216], 
          Rational[ 25, 216], 
          Rational[ 25, 216], 
          Rational[ 5, 216], 
          Rational[ 25, 216], 
          Rational[ 5, 216], 
          Rational[ 5, 216], 
          Rational[ 1, 216]}, 10], 
        HaploidFrequencies[ {
          Rational[ 8, 27], 
          Rational[ 4, 27], 
          Rational[ 4, 27], 
          Rational[ 2, 27], 
          Rational[ 4, 27], 
          Rational[ 2, 27], 
          Rational[ 2, 27], 
          Rational[ 1, 27]}, 10], 
        HaploidFrequencies[ {
          Rational[ 1, 8], 
          Rational[ 1, 8], 
          Rational[ 1, 8], 
          Rational[ 1, 8], 
          Rational[ 1, 8], 
          Rational[ 1, 8], 
          Rational[ 1, 8], 
          Rational[ 1, 8]}, 10], 
        HaploidFrequencies[ {
          Rational[ 1, 27], 
          Rational[ 2, 27], 
          Rational[ 2, 27], 
          Rational[ 4, 27], 
          Rational[ 2, 27], 
          Rational[ 4, 27], 
          Rational[ 4, 27], 
          Rational[ 8, 27]}, 10], 
        HaploidFrequencies[ {
          Rational[ 1, 216], 
          Rational[ 5, 216], 
          Rational[ 5, 216], 
          Rational[ 25, 216], 
          Rational[ 5, 216], 
          Rational[ 25, 216], 
          Rational[ 25, 216], 
          Rational[ 125, 216]}, 10], 
        HaploidFrequencies[ {0, 0, 0, 0, 0, 0, 0, 1}, 10]}]]], "Output",
  CellLabel->"Out[31]//MatrixForm="]
}, Closed]],

Cell["This is the left half of the cline:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(popLeft = Take[pop, 4]; popLeft // MatrixForm\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(HaploidFrequencies[{1, 0, 0, 0, 0, 0, 0, 0}, 10]\)},
            {\(HaploidFrequencies[{125\/216, 25\/216, 25\/216, 5\/216, 
                  25\/216, 5\/216, 5\/216, 1\/216}, 10]\)},
            {\(HaploidFrequencies[{8\/27, 4\/27, 4\/27, 2\/27, 4\/27, 2\/27, 
                  2\/27, 1\/27}, 10]\)},
            {\(HaploidFrequencies[{1\/8, 1\/8, 1\/8, 1\/8, 1\/8, 1\/8, 1\/8, 
                  1\/8}, 10]\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        HaploidFrequencies[ {1, 0, 0, 0, 0, 0, 0, 0}, 10], 
        HaploidFrequencies[ {
          Rational[ 125, 216], 
          Rational[ 25, 216], 
          Rational[ 25, 216], 
          Rational[ 5, 216], 
          Rational[ 25, 216], 
          Rational[ 5, 216], 
          Rational[ 5, 216], 
          Rational[ 1, 216]}, 10], 
        HaploidFrequencies[ {
          Rational[ 8, 27], 
          Rational[ 4, 27], 
          Rational[ 4, 27], 
          Rational[ 2, 27], 
          Rational[ 4, 27], 
          Rational[ 2, 27], 
          Rational[ 2, 27], 
          Rational[ 1, 27]}, 10], 
        HaploidFrequencies[ {
          Rational[ 1, 8], 
          Rational[ 1, 8], 
          Rational[ 1, 8], 
          Rational[ 1, 8], 
          Rational[ 1, 8], 
          Rational[ 1, 8], 
          Rational[ 1, 8], 
          Rational[ 1, 8]}, 10]}]]], "Output",
  CellLabel->"Out[32]//MatrixForm="]
}, Closed]],

Cell["\<\
In general, Ceiling[ndemes/2] demes must be given to specify the \
left part of the cline.\
\>", "Text"],

Cell["This reconstructs the whole cline:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DoubleCline[popLeft, False] // MatrixForm\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(HaploidFrequencies[{1, 0, 0, 0, 0, 0, 0, 0}, 10]\)},
            {\(HaploidFrequencies[{125\/216, 25\/216, 25\/216, 5\/216, 
                  25\/216, 5\/216, 5\/216, 1\/216}, 10]\)},
            {\(HaploidFrequencies[{8\/27, 4\/27, 4\/27, 2\/27, 4\/27, 2\/27, 
                  2\/27, 1\/27}, 10]\)},
            {\(HaploidFrequencies[{1\/8, 1\/8, 1\/8, 1\/8, 1\/8, 1\/8, 1\/8, 
                  1\/8}, 10]\)},
            {\(HaploidFrequencies[{1\/27, 2\/27, 2\/27, 4\/27, 2\/27, 4\/27, 
                  4\/27, 8\/27}, 10]\)},
            {\(HaploidFrequencies[{1\/216, 5\/216, 5\/216, 25\/216, 5\/216, 
                  25\/216, 25\/216, 125\/216}, 10]\)},
            {\(HaploidFrequencies[{0, 0, 0, 0, 0, 0, 0, 1}, 10]\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        HaploidFrequencies[ {1, 0, 0, 0, 0, 0, 0, 0}, 10], 
        HaploidFrequencies[ {
          Rational[ 125, 216], 
          Rational[ 25, 216], 
          Rational[ 25, 216], 
          Rational[ 5, 216], 
          Rational[ 25, 216], 
          Rational[ 5, 216], 
          Rational[ 5, 216], 
          Rational[ 1, 216]}, 10], 
        HaploidFrequencies[ {
          Rational[ 8, 27], 
          Rational[ 4, 27], 
          Rational[ 4, 27], 
          Rational[ 2, 27], 
          Rational[ 4, 27], 
          Rational[ 2, 27], 
          Rational[ 2, 27], 
          Rational[ 1, 27]}, 10], 
        HaploidFrequencies[ {
          Rational[ 1, 8], 
          Rational[ 1, 8], 
          Rational[ 1, 8], 
          Rational[ 1, 8], 
          Rational[ 1, 8], 
          Rational[ 1, 8], 
          Rational[ 1, 8], 
          Rational[ 1, 8]}, 10], 
        HaploidFrequencies[ {
          Rational[ 1, 27], 
          Rational[ 2, 27], 
          Rational[ 2, 27], 
          Rational[ 4, 27], 
          Rational[ 2, 27], 
          Rational[ 4, 27], 
          Rational[ 4, 27], 
          Rational[ 8, 27]}, 10], 
        HaploidFrequencies[ {
          Rational[ 1, 216], 
          Rational[ 5, 216], 
          Rational[ 5, 216], 
          Rational[ 25, 216], 
          Rational[ 5, 216], 
          Rational[ 25, 216], 
          Rational[ 25, 216], 
          Rational[ 125, 216]}, 10], 
        HaploidFrequencies[ {0, 0, 0, 0, 0, 0, 0, 1}, 10]}]]], "Output",
  CellLabel->"Out[33]//MatrixForm="]
}, Closed]],

Cell["SortByClass may be set True or False", "Text"],

Cell["\<\
The representations SymmetricDiploidFrequencies, \
SymmetricNeutralHaploidFrequencies and SymmetricNeutralDiploidFrequencies may \
also be used.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pop = 
      MakeCline[6, 3, 10, 1, 
        NumericalModel \[Rule] SymmetricNeutralHaploidFrequencies]; 
    pop // MatrixForm\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(SymmetricNeutralHaploidFrequencies[{{1, 0, 0, 0}, {0, 0, 0, 
                    0}}, 10]\)},
            {\(SymmetricNeutralHaploidFrequencies[{{64\/125, 48\/125, 
                    12\/125, 1\/125}, {1\/5, 1\/5, 1\/5, 1\/5}}, 10]\)},
            {\(SymmetricNeutralHaploidFrequencies[{{27\/125, 54\/125, 
                    36\/125, 8\/125}, {2\/5, 2\/5, 2\/5, 2\/5}}, 10]\)},
            {\(SymmetricNeutralHaploidFrequencies[{{8\/125, 36\/125, 54\/125, 
                    27\/125}, {3\/5, 3\/5, 3\/5, 3\/5}}, 10]\)},
            {\(SymmetricNeutralHaploidFrequencies[{{1\/125, 12\/125, 48\/125, 
                    64\/125}, {4\/5, 4\/5, 4\/5, 4\/5}}, 10]\)},
            {\(SymmetricNeutralHaploidFrequencies[{{0, 0, 0, 1}, {1, 1, 1, 
                    1}}, 10]\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        SymmetricNeutralHaploidFrequencies[ {{1, 0, 0, 0}, {0, 0, 0, 0}}, 10],
         
        SymmetricNeutralHaploidFrequencies[ {{
          Rational[ 64, 125], 
          Rational[ 48, 125], 
          Rational[ 12, 125], 
          Rational[ 1, 125]}, {
          Rational[ 1, 5], 
          Rational[ 1, 5], 
          Rational[ 1, 5], 
          Rational[ 1, 5]}}, 10], 
        SymmetricNeutralHaploidFrequencies[ {{
          Rational[ 27, 125], 
          Rational[ 54, 125], 
          Rational[ 36, 125], 
          Rational[ 8, 125]}, {
          Rational[ 2, 5], 
          Rational[ 2, 5], 
          Rational[ 2, 5], 
          Rational[ 2, 5]}}, 10], 
        SymmetricNeutralHaploidFrequencies[ {{
          Rational[ 8, 125], 
          Rational[ 36, 125], 
          Rational[ 54, 125], 
          Rational[ 27, 125]}, {
          Rational[ 3, 5], 
          Rational[ 3, 5], 
          Rational[ 3, 5], 
          Rational[ 3, 5]}}, 10], 
        SymmetricNeutralHaploidFrequencies[ {{
          Rational[ 1, 125], 
          Rational[ 12, 125], 
          Rational[ 48, 125], 
          Rational[ 64, 125]}, {
          Rational[ 4, 5], 
          Rational[ 4, 5], 
          Rational[ 4, 5], 
          Rational[ 4, 5]}}, 10], 
        SymmetricNeutralHaploidFrequencies[ {{0, 0, 0, 1}, {1, 1, 1, 1}}, 
          10]}]]], "Output",
  CellLabel->"Out[34]//MatrixForm="]
}, Open  ]],

Cell["This is the left half of the cline:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(popLeft = Take[pop, 3]; popLeft // MatrixForm\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(SymmetricNeutralHaploidFrequencies[{{1, 0, 0, 0}, {0, 0, 0, 
                    0}}, 10]\)},
            {\(SymmetricNeutralHaploidFrequencies[{{64\/125, 48\/125, 
                    12\/125, 1\/125}, {1\/5, 1\/5, 1\/5, 1\/5}}, 10]\)},
            {\(SymmetricNeutralHaploidFrequencies[{{27\/125, 54\/125, 
                    36\/125, 8\/125}, {2\/5, 2\/5, 2\/5, 2\/5}}, 10]\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        SymmetricNeutralHaploidFrequencies[ {{1, 0, 0, 0}, {0, 0, 0, 0}}, 10],
         
        SymmetricNeutralHaploidFrequencies[ {{
          Rational[ 64, 125], 
          Rational[ 48, 125], 
          Rational[ 12, 125], 
          Rational[ 1, 125]}, {
          Rational[ 1, 5], 
          Rational[ 1, 5], 
          Rational[ 1, 5], 
          Rational[ 1, 5]}}, 10], 
        SymmetricNeutralHaploidFrequencies[ {{
          Rational[ 27, 125], 
          Rational[ 54, 125], 
          Rational[ 36, 125], 
          Rational[ 8, 125]}, {
          Rational[ 2, 5], 
          Rational[ 2, 5], 
          Rational[ 2, 5], 
          Rational[ 2, 5]}}, 10]}]]], "Output",
  CellLabel->"Out[35]//MatrixForm="]
}, Open  ]],

Cell["This reconstructs the whole cline:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DoubleCline[popLeft, True] // MatrixForm\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(SymmetricNeutralHaploidFrequencies[{{1, 0, 0, 0}, {0, 0, 0, 
                    0}}, 10]\)},
            {\(SymmetricNeutralHaploidFrequencies[{{64\/125, 48\/125, 
                    12\/125, 1\/125}, {1\/5, 1\/5, 1\/5, 1\/5}}, 10]\)},
            {\(SymmetricNeutralHaploidFrequencies[{{27\/125, 54\/125, 
                    36\/125, 8\/125}, {2\/5, 2\/5, 2\/5, 2\/5}}, 10]\)},
            {\(SymmetricNeutralHaploidFrequencies[{{8\/125, 36\/125, 54\/125, 
                    27\/125}, {3\/5, 3\/5, 3\/5, 3\/5}}, 10]\)},
            {\(SymmetricNeutralHaploidFrequencies[{{1\/125, 12\/125, 48\/125, 
                    64\/125}, {4\/5, 4\/5, 4\/5, 4\/5}}, 10]\)},
            {\(SymmetricNeutralHaploidFrequencies[{{0, 0, 0, 1}, {1, 1, 1, 
                    1}}, 10]\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        SymmetricNeutralHaploidFrequencies[ {{1, 0, 0, 0}, {0, 0, 0, 0}}, 10],
         
        SymmetricNeutralHaploidFrequencies[ {{
          Rational[ 64, 125], 
          Rational[ 48, 125], 
          Rational[ 12, 125], 
          Rational[ 1, 125]}, {
          Rational[ 1, 5], 
          Rational[ 1, 5], 
          Rational[ 1, 5], 
          Rational[ 1, 5]}}, 10], 
        SymmetricNeutralHaploidFrequencies[ {{
          Rational[ 27, 125], 
          Rational[ 54, 125], 
          Rational[ 36, 125], 
          Rational[ 8, 125]}, {
          Rational[ 2, 5], 
          Rational[ 2, 5], 
          Rational[ 2, 5], 
          Rational[ 2, 5]}}, 10], 
        SymmetricNeutralHaploidFrequencies[ {{
          Rational[ 8, 125], 
          Rational[ 36, 125], 
          Rational[ 54, 125], 
          Rational[ 27, 125]}, {
          Rational[ 3, 5], 
          Rational[ 3, 5], 
          Rational[ 3, 5], 
          Rational[ 3, 5]}}, 10], 
        SymmetricNeutralHaploidFrequencies[ {{
          Rational[ 1, 125], 
          Rational[ 12, 125], 
          Rational[ 48, 125], 
          Rational[ 64, 125]}, {
          Rational[ 4, 5], 
          Rational[ 4, 5], 
          Rational[ 4, 5], 
          Rational[ 4, 5]}}, 10], 
        SymmetricNeutralHaploidFrequencies[ {{0, 0, 0, 1}, {1, 1, 1, 1}}, 
          10]}]]], "Output",
  CellLabel->"Out[38]//MatrixForm="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{956, 721},
WindowMargins->{{-3, Automatic}, {Automatic, 2}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "DoubleCline"->{
    Cell[1941, 59, 801, 15, 56, "DefinitionBox",
      CellTags->"DoubleCline"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"DoubleCline", 22063, 626}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 54, 0, 36, "SubsectionIcon"],
Cell[1796, 53, 46, 0, 28, "MathCaption"],
Cell[1845, 55, 93, 2, 26, "Input"],
Cell[1941, 59, 801, 15, 56, "DefinitionBox",
  CellTags->"DoubleCline"],
Cell[2745, 76, 98, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2868, 83, 178, 5, 26, "Input"],
Cell[3049, 90, 1529, 37, 147, "Output"]
}, Closed]],
Cell[4593, 130, 58, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[4676, 134, 103, 2, 26, "Input"],
Cell[4782, 138, 857, 21, 81, "Output"]
}, Closed]],
Cell[5654, 162, 57, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[5736, 166, 98, 2, 26, "Input"],
Cell[5837, 170, 1529, 37, 147, "Output"]
}, Closed]],
Cell[7381, 210, 79, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[7485, 214, 105, 2, 26, "Input"],
Cell[7593, 218, 2412, 64, 171, "Output"]
}, Closed]],
Cell[10020, 285, 58, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[10103, 289, 103, 2, 26, "Input"],
Cell[10209, 293, 1484, 40, 105, "Output"]
}, Closed]],
Cell[11708, 336, 114, 3, 18, "Text"],
Cell[11825, 341, 57, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11907, 345, 99, 2, 26, "Input"],
Cell[12009, 349, 2412, 64, 171, "Output"]
}, Closed]],
Cell[14436, 416, 52, 0, 18, "Text"],
Cell[14491, 418, 168, 4, 22, "Text"],

Cell[CellGroupData[{
Cell[14684, 426, 185, 5, 26, "Input"],
Cell[14872, 433, 2323, 57, 147, "Output"]
}, Open  ]],
Cell[17210, 493, 58, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[17293, 497, 103, 2, 26, "Input"],
Cell[17399, 501, 1253, 31, 81, "Output"]
}, Open  ]],
Cell[18667, 535, 57, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[18749, 539, 98, 2, 26, "Input"],
Cell[18850, 543, 2323, 57, 147, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

