(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    118655,       3294]*)
(*NotebookOutlinePosition[    191919,       5919]*)
(*  CellTagsIndexPosition[    191484,       5902]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Iterating one deme", "SubsectionIcon"],

Cell["This loads this package, as well as the Graphics package:", \
"MathCaption"],

Cell[BoxData[
    \(<< NumericalModels`ExactModel`; << Graphics`;\)], "Input",
  CellLabel->"In[1]:="],

Cell[CellGroupData[{

Cell["A single deme", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, 
              0]\), \(gives\ genotype\ frequencies\ after\ one\ generation\ \
of\ selection\ and\ recombination . \ \ \[Psi]\ must\ represent\ a\ haploid\ \
\(\(population\)\(.\)\)\)},
          {
            RowBox[{"StoreExact", "[", 
              RowBox[{"\[Psi]", ",", \(\[Psi]\_0\), ",", "W", ",", "0", ",", 
                RowBox[{"{", 
                  RowBox[{"t", ",", 
                    StyleBox["dt",
                      FontSlant->"Italic"]}], 
                  StyleBox["}",
                    FontSlant->"Italic"]}]}], 
              "]"}], \(stores\ results\ at\ intervals\ dt\ in\ \[Psi][t], \ 
            starting\ with\ \[Psi][
                  0] = \[Psi]\_0 . \ \ Options\ are\ passed\ directly\ to\ \(\
\(IterateExact[]\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->{"IterateExact", "StoreExact"}],

Cell["\<\
This shows the frequencies of classes 0\[Ellipsis]3, with selection \
s=10% against heterozygotes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hp = 
        MakePopulation[3, 0.49, 100, 
          NumericalModel \[Rule] SymmetricHaploidFrequencies];\)\), "\n", 
    \(\(w[s_, het]\)[i_, j_, h_] := \((1 - s)\)\^h; \), "\n", 
    \(\(hpc = 
        NestList[IterateExact[#, w[0.1, het], 0] &, hp, 100];\)\), "\n", 
    \(\(DisplayTogether @@ \((ListPlot /@ 
            Transpose[First /@ hpc])\);\)\)}], "Input",
  CellLabel->"In[31]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00942951 0.0147151 0.624036 [
[.2124 .00222 -6 -9 ]
[.2124 .00222 6 0 ]
[.40099 .00222 -6 -9 ]
[.40099 .00222 6 0 ]
[.58958 .00222 -6 -9 ]
[.58958 .00222 6 0 ]
[.77817 .00222 -6 -9 ]
[.77817 .00222 6 0 ]
[.96676 .00222 -9 -9 ]
[.96676 .00222 9 0 ]
[.01131 .13952 -18 -4.5 ]
[.01131 .13952 0 4.5 ]
[.01131 .26433 -18 -4.5 ]
[.01131 .26433 0 4.5 ]
[.01131 .38914 -18 -4.5 ]
[.01131 .38914 0 4.5 ]
[.01131 .51394 -18 -4.5 ]
[.01131 .51394 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2124 .01472 m
.2124 .02097 L
s
[(20)] .2124 .00222 0 1 Mshowa
.40099 .01472 m
.40099 .02097 L
s
[(40)] .40099 .00222 0 1 Mshowa
.58958 .01472 m
.58958 .02097 L
s
[(60)] .58958 .00222 0 1 Mshowa
.77817 .01472 m
.77817 .02097 L
s
[(80)] .77817 .00222 0 1 Mshowa
.96676 .01472 m
.96676 .02097 L
s
[(100)] .96676 .00222 0 1 Mshowa
.125 Mabswid
.07096 .01472 m
.07096 .01847 L
s
.1181 .01472 m
.1181 .01847 L
s
.16525 .01472 m
.16525 .01847 L
s
.25955 .01472 m
.25955 .01847 L
s
.30669 .01472 m
.30669 .01847 L
s
.35384 .01472 m
.35384 .01847 L
s
.44814 .01472 m
.44814 .01847 L
s
.49529 .01472 m
.49529 .01847 L
s
.54243 .01472 m
.54243 .01847 L
s
.63673 .01472 m
.63673 .01847 L
s
.68388 .01472 m
.68388 .01847 L
s
.73102 .01472 m
.73102 .01847 L
s
.82532 .01472 m
.82532 .01847 L
s
.87247 .01472 m
.87247 .01847 L
s
.91961 .01472 m
.91961 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13952 m
.03006 .13952 L
s
[(0.2)] .01131 .13952 1 0 Mshowa
.02381 .26433 m
.03006 .26433 L
s
[(0.4)] .01131 .26433 1 0 Mshowa
.02381 .38914 m
.03006 .38914 L
s
[(0.6)] .01131 .38914 1 0 Mshowa
.02381 .51394 m
.03006 .51394 L
s
[(0.8)] .01131 .51394 1 0 Mshowa
.125 Mabswid
.02381 .04592 m
.02756 .04592 L
s
.02381 .07712 m
.02756 .07712 L
s
.02381 .10832 m
.02756 .10832 L
s
.02381 .17072 m
.02756 .17072 L
s
.02381 .20193 m
.02756 .20193 L
s
.02381 .23313 m
.02756 .23313 L
s
.02381 .29553 m
.02756 .29553 L
s
.02381 .32673 m
.02756 .32673 L
s
.02381 .35794 m
.02756 .35794 L
s
.02381 .42034 m
.02756 .42034 L
s
.02381 .45154 m
.02756 .45154 L
s
.02381 .48274 m
.02756 .48274 L
s
.02381 .54515 m
.02756 .54515 L
s
.02381 .57635 m
.02756 .57635 L
s
.02381 .60755 m
.02756 .60755 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.03324 .09749 Mdot
.04267 .09775 Mdot
.0521 .09802 Mdot
.06153 .09831 Mdot
.07096 .09861 Mdot
.08039 .09893 Mdot
.08982 .09926 Mdot
.09925 .09961 Mdot
.10868 .09999 Mdot
.1181 .10038 Mdot
.12753 .1008 Mdot
.13696 .10124 Mdot
.14639 .1017 Mdot
.15582 .10219 Mdot
.16525 .10271 Mdot
.17468 .10326 Mdot
.18411 .10383 Mdot
.19354 .10445 Mdot
.20297 .10509 Mdot
.2124 .10578 Mdot
.22183 .1065 Mdot
.23126 .10726 Mdot
.24069 .10807 Mdot
.25012 .10893 Mdot
.25955 .10983 Mdot
.26898 .11079 Mdot
.27841 .11181 Mdot
.28784 .11289 Mdot
.29727 .11403 Mdot
.30669 .11523 Mdot
.31612 .11652 Mdot
.32555 .11787 Mdot
.33498 .11932 Mdot
.34441 .12084 Mdot
.35384 .12247 Mdot
.36327 .12419 Mdot
.3727 .12602 Mdot
.38213 .12796 Mdot
.39156 .13002 Mdot
.40099 .13222 Mdot
.41042 .13455 Mdot
.41985 .13702 Mdot
.42928 .13966 Mdot
.43871 .14246 Mdot
.44814 .14544 Mdot
.45757 .1486 Mdot
.467 .15197 Mdot
.47643 .15556 Mdot
.48586 .15937 Mdot
.49529 .16342 Mdot
.50471 .16773 Mdot
.51414 .17231 Mdot
.52357 .17718 Mdot
.533 .18235 Mdot
.54243 .18784 Mdot
.55186 .19367 Mdot
.56129 .19984 Mdot
.57072 .20638 Mdot
.58015 .2133 Mdot
.58958 .2206 Mdot
.59901 .22832 Mdot
.60844 .23644 Mdot
.61787 .24498 Mdot
.6273 .25393 Mdot
.63673 .26331 Mdot
.64616 .27311 Mdot
.65559 .28331 Mdot
.66502 .2939 Mdot
.67445 .30486 Mdot
.68388 .31617 Mdot
.69331 .32779 Mdot
.70273 .33969 Mdot
.71216 .35182 Mdot
.72159 .36414 Mdot
.73102 .37659 Mdot
.74045 .38911 Mdot
.74988 .40166 Mdot
.75931 .41416 Mdot
.76874 .42656 Mdot
.77817 .4388 Mdot
.7876 .45082 Mdot
.79703 .46257 Mdot
.80646 .474 Mdot
.81589 .48506 Mdot
.82532 .49573 Mdot
.83475 .50595 Mdot
.84418 .51572 Mdot
.85361 .52501 Mdot
.86304 .53381 Mdot
.87247 .54211 Mdot
.8819 .54992 Mdot
.89132 .55723 Mdot
.90075 .56406 Mdot
.91018 .57042 Mdot
.91961 .57633 Mdot
.92904 .5818 Mdot
.93847 .58685 Mdot
.9479 .59151 Mdot
.95733 .59579 Mdot
.96676 .59972 Mdot
.97619 .60332 Mdot
.03324 .25331 Mdot
.04267 .25355 Mdot
.0521 .2538 Mdot
.06153 .25406 Mdot
.07096 .25433 Mdot
.08039 .25462 Mdot
.08982 .25492 Mdot
.09925 .25523 Mdot
.10868 .25556 Mdot
.1181 .25591 Mdot
.12753 .25627 Mdot
.13696 .25665 Mdot
.14639 .25705 Mdot
.15582 .25747 Mdot
.16525 .25791 Mdot
.17468 .25837 Mdot
.18411 .25885 Mdot
.19354 .25935 Mdot
.20297 .25988 Mdot
.2124 .26043 Mdot
.22183 .261 Mdot
.23126 .2616 Mdot
.24069 .26222 Mdot
.25012 .26288 Mdot
.25955 .26356 Mdot
.26898 .26426 Mdot
.27841 .265 Mdot
.28784 .26577 Mdot
.29727 .26656 Mdot
.30669 .26739 Mdot
.31612 .26824 Mdot
.32555 .26913 Mdot
.33498 .27005 Mdot
.34441 .27099 Mdot
.35384 .27197 Mdot
.36327 .27297 Mdot
.3727 .274 Mdot
.38213 .27505 Mdot
.39156 .27613 Mdot
.40099 .27723 Mdot
.41042 .27834 Mdot
.41985 .27947 Mdot
.42928 .2806 Mdot
.43871 .28174 Mdot
.44814 .28287 Mdot
.45757 .28399 Mdot
.467 .2851 Mdot
.47643 .28617 Mdot
.48586 .2872 Mdot
.49529 .28817 Mdot
.50471 .28908 Mdot
.51414 .2899 Mdot
.52357 .29062 Mdot
.533 .29122 Mdot
.54243 .29168 Mdot
.55186 .29197 Mdot
.56129 .29206 Mdot
.57072 .29194 Mdot
.58015 .29157 Mdot
.58958 .29093 Mdot
.59901 .28998 Mdot
.60844 .28869 Mdot
.61787 .28703 Mdot
.6273 .28498 Mdot
.63673 .2825 Mdot
.64616 .27956 Mdot
.65559 .27616 Mdot
.66502 .27226 Mdot
.67445 .26785 Mdot
.68388 .26294 Mdot
.69331 .25751 Mdot
.70273 .25157 Mdot
.71216 .24515 Mdot
.72159 .23827 Mdot
.73102 .23095 Mdot
.74045 .22324 Mdot
.74988 .21519 Mdot
.75931 .20685 Mdot
.76874 .19828 Mdot
.77817 .18954 Mdot
.7876 .1807 Mdot
.79703 .17181 Mdot
.80646 .16295 Mdot
.81589 .15417 Mdot
.82532 .14553 Mdot
.83475 .13707 Mdot
.84418 .12886 Mdot
.85361 .12092 Mdot
.86304 .11329 Mdot
.87247 .10599 Mdot
.8819 .09904 Mdot
.89132 .09246 Mdot
.90075 .08625 Mdot
.91018 .08042 Mdot
.91961 .07496 Mdot
.92904 .06986 Mdot
.93847 .06512 Mdot
.9479 .06073 Mdot
.95733 .05666 Mdot
.96676 .05291 Mdot
.97619 .04946 Mdot
.03324 .24396 Mdot
.04267 .2437 Mdot
.0521 .24343 Mdot
.06153 .24315 Mdot
.07096 .24285 Mdot
.08039 .24253 Mdot
.08982 .24219 Mdot
.09925 .24184 Mdot
.10868 .24147 Mdot
.1181 .24108 Mdot
.12753 .24066 Mdot
.13696 .24022 Mdot
.14639 .23976 Mdot
.15582 .23928 Mdot
.16525 .23876 Mdot
.17468 .23822 Mdot
.18411 .23764 Mdot
.19354 .23704 Mdot
.20297 .2364 Mdot
.2124 .23572 Mdot
.22183 .235 Mdot
.23126 .23425 Mdot
.24069 .23345 Mdot
.25012 .23261 Mdot
.25955 .23171 Mdot
.26898 .23077 Mdot
.27841 .22977 Mdot
.28784 .22872 Mdot
.29727 .22761 Mdot
.30669 .22643 Mdot
.31612 .22518 Mdot
.32555 .22386 Mdot
.33498 .22247 Mdot
.34441 .221 Mdot
.35384 .21944 Mdot
.36327 .21779 Mdot
.3727 .21605 Mdot
.38213 .21421 Mdot
.39156 .21227 Mdot
.40099 .21021 Mdot
.41042 .20804 Mdot
.41985 .20575 Mdot
.42928 .20333 Mdot
.43871 .20077 Mdot
.44814 .19808 Mdot
.45757 .19524 Mdot
.467 .19225 Mdot
.47643 .18911 Mdot
.48586 .18581 Mdot
.49529 .18234 Mdot
.50471 .1787 Mdot
.51414 .17489 Mdot
.52357 .1709 Mdot
.533 .16674 Mdot
.54243 .16241 Mdot
.55186 .1579 Mdot
.56129 .15322 Mdot
.57072 .14838 Mdot
.58015 .14338 Mdot
.58958 .13824 Mdot
.59901 .13296 Mdot
.60844 .12756 Mdot
.61787 .12207 Mdot
.6273 .11649 Mdot
.63673 .11086 Mdot
.64616 .1052 Mdot
.65559 .09954 Mdot
.66502 .09391 Mdot
.67445 .08833 Mdot
.68388 .08284 Mdot
.69331 .07748 Mdot
.70273 .07226 Mdot
.71216 .06722 Mdot
.72159 .06239 Mdot
.73102 .05779 Mdot
.74045 .05343 Mdot
.74988 .04934 Mdot
.75931 .04552 Mdot
.76874 .04199 Mdot
.77817 .03874 Mdot
.7876 .03577 Mdot
.79703 .03308 Mdot
.80646 .03066 Mdot
.81589 .0285 Mdot
.82532 .02657 Mdot
.83475 .02487 Mdot
.84418 .02338 Mdot
.85361 .02208 Mdot
.86304 .02095 Mdot
.87247 .01998 Mdot
.8819 .01914 Mdot
.89132 .01843 Mdot
.90075 .01782 Mdot
.91018 .0173 Mdot
.91961 .01687 Mdot
.92904 .0165 Mdot
.93847 .0162 Mdot
.9479 .01594 Mdot
.95733 .01572 Mdot
.96676 .01555 Mdot
.97619 .0154 Mdot
.03324 .08813 Mdot
.04267 .0879 Mdot
.0521 .08765 Mdot
.06153 .08739 Mdot
.07096 .08711 Mdot
.08039 .08683 Mdot
.08982 .08653 Mdot
.09925 .08621 Mdot
.10868 .08588 Mdot
.1181 .08553 Mdot
.12753 .08516 Mdot
.13696 .08478 Mdot
.14639 .08438 Mdot
.15582 .08396 Mdot
.16525 .08352 Mdot
.17468 .08305 Mdot
.18411 .08257 Mdot
.19354 .08206 Mdot
.20297 .08153 Mdot
.2124 .08098 Mdot
.22183 .08039 Mdot
.23126 .07979 Mdot
.24069 .07915 Mdot
.25012 .07849 Mdot
.25955 .07779 Mdot
.26898 .07707 Mdot
.27841 .07631 Mdot
.28784 .07552 Mdot
.29727 .0747 Mdot
.30669 .07385 Mdot
.31612 .07295 Mdot
.32555 .07203 Mdot
.33498 .07106 Mdot
.34441 .07006 Mdot
.35384 .06902 Mdot
.36327 .06795 Mdot
.3727 .06683 Mdot
.38213 .06567 Mdot
.39156 .06448 Mdot
.40099 .06324 Mdot
.41042 .06197 Mdot
.41985 .06066 Mdot
.42928 .05931 Mdot
.43871 .05793 Mdot
.44814 .05651 Mdot
.45757 .05506 Mdot
.467 .05357 Mdot
.47643 .05206 Mdot
.48586 .05052 Mdot
.49529 .04896 Mdot
.50471 .04739 Mdot
.51414 .04579 Mdot
.52357 .04419 Mdot
.533 .04258 Mdot
.54243 .04097 Mdot
.55186 .03936 Mdot
.56129 .03777 Mdot
.57072 .0362 Mdot
.58015 .03465 Mdot
.58958 .03313 Mdot
.59901 .03165 Mdot
.60844 .03021 Mdot
.61787 .02882 Mdot
.6273 .02749 Mdot
.63673 .02622 Mdot
.64616 .02502 Mdot
.65559 .02389 Mdot
.66502 .02283 Mdot
.67445 .02185 Mdot
.68388 .02095 Mdot
.69331 .02012 Mdot
.70273 .01938 Mdot
.71216 .0187 Mdot
.72159 .0181 Mdot
.73102 .01757 Mdot
.74045 .01711 Mdot
.74988 .01671 Mdot
.75931 .01636 Mdot
.76874 .01607 Mdot
.77817 .01582 Mdot
.7876 .01561 Mdot
.79703 .01543 Mdot
.80646 .01529 Mdot
.81589 .01517 Mdot
.82532 .01507 Mdot
.83475 .015 Mdot
.84418 .01493 Mdot
.85361 .01489 Mdot
.86304 .01485 Mdot
.87247 .01482 Mdot
.8819 .01479 Mdot
.89132 .01477 Mdot
.90075 .01476 Mdot
.91018 .01475 Mdot
.91961 .01474 Mdot
.92904 .01473 Mdot
.93847 .01473 Mdot
.9479 .01473 Mdot
.95733 .01472 Mdot
.96676 .01472 Mdot
.97619 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[36]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00@P3oool5000000<0oooo0P00000/0?ooo`<000000`3oool2000002X0oooo0`0000040?oo
o`800000:P3oool3000000@0oooo0P00000W0?ooo`<00000103oool2000000@0oooo0P0000040?oo
o`00@`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002`0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo000002P0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo000002L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000<0oooo00140?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000:@3oool500000080oooo00@000000?ooo`3oool00000:03oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000:03oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000009`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool004D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo02L0oooo00@000000?ooo`3oool000000`3oool0
10000000oooo0?ooo`00000X0?ooo`@000000`3oool010000000oooo0?ooo`00000Y0?ooo`<00000
0`3oool010000000oooo0?ooo`00000W0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000030?ooo`00@P3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool00000:P3oool00`000000oooo000000030?ooo`040000003o
ool0oooo000002P0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000X0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000W0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`00@P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000:`3oool2000000<0
oooo00@000000?ooo`3oool00000:@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
000002P0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000002H0oooo
0P0000040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool004<0
oooo0`0000040?ooo`800000;@3oool00`000000oooo0?ooo`020?ooo`800000:`3oool2000000@0
oooo0P00000Z0?ooo`<00000103oool2000002P0oooo00<000000?ooo`3oool00`3oool2000000@0
oooo0P0000040?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003o
ool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo000>0?ooool000004`00000001D0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`@0000000@0oooo000000000000oooo100000000`3oool0
000000000002000000030?ooo`00000000000080000000@0oooo000000000000oooo100000000`3o
ool0000000000002000000030?ooo`00000000000080000000@0oooo000000000000oooo10000000
0`3oool0000000000002000000030?ooo`00000000000080000000@0oooo000000000000oooo1000
00000`3oool0000000000002000000030?ooo`00000000000080000000<0oooo0000000000000P00
00070?ooo`005@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0>0?ooo`80000000<0oooo0000000000000P000000
0`3oool0000000000002000000040?ooo`00000000000?ooo`@000003P3oool00`000000oooo0?oo
o`0<0?ooo`80000000<0oooo0000000000000P0000000`3oool0000000000002000000030?ooo`00
000000000080000000<0oooo000000000000403oool00`000000oooo0?ooo`080?ooo`005@3oool0
0`000000oooo0?ooo`2Q0?ooo`@0000000<0oooo0000000000000P0000000`3oool0000000000002
000002D0oooo10000000103oool000000000003oool4000002P0oooo000E0?ooo`030000003oool0
oooo09T0oooo10000000103oool000000000003oool4000000030?ooo`000000000002T0oooo0P00
00000`3oool000000000000200000300oooo000E0?ooo`030000003oool0oooo09@0oooo10000000
0`3oool0000000000002000000030?ooo`000000000002`0oooo0P0000000`3oool0000000000002
000003D0oooo000E0?ooo`030000003oool0oooo08`0oooo0P0000000`3oool00000000000020000
00030?ooo`000000000000800000<P3oool4000000030?ooo`000000000003L0oooo000E0?ooo`03
0000003oool0oooo08L0oooo10000000103oool000000000003oool4000003@0oooo0P0000000`3o
ool000000000000l0?ooo`005@3oool00`000000oooo0?ooo`220?ooo`@0000000<0oooo00000000
00000P00000i0?ooo`80000000<0oooo000000000000?`3oool001D0oooo0P00001k0?ooo`800000
00<0oooo0000000000000P0000000`3oool0000000000002000003`0oooo1000000i0?ooo`800000
1`3oool001D0oooo00<000000?ooo`3oool0M@3oool4000000040?ooo`00000000000?ooo`@00000
?P3oool2000000030?ooo`000000000003T0oooo100000070?ooo`005@3oool00`000000oooo0?oo
o`1]0?ooo`80000000<0oooo0000000000000P0000000`3oool0000000000002000004@0oooo1000
000i0?ooo`80000000<0oooo0000000000002@3oool001D0oooo00<000000?ooo`3oool0J03oool2
000000030?ooo`00000000000080000000<0oooo0000000000000P0000190?ooo`800000>@3oool4
000000`0oooo000E0?ooo`030000003oool0oooo0600oooo0P000000103oool000000000003oool4
000000030?ooo`000000000004d0oooo0P00000i0?ooo`80000000<0oooo0000000000003P3oool0
01D0oooo00<000000?ooo`3oool0EP3oool2000000030?ooo`00000000000080000000<0oooo0000
000000000P000000103oool000000000003oool200000500oooo1000000i0?ooo`8000004@3oool0
01D0oooo00<000000?ooo`3oool0CP3oool2000000040?ooo`00000000000?ooo`@0000000<0oooo
0000000000000P0000000`3oool000000000001E0?ooo`80000000<0oooo000000000000>@3oool2
000001<0oooo000E0?ooo`030000003oool0oooo0480oooo100000000`3oool00000000000020000
00030?ooo`00000000000080000000@0oooo000000000000oooo0P00001O0?ooo`800000>@3oool2
000000030?ooo`000000000001<0oooo000E0?ooo`800000=P3oool4000000030?ooo`0000000000
0080000000@0oooo000000000000oooo100000000`3oool0000000000002000000030?ooo`000000
000006@0oooo0P00000l0?ooo`8000005P3oool001D0oooo00<000000?ooo`3oool08`3oool40000
00040?ooo`00000000000?ooo`@0000000<0oooo0000000000000P0000000`3oool0000000000002
000000030?ooo`00000000000080000000<0oooo000000000000K`3oool4000003X0oooo0P00000H
0?ooo`005@3oool00`000000oooo0?ooo`070?ooo`@0000000<0oooo0000000000000P0000000`3o
ool0000000000002000000040?ooo`00000000000?ooo`@0000000<0oooo0000000000000P000000
0`3oool0000000000002000000040?ooo`00000000000?ooo`@0000000<0oooo0000000000000P00
001l0?ooo`800000>@3oool2000000030?ooo`000000000001P0oooo000E0?ooo`030000003oool0
000000<0000000@0oooo000000000000oooo100000000`3oool0000000000002000000030?ooo`00
000000000080000000@0oooo000000000000oooo100000000`3oool0000000000002000008/0oooo
0P00000l0?ooo`8000006`3oool001D0oooo00<000000?ooo`0000000`0000000`3oool000000000
002U0?ooo`@00000>@3oool2000001h0oooo000E0?ooo`030000003oool0000000<0000000@0oooo
000000000000oooo0P00002R0?ooo`800000>`3oool2000001h0oooo000E0?ooo`030000003oool0
000000<0000000@0oooo000000000000oooo100000000`3oool0000000000002000000030?ooo`00
000000000080000000@0oooo000000000000oooo100000000`3oool00000000000280?ooo`800000
?03oool200000200oooo000E0?ooo`030000003oool0oooo00T0oooo0P0000000`3oool000000000
0002000000030?ooo`00000000000080000000@0oooo000000000000oooo100000000`3oool00000
00000002000000030?ooo`00000000000080000000@0oooo000000000000oooo100000000`3oool0
00000000001d0?ooo`@00000?03oool200000200oooo000E0?ooo`030000003oool0oooo0200oooo
0P0000000`3oool0000000000002000000040?ooo`00000000000?ooo`@0000000<0oooo00000000
00000P0000000`3oool0000000000002000000030?ooo`000000000006X0oooo0P00000k0?ooo`80
00008`3oool001D0oooo0P00000c0?ooo`80000000<0oooo0000000000000P0000000`3oool00000
00000002000000040?ooo`00000000000?ooo`@00000G@3oool2000003h0oooo0P00000S0?ooo`00
5@3oool00`000000oooo0?ooo`0l0?ooo`80000000@0oooo000000000000oooo100000000`3oool0
000000000002000000030?ooo`000000000005<0oooo1000000l0?ooo`8000009@3oool001D0oooo
00<000000?ooo`3oool0A`3oool4000000030?ooo`00000000000080000000<0oooo000000000000
CP3oool2000003h0oooo0P00000U0?ooo`005@3oool00`000000oooo0?ooo`1>0?ooo`80000000@0
oooo000000000000oooo100000160?ooo`800000?P3oool2000002P0oooo000E0?ooo`030000003o
ool0oooo05@0oooo100000000`3oool0000000000002000003h0oooo0P0000000`3oool000000000
000n0?ooo`800000:03oool001D0oooo00<000000?ooo`3oool0F@3oool4000000030?ooo`000000
000000800000>@3oool2000003l0oooo0P00000Z0?ooo`000P3oool2000000@0oooo00@000000?oo
o`3oool0oooo1@0000040?ooo`030000003oool0oooo05h0oooo10000000103oool000000000003o
ool200000340oooo0P0000110?ooo`800000:P3oool000050?ooo`000000oooo0?ooo`000000203o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06<0oooo0P0000000`3oool00000
00000002000002`0oooo0P0000000`3oool000000000000n0?ooo`800000;@3oool000050?ooo`00
0000oooo0?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`<00000J03oool2000000030?oo
o`0000000000008000009`3oool200000440oooo0P00000]0?ooo`0000D0oooo0000003oool0oooo
0000000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0J`3oool4000000030?oo
o`00000000000280oooo0P0000100?ooo`800000<03oool000050?ooo`000000oooo0?ooo`000000
1`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0L03oool4000001d0
oooo0P0000000`3oool00000000000100?ooo`800000<03oool000050?ooo`000000oooo0?ooo`00
00001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0LP3oool20000
00030?ooo`000000000001P0oooo1000001e0?ooo`000P3oool2000000T0oooo0`0000050?ooo`03
0000003oool0oooo07D0oooo1000000F0?ooo`800000@`3oool200000380oooo000E0?ooo`030000
003oool0oooo07L0oooo0P0000000`3oool000000000000@0?ooo`800000AP3oool200000380oooo
000E0?ooo`030000003oool0oooo07X0oooo0P0000000`3oool000000000000:0?ooo`80000000<0
oooo000000000000@`3oool2000003D0oooo000E0?ooo`030000003oool0oooo07d0oooo10000006
0?ooo`@00000AP3oool2000003D0oooo000E0?ooo`030000003oool0oooo07l0oooo0P0000030?oo
o`80000000<0oooo000000000000AP3oool2000003L0oooo000E0?ooo`800000P`3oool4000004T0
oooo0P00000g0?ooo`005@3oool00`000000oooo0?ooo`1o0?ooo`80000000<0oooo000000000000
0P0000220?ooo`005@3oool00`000000oooo0?ooo`1m0?ooo`@000000`3oool2000000030?ooo`00
0000000004<0oooo0P00000j0?ooo`005@3oool00`000000oooo0?ooo`1j0?ooo`80000000<0oooo
000000000000203oool2000004<0oooo0P00000j0?ooo`005@3oool00`000000oooo0?ooo`1g0?oo
o`80000000<0oooo0000000000003@3oool2000003l0oooo0P00000l0?ooo`005@3oool00`000000
oooo0?ooo`1e0?ooo`@00000403oool2000000030?ooo`000000000003`0oooo0P00000l0?ooo`00
5@3oool00`000000oooo0?ooo`1b0?ooo`80000000<0oooo0000000000005@3oool2000007X0oooo
000E0?ooo`030000003oool0oooo06d0oooo0P0000000`3oool0000000000002000001/0oooo0P00
000f0?ooo`800000?`3oool001D0oooo0P00001/0?ooo`@0000000<0oooo0000000000007@3oool2
000003H0oooo0P00000o0?ooo`005@3oool00`000000oooo0?ooo`1V0?ooo`@0000000<0oooo0000
00000000903oool200000340oooo0P0000120?ooo`005@3oool00`000000oooo0?ooo`1P0?ooo`80
000000@0oooo000000000000oooo1000000W0?ooo`800000<@3oool200000480oooo000E0?ooo`03
0000003oool0oooo05/0oooo0P0000000`3oool0000000000002000000030?ooo`000000000002l0
oooo0P00000/0?ooo`800000A03oool001D0oooo00<000000?ooo`3oool0EP3oool2000000030?oo
o`00000000000080000000<0oooo000000000000=03oool2000002`0oooo0P0000140?ooo`005@3o
ool00`000000oooo0?ooo`1A0?ooo`80000000<0oooo0000000000000P0000000`3oool000000000
000k0?ooo`8000009`3oool2000004L0oooo000E0?ooo`030000003oool0oooo04T0oooo0P000000
0`3oool0000000000002000000040?ooo`00000000000?ooo`800000@03oool2000002L0oooo0P00
00170?ooo`005@3oool00`000000oooo0?ooo`120?ooo`@0000000<0oooo0000000000000P000000
0`3oool0000000000002000004T0oooo0P00001]0?ooo`005@3oool00`000000oooo0?ooo`0e0?oo
o`@0000000<0oooo0000000000000P000000103oool000000000003oool4000000030?ooo`000000
00000500oooo0P00000R0?ooo`800000B@3oool001D0oooo0P00000Y0?ooo`80000000<0oooo0000
000000000P0000000`3oool0000000000002000000030?ooo`00000000000080000000<0oooo0000
000000000P0000000`3oool000000000001J0?ooo`800000803oool2000004T0oooo000E0?ooo`03
0000003oool0oooo01<0oooo0P000000103oool000000000003oool4000000030?ooo`0000000000
0080000000<0oooo0000000000000P000000103oool000000000003oool4000000030?ooo`000000
000000800000I`3oool2000001d0oooo0P00001<0?ooo`005@3oool00`000000oooo000000030000
00040?ooo`00000000000?ooo`@0000000<0oooo0000000000000P0000000`3oool0000000000002
000000040?ooo`00000000000?ooo`@0000000<0oooo0000000000000P0000000`3oool000000000
0002000007L0oooo0P00000H0?ooo`@00000C03oool001D0oooo00<000000?ooo`0000000`000000
103oool000000000003oool4000000030?ooo`00000000000080000000<0oooo000000000000R`3o
ool2000001P0oooo0P00001>0?ooo`005@3oool00`000000oooo0?ooo`2e0?ooo`800000D@3oool0
01D0oooo00<000000?ooo`0000000`000000103oool000000000003oool4000000030?ooo`000000
00000080000000<0oooo0000000000000P000000103oool000000000003oool2000008H0oooo0P00
000B0?ooo`800000D@3oool00080oooo0P0000040?ooo`030000003oool0oooo00<0oooo0`000004
0?ooo`030000003oool0000000<0000000@0oooo000000000000oooo100000000`3oool000000000
0002000000030?ooo`00000000000080000000@0oooo000000000000oooo100000000`3oool00000
00000002000000030?ooo`00000000000080000000@0oooo000000000000oooo1000001b0?ooo`80
00003`3oool2000005@0oooo00001@3oool000000?ooo`3oool0000000X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0K0?ooo`80000000<0oooo0000000000000P0000000`3oool0
000000000002000000040?ooo`00000000000?ooo`@0000000<0oooo0000000000000P0000000`3o
ool0000000000002000000030?ooo`000000000000800000I@3oool2000000/0oooo1000001D0?oo
o`0000D0oooo0000003oool0oooo000000070?ooo`D00000103oool300000300oooo100000000`3o
ool0000000000002000000030?ooo`00000000000080000000@0oooo000000000000oooo10000000
0`3oool0000000000002000005P0oooo0P00000;0?ooo`800000EP3oool000050?ooo`000000oooo
0?ooo`0000001`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo03l0oooo0P00
00000`3oool0000000000002000000030?ooo`00000000000080000000<0oooo0000000000000P00
0000103oool000000000003oool2000005L0oooo0P00001I0?ooo`0000D0oooo0000003oool0oooo
000000080?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0C03oool4000000040?oo
o`00000000000?ooo`@0000000<0oooo0000000000000P0000190?ooo`8000000`3oool4000005T0
oooo00001@3oool000000?ooo`3oool0000000T0oooo0P0000050?ooo`030000003oool0oooo05H0
oooo0P0000000`3oool0000000000002000000030?ooo`00000000000080000000@0oooo00000000
0000oooo0P00000n0?ooo`@0000000<0oooo000000000000F`3oool00080oooo0P00000;0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0GP3oool4000000040?ooo`00000000000?oo
o`@0000000<0oooo0000000000000P00000g0?ooo`@00000GP3oool001D0oooo00<000000?ooo`3o
ool0J03oool2000000030?ooo`00000000000080000000<0oooo0000000000000P0000000`3oool0
00000000000Z0?ooo`@0000000<0oooo0000000000000P00001N0?ooo`005@3oool00`000000oooo
0?ooo`1`0?ooo`@0000000<0oooo0000000000000P000000103oool000000000003oool4000001X0
oooo0P000000103oool000000000003oool4000000<0oooo0P00001N0?ooo`005@3oool00`000000
oooo0?ooo`1g0?ooo`80000000@0oooo000000000000oooo100000000`3oool00000000000020000
00030?ooo`00000000000080000000@0oooo000000000000oooo100000000`3oool0000000000002
000000030?ooo`00000000000080000000<0oooo000000000000J03oool001D0oooo00<000000?oo
o`3oool0PP3oool4000000030?ooo`00000000000080000000@0oooo000000000000oooo10000000
0`3oool0000000000002000000030?ooo`00000000000100oooo0P00001K0?ooo`005@3oool20000
0:`0oooo0P00001K0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000
003oool0oooo0:d0oooo0P00001I0?ooo`005@3oool00`000000oooo0?ooo`2]0?ooo`800000F@3o
ool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`2`0?oo
o`800000EP3oool001D0oooo00<000000?ooo`3oool0/03oool2000005H0oooo000E0?ooo`030000
003oool0oooo0?l0oooo2@3oool001D0oooo0P00002c0?ooo`800000E03oool001D0oooo00<00000
0?ooo`3oool0/P3oool2000005@0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0
oooo00<000000?ooo`3oool0]@3oool200000540oooo000E0?ooo`030000003oool0oooo0;D0oooo
0P00001A0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0
oooo0;P0oooo0P00001>0?ooo`005@3oool00`000000oooo0?ooo`2h0?ooo`800000CP3oool001D0
oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool200000?l0oooo2P3oool001D0oooo00<0
00000?ooo`3oool0^P3oool2000004`0oooo000E0?ooo`030000003oool0oooo0;X0oooo0P00001<
0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0;d0
oooo0P0000190?ooo`005@3oool00`000000oooo0?ooo`2m0?ooo`800000B@3oool00080oooo0P00
00040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0?l0oooo2@3o
ool000050?ooo`000000oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0o`3oool90?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000
003oool0oooo0?ooo`000000103oool300000;l0oooo0P0000170?ooo`0000D0oooo0000003oool0
oooo000000070?ooo`@000001@3oool00`000000oooo0?ooo`2o0?ooo`800000A`3oool000050?oo
o`000000oooo0?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0
oooo2@3oool000050?ooo`000000oooo0?ooo`000000203oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0<80oooo0P0000140?ooo`000P3oool2000000X0oooo0P0000050?ooo`030000
003oool0oooo0<80oooo0P0000140?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E
0?ooo`030000003oool0oooo0<@0oooo0P0000120?ooo`005@3oool00`000000oooo0?ooo`340?oo
o`800000@P3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool200000?l0oooo
2P3oool001D0oooo00<000000?ooo`3oool0a`3oool2000003l0oooo000E0?ooo`030000003oool0
oooo0<L0oooo0P00000o0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`03
0000003oool0oooo0<X0oooo0P00000l0?ooo`005@3oool00`000000oooo0?ooo`3:0?ooo`800000
?03oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3<
0?ooo`800000>P3oool001D0oooo0P00003=0?ooo`800000>P3oool001D0oooo00<000000?ooo`3o
ool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003o
ool0oooo0<l0oooo0P00000g0?ooo`005@3oool00`000000oooo0?ooo`3?0?ooo`800000=`3oool0
01D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3A0?ooo`80
0000=@3oool001D0oooo00<000000?ooo`3oool0d@3oool2000003D0oooo000E0?ooo`800000o`3o
ool:0?ooo`005@3oool00`000000oooo0?ooo`3D0?ooo`800000<P3oool001D0oooo00<000000?oo
o`3oool0e03oool200000380oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo
00<000000?ooo`3oool0eP3oool200000300oooo000E0?ooo`030000003oool0oooo0=H0oooo0P00
000`0?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<00000
0?ooo`3oool0f@3oool2000002d0oooo00001@3oool000000?ooo`3oool0000000L0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0=T0oooo0P00000]0?ooo`0000D0oooo
0000003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`3o0?ooo`T0oooo00001@3oool000000?ooo`3oool0000000P0oooo0`0000050?ooo`<00000
g03oool2000002X0oooo00001@3oool000000?ooo`3oool0000000L0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo0=`0oooo0P00000Z0?ooo`0000D0oooo0000003oool0
oooo000000070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`3o0?oo
o`T0oooo00020?ooo`8000002@3oool3000000D0oooo00<000000?ooo`3oool0gP3oool2000002P0
oooo000E0?ooo`030000003oool0oooo0=h0oooo0P00000X0?ooo`005@3oool00`000000oooo0?oo
o`3Q0?ooo`8000009@3oool001D0oooo00<000000?ooo`3oool0h@3oool2000002D0oooo000E0?oo
o`030000003oool0oooo0><0oooo0P00000S0?ooo`005@3oool200000>@0oooo0P00000S0?ooo`00
5@3oool00`000000oooo0?ooo`3V0?ooo`800000803oool001D0oooo00<000000?ooo`3oool0iP3o
ool200000200oooo000E0?ooo`030000003oool0oooo0>P0oooo0P00000N0?ooo`005@3oool00`00
0000oooo0?ooo`3X0?ooo`8000007P3oool001D0oooo00<000000?ooo`3oool0j`3oool2000001/0
oooo000E0?ooo`030000003oool0oooo0>/0oooo0P00000K0?ooo`005@3oool00`000000oooo0?oo
o`3^0?ooo`800000603oool001D0oooo00<000000?ooo`3oool0kP3oool2000001P0oooo000E0?oo
o`800000l@3oool2000001H0oooo000E0?ooo`030000003oool0oooo0?00oooo0P0000000`3oool0
00000000000C0?ooo`005@3oool00`000000oooo0?ooo`3c0?ooo`@000004@3oool001D0oooo00<0
00000?ooo`3oool0m@3oool200000140oooo000E0?ooo`030000003oool0oooo0?P0oooo0P00000>
0?ooo`005@3oool00`000000oooo0?ooo`3h0?ooo`@00000303oool001D0oooo00<000000?ooo`3o
ool0nP3oool2000000030?ooo`000000000000T0oooo000E0?ooo`030000003oool0oooo0?d0oooo
100000070?ooo`005@3oool200000?l0oooo0@3oool2000000L0oooo000E0?ooo`030000003oool0
oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-8.34219, -0.0741839, \
0.389783, 0.00588983}}]
}, Open  ]],

Cell["\<\
Initially, the population is near p=0.5; classes 1, 2 are most \
common, and 0, 3 less common.  As the rarer allels are eliminated, class 0 is \
fixed (above right).\
\>", "Text"],

Cell["\<\
Multiplicative selection against heterozygotes generates no linkage \
disequilibrium:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({AlleleFrequencyMean[hpc // Last], 
      DisequilibriumMean[hpc // Last]}\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \({0.019296498000214598`, 0.`}\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell["\<\
This stores genotype frequencies in pop[0.1,hp][t], every 10 \
generations:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(StoreExact[pop[0.1, hp], hp, w[0.1, het], 0, {100, 10}];\)\)], "Input",\

  CellLabel->"In[39]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(?? pop\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \("Global`pop"\)], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(\(pop[0.1`, 
                        SymmetricHaploidFrequencies[{0.132651`, 0.382347`, 
                            0.367353`, 0.11764899999999999`}, 100]]\)[0] = 
                    SymmetricHaploidFrequencies[{0.132651`, 0.382347`, 
                        0.367353`, 0.11764899999999999`}, 100]\)},
                {" "},
                {\(\(pop[0.1`, 
                        SymmetricHaploidFrequencies[{0.132651`, 0.382347`, 
                            0.367353`, 0.11764899999999999`}, 100]]\)[10] = 
                    SymmetricHaploidFrequencies[{0.1379447921786595`, 
                        0.3870899060178647`, 0.36207382430418367`, 
                        0.11289147749929233`}, 100]\)},
                {" "},
                {\(\(pop[0.1`, 
                        SymmetricHaploidFrequencies[{0.132651`, 0.382347`, 
                            0.367353`, 0.11764899999999999`}, 100]]\)[20] = 
                    SymmetricHaploidFrequencies[{0.14707947790371123`, 
                        0.3946647405519953`, 0.3530070037755269`, 
                        0.1052487777687668`}, 100]\)},
                {" "},
                {\(\(pop[0.1`, 
                        SymmetricHaploidFrequencies[{0.132651`, 0.382347`, 
                            0.367353`, 0.11764899999999999`}, 100]]\)[30] = 
                    SymmetricHaploidFrequencies[{0.16313204520271116`, 
                        0.4062726559995522`, 0.3372676222868551`, 
                        0.09332767651088168`}, 100]\)},
                {" "},
                {\(\(pop[0.1`, 
                        SymmetricHaploidFrequencies[{0.132651`, 0.382347`, 
                            0.367353`, 0.11764899999999999`}, 100]]\)[40] = 
                    SymmetricHaploidFrequencies[{0.19202594664189038`, 
                        0.4224523450967958`, 0.3097949122653442`, 
                        0.07572679599596983`}, 100]\)},
                {" "},
                {\(\(pop[0.1`, 
                        SymmetricHaploidFrequencies[{0.132651`, 0.382347`, 
                            0.367353`, 0.11764899999999999`}, 100]]\)[50] = 
                    SymmetricHaploidFrequencies[{0.24520322106331183`, 
                        0.43966318239263513`, 0.26278028093509187`, 
                        0.05235331560896128`}, 100]\)},
                {" "},
                {\(\(pop[0.1`, 
                        SymmetricHaploidFrequencies[{0.132651`, 0.382347`, 
                            0.367353`, 0.11764899999999999`}, 100]]\)[60] = 
                    SymmetricHaploidFrequencies[{0.34228775307626746`, 
                        0.44110104462588`, 0.1894800790868388`, 
                        0.027131123211013606`}, 100]\)},
                {" "},
                {\(\(pop[0.1`, 
                        SymmetricHaploidFrequencies[{0.132651`, 0.382347`, 
                            0.367353`, 0.11764899999999999`}, 100]]\)[70] = 
                    SymmetricHaploidFrequencies[{0.5016931063585274`, 
                        0.3890662122641259`, 0.10057444521829367`, 
                        0.008666236159053072`}, 100]\)},
                {" "},
                {\(\(pop[0.1`, 
                        SymmetricHaploidFrequencies[{0.132651`, 0.382347`, 
                            0.367353`, 0.11764899999999999`}, 100]]\)[80] = 
                    SymmetricHaploidFrequencies[{0.69884949796902`, 
                        0.2659798436703779`, 0.03374368751522654`, 
                        0.0014269708453752093`}, 100]\)},
                {" "},
                {\(\(pop[0.1`, 
                        SymmetricHaploidFrequencies[{0.132651`, 0.382347`, 
                            0.367353`, 0.11764899999999999`}, 100]]\)[90] = 
                    SymmetricHaploidFrequencies[{0.857644862369834`, 
                        0.1351335143959624`, 0.007097369208098953`, 
                        0.00012425402610456157`}, 100]\)},
                {" "},
                {\(\(pop[0.1`, 
                        SymmetricHaploidFrequencies[{0.132651`, 0.382347`, 
                            0.367353`, 0.11764899999999999`}, 100]]\)[100] = 
                    SymmetricHaploidFrequencies[{0.9432203853602429`, 
                        0.055676920423201104`, 0.0010955090722258296`, 
                        7.185144330342598`*^-6}, 100]\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ pop],
      Editable->False]], "Print",
  CellLabel->"From In[40]:="]
}, Closed]],

Cell["\<\
Storing large numbers of genotypes in every generation would waste \
memory.  \
\>", "Text"],

Cell["\<\
It is useful to store results in the form pop[pars] so that results \
for different parameter sets can be kept tidily.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Immigration into one deme", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, 
              m]\), \(allows\ for\ immigration\ from\ a\ source\ of\ the\ \
same\ size, \ fixed\ for\ ' 1'\ alleles\)},
          {\(IterateExact[\[Psi], W, m, 
              FixedEnds -> {\[Psi]\_s}]\), \(allows\ for\ immigration\ from\ \
a\ haploid\ source\ \[Psi]\_s\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->"IterateExact"],

Cell["\<\
This shows the allele frequency at three loci, with additive \
selection \[Sigma] = -0.1 against '1' alleles, and immigration at 10% from a \
source fixed for '1':\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hp = 
        MakePopulation[3, 0, 100, 
          NumericalModel \[Rule] SymmetricHaploidFrequencies];\)\), "\n", 
    \(\(w[\[Sigma]_]\)[i_, j_, h_] := 
      1 + \[Sigma] \((i + j - 3)\); \), "\n", 
    \(\(StoreExact[pop[\(-0.1\), 0.1, hp], hp, w[\(-0.1\)], 
        0.1, {300, 10}];\)\), "\n", 
    \(\(pt[i_] := 
        Table[{t, \(\(pop[\(-0.1\), 0.1, hp]\)[t]\)\[LeftDoubleBracket]1, 
              i\[RightDoubleBracket]}, {t, 0, 300, 10}];\)\), "\n", 
    \(\(DisplayTogether @@ 
        Table[ListPlot[pt[i], PlotJoined -> True], {i, 3}];\)\)}], "Input",
  CellLabel->"In[7]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0.0147151 0.588604 [
[.18254 .00222 -6 -9 ]
[.18254 .00222 6 0 ]
[.34127 .00222 -9 -9 ]
[.34127 .00222 9 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -9 -9 ]
[.65873 .00222 9 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(50)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(100)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(150)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(200)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(250)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(300)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.05556 .26673 L
.0873 .14955 L
.11905 .10292 L
.15079 .08013 L
.18254 .06743 L
.21429 .0597 L
.24603 .05469 L
.27778 .0513 L
.30952 .04893 L
.34127 .04723 L
.37302 .04599 L
.40476 .04507 L
.43651 .04439 L
.46825 .04387 L
.5 .04348 L
.53175 .04319 L
.56349 .04296 L
.59524 .04279 L
.62698 .04265 L
.65873 .04255 L
.69048 .04247 L
.72222 .04241 L
.75397 .04237 L
.78571 .04233 L
.81746 .0423 L
.84921 .04228 L
.88095 .04227 L
.9127 .04225 L
.94444 .04224 L
.97619 .04224 L
s
.02381 .01472 m
.05556 .20752 L
.0873 .23214 L
.11905 .21725 L
.15079 .20042 L
.18254 .18686 L
.21429 .17661 L
.24603 .16897 L
.27778 .16328 L
.30952 .15901 L
.34127 .15579 L
.37302 .15335 L
.40476 .1515 L
.43651 .15009 L
.46825 .14901 L
.5 .14818 L
.53175 .14755 L
.56349 .14706 L
.59524 .14668 L
.62698 .14639 L
.65873 .14617 L
.69048 .146 L
.72222 .14587 L
.75397 .14576 L
.78571 .14569 L
.81746 .14562 L
.84921 .14558 L
.88095 .14554 L
.9127 .14551 L
.94444 .14549 L
.97619 .14547 L
s
.02381 .01472 m
.05556 .09688 L
.0873 .16088 L
.11905 .19634 L
.15079 .21516 L
.18254 .22548 L
.21429 .23138 L
.24603 .23489 L
.27778 .23705 L
.30952 .23842 L
.34127 .23932 L
.37302 .23993 L
.40476 .24034 L
.43651 .24063 L
.46825 .24084 L
.5 .24099 L
.53175 .2411 L
.56349 .24119 L
.59524 .24125 L
.62698 .24129 L
.65873 .24133 L
.69048 .24135 L
.72222 .24137 L
.75397 .24139 L
.78571 .2414 L
.81746 .24141 L
.84921 .24142 L
.88095 .24142 L
.9127 .24143 L
.94444 .24143 L
.97619 .24143 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[14]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00>`3oool3000000@0oooo0P00000N0?ooo`<00000103oool2000000@0oooo0P00000L0?oo
o`<000000`3oool3000000@0oooo0P00000K0?ooo`D000000`3oool2000000@0oooo0P00000K0?oo
o`D000000P3oool3000000@0oooo0P00000L0?ooo`<00000103oool2000000@0oooo0P0000030?oo
o`00>P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000007P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
703oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0I0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00000K0?ooo`060000003oool0oooo0000003oool000000`3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo01P0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool003h0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000L0?ooo`030000003oool0
oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000L0?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0L0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool100000040oooo0@3o
ool003h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000L0?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0K0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo01X0oooo0P0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool003X0oooo100000030?ooo`040000003oool0oooo000001h0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001`0oooo00@0
00000?ooo`3oool0oooo100000030?ooo`040000003oool0oooo000001X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000006P3o
ool01P000000oooo0?ooo`3oool000000?ooo`@000000`3oool010000000oooo0?ooo`00000N0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool100000040oooo0@3o
ool003X0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000M0?ooo`800000103o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001/0oooo0P0000030?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool000006P3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000J0?ooo`070000
003oool0oooo0?ooo`000000oooo000000060?ooo`040000003oool0oooo000001X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool003X0oooo1@0000030?ooo`8000007`3oool00`000000oooo0?ooo`030?ooo`800000
103oool2000001d0oooo00@000000?ooo`3oool0oooo1@0000030?ooo`800000703oool3000000@0
oooo0P0000040?ooo`800000703oool300000080oooo1@0000030?ooo`800000703oool3000000@0
oooo0P0000040?ooo`8000000`3oool00?l0oooo8@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo
0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`003P3ooooo000001000000
0`3oool001D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool001D0oooo0P00003o0?ooo`X0oooo000E0?oo
o`800000o`3oool:0?ooo`005@3oool200000?l0oooo2P3oool001D0oooo0`00003o0?ooo`T0oooo
000E0?ooo`<00000o`3oool90?ooo`005@3oool3000007T0ooooQP0000090?ooo`005@3oool20000
00030?ooo`000000oooo04`0oooo:`00002?0?ooo`005@3oool2000000030?ooo`000000oooo04@0
oooo2000002j0?ooo`005@3oool2000000030?ooo`000000oooo03D0oooo3`0000320?ooo`005@3o
ool01@000000oooo0000003oool000000300oooo1@00003A0?ooo`005@3oool01@000000oooo0000
003oool0000002`0oooo1000003F0?ooo`005@3oool00`000000oooo000000020?ooo`030000003o
ool0oooo02D0oooo1000003J0?ooo`005@3oool00`000000oooo000000020?ooo`030000003oool0
oooo0280oooo0`00003N0?ooo`005@3oool00`000000oooo000000020?ooo`030000003oool0oooo
01l0oooo0`00003Q0?ooo`005@3oool3000000<0oooo00<000000?ooo`3oool06`3oool300000>@0
oooo000E0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0603oool300000>L0
oooo000E0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`3X0?ooo`005@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0j@3oool001D0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`0C0?ooo`800000k03oool001D0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0>`0oooo000E0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3]0?ooo`005@3oool2000000030?oo
o`000000oooo00<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3^0?ooo`005@3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`3^0?ooo`005@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`3_0?ooo`005@3oool01@000000oooo0?ooo`3oool0000000D0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3`0?ooo`005@3oool01@000000oooo0?oo
o`3oool0000000D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3`0?ooo`005@3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`3a0?ooo`000P3oool2000000@0oooo00@000000?ooo`3oool0oooo1@0000040?ooo`050000
003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?80
oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`3c0?ooo`0000D0oooo0000003oool0oooo000000090?ooo`030000003oool0oooo
00@0oooo0`0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3c0?ooo`0000D0oooo0000003oool0oooo0000000:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0m03oool000050?ooo`000000oooo0?ooo`0000001`3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0m@3oool000050?ooo`000000oooo
0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0m@3o
ool00080oooo0P0000090?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo00@000000?ooo`3oool00000LP3ooomm000000T0oooo000E0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0000001I0?oooaX00000QP3oool0
01D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`800000B03ooolA0000
0:00oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool2000003l0
oooo2@00002a0?ooo`005@3oool2000000@0oooo00<000000?ooo`3oool01`3oool2000003L0oooo
2000002j0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo0P00
000^0?ooo`T00000`P3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0000002L0oooo1P00003;0?ooo`005@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`D00000d@3oool0
01D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool06`3oool300000=H0oooo000E0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0
oooo0`00003I0?ooo`005@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`<00000g03oool001D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0403oool200000=l0oooo000E0?ooo`8000001@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool200000>40oooo000E0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00T0oooo0`00003S0?ooo`005@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool2000000L0oooo0P00003V0?ooo`00
5@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`020?ooo`800000j03oool001D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo1000003Z0?ooo`005@3oool0
0`000000oooo0?ooo`050?ooo`8000000`3oool00`000000oooo0?ooo`0=0?ooo`@00000jP3oool0
01D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000>0?ooo`800000103oool00`00
0000oooo0?ooo`3W0?ooo`005@3oool00`000000oooo0?ooo`080?ooo`800000303oool2000000L0
oooo0`00003V0?ooo`005@3oool2000000X0oooo0P0000090?ooo`800000303oool500000>40oooo
000E0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`0000000000103oool3000001<0oooo
1000003M0?ooo`005@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`00000000006P3oool400000=T0oooo000E0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`L00000dP3oool001D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0[0?ooo`P00000bP3oool001D0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0d0?ooob/00000W`3oool00080oooo0P0000040?ooo`03
0000003oool0oooo00<0oooo0`0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0G`3ooonF000000T0oooo00001@3oool000000?ooo`3oool0000000X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?h0oooo00001@3oool00000
0?ooo`3oool0000000L0oooo1@0000040?ooo`<000001`3oool00`000000oooo0?ooo`3n0?ooo`00
00D0oooo0000003oool0oooo000000070?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`3o0?ooo`0000D0oooo0000003oool0oooo000000080?oo
o`030000003oool0000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?oo
o`0000D0oooo0000003oool0oooo000000090?ooo`8000001@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0?l0oooo00020?ooo`8000002`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool10?ooo`005@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0?l0oooo0@3oool001D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`3o0?ooo`40oooo000E0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0o`3oool10?ooo`005@3oool2000000H0oooo00<000000?ooo`3oool0o`3oool10?oo
o`005@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo0@3oool001D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`40oooo000E0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0o`3oool10?ooo`005@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0?l0oooo0P3oool001D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`3o0?ooo`80oooo000E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0o`3oool20?ooo`005@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo
0P3oool001D0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo0P3oool001D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooo`80oooo000E0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0o`3oool20?ooo`005@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0?l0oooo0P3oool001D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`3o0?ooo`80oooo000E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3o
ool20?ooo`005@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo0P3oool0
01D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000E0?ooo`80
0000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo000E0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0o`3oool30?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0?l0oooo0`3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool30?oo
o`000P3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00001@3oool000000?ooo`3oool0000000L0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0o`3oool30?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo0`3oool0
00050?ooo`000000oooo0?ooo`0000001`3oool4000000D0oooo0`0000030?ooo`030000003oool0
oooo0?l0oooo0`3oool000050?ooo`000000oooo0?ooo`0000001`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool30?ooo`0000D0oooo0000
003oool0oooo000000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3o0?ooo`@0oooo00020?ooo`8000002P3oool2000000D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000E0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0o`3oool40?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0?l0oooo103oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3o0?ooo`@0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool4
0?ooo`005@3oool2000000<0oooo00<000000?ooo`3oool0o`3oool40?ooo`005@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo103oool001D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000E0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0o`3oool40?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0?l0oooo103oool001D0oooo00D000000?ooo`3oool0oooo0000003o0?ooo`L0oooo000E0?oo
o`050000003oool0oooo0?ooo`000000o`3oool70?ooo`005@3oool01@000000oooo0?ooo`3oool0
00000?l0oooo1`3oool001D0oooo0P0000020?ooo`030000003oool0oooo0?l0oooo1@3oool001D0
oooo00D000000?ooo`3oool0oooo0000003o0?ooo`L0oooo000E0?ooo`050000003oool0oooo0?oo
o`000000o`3oool70?ooo`005@3oool01@000000oooo0?ooo`3oool000000?l0oooo1`3oool001D0
oooo00D000000?ooo`3oool0oooo0000003o0?ooo`L0oooo000E0?ooo`050000003oool0oooo0?oo
o`000000o`3oool70?ooo`005@3oool01@000000oooo0?ooo`3oool000000?l0oooo1`3oool001D0
oooo00D000000?ooo`3oool0oooo0000003o0?ooo`L0oooo000E0?ooo`8000000P3oool00`000000
oooo0?ooo`3o0?ooo`D0oooo000E0?ooo`040000003oool0oooo00000?l0oooo203oool001D0oooo
00@000000?ooo`3oool00000o`3oool80?ooo`005@3oool010000000oooo0?ooo`00003o0?ooo`P0
oooo000E0?ooo`040000003oool0oooo00000?l0oooo203oool00080oooo0P0000040?ooo`030000
003oool0oooo0080oooo0`0000050?ooo`040000003oool0oooo00000?l0oooo203oool000050?oo
o`000000oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?oo
o`3oool00000o`3oool80?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0
oooo0?ooo`000000103oool010000000oooo0?ooo`00003o0?ooo`P0oooo00001@3oool000000?oo
o`3oool0000000P0oooo0`0000050?ooo`@00000o`3oool80?ooo`0000D0oooo0000003oool0oooo
000000070?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`00003o0?oo
o`P0oooo00001@3oool000000?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`040000003oool0oooo00000?l0oooo203oool00080oooo0P0000090?ooo`<000001@3oool0
10000000oooo0?ooo`00003o0?ooo`P0oooo000E0?ooo`030000003oool000000?l0oooo2@3oool0
01D0oooo00<000000?ooo`000000o`3oool90?ooo`005@3oool00`000000oooo0000003o0?ooo`T0
oooo000E0?ooo`<00000o`3oool90?ooo`005@3oool00`000000oooo0000003o0?ooo`T0oooo000E
0?ooo`030000003oool000000?l0oooo2@3oool001D0oooo00<000000?ooo`000000o`3oool90?oo
o`005@3oool00`000000oooo0000003o0?ooo`T0oooo000E0?ooo`030000003oool000000?l0oooo
2@3oool001D0oooo00<000000?ooo`000000o`3oool90?ooo`005@3oool00`000000oooo0000003o
0?ooo`T0oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool200000?l0oooo2P3oool001D0oooo
0P00003o0?ooo`X0oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool200000?l0oooo2P3oool0
01D0oooo0P00003o0?ooo`X0oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool200000?l0oooo
2P3oool001D0oooo0P00003o0?ooo`X0oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool20000
0?l0oooo2P3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool000d0oooo0`000005
0?ooo`030000003oool0oooo0?l0oooo2@3oool000h0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo000>0?ooo`030000003oool0oooo00@0oooo0`00003o0?ooo`T0
oooo000>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oool90?ooo`003P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo2@3oool000d0oooo0P000006
0?ooo`030000003oool0oooo0?l0oooo2@3oool000h0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-24.9809, -0.0825899, 1.169, \
0.00630494}}]
}, Open  ]],

Cell["\<\
An equilibrium is reached with allele frequency 0.677 and linkage \
disequilibrium 0.016:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({#\[LeftDoubleBracket]1\[RightDoubleBracket], AlleleFrequencyMean[#], 
          DisequilibriumMean[#]} &\)@\(pop[\(-0.1\), 0.1, hp]\)[
        300]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \({{0.046756980600699424`, 0.22215225408202`, 0.38517905786383033`, 
        0.34591170745345035`}, 0.6767484973900105`, 
      0.01631619802175671`}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell["\<\
The same result is produced by iterating the full genotype \
frequencies:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hp2 = MakePopulation[3, 0, 100];\)\), "\n", 
    \(\(w2[\[Sigma]_List]\)[x_, y_] := 
      1 + \[Sigma] . \((x + y - 1)\); \), "\n", 
    \(\(StoreExact[\[Psi], hp2, w2[{\(-0.1\), \(-0.1\), \(-0.1\)}], 
        0.1, {300, 10}];\)\), "\n", 
    \(\({#\[LeftDoubleBracket]1\[RightDoubleBracket], AlleleFrequencyMean[#], 
          DisequilibriumMean[#]} &\)@\[Psi][300]\)}], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \({{0.046756980600699424`, 0.07405075136067334`, 0.07405075136067331`, 
        0.12839301928794347`, 0.07405075136067334`, 0.1283930192879435`, 
        0.12839301928794342`, 0.34591170745345035`}, 0.6767484973900105`, 
      0.016316198021756694`}\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["\<\
An equilibrium is reached at p=0.33, 0.56 for the most strongly \
selected loci, but migration swamps selection at the weakly selected locus.\
\
\>", "Text"],

Cell[TextData[{
  ButtonBox["Note",
    ButtonData:>{"Potential problems", "Redefining fitness"},
    ButtonStyle->"AddOnsLink"],
  ": ",
  StyleBox["by default, a table of offspring frequencies is stored for each \
fitness function w[] that is supplied.  Thus, if one uses \
IterateExact[\[Psi],W,m], and then redefines W without changing its name, the \
wrong results will be produced.  It is ",
    FontWeight->"Plain"],
  "essential",
  StyleBox[" that fitness functions have unique names.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["IterateExact can be used to find algebraic solutions:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(vars = {p[0], p[1], p[2]};\)\), "\[IndentingNewLine]", 
    \(newP = \(IterateExact[SymmetricHaploidFrequencies[vars, 1], 
            w[\[Sigma]], m]\)\[LeftDoubleBracket]1\[RightDoubleBracket] // 
        Simplify\)}], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \({\((\((\(-1\) + 
                m)\)\ \((8\ \((\(-1\) + 
                      3\ \[Sigma])\)\ p[0]\^2 + \((\(-1\) + \[Sigma])\)\ p[1]\
\^2 + 4\ p[0]\ \((\((\(-2\) + 4\ \[Sigma])\)\ p[
                          1] + \((\(-1\) + \[Sigma])\)\ p[
                          2])\))\))\)/\((8\ \((\(-\((p[0] + p[1] + 
                        p[2])\)\)\ \((\((\(-1\) + 3\ \[Sigma])\)\ p[
                          0] + \((\(-1\) + \[Sigma])\)\ p[
                          1] - \((1 + \[Sigma])\)\ p[2])\) + 
                m\ \((1 - p[0]\^2 - 2\ p[0]\ p[1] - p[1]\^2 - 2\ p[0]\ p[2] - 
                      2\ p[1]\ p[2] - 
                      p[2]\^2 + \[Sigma]\ \((1 + 3\ p[0]\^2 + p[1]\^2 - 
                            p[2]\^2 + 
                            2\ p[0]\ \((2\ p[1] + 
                                  p[2])\))\))\))\))\), \((\((\(-1\) + 
                m)\)\ \((p[
                    1]\ \((3\ \((\(-1\) + \[Sigma])\)\ p[1] - 4\ p[2])\) + 
                4\ p[0]\ \((\((\(-1\) + 2\ \[Sigma])\)\ p[
                          1] + \((\(-1\) + \[Sigma])\)\ p[
                          2])\))\))\)/\((4\ \((\(-\((p[0] + p[1] + 
                        p[2])\)\)\ \((\((\(-1\) + 3\ \[Sigma])\)\ p[
                          0] + \((\(-1\) + \[Sigma])\)\ p[
                          1] - \((1 + \[Sigma])\)\ p[2])\) + 
                m\ \((1 - p[0]\^2 - 2\ p[0]\ p[1] - p[1]\^2 - 2\ p[0]\ p[2] - 
                      2\ p[1]\ p[2] - 
                      p[2]\^2 + \[Sigma]\ \((1 + 3\ p[0]\^2 + p[1]\^2 - 
                            p[2]\^2 + 
                            2\ p[0]\ \((2\ p[1] + 
                                  p[2])\))\))\))\))\), \((1\/8\ \((\(-1\) + 
                  m)\)\ \((\(-1\) + \[Sigma])\)\ p[1]\^2 + 
            1\/2\ \((\(-1\) + m)\)\ \((\(-1\) + \[Sigma])\)\ p[0]\ p[
                2] - \((\(-1\) + m)\)\ p[1]\ p[
                2] + \((1 + \[Sigma])\)\ \((m - \((\(-1\) + 
                        m)\)\ p[2]\^2)\))\)/\((\((\(-1\) + m)\)\ \((\(-1\) + 
                  3\ \[Sigma])\)\ p[0]\^2 + 
            2\ \((\(-1\) + m)\)\ \((\(-1\) + 2\ \[Sigma])\)\ p[0]\ p[
                1] + \((\(-1\) + m)\)\ \((\(-1\) + \[Sigma])\)\ p[1]\^2 + 
            2\ \((\(-1\) + m)\)\ \((\(-1\) + \[Sigma])\)\ p[0]\ p[2] - 
            2\ \((\(-1\) + m)\)\ p[1]\ p[
                2] + \((1 + \[Sigma])\)\ \((m - \((\(-1\) + 
                        m)\)\ p[2]\^2)\))\)}\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell[TextData[{
  "Algebraic solution of the equilibrium is too hard for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " even for this two locus example."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Varying deme size", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, m, 
              DemeSize -> F]\), \(changes\ deme\ size\ to\ F[n, W\&_]\)},
          {\(\(ExponentialF[r, \[Beta], \[Lambda]]\)[n, 
              W\&_]\), \(represents\ r\[VeryThinSpace]n\[VeryThinSpace]\(W\&_\
\^\[Beta]\) Exp[\(-\[Lambda]\)\[VeryThinSpace]n]\)},
          {\(\(PowerF[r, \[Beta], \[Lambda]]\)[n, 
              W\&_]\), \(represents\ r\[VeryThinSpace]n\^\(1 - \[Lambda]\)\
\[VeryThinSpace]W\&_\^\[Beta]\)},
          {\(StoreExact[\[Psi], \[Psi]\_0, W, m, {t, dt}, 
              DemeSize -> 
                F]\), \(stores\ results\ in\ \[Psi]\ for\ t\ generations\ at\ \
intervals\ dt\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->"DemeSize"],

Cell["\<\
This sets deme size to decrease with density and increase with mean \
fitness, and iterates for 30 generations:\
\>", "MathCaption"],

Cell[BoxData[{
    \(\(\(w[s_, add]\)[i_, j_, h_] := \((1 - s)\)\^\(i + j\);\)\), "\n", 
    \(\(hp = 
        MakePopulation[3, 0.2, 1, 
          NumericalModel \[Rule] SymmetricHaploidFrequencies];\)\), "\n", 
    \(\(StoreExact[pop2[0.2], hp, w[0.2, add], 0, {30, 1}, 
        DemeSize -> ExponentialF[2, 1, 1]];\)\)}], "Input",
  CellLabel->"In[41]:="],

Cell["This plots deme size and allele frequencies:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tn = Table[{t, DemeSize[\(pop2[0.2]\)[t]]}, {t, 0, 30}];\)\), "\n", 
    \(\(tp = 
        Table[AlleleFrequencyTable[\(pop2[0.2]\)[t]], {t, 30}] // 
          Transpose;\)\), "\n", 
    \(\(tw = 
        Table[MeanW[MakeDiploid[\(pop2[0.2]\)[t]], w[0.2, add]], {t, 
            30}];\)\), "\[IndentingNewLine]", 
    \(\(Show[
        GraphicsArray[{DisplayTogether[
              ListPlot[tn, PlotJoined -> True], \[IndentingNewLine]ListPlot[
                tw, PlotJoined -> True, 
                PlotStyle -> Red], \[IndentingNewLine]ListPlot[Log[2  tw], 
                PlotJoined -> True, PlotStyle -> Dashing[{0.05, 0.05}]], 
              PlotRange -> {{0, 30}, {0, 1}}], 
            DisplayTogether @@ 
              MapThread[
                ListPlot[#1, PlotJoined -> True, 
                    PlotStyle -> #2] &, {tp, {Red, Green, 
                    Blue}}]}]];\)\)}], "Input",
  CellLabel->"In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .61803 m
.03333 .35594 L
.06667 .32655 L
.1 .32555 L
.13333 .33501 L
.16667 .34819 L
.2 .36175 L
.23333 .3741 L
.26667 .38463 L
.3 .3933 L
.33333 .40032 L
.36667 .40595 L
.4 .41045 L
.43333 .41405 L
.46667 .41692 L
.5 .41922 L
.53333 .42105 L
.56667 .42252 L
.6 .42369 L
.63333 .42463 L
.66667 .42538 L
.7 .42598 L
.73333 .42647 L
.76667 .42685 L
.8 .42716 L
.83333 .4274 L
.86667 .4276 L
.9 .42776 L
.93333 .42788 L
.96667 .42799 L
1 .42807 L
s
1 0 0 r
.03333 .50428 m
.06667 .52254 L
.1 .53851 L
.13333 .55227 L
.16667 .56396 L
.2 .5738 L
.23333 .582 L
.26667 .58877 L
.3 .59434 L
.33333 .5989 L
.36667 .60261 L
.4 .60561 L
.43333 .60805 L
.46667 .61001 L
.5 .6116 L
.53333 .61287 L
.56667 .61389 L
.6 .61472 L
.63333 .61538 L
.66667 .61591 L
.7 .61633 L
.73333 .61667 L
.76667 .61694 L
.8 .61716 L
.83333 .61733 L
.86667 .61747 L
.9 .61759 L
.93333 .61768 L
.96667 .61775 L
1 .6178 L
s
0 g
[ .05 .05 ] 0 setdash
.03333 .30267 m
.06667 .32466 L
.1 .34326 L
.13333 .35885 L
.16667 .3718 L
.2 .38249 L
.23333 .39126 L
.26667 .39841 L
.3 .40423 L
.33333 .40895 L
.36667 .41276 L
.4 .41584 L
.43333 .41832 L
.46667 .42031 L
.5 .42192 L
.53333 .4232 L
.56667 .42423 L
.6 .42506 L
.63333 .42573 L
.66667 .42626 L
.7 .42668 L
.73333 .42702 L
.76667 .4273 L
.8 .42751 L
.83333 .42769 L
.86667 .42783 L
.9 .42794 L
.93333 .42803 L
.96667 .4281 L
1 .42816 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 3.53162 [
[.18254 .00222 -3 -9 ]
[.18254 .00222 3 0 ]
[.34127 .00222 -6 -9 ]
[.34127 .00222 6 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.81746 .00222 -6 -9 ]
[.81746 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .10301 -30 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .1913 -24 -4.5 ]
[.01131 .1913 0 4.5 ]
[.01131 .27959 -30 -4.5 ]
[.01131 .27959 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .45617 -30 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .54446 -24 -4.5 ]
[.01131 .54446 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(10)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(15)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(20)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(25)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(30)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10301 m
.03006 .10301 L
s
[(0.025)] .01131 .10301 1 0 Mshowa
.02381 .1913 m
.03006 .1913 L
s
[(0.05)] .01131 .1913 1 0 Mshowa
.02381 .27959 m
.03006 .27959 L
s
[(0.075)] .01131 .27959 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.1)] .01131 .36788 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.125)] .01131 .45617 1 0 Mshowa
.02381 .54446 m
.03006 .54446 L
s
[(0.15)] .01131 .54446 1 0 Mshowa
.125 Mabswid
.02381 .03237 m
.02756 .03237 L
s
.02381 .05003 m
.02756 .05003 L
s
.02381 .06769 m
.02756 .06769 L
s
.02381 .08535 m
.02756 .08535 L
s
.02381 .12066 m
.02756 .12066 L
s
.02381 .13832 m
.02756 .13832 L
s
.02381 .15598 m
.02756 .15598 L
s
.02381 .17364 m
.02756 .17364 L
s
.02381 .20895 m
.02756 .20895 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24427 m
.02756 .24427 L
s
.02381 .26193 m
.02756 .26193 L
s
.02381 .29724 m
.02756 .29724 L
s
.02381 .3149 m
.02756 .3149 L
s
.02381 .33256 m
.02756 .33256 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .38554 m
.02756 .38554 L
s
.02381 .40319 m
.02756 .40319 L
s
.02381 .42085 m
.02756 .42085 L
s
.02381 .43851 m
.02756 .43851 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49148 m
.02756 .49148 L
s
.02381 .50914 m
.02756 .50914 L
s
.02381 .5268 m
.02756 .5268 L
s
.02381 .56212 m
.02756 .56212 L
s
.02381 .57977 m
.02756 .57977 L
s
.02381 .59743 m
.02756 .59743 L
s
.02381 .61509 m
.02756 .61509 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.05556 .60332 m
.0873 .50184 L
.11905 .41547 L
.15079 .34276 L
.18254 .28212 L
.21429 .23193 L
.24603 .19065 L
.27778 .15688 L
.30952 .12937 L
.34127 .10704 L
.37302 .08896 L
.40476 .07436 L
.43651 .0626 L
.46825 .05312 L
.5 .04551 L
.53175 .03939 L
.56349 .03449 L
.59524 .03055 L
.62698 .02739 L
.65873 .02487 L
.69048 .02284 L
.72222 .02122 L
.75397 .01992 L
.78571 .01888 L
.81746 .01805 L
.84921 .01738 L
.88095 .01685 L
.9127 .01642 L
.94444 .01608 L
.97619 .01581 L
s
0 1 0 r
.05556 .60332 m
.0873 .50184 L
.11905 .41547 L
.15079 .34276 L
.18254 .28212 L
.21429 .23193 L
.24603 .19065 L
.27778 .15688 L
.30952 .12937 L
.34127 .10704 L
.37302 .08896 L
.40476 .07436 L
.43651 .0626 L
.46825 .05312 L
.5 .04551 L
.53175 .03939 L
.56349 .03449 L
.59524 .03055 L
.62698 .02739 L
.65873 .02487 L
.69048 .02284 L
.72222 .02122 L
.75397 .01992 L
.78571 .01888 L
.81746 .01805 L
.84921 .01738 L
.88095 .01685 L
.9127 .01642 L
.94444 .01608 L
.97619 .01581 L
s
0 0 1 r
.05556 .60332 m
.0873 .50184 L
.11905 .41547 L
.15079 .34276 L
.18254 .28212 L
.21429 .23193 L
.24603 .19065 L
.27778 .15688 L
.30952 .12937 L
.34127 .10704 L
.37302 .08896 L
.40476 .07436 L
.43651 .0626 L
.46825 .05312 L
.5 .04551 L
.53175 .03939 L
.56349 .03449 L
.59524 .03055 L
.62698 .02739 L
.65873 .02487 L
.69048 .02284 L
.72222 .02122 L
.75397 .01992 L
.78571 .01888 L
.81746 .01805 L
.84921 .01738 L
.88095 .01685 L
.9127 .01642 L
.94444 .01608 L
.97619 .01581 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{554, 163},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008Z0000Xb000`400?l00000o`00003oo`3ooooo
0?ooob`0oooo003o0?ooool0oooo;03oool00?l0ooooo`3oool/0?ooo`00o`3ooooo0?ooob`0oooo
003o0?ooool0oooo;03oool00?l0ooooo`3oool/0?ooo`00AP3oool3000001l0oooo0`0000040?oo
o`800000703oool3000000<0oooo0`00000K0?ooo`D000000`3oool2000001/0oooo1@0000020?oo
o`<000007@3oool3000000@0oooo0P00003o0?ooobD0oooo00150?ooo`050000003oool0oooo0?oo
o`0000007`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001`0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000K0?ooo`060000003oool0oooo0000003oool000000`3oool0
0`000000oooo0?ooo`0I0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`00003o0?ooob@0oooo00190?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`00000L0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001`0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0M0?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0o`3ooolR0?ooo`00B@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000703oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0K0?ooo`8000000`3oool010000000oooo0?ooo`00
003o0?ooob@0oooo00150?ooo`@00000803oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000001`0oooo00@000000?ooo`3oool0oooo1000000K0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`00000J0?ooo`060000003oool0oooo0?ooo`000000oooo1000
000P0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0F@3oool3000001d0oooo
0`0000040?ooo`8000006`3oool3000000<0oooo0`00000I0?ooo`D000000`3oool2000001T0oooo
1@0000020?ooo`<000006P3oool3000000@0oooo0P00000B0?ooo`00A@3oool00`000000oooo0?oo
o`0P0?ooo`800000103oool010000000oooo0?ooo`00000K0?ooo`8000000`3oool00`000000oooo
0?ooo`0L0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000J0?oo
o`070000003oool0oooo0?ooo`000000oooo0000000O0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`00001J0?ooo`050000003oool0oooo0?ooo`0000007@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000001/0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`00000I0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0F
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000A0?ooo`00A@3o
ool5000001l0oooo00<000000?ooo`3oool00`3oool2000001d0oooo00@000000?ooo`3oool0oooo
1@00000K0?ooo`<00000103oool2000001`0oooo0`0000020?ooo`D00000703oool3000000@0oooo
0P00001O0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000K0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0J0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool0
0?l0ooooIP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000006`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01T0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0H0?ooo`8000000`3oool010000000oooo0?ooo`00000A0?ooo`00o`3o
oomR0?ooo`@000007P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001/0oooo
00@000000?ooo`3oool0oooo1000000I0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`00000H0?ooo`060000003oool0oooo0?ooo`000000oooo1000000M0?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool00?l0ooooHP3oool00`000000oooo
0?ooo`0N0?ooo`800000103oool010000000oooo0?ooo`00000J0?ooo`8000000`3oool00`000000
oooo0?ooo`0J0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000H
0?ooo`070000003oool0oooo0?ooo`000000oooo0000000L0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`00000A0?ooo`008`3ooooP000005h0oooo1@00000M0?ooo`03
0000003oool0oooo00<0oooo0P00000L0?ooo`040000003oool0oooo0?ooo`D000006@3oool30000
00@0oooo0P00000J0?ooo`<000000P3oool5000001T0oooo0`0000040?ooo`8000004P3oool002<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3V0?ooo`008`3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo0>H0oooo000S0?ooo`030000003oool0oooo0?l0oooo703o
ool00`000000oooo0?ooo`3V0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<00000
0?ooo`3oool0iP3oool002<0oooo00<000000?ooo`3oool0o`3ooolG0?oook8000009`000?l50000
0100oooo000S0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?ooo`04
0000003oool0oooo0?oooa`0003o0`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
01<0oooo000S0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`200?ooo`h0
003oF03oool002<0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo07T0oooo
1`000?mV0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooa`0oooo0P00001c0?ooo`L0003oK@3o
ool002<0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo06/0oooo1`000?md
0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0I@3oool60000
og/0oooo000S0?ooo`030000003oool0oooo0?l0oooo703oool2000006<0oooo0`000?n10?ooo`00
8`3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0GP3oool40000oh@0oooo
000S0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`1K0?ooo`<0003oR03o
ool002<0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo05P0oooo0`000?n;
0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooa`0oooo0P00001F0?ooo`<0003oSP3oool002<0
oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo05<0oooo0P000?nA0?ooo`00
8`3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0D@3oool20000oi<0oooo
000S0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`1>0?ooo`<0003oU@3o
ool002<0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`800000C@3oool20000oiP0oooo000S0?oo
o`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`1:0?ooo`80003oVP3oool002<0
oooo00<000000?ooo`3oool0o03oool2000000@0oooo00<000000?ooo`3oool00`3oool200000080
oooo1@0000020?ooo`<000001@3oool00`000000oooo0?ooo`180?ooo`80003oW03oool002<0oooo
00<000000?ooo`3oool0n`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0AP3oool20000oih0oooo000S0?ooo`030000003oool0oooo0?/0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool3000004@0oooo0P000?nP0?ooo`00403oool2000000@0oooo00@0
00000?ooo`3oool0oooo1@0000040?ooo`030000003oool0oooo0?/0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`120?ooo`80003oXP3oool000l0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?/0oooo00@00000
0?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`00
00000`0000050?ooo`030000003oool0oooo0440oooo00<0003o0?ooo`3oool0XP3oool000l0oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?/0
oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`000000203oool00`000000oooo0?ooo`0o0?ooo`80003oY@3oool000l0oooo00@00000
0?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`800000o@3oool2000000X0oooo0P00
00030?ooo`<000000P3oool5000000@0oooo0P00000o0?ooo`030000o`3oool0oooo0:D0oooo000?
0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo0:H0oooo
000?0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`0k0?ooo`80003oZ@3oool00100oooo
0P0000090?ooo`<000001@3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0
>P3oool00`000?l0oooo0?ooo`2Y0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooa`0oooo0P00
000j0?ooo`030000o`3oool0oooo0:X0oooo000S0?ooo`030000003oool0oooo0?l0oooo703oool0
0`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo0:/0oooo000S0?ooo`030000003oool0oooo
0?l0oooo703oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0oooo0:`0oooo000S0?ooo`03
0000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`0f0?ooo`030000o`3oool0oooo0:d0
oooo000S0?ooo`030000003oool0oooo0?l0oooo703oool2000003H0oooo00<0003o0?ooo`3oool0
[P3oool002<0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo03D0oooo00<0
003o0?ooo`3oool0[P3oool002<0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0
oooo03@0oooo00<0003o0?ooo`3oool0[`3oool002<0oooo00<000000?ooo`3oool0o`3ooolL0?oo
o`030000003oool0oooo03<0oooo00<0003o0?ooo`3oool0/03oool002<0oooo00<000000?ooo`3o
ool0o`3ooolL0?ooo`800000<`3oool00`000?l0oooo0?ooo`2a0?ooo`008`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<00000
1@3oool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0oooo0;80oooo000S0?ooo`030000003o
ool0oooo0?l0oooo0P3oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003o
ool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0300oooo00<0003o0?oo
o`3oool0/`3oool002<0oooo00<000000?ooo`3oool0o`3oool20?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo02l0oooo00<0003o0?ooo`3oool0]03oool002<0oooo00<000000?ooo`3oool0o`3oool20?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`020?ooo`<00000;P3oool00`000?l0oooo0?ooo`2e0?ooo`008`3oool00`000000oooo0?ooo`3o
0?ooo`80oooo00@000000?ooo`3oool00000203oool01@000000oooo0?ooo`000000oooo00@00000
1@3oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo0;D0oooo000S0?ooo`030000003o
ool0oooo0?l0oooo0P3oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003o
ool00000203oool00`000000oooo0?ooo`0]0?ooo`030000o`3oool0oooo0;H0oooo000S0?ooo`03
0000003oool0oooo0?l0oooo0`3oool2000000X0oooo0P0000020?ooo`D00000103oool00`000000
oooo0?ooo`0/0?ooo`030000o`3oool0oooo0;L0oooo000S0?ooo`030000003oool0oooo0?l0oooo
703oool2000002`0oooo00<0003o0?ooo`3oool0^03oool002<0oooo00<000000?ooo`3oool0o`3o
oolL0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0^@3oool002<0oooo00<00000
0?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0^@3oool0
02<0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo02T0oooo00<0003o0?oo
o`3oool0^P3oool002<0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`800000:@3oool00`000?l0
oooo0?ooo`2k0?ooo`00403oool2000000@0oooo00<000000?ooo`3oool00`3oool3000000@0oooo
00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0
_03oool000l0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0;`0oooo
000?0?ooo`040000003oool0oooo000000L0oooo1@0000040?ooo`800000o`3ooolM0?ooo`800000
9`3oool00`000?l0oooo0?ooo`2m0?ooo`003`3oool010000000oooo0?ooo`0000070?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo02D0
oooo00<0003o0?ooo`3oool0_P3oool000l0oooo00@000000?ooo`3oool00000203oool00`000000
oooo000000050?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`0U0?ooo`03
0000o`3oool0oooo0;h0oooo000?0?ooo`040000003oool0oooo000000T0oooo0P0000050?ooo`03
0000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0;l0
oooo000@0?ooo`8000002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo
703oool2000002@0oooo00<0003o0?ooo`3oool0`03oool002<0oooo00<000000?ooo`3oool0o`3o
oolL0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool0`03oool002<0oooo00<00000
0?ooo`3oool0o03oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo00<00000
0?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`31
0?ooo`008`3oool00`000000oooo0?ooo`3k0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0<40oooo000S0?ooo`030000003o
ool0oooo0?/0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool300000240oooo00<0003o0?ooo`3o
ool0`P3oool002<0oooo00<000000?ooo`3oool0n`3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0``3oool002<0oooo00<000000?ooo`3o
ool0n`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`0000000`0000050?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0``3oool0
02<0oooo00<000000?ooo`3oool0n`3oool010000000oooo0?ooo`0000080?ooo`060000003oool0
oooo0000003oool000000`3oool00`000000oooo000000080?ooo`030000003oool0oooo01l0oooo
00<0003o0?ooo`3oool0a03oool002<0oooo00<000000?ooo`3oool0o03oool2000000X0oooo0P00
00020?ooo`D0000000<0oooo0000000000000`0000040?ooo`800000803oool00`000?l0oooo0?oo
o`340?ooo`008`3oool00`000000oooo0?ooo`040?ooo`800000o`3ooolF0?ooo`030000003oool0
oooo01h0oooo00<0003o0?ooo`3oool0a@3oool002<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`350?oo
o`008`3oool00`000000oooo0?ooo`070?ooo`800000o`3ooolC0?ooo`030000003oool0oooo01d0
oooo00<0003o0?ooo`3oool0aP3oool002<0oooo00<000000?ooo`3oool02@3oool200000?l0oooo
4@3oool2000001d0oooo00<0003o0?ooo`3oool0a`3oool002<0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`3o0?ooo`h0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?oo
o`370?ooo`008`3oool00`000000oooo0?ooo`0;0?ooo`/00000o`3oool60?ooo`030000003oool0
oooo01/0oooo00<0003o0?ooo`3oool0b03oool002<0oooo00<000000?ooo`3oool02P3oool01000
0000oooo0?ooo`0000080?ooo`<00000o`3oool30?ooo`030000003oool0oooo01/0oooo00<0003o
0?ooo`3oool0b03oool002<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?oo
o`<00000o`3oool2000001/0oooo00<0003o0?ooo`3oool0b@3oool002<0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0A0?ooo`<00000o03oool00`000000oooo0?ooo`0J0?ooo`03
0000o`3oool0oooo0<T0oooo000S0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
5@3oool300000?T0oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`3:0?ooo`008`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo0P00003g0?ooo`030000003o
ool0oooo01T0oooo00<0003o0?ooo`3oool0bP3oool002<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0?0?ooo`<000002P3oool300000?@0oooo0P00000I0?ooo`030000o`3oool0
oooo0</0oooo000@0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo0P00000;0?ooo`800000g`3oool20000
00@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0603oool00`00
0?l0oooo0?ooo`3;0?ooo`003`3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo0`00000:
0?ooo`800000g03oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool05`3oool00`000?l0oooo0?ooo`3<0?ooo`003`3oool010000000oooo0?ooo`00
00070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01P0oooo0`0000090?ooo`<00000f@3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`3<0?ooo`00
3`3oool010000000oooo0?ooo`0000070?ooo`@000001@3oool2000000D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`090?ooo`<00000eP3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00@0oooo0`00000G0?ooo`030000o`3oool0oooo0<`0oooo000?0?ooo`04
0000003oool0oooo000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo02X0oooo0`00003C0?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo0<d0oooo000?0?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02h0oooo0`00003@0?ooo`040000003oool0oooo000000P0oooo0P00
00060?ooo`030000003oool0oooo01H0oooo00<0003o0?ooo`3oool0c@3oool00100oooo0P00000:
0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02H0oooo10000007
0?ooo`@00000c@3oool2000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E
0?ooo`030000o`3oool0oooo0<h0oooo000S0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0:P3oool4000000L0oooo1000003L0?ooo`8000005P3oool00`000?l0oooo0?ooo`3>0?oo
o`008`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02h0oooo0`0000080?ooo`@0
0000f03oool00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo0<l0oooo000S0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`090?ooo`<00000
e@3oool00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo0<l0oooo000S0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0@03oool600000<l0oooo00<000000?ooo`3oool0503o
ool00`000?l0oooo0?ooo`3?0?ooo`008`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo03`0oooo2@0000000`3oool000000000000500000<P0oooo0P00000D0?ooo`030000o`3oool0
oooo0=00oooo000S0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool30000
00D0oooo200000300?ooo`030000003oool0oooo01<0oooo00<0003o0?ooo`3oool0d03oool002<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1C0?oooa800000/@3oool00`000000
oooo0?ooo`0B0?ooo`030000o`3oool0oooo0=40oooo000S0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0E`3oool8000000H0oooo5P00002K0?ooo`030000003oool0oooo0180oooo
00<0003o0?ooo`3oool0d@3oool002<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1^0?ooo`P000001@3ooold000006L0oooo0P00000B0?ooo`030000o`3oool0oooo0=80oooo000S
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0W`3oool3000000X0oooo;000000n
0?ooo`030000003oool0oooo0140oooo00<0003o0?ooo`3oool0dP3oool002<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3o0?oooaL0oooo00<000000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`3B0?ooo`008`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0
oooo5`3oool200000140oooo00<0003o0?ooo`3oool0d`3oool002<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`3o0?oooaL0oooo00<000000?ooo`3oool0403oool00`000?l0oooo
0?ooo`3C0?ooo`008`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?L0oooo0P00
00040?ooo`030000003oool0oooo0080oooo0`0000020?ooo`D000000P3oool3000000D0oooo00<0
00000?ooo`3oool0403oool00`000?l0oooo0?ooo`3C0?ooo`008`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0?H0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`020?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00l0oooo00<0003o0?ooo`3oool0e03oool002<0oooo00D000000?ooo`3oool0
oooo0000003i0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0`00000?0?ooo`030000o`3oool0oooo
0=@0oooo000S0?ooo`050000003oool0oooo0?ooo`000000n@3oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00h0oooo00<0003o0?ooo`3oool0e@3oool002<0oooo00D000000?oo
o`3oool0oooo0000003i0?ooo`040000003oool0oooo000000T0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0000000<000001@3oool00`000000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo0=D0oooo000S0?ooo`050000003oool0oooo0?ooo`000000n@3oool010000000oooo
0?ooo`0000080?ooo`8000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000203oool0
0`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo0=D0oooo000S0?ooo`050000003oool0oooo
0?ooo`000000nP3oool2000000X0oooo00<000000?ooo`3oool00P3oool300000080oooo1@000004
0?ooo`8000003P3oool00`000?l0oooo0?ooo`3F0?ooo`008`3oool01@000000oooo0?ooo`3oool0
00000?l0oooo6P3oool00`000000oooo0?ooo`0=0?ooo`030000o`3oool0oooo0=H0oooo000@0?oo
o`800000103oool00`000000oooo0?ooo`020?ooo`<000001@3oool01@000000oooo0?ooo`3oool0
00000?l0oooo6P3oool00`000000oooo0?ooo`0=0?ooo`030000o`3oool0oooo0=H0oooo000?0?oo
o`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`000000o`3ooolJ0?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`3oool0
e`3oool000l0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000@0
oooo0P0000000`3oool000000?ooo`3o0?oooaX0oooo0P00000=0?ooo`030000o`3oool0oooo0=L0
oooo000?0?ooo`040000003oool0oooo000000P0oooo0`0000050?ooo`040000003oool0oooo0000
0?l0oooo6`3oool00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo0=L0oooo000?0?ooo`04
0000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0
oooo00000?l0oooo6`3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo0=P0oooo000?
0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000
003oool0oooo000000<0oooo0P3o003o0?oooaH0oooo00<000000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`3H0?ooo`00403oool2000000T0oooo0`0000050?ooo`040000003oool0oooo000000D0
oooo0P3o003o0?oooa@0oooo0P00000<0?ooo`030000o`3oool0oooo0=P0oooo000S0?ooo`040000
003oool0oooo000000L0oooo0P3o003o0?oooa80oooo00<000000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`3I0?ooo`008`3oool010000000oooo0?ooo`0000090?ooo`80o`00o`3oool@0?ooo`03
0000003oool0oooo00X0oooo00<0003o0?ooo`3oool0f@3oool002<0oooo00@000000?ooo`3oool0
00002`3oool20?l00?l0oooo3P3oool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0=T0
oooo000S0?ooo`030000003oool0000000h0oooo0`3o003o0?ooo`/0oooo0P00000:0?ooo`030000
o`3oool0oooo0=X0oooo000S0?ooo`030000003oool000000140oooo0P3o003_0?ooo`800000103o
ool00`000000oooo0?ooo`020?ooo`<000000`3oool3000000D0oooo00<000000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`3J0?ooo`008`3oool00`000000oooo0000000C0?ooo`80o`00k03oool0
10000000oooo0?ooo`0000090?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool0fP3oool002<0oooo00<0
00000?ooo`0000005@3oool30?l00>T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000?l0oooo
0?ooo`3K0?ooo`008`3oool00`000000oooo0000000H0?ooo`80o`00i`3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool3000000P0oooo
00<0003o0?ooo`3oool0f`3oool002<0oooo00<000000?ooo`0000006P3oool20?l00>D0oooo00@0
00000?ooo`3oool000002@3oool010000000oooo0?ooo`3oool4000000D0oooo00<000000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`3K0?ooo`008`3oool00`000000oooo0000000L0?ooo`<0o`00
hP3oool010000000oooo0?ooo`0000080?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<0003o0?ooo`3oool0g03oool002<0oooo00<000000?ooo`000000
7`3oool30?l00>00oooo0P00000:0?ooo`040000003oool0oooo0?ooo`D00000103oool00`000000
oooo0?ooo`070?ooo`030000o`3oool0oooo0=`0oooo000S0?ooo`030000003oool000000280oooo
0`3o003f0?ooo`800000203oool00`000?l0oooo0?ooo`3L0?ooo`008`3oool2000002H0oooo0`3o
003c0?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool0g03oool002<0oooo0P00000Y
0?ooo`@0o`00k`3oool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo0=d0oooo000S0?oo
o`800000;@3oool40?l00>/0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`3M0?oo
o`008`3oool200000340oooo103o003W0?ooo`8000001`3oool00`000?l0oooo0?ooo`3M0?ooo`00
8`3oool2000003D0oooo0`3o003T0?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool0
gP3oool002<0oooo0P00000h0?ooo`H0o`00gP3oool00`000000oooo0?ooo`050?ooo`030000o`3o
ool0oooo0=h0oooo000S0?ooo`800000?P3oool80?l00=H0oooo00<000000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`3N0?ooo`008`3oool2000004H0oooo1`3o003?0?ooo`8000001@3oool00`00
0?l0oooo0?ooo`3O0?ooo`008`3oool00`000000oooo0?ooo`1<0?ooo`l0o`00`03oool00`000000
oooo0?ooo`040?ooo`030000o`3oool0oooo0=l0oooo000K0?ooo`<000001@3oool00`000000oooo
0?ooo`1K0?ooo`l0o`00/@3oool00`000000oooo0?ooo`3V0?ooo`00703oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo06X0oooo9@3o002<0?ooo`030000003oool0oooo0>H0oooo000L
0?ooo`030000003oool0oooo00@0oooo0P00002@0?ooodh0o`00?P3oool200000>L0oooo000L0?oo
o`030000003oool0oooo0?l0ooooo`3oool=0?ooo`00703oool00`000000oooo0?ooo`3o0?ooool0
oooo3@3oool001/0oooo0P00003o0?ooool0oooo3`3oool001`0oooo00<000000?ooo`3oool0o`3o
oooo0?ooo`d0oooo003o0?ooool0oooo;03oool00?l0ooooo`3oool/0?ooo`00o`3ooooo0?ooob`0
oooo003o0?ooool0oooo;03oool00001\
\>"],
  ImageRangeCache->{{{0, 553}, {162, 0}} -> {-0.0548581, -0.0147182, \
0.00381504, 0.00381504}, {{14.375, 264}, {158.125, 3.8125}} -> {-4.73372, \
-0.114826, 0.134628, 0.00726106}, {{288.938, 538.562}, {158.125, 3.8125}} -> \
{-45.7716, -0.0257426, 0.142278, 0.00127894}}]
}, Open  ]],

Cell[TextData[{
  "Initially, ",
  StyleBox["mean fitness",
    FontColor->RGBColor[1, 0, 0]],
  " is low, because deleterious alleles are present at the three loci.  \
Population size therefore decreases to a minimum of ~0.4.  As the deleterious \
alleles are eliminated, ",
  StyleBox["mean fitness",
    FontColor->RGBColor[1, 0, 0]],
  " increases, and population size increases to its equilibrium value of \
0.7."
}], "Text"],

Cell[TextData[{
  "In this example, the recursion for deme size is given by ",
  "ExponentialF[2,1,1]",
  ", which represents ",
  Cell[BoxData[
      \(TraditionalForm\`\(n\^*\) = 
        2  n\ Exp[\(-n\)]\ \(\(W\&_\)\(.\)\(\ \)\)\)]],
  "The equilibrium density is ",
  Cell[BoxData[
      \(TraditionalForm\`n = Log[2  W\&_]\ for\ W\&_ > 1\/2; \ 
      if\ W\&_ < 1\/2, \ the\ population\ goes\ \(\(extinct\)\(.\)\)\)]],
  "  In this example, the population density soon approaches a \
quasi-equilibrium of ",
  Cell[BoxData[
      \(TraditionalForm\`n = Log[2  W\&_]\)]],
  " (dashed line)."
}], "Text"],

Cell[TextData[{
  "The option DemeSize->F is passed to ",
  ButtonBox["NewGametes",
    ButtonData:>{"Symmetric model: recursions", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ", which changes deme size accordingly.  Note that deme size is assumed to \
remain constant through meiosis and random union, but changes as a result of \
",
  ButtonBox["migration",
    ButtonData:>{"Symmetric model: migration", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text"],

Cell[TextData[{
  "When ",
  ButtonBox["compiled",
    ButtonData:>{"Symmetric model:iterating one deme", "Compiling"},
    ButtonStyle->"AddOnsLink"],
  " code is used, only certain settings for F can be used."
}], "Text",
  CellTags->"Deme size (compiling)"],

Cell[TextData[{
  "The logistic model ",
  Cell[BoxData[
      \(TraditionalForm\`f[n, W\&_] = 
        n + r\[VeryThinSpace]\(n(1 - n\/K)\)\)]],
  " should be avoided,because in discrete time, it can lead to negative \
population sizes."
}], "Text"],

Cell[TextData[{
  StyleBox["Note: ",
    FontWeight->"Bold"],
  " In ",
  ButtonBox["MigrateExact",
    ButtonData:>{"Symmetric model: migration", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ", m denotes the fraction of the population thatmigrates: it is the forward \
migration rate.  The deme size after migration is ",
  Cell[BoxData[
      \(TraditionalForm\`\(n\^*\) m + n(1 - m), \ 
      and\ the\ proportion\ of\ immigrants\ is\ \(\(n\^*\) m\)\/\(\(n\^*\) m \
+ n(1 - m)\)\)]],
  "; this increases as deme size, n, decreases.  "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The life cycle", "SubsubsectionIcon",
  CellTags->"Life cycle"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(\(\ \)\(IterateExact[\[Psi], W, m, 
              MigrationOrder \[Rule] 
                UMS]\)\), \(represents\ the\ default\ order\ of\ events\ \
random\ union \[Rule] \(migration \[Rule] \(selection \[Rule] 
                  meiosis . \ \ \n
                      Regulation\ of\ population\ size\ always\ occurs\ \
immediately\ after\ \(\(selection\)\(.\)\)\)\)\)},
          {\(\(\ \)\(IterateExact[\[Psi], W, m, 
              MigrationOrder \[Rule] 
                MUS]\)\), \(\(represents\ migration\)\(\[Rule]\)\(random\ \
union \[Rule] \(selection \[Rule] \(\(meiosis\)\(.\)\)\)\)\(\ \)\)},
          {\(\(\ \)\(IterateExact[\[Psi], W, m, 
              MigrationOrder \[Rule] 
                USM]\)\), \(represents\ random\ union \[Rule] \(selection \
\[Rule] \(migration \[Rule] \(\(meiosis\)\(.\)\)\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}],

Cell["\<\
The default order of events in the life cycle is MigrationOrder\
\[Rule]UMS, representing random union of gametes\[Rule]diploid migration\
\[Rule]selection\[Rule]meiosis.  For a single deme with immigration from a \
population \[Psi]s, this is implemented by:\
\>", "Text"],

Cell[BoxData[
    \(NewGametes[
      MigrateExact[MakeDiploid[SymmetricHaploidFrequencies[\[Psi], nd]], 
        MakeDiploid[\[Psi]s], m], W, opts]\)], "Input"],

Cell["\<\
In this example, there are 3 loci with 10% selection aaginst '1' \
alleles, balanced by immigration of m=0.05:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pop0 = 
        MakePopulation[3, 0, 
          NumericalModel \[Rule] 
            SymmetricHaploidFrequencies];\)\), "\[IndentingNewLine]", 
    \(\(ppUMS = 
        Nest[IterateExact[#, 0.9\^\(#1 + #2\) &, 0.05] &, pop0, 
          100];\)\), "\[IndentingNewLine]", 
    \({AlleleFrequencyMean[ppUMS], DisequilibriumMean[ppUMS]}\)}], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \({0.23842150867099912`, 0.03163175544016109`}\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell["\<\
MigrationOrder\[Rule]MUS represents haploid migration\[Rule]random \
union of gametes\[Rule]selection\[Rule]meiosis.  For a single deme with \
immigration from a population fixed for '1' alleles, this is implemented \
by:\
\>", "Text"],

Cell[BoxData[
    \(\(\(\ \ \)\(NewGametes[
      MakeDiploid[
        MigrateExact[SymmetricHaploidFrequencies[\[Psi], nd], \[Psi]s, m]], 
      W, opts]\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ppMUS = 
        Nest[IterateExact[#, 0.9\^\(#1 + #2\) &, 0.05, 
              MigrationOrder \[Rule] MUS] &, pop0, 
          100];\)\), "\[IndentingNewLine]", 
    \({AlleleFrequencyMean[ppMUS], DisequilibriumMean[ppMUS]}\)}], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({0.3658278205113204`, 0.015429956791798224`}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell["\<\
With strong selection (s=10% on each of 3 loci), this leads to a \
substantially higher equilibrium frequency than \
MigrationOrder\[Rule]UMS.\
\>", "Text"],

Cell["\<\
MigrationOrder\[Rule]USM represents random union of \
gametes\[Rule]selection\[Rule]diploid migration\[Rule]meiosis.  For a single \
deme with immigration from a population fixed for '1' alleles, this is \
implemented by:\
\>", "Text"],

Cell[BoxData[
    \(MigrateExact[
      NewGametes[MakeDiploid[SymmetricHaploidFrequencies[\[Psi], nd]], W, 
        opts], \[Psi]s, m]\)], "Input"],

Cell["\<\
Note that this really implements random union of \
gametes\[Rule]selection\[Rule]meiosis\[Rule]haploid migration.  However, the \
two are equivalent, since migration is a linear process.  With strong \
selection (s=10% on each of 3 loci), this leads to a slightly higher \
equilibrium frequency than MigrationOrder\[Rule]MUS, and much stronger \
disequilibrium.  This is because the final step was migration, rather than \
selection:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ppUSM = 
        Nest[IterateExact[#, 0.9\^\((#1 + #2)\) &, 0.05, 
              MigrationOrder \[Rule] USM] &, pop0, 
          100];\)\), "\[IndentingNewLine]", 
    \({AlleleFrequencyMean[ppUSM], DisequilibriumMean[ppUSM]}\)}], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({0.39749432198123963`, 0.033766083010965176`}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Compiling", "SubsubsectionIcon",
  CellTags->"Compiling"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, m, 
              Compiled \[Rule] 
                True]\), \(uses\ compiled\ codeto\ iterate\ one\ \
generation\)},
          {
            RowBox[{"StoreExact", "[", 
              RowBox[{"\[Psi]", ",", \(\[Psi]\_0\), ",", "W", ",", "m", ",", 
                RowBox[{"{", 
                  RowBox[{"t", ",", 
                    StyleBox["dt",
                      FontSlant->"Italic"]}], 
                  StyleBox["}",
                    FontSlant->"Italic"]}], 
                StyleBox[",",
                  FontSlant->"Italic"], \(Compiled \[Rule] True\)}], 
              "]"}], \(uses\ compiled\ code\ to\ store\ results\ for\ t\ \
generations\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->"Compiled"],

Cell[TextData[{
  "Functions can be greatly speeded by ",
  ButtonBox["compiling",
    ButtonData:>{"Compile"},
    ButtonStyle->"RefGuideLink"],
  ".  This requires that only numbers, or rectangular arrays of numbers, are \
used internally.  However, an arbitrary fitness function can still be \
supplied.  This is used to calculate and store a table of fitnesses, which is \
then used by the compiled code. "
}], "Text"],

Cell["Other options can be set as for uncompiled code.", "Text"],

Cell[TextData[{
  ButtonBox["Note",
    ButtonData:>{"Potential problems", "Redefining fitness"},
    ButtonStyle->"AddOnsLink"],
  StyleBox[":",
    FontWeight->"Bold"],
  "  Compilation cannot be used if fitnesses change in every generation.  The \
option ",
  ButtonBox["StoreResults",
    ButtonData:>{"Symmetric model: recursions", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  "->False should also be set, to prevent all the fitness tables being \
stored."
}], "Text",
  CellTags->"StoreResults (compiling)"],

Cell["\<\
In this example,using compiled code speeds calculations by about \
fourfold:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hp = 
        MakePopulation[3, 0, 100, 
          NumericalModel \[Rule] SymmetricHaploidFrequencies];\)\), "\n", 
    \(\(\(w[\[Sigma]_]\)[i_, j_, h_] := 
        1 + \[Sigma] \((i + j - 3)\);\)\), "\n", 
    \({Timing[
          StoreExact[pop[\(-0.1\), 0.1, hp], hp, w[\(-0.1\)], 
            0.1, {300, 10}]; \[IndentingNewLine]\(pop[\(-0.1\), 0.1, hp]\)[
            300]], \[IndentingNewLine]Timing[
          StoreExact[pop[\(-0.1\), 0.1, hp], hp, w[\(-0.1\)], 0.1, {300, 10}, 
            Compiled \[Rule] True]; \[IndentingNewLine]\(pop[\(-0.1\), 0.1, 
              hp]\)[300]]} // TableForm\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\(4.383333333333333`\ Second\), \
\(SymmetricHaploidFrequencies[{0.046756980600699424`, 0.22215225408202`, 
                0.38517905786383033`, 0.34591170745345035`}, 100.`]\)},
          {\(0.9666666666666686`\ Second\), \
\(SymmetricHaploidFrequencies[{0.046756980600699403`, 0.22215225408201988`, 
                0.3851790578638303`, 0.34591170745345035`}, 100.`]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[4]//TableForm="]
}, Open  ]],

Cell["\<\
This checks thatn the compiled code gives the same results as \
uncompiled code for other life cycles:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hp = 
        MakePopulation[3, 0, 100, 
          NumericalModel \[Rule] SymmetricHaploidFrequencies];\)\), "\n", 
    \(\(w[\[Sigma]_]\)[i_, j_, h_] := 
      1 + \[Sigma] \((i + j - 3)\); \), "\n", 
    \({Timing[
          StoreExact[pop[\(-0.1\), 0.1, hp], hp, w[\(-0.1\)], 0.1, {300, 10}, 
            MigrationOrder \[Rule] MUS]; \[IndentingNewLine]\(pop[\(-0.1\), 
              0.1, hp]\)[300]], \[IndentingNewLine]Timing[
          StoreExact[pop[\(-0.1\), 0.1, hp], hp, w[\(-0.1\)], 0.1, {300, 10}, 
            Compiled \[Rule] True, 
            MigrationOrder \[Rule] MUS]; \[IndentingNewLine]\(pop[\(-0.1\), 
              0.1, hp]\)[300]]} // TableForm\)}], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\(3.86666666666666`\ Second\), \
\(SymmetricHaploidFrequencies[{0.009477242153970977`, 0.09840407274464914`, 
                0.3665583089333623`, 0.5255603761680175`}, 100.`]\)},
          {\(0.9500000000000028`\ Second\), \
\(SymmetricHaploidFrequencies[{0.009477242153970963`, 0.09840407274464907`, 
                0.36655830893336216`, 0.5255603761680178`}, 100.`]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[8]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[
          StoreExact[pop[\(-0.1\), 0.1, hp], hp, w[\(-0.1\)], 0.1, {300, 10}, 
            MigrationOrder \[Rule] USM]; \[IndentingNewLine]\(pop[\(-0.1\), 
              0.1, hp]\)[300]], \[IndentingNewLine]Timing[
          StoreExact[pop[\(-0.1\), 0.1, hp], hp, w[\(-0.1\)], 0.1, {300, 10}, 
            Compiled \[Rule] True, 
            MigrationOrder \[Rule] USM]; \[IndentingNewLine]\(pop[\(-0.1\), 
              0.1, hp]\)[300]]} // TableForm\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\(3.9166666666666856`\ Second\), \
\(SymmetricHaploidFrequencies[{0.008529840969526678`, 0.08856557703841038`, 
                0.3299044102882033`, 0.5730001717038599`}, 100.`]\)},
          {\(0.9833333333333201`\ Second\), \
\(SymmetricHaploidFrequencies[{0.008529840969526654`, 0.08856557703841021`, 
                0.329904410288203`, 0.5730001717038602`}, 100.`]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[7]//TableForm="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{875, 698},
WindowMargins->{{24, Automatic}, {Automatic, 0}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "IterateExact"->{
    Cell[2043, 64, 991, 21, 88, "DefinitionBox",
      CellTags->{"IterateExact", "StoreExact"}],
    Cell[39872, 1104, 484, 10, 56, "DefinitionBox",
      CellTags->"IterateExact"]},
  "StoreExact"->{
    Cell[2043, 64, 991, 21, 88, "DefinitionBox",
      CellTags->{"IterateExact", "StoreExact"}]},
  "DemeSize"->{
    Cell[68284, 1821, 817, 16, 108, "DefinitionBox",
      CellTags->"DemeSize"]},
  "Deme size (compiling)"->{
    Cell[106897, 2959, 260, 7, 23, "Text",
      CellTags->"Deme size (compiling)"]},
  "Life cycle"->{
    Cell[108001, 2996, 69, 1, 24, "SubsubsectionIcon",
      CellTags->"Life cycle"]},
  "MigrationOrder"->{
    Cell[108073, 2999, 990, 18, 90, "DefinitionBox",
      CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}]},
  "UMS"->{
    Cell[108073, 2999, 990, 18, 90, "DefinitionBox",
      CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}]},
  "MUS"->{
    Cell[108073, 2999, 990, 18, 90, "DefinitionBox",
      CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}]},
  "USM"->{
    Cell[108073, 2999, 990, 18, 90, "DefinitionBox",
      CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}]},
  "Compiling"->{
    Cell[112539, 3128, 63, 1, 20, "SubsubsectionIcon",
      CellTags->"Compiling"]},
  "Compiled"->{
    Cell[112605, 3131, 870, 21, 56, "DefinitionBox",
      CellTags->"Compiled"]},
  "StoreResults (compiling)"->{
    Cell[113970, 3167, 519, 14, 24, "Text",
      CellTags->"StoreResults (compiling)"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"IterateExact", 190012, 5860},
  {"StoreExact", 190214, 5865},
  {"DemeSize", 190329, 5868},
  {"Deme size (compiling)", 190441, 5871},
  {"Life cycle", 190545, 5874},
  {"MigrationOrder", 190654, 5877},
  {"UMS", 190777, 5880},
  {"MUS", 190900, 5883},
  {"USM", 191023, 5886},
  {"Compiling", 191152, 5889},
  {"Compiled", 191254, 5892},
  {"StoreResults (compiling)", 191369, 5895}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 44, 0, 36, "SubsectionIcon"],
Cell[1786, 53, 82, 1, 28, "MathCaption"],
Cell[1871, 56, 102, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[1998, 62, 42, 0, 24, "SubsubsectionIcon"],
Cell[2043, 64, 991, 21, 88, "DefinitionBox",
  CellTags->{"IterateExact", "StoreExact"}],
Cell[3037, 87, 129, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3191, 94, 417, 9, 76, "Input"],
Cell[3611, 105, 30171, 848, 184, 10349, 598, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[33797, 956, 189, 4, 22, "Text"],
Cell[33989, 962, 116, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[34130, 969, 132, 3, 26, "Input"],
Cell[34265, 974, 87, 2, 20, "Output"]
}, Open  ]],
Cell[34367, 979, 106, 3, 28, "MathCaption"],
Cell[34476, 984, 120, 3, 26, "Input"],

Cell[CellGroupData[{
Cell[34621, 991, 64, 2, 26, "Input"],
Cell[34688, 995, 75, 2, 20, "Print"],
Cell[34766, 999, 4750, 87, 526, "Print"]
}, Closed]],
Cell[39531, 1089, 102, 3, 18, "Text"],
Cell[39636, 1094, 142, 3, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[39815, 1102, 54, 0, 20, "SubsubsectionIcon"],
Cell[39872, 1104, 484, 10, 56, "DefinitionBox",
  CellTags->"IterateExact"],
Cell[40359, 1116, 194, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[40578, 1124, 613, 13, 90, "Input"],
Cell[41194, 1139, 21752, 544, 184, 4748, 329, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[62961, 1686, 120, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[63106, 1693, 208, 4, 26, "Input"],
Cell[63317, 1699, 206, 4, 20, "Output"]
}, Open  ]],
Cell[63538, 1706, 104, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[63667, 1713, 429, 8, 74, "Input"],
Cell[64099, 1723, 306, 5, 20, "Output"]
}, Open  ]],
Cell[64420, 1731, 167, 4, 22, "Text"],
Cell[64590, 1737, 554, 14, 40, "Text"],
Cell[65147, 1753, 76, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[65248, 1757, 277, 5, 42, "Input"],
Cell[65528, 1764, 2478, 42, 191, "Output"]
}, Open  ]],
Cell[68021, 1809, 177, 5, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[68235, 1819, 46, 0, 20, "SubsubsectionIcon"],
Cell[68284, 1821, 817, 16, 108, "DefinitionBox",
  CellTags->"DemeSize"],
Cell[69104, 1839, 142, 3, 28, "MathCaption"],
Cell[69249, 1844, 357, 7, 58, "Input"],
Cell[69609, 1853, 67, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[69701, 1857, 945, 20, 117, "Input"],
Cell[70649, 1879, 34714, 1032, 169, 9856, 720, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[105378, 2914, 430, 11, 36, "Text"],
Cell[105811, 2927, 608, 16, 64, "Text"],
Cell[106422, 2945, 472, 12, 38, "Text"],
Cell[106897, 2959, 260, 7, 23, "Text",
  CellTags->"Deme size (compiling)"],
Cell[107160, 2968, 250, 7, 34, "Text"],
Cell[107413, 2977, 551, 14, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[108001, 2996, 69, 1, 24, "SubsubsectionIcon",
  CellTags->"Life cycle"],
Cell[108073, 2999, 990, 18, 90, "DefinitionBox",
  CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}],
Cell[109066, 3019, 283, 5, 36, "Text"],
Cell[109352, 3026, 161, 3, 27, "Input"],
Cell[109516, 3031, 141, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[109682, 3038, 393, 9, 57, "Input"],
Cell[110078, 3049, 103, 2, 20, "Output"]
}, Open  ]],
Cell[110196, 3054, 245, 5, 36, "Text"],
Cell[110444, 3061, 171, 4, 27, "Input"],

Cell[CellGroupData[{
Cell[110640, 3069, 285, 6, 43, "Input"],
Cell[110928, 3077, 103, 2, 20, "Output"]
}, Open  ]],
Cell[111046, 3082, 166, 4, 22, "Text"],
Cell[111215, 3088, 245, 5, 36, "Text"],
Cell[111463, 3095, 148, 3, 27, "Input"],
Cell[111614, 3100, 457, 8, 50, "Text"],

Cell[CellGroupData[{
Cell[112096, 3112, 287, 6, 47, "Input"],
Cell[112386, 3120, 104, 2, 20, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[112539, 3128, 63, 1, 20, "SubsubsectionIcon",
  CellTags->"Compiling"],
Cell[112605, 3131, 870, 21, 56, "DefinitionBox",
  CellTags->"Compiled"],
Cell[113478, 3154, 422, 9, 37, "Text"],
Cell[113903, 3165, 64, 0, 22, "Text"],
Cell[113970, 3167, 519, 14, 24, "Text",
  CellTags->"StoreResults (compiling)"],
Cell[114492, 3183, 107, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[114624, 3190, 663, 13, 102, "Input"],
Cell[115290, 3205, 621, 14, 47, "Output"]
}, Open  ]],
Cell[115926, 3222, 133, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[116084, 3229, 729, 14, 102, "Input"],
Cell[116816, 3245, 621, 14, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[117474, 3264, 517, 9, 72, "Input"],
Cell[117994, 3275, 621, 14, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

