(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     72905,       1616]*)
(*NotebookOutlinePosition[    142854,       4158]*)
(*  CellTagsIndexPosition[    142712,       4150]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Iterating a cline", "SubsectionIcon"],

Cell["This loads this package, as well as the Graphics package:", \
"MathCaption"],

Cell[BoxData[
    \(<< NumericalModels`ExactModel`; << Graphics`;\)], "Input",
  CellLabel->"In[2]:="],

Cell[CellGroupData[{

Cell["A simple example", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, 
              m]\), \(iterates\ a\ cline; \ \ \[Psi]\ represents\ a\ list\ of\
\ haploid\ \(\(populations\)\(.\)\)\)},
          {
            RowBox[{"StoreExact", "[", 
              RowBox[{"\[Psi]", ",", \(\[Psi]\_0\), ",", "W", ",", "m", ",", 
                RowBox[{"{", 
                  RowBox[{"t", ",", 
                    StyleBox["dt",
                      FontSlant->"Italic"]}], 
                  StyleBox["}",
                    FontSlant->"Italic"]}]}], 
              "]"}], \(stores\ results\ at\ intervals\ dt\ in\ \[Psi][t], \ 
            starting\ with\ \[Psi][
                  0] = \[Psi]\_0 . \ \ Options\ are\ passed\ directly\ to\ \(\
\(IterateExact[]\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->{"IterateExact", "StoreExact"}],

Cell["\<\
This shows a cline at three loci, maintained by 10% selection \
against heterozygotes.  Clines are plotted every 10 generations:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hp[ng_] := 
        MakeCline[10, ng, 100, 
          NumericalModel \[Rule] SymmetricHaploidFrequencies];\)\), "\n", 
    \(\(\(\(w[s_]\)[_]\)[i_, j_, h_] := \((1 - s)\)\^h;\)\), "\n", 
    \(\(StoreExact[cline[3, 0.2], hp[3], w[0.2], 0.5, {30, 10}];\)\), "\n", 
    \(\(DisplayTogether @@ 
        Table[ListPlot[AlleleFrequencyMean[\(cline[3, 0.2]\)[t]], 
            PlotJoined -> True], {t, 0, 30, 10}];\)\)}], "Input",
  CellLabel->"In[48]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.588604 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.11905 .01472 m
.21429 .01472 L
.30952 .01472 L
.40476 .01472 L
.5 .01472 L
.59524 .60332 L
.69048 .60332 L
.78571 .60332 L
.88095 .60332 L
.97619 .60332 L
s
.11905 .01679 m
.21429 .02118 L
.30952 .03681 L
.40476 .08664 L
.5 .21517 L
.59524 .40286 L
.69048 .53139 L
.78571 .58122 L
.88095 .59685 L
.97619 .60125 L
s
.11905 .01976 m
.21429 .02558 L
.30952 .04401 L
.40476 .09654 L
.5 .22099 L
.59524 .39704 L
.69048 .5215 L
.78571 .57402 L
.88095 .59245 L
.97619 .59827 L
s
.11905 .02058 m
.21429 .02663 L
.30952 .04551 L
.40476 .09844 L
.5 .22207 L
.59524 .39596 L
.69048 .5196 L
.78571 .57252 L
.88095 .5914 L
.97619 .59745 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[48]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00AP3oool500000340oooo0`00000_0?ooo`<00000<@3oool3000002h0oooo0`0000040?oo
o`800000103oool004L0oooo00@000000?ooo`3oool00000<P3oool00`000000oooo0?ooo`0]0?oo
o`050000003oool0oooo0?ooo`000000;`3oool01@000000oooo0?ooo`3oool0000002h0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`00B03oool00`000000oooo0?oo
o`0_0?ooo`D00000;P3oool01@000000oooo0?ooo`3oool0000002l0oooo00D000000?ooo`3oool0
oooo0000000^0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool004T0
oooo00<000000?ooo`3oool0;P3oool010000000oooo0?ooo`00000_0?ooo`@00000<@3oool30000
02l0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`00AP3oool01@00
0000oooo0?ooo`3oool000000300oooo00<000000?ooo`000000;`3oool00`000000oooo0?ooo`0a
0?ooo`050000003oool0oooo0?ooo`000000;P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000<0oooo00160?ooo`050000003oool0oooo0?ooo`000000<@3oool200000300oooo
00<000000?ooo`3oool0<03oool01@000000oooo0?ooo`3oool0000002d0oooo0P0000040?ooo`04
0000003oool0oooo000000<0oooo00170?ooo`<00000<`3oool00`000000oooo0?ooo`0_0?ooo`80
0000<@3oool3000002l0oooo00<000000?ooo`3oool00`3oool2000000@0oooo000E0?ooo`030000
003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool000l0
ooooo`00000A00000040oooo000E0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool>000000`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`005@3o
ool00`000000oooo0?ooo`0G0?oooah00000<03oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo00D0oooo000E0?ooo`030000003oool0oooo02D0oooo5`0000120?ooo`030000003oool0
oooo08L0oooo000E0?ooo`030000003oool0oooo03D0oooo1@0000020?ooo`H00000?@3oool00`00
0000oooo0?ooo`260?ooo`005@3oool00`000000oooo0?ooo`0j0?ooo`D000000`3oool7000003H0
oooo00<000000?ooo`3oool0QP3oool001D0oooo00<000000?ooo`3oool0?`3oool5000000D0oooo
1000000b0?ooo`030000003oool0oooo08H0oooo000E0?ooo`030000003oool0oooo04@0oooo1@00
00040?ooo`800000<03oool00`000000oooo0?ooo`260?ooo`005@3oool2000004X0oooo10000002
0?ooo`800000;P3oool00`000000oooo0?ooo`260?ooo`005@3oool00`000000oooo0?ooo`1=0?oo
o`8000000P3oool2000002`0oooo00<000000?ooo`3oool0QP3oool001D0oooo00<000000?ooo`3o
ool0C`3oool200000080oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`250?ooo`00
5@3oool00`000000oooo0?ooo`1@0?ooo`<0000000<0oooo000000000000:P3oool00`000000oooo
0?ooo`250?ooo`005@3oool00`000000oooo0?ooo`1B0?ooo`8000000P3oool2000002P0oooo00<0
00000?ooo`3oool0Q@3oool001D0oooo00<000000?ooo`3oool0E03oool200000080oooo0P00000V
0?ooo`030000003oool0oooo08D0oooo000E0?ooo`030000003oool0oooo05H0oooo0P0000020?oo
o`800000903oool00`000000oooo0?ooo`250?ooo`005@3oool00`000000oooo0?ooo`1G0?ooo`<0
00000P3oool200000280oooo00<000000?ooo`3oool0Q@3oool001D0oooo0P00001J0?ooo`<00000
0P3oool200000240oooo00<000000?ooo`3oool0Q03oool001D0oooo00<000000?ooo`3oool0F`3o
ool300000080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`240?ooo`005@3oool0
0`000000oooo0?ooo`1L0?ooo`@0000000<0oooo0000000000007P3oool00`000000oooo0?ooo`24
0?ooo`005@3oool00`000000oooo0?ooo`1N0?ooo`<000000P3oool2000001`0oooo00<000000?oo
o`3oool0Q03oool001D0oooo00<000000?ooo`3oool0H03oool300000080oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`240?ooo`005@3oool00`000000oooo0?ooo`1R0?ooo`@00000
6`3oool00`000000oooo0?ooo`240?ooo`005@3oool00`000000oooo0?ooo`1S0?ooo`@000006P3o
ool00`000000oooo0?ooo`240?ooo`005@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0
000001X0oooo00<000000?ooo`3oool0P`3oool001D0oooo0P00001V0?ooo`80000000<0oooo0000
003oool0603oool00`000000oooo0?ooo`230?ooo`005@3oool00`000000oooo0?ooo`1V0?ooo`<0
00006@3oool00`000000oooo0?ooo`230?ooo`005@3oool00`000000oooo0?ooo`1W0?ooo`<00000
603oool00`000000oooo0?ooo`230?ooo`005@3oool00`000000oooo0?ooo`1X0?ooo`030000003o
ool0000001L0oooo00<000000?ooo`3oool0P`3oool001D0oooo00<000000?ooo`3oool0J03oool2
000000030?ooo`000000oooo01D0oooo00<000000?ooo`3oool0P`3oool00080oooo0P0000040?oo
o`040000003oool0oooo0?ooo`D00000103oool00`000000oooo0?ooo`1Y0?ooo`<000005`3oool0
0`000000oooo0?ooo`220?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0JP3oool3000001H0oooo00<000000?ooo`3oool0PP3o
ool000050?ooo`000000oooo0?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo06/0oooo00<000000?ooo`0000005@3oool00`000000oooo0?ooo`220?ooo`0000D0oooo
0000003oool0oooo0000000:0?ooo`030000003oool0oooo00<0oooo0`00001[0?ooo`<000005@3o
ool00`000000oooo0?ooo`220?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1/0?ooo`<00000503oool00`000000oooo
0?ooo`220?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`1]0?ooo`030000003oool0000001<0oooo00<000000?ooo`3o
ool0PP3oool00080oooo0P0000090?ooo`<000001@3oool00`000000oooo0?ooo`1^0?ooo`030000
003oool0000001<0oooo00<000000?ooo`3oool0P@3oool001D0oooo00<000000?ooo`3oool0KP3o
ool3000001<0oooo00<000000?ooo`3oool0P@3oool001D0oooo00<000000?ooo`3oool0K`3oool3
00000180oooo00<000000?ooo`3oool0P@3oool001D0oooo00<000000?ooo`3oool0L03oool00`00
0000oooo0000000A0?ooo`030000003oool0oooo0840oooo000E0?ooo`030000003oool0oooo0740
oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`210?ooo`005@3oool2000007<0oooo
0P00000@0?ooo`030000003oool0oooo0840oooo000E0?ooo`030000003oool0oooo0780oooo0`00
000@0?ooo`030000003oool0oooo0800oooo000E0?ooo`030000003oool0oooo07<0oooo00<00000
0?ooo`0000003`3oool00`000000oooo0?ooo`200?ooo`005@3oool00`000000oooo0?ooo`1d0?oo
o`030000003oool0000000h0oooo00<000000?ooo`3oool0P03oool001D0oooo00<000000?ooo`3o
ool0M@3oool2000000h0oooo00<000000?ooo`3oool0P03oool001D0oooo00<000000?ooo`3oool0
M@3oool3000000d0oooo00<000000?ooo`3oool0P03oool001D0oooo00<000000?ooo`3oool0MP3o
ool00`000000oooo0000000<0?ooo`030000003oool0oooo0800oooo000E0?ooo`030000003oool0
oooo07L0oooo0P00000=0?ooo`030000003oool0oooo07l0oooo000E0?ooo`800000N@3oool20000
00`0oooo00<000000?ooo`3oool0O`3oool001D0oooo00<000000?ooo`3oool0N03oool00`000000
oooo0000000;0?ooo`030000003oool0oooo07l0oooo000E0?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`0000002P3oool00`000000oooo0?ooo`1o0?ooo`005@3oool00`000000oooo0?oo
o`1j0?ooo`8000002P3oool00`000000oooo0?ooo`1o0?ooo`005@3oool00`000000oooo0?ooo`1k
0?ooo`8000002@3oool00`000000oooo0?ooo`1o0?ooo`005@3oool00`000000oooo0?ooo`1k0?oo
o`030000003oool0000000T0oooo00<000000?ooo`3oool0OP3oool001D0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo000000080?ooo`030000003oool0oooo07h0oooo000E0?ooo`030000
003oool0oooo07d0oooo0P0000080?ooo`030000003oool0oooo07h0oooo000E0?ooo`800000O`3o
ool2000000L0oooo00<000000?ooo`3oool0OP3oool001D0oooo00<000000?ooo`3oool0OP3oool2
000000L0oooo00<000000?ooo`3oool0OP3oool001D0oooo00<000000?ooo`3oool0O`3oool20000
00H0oooo00<000000?ooo`3oool0OP3oool001D0oooo00<000000?ooo`3oool0O`3oool2000000L0
oooo00<000000?ooo`3oool0O@3oool001D0oooo00<000000?ooo`3oool0P03oool2000000H0oooo
00<000000?ooo`3oool0O@3oool00080oooo0P0000040?ooo`030000003oool0oooo00<0oooo0`00
00040?ooo`030000003oool0oooo0800oooo0P0000060?ooo`030000003oool0oooo07d0oooo0000
1@3oool000000?ooo`3oool0000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`210?ooo`8000001@3oool00`000000oooo0?ooo`1m0?ooo`0000D0oooo0000003oool0oooo0000
00070?ooo`D00000103oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0O@3oool000050?ooo`000000oooo0?ooo`0000001`3oool010000000oooo0?oo
o`0000050?ooo`<00000PP3oool2000000@0oooo00<000000?ooo`3oool0O@3oool000050?ooo`00
0000oooo0?ooo`000000203oool00`000000oooo000000050?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1m0?ooo`0000D0oooo0000003oool0oooo
000000090?ooo`8000001@3oool00`000000oooo0?ooo`230?ooo`800000103oool00`000000oooo
0?ooo`1l0?ooo`000P3oool2000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`240?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0O03oool001D0oooo00<00000
0?ooo`3oool0Q03oool2000000<0oooo00<000000?ooo`3oool0O03oool001D0oooo00<000000?oo
o`3oool0Q@3oool01@000000oooo0?ooo`3oool0000007h0oooo000E0?ooo`030000003oool0oooo
08D0oooo0P0000020?ooo`030000003oool0oooo07`0oooo000E0?ooo`030000003oool0oooo08H0
oooo00@000000?ooo`3oool00000OP3oool001D0oooo0P0000270?ooo`8000000P3oool00`000000
oooo0?ooo`1k0?ooo`005@3oool00`000000oooo0?ooo`270?ooo`040000003oool0oooo000007d0
oooo000E0?ooo`030000003oool0oooo08L0oooo0P0000000`3oool000000?ooo`1l0?ooo`005@3o
ool00`000000oooo0?ooo`280?ooo`030000003oool0000007d0oooo000E0?ooo`030000003oool0
oooo08T0oooo0P00001m0?ooo`005@3oool00`000000oooo0?ooo`290?ooo`800000O@3oool001D0
oooo00<000000?ooo`3oool0RP3oool2000007`0oooo000E0?ooo`030000003oool0oooo08X0oooo
0P00001l0?ooo`005@3oool2000008`0oooo00<000000?ooo`3oool0NP3oool001D0oooo00<00000
0?ooo`3oool0R`3oool2000007/0oooo000E0?ooo`030000003oool0oooo08/0oooo0P00001k0?oo
o`005@3oool00`000000oooo0?ooo`2;0?ooo`<00000NP3oool001D0oooo00<000000?ooo`3oool0
S03oool2000007X0oooo000E0?ooo`030000003oool0oooo08`0oooo0`00001i0?ooo`005@3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0000007T0oooo000E0?ooo`030000003oool0oooo
08`0oooo00@000000?ooo`3oool00000N03oool001D0oooo0P00002=0?ooo`040000003oool0oooo
000007P0oooo000E0?ooo`030000003oool0oooo08`0oooo00D000000?ooo`3oool0oooo0000001g
0?ooo`005@3oool00`000000oooo0?ooo`2=0?ooo`040000003oool0oooo000007L0oooo000E0?oo
o`030000003oool0oooo08d0oooo00D000000?ooo`3oool0oooo0000001f0?ooo`005@3oool00`00
0000oooo0?ooo`2=0?ooo`050000003oool0oooo0?ooo`000000MP3oool00080oooo0P0000040?oo
o`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1c0?ooo`0000D0oooo0000003oool0oooo000000070?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0L`3oool000050?ooo`000000oooo0?ooo`0000001`3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0780oooo00001@3oool000000?ooo`3oool0000000L0oooo1000
00050?ooo`<00000SP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0780oooo0000
1@3oool000000?ooo`3oool0000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L@3oool000050?ooo`000000
oooo0?ooo`000000203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`1a0?ooo`000P3oool2000000X0oooo0P000005
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1`
0?ooo`005@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00@0oooo0P00001a0?oo
o`005@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0K`3oool001D0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`050?ooo`800000
L03oool001D0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo06h0oooo000E0?ooo`800000T03oool00`000000oooo0?ooo`050?ooo`800000K`3oool0
01D0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
06d0oooo000E0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01P3oool2000006h0
oooo000E0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01`3oool2000006d0oooo
000E0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0203oool2000006`0oooo000E
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool2000006/0oooo000E0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool2000006/0oooo000E0?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool02@3oool2000006X0oooo000E0?ooo`800000
T@3oool00`000000oooo0?ooo`0:0?ooo`800000J@3oool001D0oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`0;0?ooo`800000J03oool001D0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`0;0?ooo`800000J03oool001D0oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`0;0?ooo`800000I`3oool001D0oooo00<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`0<0?ooo`800000IP3oool001D0oooo00<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`0=0?ooo`800000I@3oool001D0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?oo
o`0=0?ooo`<00000I03oool001D0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0>
0?ooo`800000I03oool001D0oooo0P00002B0?ooo`030000003oool0oooo00l0oooo0P00001S0?oo
o`005@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo00l0oooo0P00001R0?ooo`00
5@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo00l0oooo0`00001Q0?ooo`005@3o
ool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0100oooo0`00001P0?ooo`005@3oool0
0`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0140oooo0P00001P0?ooo`000P3oool20000
00@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0TP3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0000005l0oooo00001@3oool000000?ooo`3oool00000
00L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0980oooo00<00000
0?ooo`3oool04P3oool3000005h0oooo00001@3oool000000?ooo`3oool0000000L0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool04P3o
ool3000005d0oooo00001@3oool000000?ooo`3oool0000000P0oooo0`0000050?ooo`<00000T`3o
ool00`000000oooo0?ooo`0C0?ooo`<00000G03oool000050?ooo`000000oooo0?ooo`0000001`3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0000005`0oooo00001@3oool000000?ooo`3oool0000000L0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0000001K0?ooo`000P3oool2000000T0oooo0`0000050?ooo`030000
003oool0oooo09<0oooo00<000000?ooo`3oool05@3oool3000005X0oooo000E0?ooo`030000003o
ool0oooo09<0oooo00<000000?ooo`3oool05P3oool3000005T0oooo000E0?ooo`030000003oool0
oooo09@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0000001I0?ooo`005@3oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`000000F03oool001D0
oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0G0?ooo`<00000E`3oool001D0oooo
0P00002E0?ooo`030000003oool0oooo01P0oooo0`00001F0?ooo`005@3oool00`000000oooo0?oo
o`2D0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`0000000P00001D0?ooo`005@3oool0
0`000000oooo0?ooo`2D0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`0000000`00001B
0?ooo`005@3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool00`00001A0?ooo`005@3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo01X0
oooo0P0000020?ooo`<00000C`3oool001D0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`0L0?ooo`8000000P3oool3000004d0oooo000E0?ooo`030000003oool0oooo09D0oooo00<0
00000?ooo`3oool07P3oool200000080oooo0`00001;0?ooo`005@3oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo0200oooo0P000000103oool0000000000000001:0?ooo`005@3oool2
000009H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`03000004P0oooo000E0?oo
o`030000003oool0oooo09D0oooo00<000000?ooo`3oool08`3oool200000080oooo0`0000160?oo
o`005@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo02@0oooo0P0000020?ooo`80
0000A@3oool001D0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0V0?ooo`800000
0P3oool2000004<0oooo000E0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0:03o
ool200000080oooo0P0000110?ooo`005@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0
oooo02X0oooo0P0000020?ooo`800000?`3oool001D0oooo00<000000?ooo`3oool0UP3oool00`00
0000oooo0?ooo`0/0?ooo`80000000<0oooo000000000000?P3oool001D0oooo00<000000?ooo`3o
ool0UP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00800000?03oool001D0oooo
0P00002H0?ooo`030000003oool0oooo02h0oooo0P0000020?ooo`@00000>03oool001D0oooo00<0
00000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`800000103oool5000003<0oooo000E
0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0<P3oool4000000D0oooo1@00000^
0?ooo`005@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03H0oooo1`0000030?oo
o`D00000:@3oool001D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0m0?ooo`H0
00000P3oool5000002@0oooo000=0?ooo`<000001@3oool00`000000oooo0?ooo`2G0?ooo`030000
003oool0oooo04<0oooo5`00000D0?ooo`003P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo09P0oooo00<000000?ooo`3oool0B@3ooolM000000L0oooo000>0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`1I0?ooo`d000001`3oool0
00h0oooo00<000000?ooo`3oool0103oool3000009P0ooooJ@0000070?ooo`003P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo2@3oool000d0oooo0P0000060?ooo`030000
003oool0oooo0?l0oooo2@3oool000h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.829852, -0.07747, \
0.0386179, 0.00624851}}]
}, Closed]],

Cell["\<\
This compares cline widths as the number of loci increases from 1 \
to 5:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Do[Print[ng]; 
        StoreExact[cline[ng, 0.2], hp[ng], w[0.2], 0.5, {20, 10}], {ng, 
          5}];\)\), "\n", 
    \(\(DisplayTogether @@ 
        MapThread[\[IndentingNewLine]ListPlot[
              AlleleFrequencyMean[\(cline[#1, 0.2]\)[20]], 
              PlotJoined -> True, PlotStyle -> #2] &, {{1, 2, 3, 4, 5}, {Red, 
              Orange, Green, Blue, Black}}];\)\)}], "Input",
  CellLabel->"In[52]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.591 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13292 -18 -4.5 ]
[.01131 .13292 0 4.5 ]
[.01131 .25112 -18 -4.5 ]
[.01131 .25112 0 4.5 ]
[.01131 .36932 -18 -4.5 ]
[.01131 .36932 0 4.5 ]
[.01131 .48751 -18 -4.5 ]
[.01131 .48751 0 4.5 ]
[.01131 .60571 -6 -4.5 ]
[.01131 .60571 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13292 m
.03006 .13292 L
s
[(0.2)] .01131 .13292 1 0 Mshowa
.02381 .25112 m
.03006 .25112 L
s
[(0.4)] .01131 .25112 1 0 Mshowa
.02381 .36932 m
.03006 .36932 L
s
[(0.6)] .01131 .36932 1 0 Mshowa
.02381 .48751 m
.03006 .48751 L
s
[(0.8)] .01131 .48751 1 0 Mshowa
.02381 .60571 m
.03006 .60571 L
s
[(1)] .01131 .60571 1 0 Mshowa
.125 Mabswid
.02381 .04427 m
.02756 .04427 L
s
.02381 .07382 m
.02756 .07382 L
s
.02381 .10337 m
.02756 .10337 L
s
.02381 .16247 m
.02756 .16247 L
s
.02381 .19202 m
.02756 .19202 L
s
.02381 .22157 m
.02756 .22157 L
s
.02381 .28067 m
.02756 .28067 L
s
.02381 .31022 m
.02756 .31022 L
s
.02381 .33977 m
.02756 .33977 L
s
.02381 .39886 m
.02756 .39886 L
s
.02381 .42841 m
.02756 .42841 L
s
.02381 .45796 m
.02756 .45796 L
s
.02381 .51706 m
.02756 .51706 L
s
.02381 .54661 m
.02756 .54661 L
s
.02381 .57616 m
.02756 .57616 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.11905 .02469 m
.21429 .03528 L
.30952 .0649 L
.40476 .13006 L
.5 .24205 L
.59524 .37838 L
.69048 .49037 L
.78571 .55553 L
.88095 .58515 L
.97619 .59574 L
s
1 .5 0 r
.11905 .0219 m
.21429 .02989 L
.30952 .05382 L
.40476 .11361 L
.5 .23267 L
.59524 .38776 L
.69048 .50682 L
.78571 .56661 L
.88095 .59054 L
.97619 .59853 L
s
0 1 0 r
.11905 .01978 m
.21429 .02563 L
.30952 .04413 L
.40476 .09687 L
.5 .22183 L
.59524 .3986 L
.69048 .52356 L
.78571 .5763 L
.88095 .5948 L
.97619 .60065 L
s
0 0 1 r
.11905 .01823 m
.21429 .02237 L
.30952 .03609 L
.40476 .08087 L
.5 .21006 L
.59524 .41037 L
.69048 .53956 L
.78571 .58434 L
.88095 .59806 L
.97619 .6022 L
s
0 0 0 r
.11905 .01711 m
.21429 .01997 L
.30952 .02979 L
.40476 .06669 L
.5 .19839 L
.59524 .42204 L
.69048 .55374 L
.78571 .59064 L
.88095 .60047 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[52]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00AP3oool500000340oooo0`00000_0?ooo`<00000<@3oool3000002d0oooo0`0000040?oo
o`8000001@3oool004L0oooo00@000000?ooo`3oool00000<P3oool00`000000oooo0?ooo`0]0?oo
o`050000003oool0oooo0?ooo`000000;`3oool01@000000oooo0?ooo`3oool0000002d0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`00B03oool00`000000oooo0?oo
o`0_0?ooo`D00000;P3oool01@000000oooo0?ooo`3oool0000002l0oooo00D000000?ooo`3oool0
oooo0000000]0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool004T0
oooo00<000000?ooo`3oool0;P3oool010000000oooo0?ooo`00000_0?ooo`@00000<@3oool30000
02h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`00AP3oool01@00
0000oooo0?ooo`3oool000000300oooo00<000000?ooo`000000;`3oool00`000000oooo0?ooo`0a
0?ooo`050000003oool0oooo0?ooo`000000;@3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000@0oooo00160?ooo`050000003oool0oooo0?ooo`000000<@3oool200000300oooo
00<000000?ooo`3oool0<03oool01@000000oooo0?ooo`3oool0000002`0oooo0P0000040?ooo`04
0000003oool0oooo000000@0oooo00170?ooo`<00000<`3oool00`000000oooo0?ooo`0_0?ooo`80
0000<@3oool3000002h0oooo00<000000?ooo`3oool00`3oool2000000D0oooo000F0?ooo`030000
003oool0oooo0?l0oooo203oool001H0oooo00<000000?ooo`3oool0o`3oool80?ooo`005P3oool0
0`000000oooo0?ooo`3o0?ooo`P0oooo000F0?ooo`030000003oool0oooo0?l0oooo203oool000l0
ooooo`00000A00000040oooo000F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3ooolO000000P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool001H0oooo00<000000?ooo`3oool05P3o
ool80?mo00H00?l040000?l00`3oool0000000000007000002H0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool01P3o
ool001H0oooo00<000000?ooo`3oool05P3oool50?l000<0oooo3@3oO`09003o00L0003o0`3oool9
00000<00oooo000F0?ooo`030000003oool0oooo01/0oooo2@3o00070?ooo`P0ogl000<0oooo003o
0000o`000`00o`020?ooo`H0003o1P3oool500000;/0oooo000F0?ooo`030000003oool0oooo02@0
oooo2@3o00060?ooo`@0ogl00P3oool5003o00<0oooo1`000?l40?ooo`<00000^03oool001H0oooo
00<000000?ooo`3oool0;@3oool60?l000@0oooo0`3oO`040?ooo`D00?l01@3oool40000o`<0oooo
0`00002e0?ooo`005P3oool00`000000oooo0?ooo`0c0?ooo`<0o`00103oool40?mo00D0oooo1@00
o`040?ooo`80003o103oool200000;<0oooo000F0?ooo`800000=`3oool30?l000D0oooo103oO`06
0?ooo`@00?l00P3oool20000o`@0oooo0`00002`0?ooo`005P3oool00`000000oooo0?ooo`0i0?oo
o`<0o`001P3oool30?mo00L0oooo0P00o`020?ooo`<0003o103oool200000:h0oooo000F0?ooo`03
0000003oool0oooo03`0oooo103o00050?ooo`@0ogl01@3oool2003o00<0oooo0P000?l40?ooo`<0
0000Z`3oool001H0oooo00<000000?ooo`3oool0@03oool30?l000H0oooo0`3oO`040?ooo`800?l0
0`3oool20000o`D0oooo0`00002X0?ooo`005P3oool00`000000oooo0?ooo`130?ooo`<0o`001P3o
ool00`3oO`00oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo0P000?l60?ooo`800000YP3o
ool001H0oooo00<000000?ooo`3oool0AP3oool30?l000@0oooo0P3oO`040?ooo`800?l0103oool2
0000o`H0oooo0`00002S0?ooo`005P3oool00`000000oooo0?ooo`190?ooo`<0o`000`3oool20?mo
00@0oooo0P00o`040?ooo`80003o1`3oool00`000000oooo0?ooo`2P0?ooo`005P3oool00`000000
oooo0?ooo`1<0?ooo`030?l0003oool0oooo0080oooo00<0ogl00?ooo`3oool00`3oool2003o00@0
oooo0`000?l40?ooo`030000003oool0oooo0:00oooo000F0?ooo`800000CP3oool20?l000<0oooo
0P3oO`050?ooo`800?l01@3oool20000o`<0oooo00<000000?ooo`3oool0W`3oool001H0oooo00<0
00000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`020?ooo`80ogl01@3oool2003o00D0oooo0P00
0?l20?ooo`030000003oool0oooo09h0oooo000F0?ooo`030000003oool0oooo0500oooo0P3o0004
0?ooo`030?mo003oool0oooo00@0oooo0P00o`050?ooo`030000o`3oool000000:00oooo000F0?oo
o`030000003oool0oooo0580oooo00<0o`000?ooo`3oool00P3oool20?mo00H0oooo00<00?l00?oo
o`3oool00P3oool010000?l0oooo0?ooo`00002O0?ooo`005P3oool00`000000oooo0?ooo`1C0?oo
o`80o`00103oool00`3oO`00oooo0?ooo`040?ooo`800?l00`3oool010000?l0oooo0?ooo`00002N
0?ooo`005P3oool00`000000oooo0?ooo`1E0?ooo`030?l0003oool0oooo0080oooo0P3oO`060?oo
o`800?l00P3oool010000?l0oooo0?ooo`00002M0?ooo`005P3oool00`000000oooo0?ooo`1F0?oo
o`80o`00103oool20?mo00H0oooo00H00?l00?ooo`3oool0003o0?ooo`00002M0?ooo`005P3oool0
0`000000oooo0?ooo`1H0?ooo`80o`00103oool00`3oO`00oooo0?ooo`030?ooo`04003o003oool0
oooo0000o`80oooo00<000000?ooo`3oool0VP3oool001H0oooo0P00001K0?ooo`030?l0003oool0
oooo0080oooo0P3oO`040?ooo`04003o003oool0oooo0000o`80oooo00<000000?ooo`3oool0V@3o
ool001H0oooo00<000000?ooo`3oool0F`3oool20?l000@0oooo0P3oO`030?ooo`06003o003oool0
oooo0000o`3oool00000V`3oool001H0oooo00<000000?ooo`3oool0G@3oool00`3o0000oooo0?oo
o`030?ooo`070?mo003oool0oooo0?ooo`00o`00oooo0000o`020?ooo`030000003oool0oooo09P0
oooo000F0?ooo`030000003oool0oooo05h0oooo0P3o00040?ooo`040?mo003oool0oooo003o0080
oooo00@0003o0?ooo`3oool00000V@3oool001H0oooo00<000000?ooo`3oool0H03oool01@3o0000
oooo0?ooo`3oool0ogl000<0oooo00H00?l00?ooo`3oool0003o0?ooo`00002I0?ooo`000P3oool2
000000@0oooo00@000000?ooo`3oool0oooo1@0000050?ooo`030000003oool0oooo0640oooo0P3o
00020?ooo`050?mo003oool0oooo0?ooo`00o`000P3oool00`000?l0oooo0000002H0?ooo`0000D0
oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool0H`3oool0103o0000oooo0?ooo`3oO`030?ooo`03003o003oool0003o0080oooo00<000000?oo
o`3oool0U@3oool000050?ooo`000000oooo0?ooo`0000002@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo06@0oooo00@0o`000?ooo`3oool0ogl00P3oool01P00o`00oooo0?ooo`00
0?l0oooo000009L0oooo00001@3oool000000?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
103oool2000006D0oooo00D0o`000?ooo`3oool0oooo0?mo00020?ooo`06003o003oool0oooo0000
o`3oool00000UP3oool000050?ooo`000000oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool0I@3oool0103o0000oooo0?ooo`3oO`030?ooo`03003o
003oool0003o0080oooo00<000000?ooo`3oool0T`3oool000050?ooo`000000oooo0?ooo`000000
1`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0IP3oool0103o0000
oooo0?ooo`3oO`020?ooo`04003o003oool0oooo0000o`80oooo00<000000?ooo`3oool0TP3oool0
0080oooo0P0000090?ooo`<000001P3oool00`000000oooo0?ooo`1W0?ooo`040?l0003oool0oooo
0?mo0080oooo00H00?l00?ooo`3oool0003o0?ooo`00002D0?ooo`005P3oool00`000000oooo0?oo
o`1X0?ooo`040?l0003oool0oooo0?mo0080oooo00H00?l00?ooo`3oool0003o0?ooo`00002C0?oo
o`005P3oool00`000000oooo0?ooo`1X0?ooo`040?l0003oool0oooo0?mo00<0oooo00<00?l00?oo
o`000?l00P3oool00`000000oooo0?ooo`2@0?ooo`005P3oool00`000000oooo0?ooo`1Y0?ooo`04
0?l0003oool0oooo0?mo0080oooo00H00?l00?ooo`3oool0003o0?ooo`00002B0?ooo`005P3oool0
0`000000oooo0?ooo`1Z0?ooo`040?l0003oool0oooo0?mo0080oooo00H00?l00?ooo`3oool0003o
0?ooo`00002A0?ooo`005P3oool2000006`0oooo00@0o`000?ooo`3oool0ogl00P3oool00`00o`00
oooo0000o`020?ooo`030000003oool0oooo08h0oooo000F0?ooo`030000003oool0oooo06`0oooo
00@0o`000?ooo`3oool0ogl00P3oool01@00o`00oooo0000o`3oool000000900oooo000F0?ooo`03
0000003oool0oooo06`0oooo00@0o`000?ooo`3oool0ogl00P3oool01P00o`00oooo0?ooo`000?l0
oooo000008l0oooo000F0?ooo`030000003oool0oooo06d0oooo00@0o`000?ooo`3oool0ogl00P3o
ool01P00o`00oooo0?ooo`000?l0oooo000008h0oooo000F0?ooo`030000003oool0oooo06h0oooo
00@0o`000?ooo`3oool0ogl00P3oool01@00o`00oooo0000o`3oool0000008h0oooo000F0?ooo`03
0000003oool0oooo06l0oooo00@0o`000?ooo`3oool0ogl00P3oool01@00o`00oooo0000o`3oool0
000008d0oooo000F0?ooo`030000003oool0oooo0700oooo00<0o`000?ooo`3oO`000P3oool01P00
o`00oooo0?ooo`000?l0oooo000008`0oooo000F0?ooo`030000003oool0oooo0740oooo00<0o`00
0?ooo`3oO`000P3oool00`00o`00oooo0000o`020?ooo`030000003oool0oooo08T0oooo000F0?oo
o`800000LP3oool0103o0000oooo0?ooo`3oO`020?ooo`05003o003oool0003o0?ooo`000000R`3o
ool001H0oooo00<000000?ooo`3oool0LP3oool01P3o0000oooo0?ooo`3oO`00oooo003o0080oooo
00<0003o0?ooo`000000RP3oool001H0oooo00<000000?ooo`3oool0L`3oool01P3o0000oooo0?oo
o`3oO`00oooo003o0080oooo00<0003o0?ooo`000000R@3oool001H0oooo00<000000?ooo`3oool0
M03oool00`3o0000oooo0?mo00020?ooo`05003o003oool0003o0?ooo`000000R@3oool001H0oooo
00<000000?ooo`3oool0M@3oool00`3o0000oooo0?mo00020?ooo`05003o003oool0003o0?ooo`00
0000R03oool001H0oooo00<000000?ooo`3oool0M@3oool01P3o0000oooo0?ooo`3oO`00oooo003o
0080oooo00<0003o0000003oool0Q`3oool001H0oooo00<000000?ooo`3oool0MP3oool02P3o0000
oooo0?ooo`3oO`00oooo003o003oool0003o0?ooo`0000270?ooo`005P3oool00`000000oooo0?oo
o`1g0?ooo`030?l0003oool0ogl00080oooo00@00?l00?ooo`000?l00000Q`3oool001H0oooo0P00
001i0?ooo`030?l0003oool0ogl00080oooo00<00?l00000o`000000Q`3oool001H0oooo00<00000
0?ooo`3oool0N@3oool0203o0000oooo0?mo003oool00?l00?ooo`000?l00000QP3oool001H0oooo
00<000000?ooo`3oool0N@3oool0203o0000oooo0?ooo`3oO`00oooo003o00000?l00000QP3oool0
01H0oooo00<000000?ooo`3oool0NP3oool0203o0000oooo0?ooo`3oO`000?l00?ooo`000?l00000
Q@3oool001H0oooo00<000000?ooo`3oool0N`3oool01`3o0000oooo0?mo003oool00?l00000o`00
0000Q@3oool00080oooo0P0000040?ooo`030000003oool0oooo00<0oooo0`0000050?ooo`030000
003oool0oooo07`0oooo00L0o`000?ooo`3oO`000?l00?ooo`000?l0000008@0oooo00001@3oool0
00000?ooo`3oool0000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1m0?oo
o`060?l0003oool0ogl0003o00000?l00000Q03oool000050?ooo`000000oooo0?ooo`0000001`3o
ool5000000D0oooo00<000000?ooo`3oool0O@3oool01P3o0000oooo0?mo003oool00?l0000008@0
oooo00001@3oool000000?ooo`3oool0000000L0oooo00@000000?ooo`3oool000001P3oool20000
07l0oooo00H0o`000?ooo`3oO`000?l00000o`0000230?ooo`0000D0oooo0000003oool0oooo0000
00080?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0O`3oool01@3o0000ogl00?oo
o`00o`00000008<0oooo00001@3oool000000?ooo`3oool0000000T0oooo0P0000060?ooo`030000
003oool0oooo0800oooo00D0o`000?mo0000o`00003o000000220?ooo`000P3oool2000000/0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`200?ooo`050?l0003oool0ogl0003o0000
0000PP3oool001H0oooo00<000000?ooo`3oool0P@3oool01@3o0000ogl0003o00000?l000000840
oooo000F0?ooo`030000003oool0oooo0880oooo00@0o`000?mo00000?l00000P@3oool001H0oooo
00<000000?ooo`3oool0PP3oool0103o0000oooo003o000000210?ooo`005P3oool00`000000oooo
0?ooo`230?ooo`040?l0003oO`00003o00000800oooo000F0?ooo`800000Q@3oool00`3o00000?l0
000000200?ooo`005P3oool00`000000oooo0?ooo`250?ooo`030?mo00000?l0000007l0oooo000F
0?ooo`030000003oool0oooo08D0oooo00<0o`00003o00000000O`3oool001H0oooo00<000000?oo
o`3oool0QP3oool00`3o0000003o0000001n0?ooo`005P3oool00`000000oooo0?ooo`270?ooo`03
0?mo00000000oooo07d0oooo000F0?ooo`030000003oool0oooo08L0oooo00<0o`000000003oool0
O@3oool001H0oooo00<000000?ooo`3oool0R03oool00`3oO`0000000?ooo`1l0?ooo`005P3oool0
0`000000oooo0?ooo`290?ooo`030000003oool0oooo07/0oooo000F0?ooo`800000R`3oool00`00
0000oooo0?ooo`1j0?ooo`005P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo07X0
oooo000F0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0N@3oool001H0oooo00<0
00000?ooo`3oool0R`3oool00`000000ogl00?ooo`1i0?ooo`005P3oool00`000000oooo0?ooo`2<
0?ooo`030000003o0000oooo07P0oooo000F0?ooo`030000003oool0oooo08`0oooo00<000000?mo
003oool0N03oool001H0oooo00<000000?ooo`3oool0S03oool00`000000003o0?l0001h0?ooo`00
5P3oool00`000000oooo0?ooo`2=0?ooo`0300000000o`00o`0007L0oooo000F0?ooo`800000SP3o
ool00`000000003o0?mo001g0?ooo`005P3oool00`000000oooo0?ooo`2>0?ooo`0300000000o`00
o`0007H0oooo000F0?ooo`030000003oool0oooo08h0oooo00@000000000o`3oO`00o`00M@3oool0
01H0oooo00<000000?ooo`3oool0S`3oool0100000000?l00?mo003o001d0?ooo`005P3oool00`00
0000oooo0?ooo`2?0?ooo`04000000000?l0ogl00?l007@0oooo00020?ooo`800000103oool00`00
0000oooo0?ooo`020?ooo`<000001P3oool00`000000oooo0?ooo`2?0?ooo`05000000000?l00?l0
0?mo003o0000L`3oool000050?ooo`000000oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool0T03oool01@000000003o0?mo003oool0o`000780oooo
00001@3oool000000?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo000000050?ooo`03
0000003oool0oooo0900oooo00D000000000o`00o`00ogl00?l0001b0?ooo`0000D0oooo0000003o
ool0oooo000000070?ooo`@000001P3oool200000980oooo00D00000003o003oool0ogl00?l0001a
0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0T@3oool01P000000003o003o003oO`00oooo0?l00700oooo00001@3oool000000?oo
o`3oool0000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2B0?ooo`060000
0000o`00oooo0?mo003oool0o`00K`3oool00080oooo0P00000:0?ooo`8000001P3oool00`000000
oooo0?ooo`2B0?ooo`06000000000?l00?l00?mo003oool0o`00K`3oool001H0oooo00<000000?oo
o`3oool0TP3oool01`000000003o0?ooo`00o`00ogl00?ooo`3o0000KP3oool001H0oooo00<00000
0?ooo`3oool0T`3oool01`000000003o003o003oool0ogl00?ooo`3o0000K@3oool001H0oooo00<0
00000?ooo`3oool0T`3oool01@000000003o0?ooo`00o`00ogl00080oooo00<0o`000?ooo`3oool0
JP3oool001H0oooo00<000000?ooo`3oool0U03oool01@000000003o003o003oool0ogl00080oooo
00<0o`000?ooo`3oool0J@3oool001H0oooo0P00002E0?ooo`06000000000?l0oooo003o003oool0
ogl00P3oool00`3o0000oooo0?ooo`1X0?ooo`005P3oool00`000000oooo0?ooo`2E0?ooo`030000
00000?l00?l00080oooo00<0ogl00?ooo`3o0000JP3oool001H0oooo00<000000?ooo`3oool0U@3o
ool010000000003o0?ooo`00o`020?ooo`030?mo003oool0o`0006T0oooo000F0?ooo`030000003o
ool0oooo09D0oooo00L000000?ooo`000?l0oooo003o003oool0ogl00080oooo00<0o`000?ooo`3o
ool0IP3oool001H0oooo00<000000?ooo`3oool0UP3oool01`000000003o0?ooo`3oool00?l00?oo
o`3oO`000P3oool00`3o0000oooo0?ooo`1U0?ooo`005P3oool00`000000oooo0?ooo`2F0?ooo`05
0000003oool0003o0?ooo`00o`000P3oool0103oO`00oooo0?ooo`3o001V0?ooo`005P3oool00`00
0000oooo0?ooo`2G0?ooo`050000003oool0003o0?ooo`00o`000P3oool0103oO`00oooo0?ooo`3o
001U0?ooo`005P3oool00`000000oooo0?ooo`2G0?ooo`060000003oool0oooo0000o`3oool00?l0
0P3oool00`3oO`00oooo0?l0001U0?ooo`005P3oool2000009T0oooo00<000000?ooo`000?l00P3o
ool01P00o`00oooo0?ooo`3oO`00oooo0?l006@0oooo000F0?ooo`030000003oool0oooo09T0oooo
00<000000?ooo`000?l00P3oool00`00o`00oooo0?mo00020?ooo`030?l0003oool0oooo0640oooo
000F0?ooo`030000003oool0oooo09X0oooo00D000000?ooo`000?l0oooo003o00020?ooo`040?mo
003oool0oooo0?l00680oooo000F0?ooo`030000003oool0oooo09X0oooo00H000000?ooo`3oool0
003o0?ooo`00o`020?ooo`040?mo003oool0oooo0?l00640oooo000F0?ooo`030000003oool0oooo
09/0oooo00<000000?ooo`000?l00P3oool01000o`00oooo0?ooo`3oO`020?ooo`030?l0003oool0
oooo05h0oooo000F0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`000?l00P3oool01000
o`00oooo0?ooo`3oO`020?ooo`030?l0003oool0oooo05d0oooo000F0?ooo`030000003oool0oooo
09`0oooo00H000000?ooo`3oool0003o0?ooo`00o`020?ooo`040?mo003oool0oooo0?l005l0oooo
000F0?ooo`030000003oool0oooo09d0oooo00H000000?ooo`3oool0003o0?ooo`00o`020?ooo`04
0?mo003oool0oooo0?l005h0oooo000F0?ooo`800000W`3oool00`000000oooo0000o`020?ooo`04
003o003oool0oooo0?mo0080oooo00<0o`000?ooo`3oool0F`3oool001H0oooo00<000000?ooo`3o
ool0W`3oool00`000000oooo0000o`020?ooo`04003o003oool0oooo0?mo0080oooo00<0o`000?oo
o`3oool0FP3oool001H0oooo00<000000?ooo`3oool0W`3oool01P000000oooo0?ooo`000?l0oooo
003o00<0oooo00@0ogl00?ooo`3oool0o`00F`3oool001H0oooo00<000000?ooo`3oool0X03oool0
1P000000oooo0?ooo`000?l0oooo003o0080oooo00D0ogl00?ooo`3oool0oooo0?l0001J0?ooo`00
5P3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0003o0080oooo00@00?l00?ooo`3oool0
ogl00P3oool00`3o0000oooo0?ooo`1H0?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool0
0P3oool3000000H0oooo00<000000?ooo`3oool0X@3oool010000000oooo0?ooo`000?l20?ooo`04
003o003oool0oooo0?mo0080oooo00<0o`000?ooo`3oool0E`3oool000050?ooo`000000oooo0?oo
o`0000001`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0XP3oool0
1P000000oooo0?ooo`000?l0oooo003o00<0oooo00@0ogl00?ooo`3oool0o`00F03oool000050?oo
o`000000oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool0X`3oool00`000000oooo0000o`020?ooo`05003o003oool0oooo0?ooo`3oO`000P3oool0
0`3o0000oooo0?ooo`1E0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`<000001P3oool2
00000:D0oooo00<000000?ooo`000?l00P3oool01@00o`00oooo0?ooo`3oool0ogl00080oooo00<0
o`000?ooo`3oool0E03oool000050?ooo`000000oooo0?ooo`0000001`3oool01@000000oooo0?oo
o`3oool0000000D0oooo00<000000?ooo`3oool0Y03oool010000000oooo0?ooo`000?l20?ooo`04
003o003oool0oooo0?mo00<0oooo0P3o001D0?ooo`0000D0oooo0000003oool0oooo000000070?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`2U0?ooo`040000003oool0
oooo0000o`80oooo00@00?l00?ooo`3oool0ogl0103oool00`3o0000oooo0?ooo`1A0?ooo`000P3o
ool2000000T0oooo0`0000060?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`000?l00P3o
ool01@00o`00oooo0?ooo`3oool0ogl000@0oooo0P3o001A0?ooo`005P3oool00`000000oooo0?oo
o`2W0?ooo`030000003oool0003o0080oooo00D00?l00?ooo`3oool0oooo0?mo00050?ooo`030?l0
003oool0oooo04h0oooo000F0?ooo`030000003oool0oooo0:L0oooo00@000000?ooo`3oool0003o
0P3oool01000o`00oooo0?ooo`3oool20?mo00@0oooo0P3o001>0?ooo`005P3oool00`000000oooo
0?ooo`2X0?ooo`040000003oool0oooo0000o`80oooo00<00?l00?ooo`3oool00P3oool00`3oO`00
oooo0?ooo`030?ooo`030?l0003oool0oooo04/0oooo000F0?ooo`030000003oool0oooo0:T0oooo
00<000000?ooo`000?l00P3oool00`00o`00oooo0?ooo`030?ooo`80ogl0103oool20?l004/0oooo
000F0?ooo`800000ZP3oool010000000oooo0?ooo`000?l20?ooo`03003o003oool0oooo00@0oooo
0P3oO`040?ooo`030?l0003oool0oooo04P0oooo000F0?ooo`030000003oool0oooo0:X0oooo00@0
00000?ooo`3oool0003o0P3oool00`00o`00oooo0?ooo`050?ooo`030?mo003oool0oooo0080oooo
0P3o00180?ooo`005P3oool00`000000oooo0?ooo`2[0?ooo`040000003oool0oooo0000o`80oooo
0P00o`060?ooo`80ogl0103oool20?l004H0oooo000F0?ooo`030000003oool0oooo0:`0oooo00<0
00000?ooo`000?l0103oool2003o00H0oooo0P3oO`040?ooo`030?l0003oool0oooo04<0oooo000F
0?ooo`030000003oool0oooo0:`0oooo00@000000?ooo`3oool0003o1@3oool2003o00H0oooo00<0
ogl00?ooo`3oool00P3oool20?l004<0oooo000F0?ooo`030000003oool0oooo0:d0oooo00@00000
0?ooo`3oool0003o1P3oool2003o00D0oooo0P3oO`040?ooo`030?l0003oool0oooo0400oooo000F
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool00P000?l60?ooo`03003o003oool0
oooo00@0oooo00<0ogl00?ooo`3oool00P3oool20?l00400oooo000F0?ooo`030000003oool0oooo
0:h0oooo00<000000?ooo`3oool00P3oool20000o`D0oooo0P00o`050?ooo`80ogl0103oool00`3o
0000oooo0?ooo`0m0?ooo`005P3oool200000;00oooo00<000000?ooo`3oool00`3oool20000o`D0
oooo0P00o`050?ooo`80ogl00`3oool20?l003d0oooo000F0?ooo`030000003oool0oooo0;00oooo
00<000000?ooo`3oool0103oool30000o`@0oooo0P00o`050?ooo`030?mo003oool0oooo0080oooo
00<0o`000?ooo`3oool0>P3oool001H0oooo00<000000?ooo`3oool0/@3oool2000000L0oooo0P00
0?l40?ooo`800?l0103oool20?mo00<0oooo0`3o000i0?ooo`005P3oool00`000000oooo0?ooo`2c
0?ooo`<000001P3oool20000o`@0oooo0P00o`040?ooo`80ogl0103oool30?l003H0oooo000F0?oo
o`030000003oool0oooo0;H0oooo0`0000050?ooo`80003o103oool2003o00@0oooo00<0ogl00?oo
o`3oool0103oool30?l003<0oooo000F0?ooo`030000003oool0oooo0;T0oooo0P0000050?ooo`80
003o103oool00`00o`00oooo0?ooo`020?ooo`<0ogl01P3oool30?l00300oooo000F0?ooo`030000
003oool0oooo0;/0oooo0`0000040?ooo`80003o0`3oool2003o00D0oooo103oO`050?ooo`@0o`00
;03oool001H0oooo00<000000?ooo`3oool0_P3oool2000000@0oooo0`000?l20?ooo`800?l01`3o
ool30?mo00H0oooo0`3o000Y0?ooo`005P3oool200000<40oooo0`0000040?ooo`80003o0P3oool4
003o00H0oooo103oO`050?ooo`<0o`009P3oool001H0oooo00<000000?ooo`3oool0``3oool30000
00<0oooo0P000?l40?ooo`D00?l01@3oool40?mo00@0oooo0`3o000S0?ooo`005P3oool00`000000
oooo0?ooo`360?ooo`8000000`3oool40000o`D0oooo1@00o`040?ooo`<0ogl0103oool60?l001d0
oooo000F0?ooo`030000003oool0oooo0<P0oooo0`0000040?ooo`L0003o0`3oool5003o0080oooo
103oO`060?ooo`T0o`00503oool001H0oooo00<000000?ooo`3oool0b`3oool5000000H0oooo1P00
0?l20?ooo`D00?l000<0oooo0?mo003oO`001P3oO`070?ooo`P0o`00303oool000d0oooo0`000006
0?ooo`030000003oool0oooo0=00oooo2@0000030?ooo`L0003o2@00o`0=0?mo0080oooo103o0008
0?ooo`003P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=T0oooo2@0000000`3o
ool0003o0000o`0>0000o`H00?l01P3oO`080?ooo`003P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0>80oooo7@0000080?ooo`003P3oool00`000000oooo0?ooo`050?ooo`800000
o`3oool90?ooo`003P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo203o
ool000d0oooo0P0000070?ooo`030000003oool0oooo0?l0oooo203oool000h0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`P0oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.853268, -0.0773787, \
0.0387714, 0.00624792}}]
}, Closed]],

Cell["\<\
Clines get steeper as the number of loci increases, because linkage \
disequilibrium between the clines makes selection more effective.\
\>", "Text"],

Cell[TextData[{
  "The function becomes somewhat slower as the number of loci, n,  increases, \
because the number of diploid genotype classes increases as ",
  Cell[BoxData[
      \(TraditionalForm\`\((n + 1)\)\^2\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Compiling", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, m, 
              Compiled -> 
                True]\), \(compiles\ the\ \(\(recursions\)\(.\)\(\ \)\)\)},
          {
            RowBox[{"StoreExact", "[", 
              RowBox[{"\[Psi]", ",", \(\[Psi]\_0\), ",", "W", ",", "m", ",", 
                RowBox[{"{", 
                  RowBox[{"t", ",", 
                    StyleBox["dt",
                      FontSlant->"Italic"]}], 
                  StyleBox["}",
                    FontSlant->"Italic"]}], 
                StyleBox[",",
                  FontSlant->"Italic"], \(Compiled -> True\)}], 
              "]"}], \(stores\ calculations\ made\ using\ compiled\ \
\(\(code\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->"Compiled"],

Cell[TextData[{
  "Functions can be greatly speeded by ",
  ButtonBox["compiling",
    ButtonData:>{"Compile"},
    ButtonStyle->"RefGuideLink"],
  ".  This requires that only numbers, or rectangular arrays of numbers, are \
used internally.  However, an arbitrary fitness function can still be \
supplied.  This isused to calculate and store a table of fitnesses, which is \
then used by the compiled code. "
}], "Text"],

Cell["Other options can be set as for uncompiled code.", "Text"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  "  Compilation cannot be used if fitnesses change in every generation.  The \
option StoreResultsa->False should also be set, to prevent all the fitness \
tables being stored."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hp[ng_] := 
        MakeCline[10, ng, 100, 
          NumericalModel \[Rule] SymmetricHaploidFrequencies];\)\), "\n", 
    \(\(\(\(w[s_]\)[_]\)[i_, j_, h_] := \((1 - s)\)\^h;\)\), "\n", 
    \({Timing[
          Nest[IterateExact[#, w[0.2], 0.5] &, hp[3], 
            10]], \[IndentingNewLine]Timing[
          Nest[IterateExact[#, w[0.2], 0.5, Compiled -> True] &, hp[3], 
            10]]} // MatrixForm\)}], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1.6333333333333258`\ Second\), \
\({SymmetricHaploidFrequencies[{0.9896481720037584`, 0.01015092332865933`, 
                    0.0001974869451590067`, 3.417722423400431`*^-6}, 100.`], 
                SymmetricHaploidFrequencies[{0.9688971553793487`, 
                    0.029329720598042487`, 0.0016899521258168123`, 
                    0.00008317189679187163`}, 100.`], 
                SymmetricHaploidFrequencies[{0.9032379901784269`, 
                    0.08259480864280272`, 0.0124759257348538`, 
                    0.0016912754439166987`}, 100.`], 
                SymmetricHaploidFrequencies[{0.7405451521006791`, 
                    0.17494642373740965`, 0.06186373061768236`, 
                    0.02264469354422885`}, 100.`], 
                SymmetricHaploidFrequencies[{0.4448245704909492`, 
                    0.23677143143602614`, 0.17030696060361913`, 
                    0.14809703746940556`}, 100.`], 
                SymmetricHaploidFrequencies[{0.14809703746940564`, 
                    0.1703069606036192`, 0.23677143143602614`, 
                    0.4448245704909492`}, 100.`], 
                SymmetricHaploidFrequencies[{0.02264469354422886`, 
                    0.06186373061768237`, 0.17494642373740965`, 
                    0.7405451521006792`}, 100.`], 
                SymmetricHaploidFrequencies[{0.0016912754439167002`, 
                    0.012475925734853803`, 0.08259480864280272`, 
                    0.9032379901784268`}, 100.`], 
                SymmetricHaploidFrequencies[{0.00008317189679187163`, 
                    0.0016899521258168123`, 0.029329720598042477`, 
                    0.968897155379349`}, 100.`], 
                SymmetricHaploidFrequencies[{3.417722423400432`*^-6, 
                    0.00019748694515900672`, 0.010150923328659323`, 
                    0.9896481720037583`}, 100.`]}\)},
            {\(0.09999999999999432`\ Second\), \
\({SymmetricHaploidFrequencies[{0.9896481720037583`, 0.010150923328659328`, 
                    0.00019748694515900675`, 3.417722423400433`*^-6}, 100.`], 
                SymmetricHaploidFrequencies[{0.9688971553793488`, 
                    0.029329720598042484`, 0.001689952125816812`, 
                    0.00008317189679187163`}, 100.`], 
                SymmetricHaploidFrequencies[{0.9032379901784268`, 
                    0.0825948086428027`, 0.0124759257348538`, 
                    0.0016912754439166995`}, 100.`], 
                SymmetricHaploidFrequencies[{0.740545152100679`, 
                    0.17494642373740962`, 0.061863730617682376`, 
                    0.02264469354422887`}, 100.`], 
                SymmetricHaploidFrequencies[{0.4448245704909491`, 
                    0.23677143143602608`, 0.17030696060361913`, 
                    0.1480970374694056`}, 100.`], 
                SymmetricHaploidFrequencies[{0.14809703746940547`, 
                    0.17030696060361908`, 0.2367714314360261`, 
                    0.4448245704909492`}, 100.`], 
                SymmetricHaploidFrequencies[{0.02264469354422884`, 
                    0.061863730617682335`, 0.1749464237374096`, 
                    0.7405451521006792`}, 100.`], 
                SymmetricHaploidFrequencies[{0.0016912754439166984`, 
                    0.012475925734853795`, 0.08259480864280269`, 
                    0.9032379901784269`}, 100.`], 
                SymmetricHaploidFrequencies[{0.00008317189679187156`, 
                    0.0016899521258168112`, 0.029329720598042466`, 
                    0.9688971553793488`}, 100.`], 
                SymmetricHaploidFrequencies[{3.417722423400429`*^-6, 
                    0.00019748694515900656`, 0.010150923328659321`, 
                    0.9896481720037584`}, 100.`]}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[8]//MatrixForm="]
}, Closed]],

Cell["\<\
Compield code produces the same result as uncompiled code for all \
life cycles:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[
          Nest[IterateExact[#, w[0.2], 0.5, MigrationOrder -> MUS] &, hp[3], 
            10]], \[IndentingNewLine]Timing[
          Nest[IterateExact[#, w[0.2], 0.5, Compiled -> True, 
                MigrationOrder -> MUS] &, hp[3], 10]]} // 
      MatrixForm\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1.3333333333333428`\ Second\), \
\({SymmetricHaploidFrequencies[{0.9884887686488423`, 0.011377964348231668`, 
                    0.00013218608856845632`, 1.0809143577869332`*^-6}, 
                  100.`], 
                SymmetricHaploidFrequencies[{0.9644698720424189`, 
                    0.034306292137276866`, 0.0011963800779268635`, 
                    0.000027455742377371965`}, 100.`], 
                SymmetricHaploidFrequencies[{0.8873217322362368`, 
                    0.10211584022675599`, 0.009947359664841443`, 
                    0.0006150678721659452`}, 100.`], 
                SymmetricHaploidFrequencies[{0.6966778628071438`, 
                    0.233012801606575`, 0.0602623855903844`, 
                    0.010046949995896805`}, 100.`], 
                SymmetricHaploidFrequencies[{0.36951144407640185`, 
                    0.3274400146187143`, 0.21059376518781603`, 
                    0.09245477611706775`}, 100.`], 
                SymmetricHaploidFrequencies[{0.09245477611706776`, 
                    0.2105937651878161`, 0.32744001461871436`, 
                    0.369511444076402`}, 100.`], 
                SymmetricHaploidFrequencies[{0.010046949995896805`, 
                    0.060262385590384396`, 0.23301280160657498`, 
                    0.6966778628071438`}, 100.`], 
                SymmetricHaploidFrequencies[{0.0006150678721659455`, 
                    0.009947359664841443`, 0.10211584022675597`, 
                    0.8873217322362364`}, 100.`], 
                SymmetricHaploidFrequencies[{0.000027455742377371976`, 
                    0.0011963800779268637`, 0.034306292137276886`, 
                    0.9644698720424187`}, 100.`], 
                SymmetricHaploidFrequencies[{1.080914357786933`*^-6, 
                    0.0001321860885684563`, 0.01137796434823167`, 
                    0.988488768648842`}, 100.`]}\)},
            {\(0.2666666666666515`\ Second\), \
\({SymmetricHaploidFrequencies[{0.9884887686488423`, 0.011377964348231668`, 
                    0.00013218608856845635`, 1.0809143577869336`*^-6}, 
                  100.`], 
                SymmetricHaploidFrequencies[{0.9644698720424189`, 
                    0.034306292137276866`, 0.0011963800779268635`, 
                    0.000027455742377371965`}, 100.`], 
                SymmetricHaploidFrequencies[{0.8873217322362367`, 
                    0.10211584022675596`, 0.009947359664841445`, 
                    0.0006150678721659454`}, 100.`], 
                SymmetricHaploidFrequencies[{0.6966778628071437`, 
                    0.23301280160657503`, 0.06026238559038444`, 
                    0.010046949995896816`}, 100.`], 
                SymmetricHaploidFrequencies[{0.36951144407640185`, 
                    0.3274400146187144`, 0.21059376518781614`, 
                    0.0924547761170678`}, 100.`], 
                SymmetricHaploidFrequencies[{0.09245477611706772`, 
                    0.210593765187816`, 0.32744001461871436`, 
                    0.369511444076402`}, 100.`], 
                SymmetricHaploidFrequencies[{0.010046949995896797`, 
                    0.06026238559038437`, 0.23301280160657495`, 
                    0.6966778628071438`}, 100.`], 
                SymmetricHaploidFrequencies[{0.0006150678721659451`, 
                    0.009947359664841443`, 0.10211584022675597`, 
                    0.8873217322362367`}, 100.`], 
                SymmetricHaploidFrequencies[{0.00002745574237737195`, 
                    0.0011963800779268632`, 0.03430629213727688`, 
                    0.9644698720424189`}, 100.`], 
                SymmetricHaploidFrequencies[{1.0809143577869326`*^-6, 
                    0.00013218608856845626`, 0.011377964348231668`, 
                    0.9884887686488422`}, 100.`]}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[9]//MatrixForm="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[
          Nest[IterateExact[#, w[0.2], 0.5, MigrationOrder -> USM] &, hp[3], 
            10]], \[IndentingNewLine]Timing[
          Nest[IterateExact[#, w[0.2], 0.5, Compiled -> True, 
                MigrationOrder -> USM] &, hp[3], 10]]} // 
      MatrixForm\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1.3000000000000114`\ Second\), \
\({SymmetricHaploidFrequencies[{0.9857236344796867`, 0.01393684305327815`, 
                    0.00033291561587611777`, 6.6068511591080015`*^-6}, 
                  100.`], 
                SymmetricHaploidFrequencies[{0.9566067938234153`, 
                    0.04042943629523327`, 0.002809376429596161`, 
                    0.00015439345175541255`}, 100.`], 
                SymmetricHaploidFrequencies[{0.8678248073915447`, 
                    0.1102297971196852`, 0.019207501397535017`, 
                    0.00273789409123535`}, 100.`], 
                SymmetricHaploidFrequencies[{0.673125596365801`, 
                    0.21569603225400058`, 0.08279105925044715`, 
                    0.028387312129751322`}, 100.`], 
                SymmetricHaploidFrequencies[{0.38961552188922755`, 
                    0.2684756703356004`, 0.198257696533156`, 
                    0.14365111124201618`}, 100.`], 
                SymmetricHaploidFrequencies[{0.14365111124201616`, 
                    0.19825769653315603`, 0.2684756703356003`, 
                    0.38961552188922755`}, 100.`], 
                SymmetricHaploidFrequencies[{0.02838731212975132`, 
                    0.08279105925044715`, 0.21569603225400055`, 
                    0.6731255963658009`}, 100.`], 
                SymmetricHaploidFrequencies[{0.00273789409123535`, 
                    0.019207501397535017`, 0.11022979711968517`, 
                    0.8678248073915444`}, 100.`], 
                SymmetricHaploidFrequencies[{0.00015439345175541252`, 
                    0.0028093764295961604`, 0.04042943629523327`, 
                    0.956606793823415`}, 100.`], 
                SymmetricHaploidFrequencies[{6.606851159108`*^-6, 
                    0.00033291561587611777`, 0.013936843053278154`, 
                    0.9857236344796866`}, 100.`]}\)},
            {\(0.26666666666667993`\ Second\), \
\({SymmetricHaploidFrequencies[{0.9857236344796867`, 0.01393684305327815`, 
                    0.0003329156158761179`, 6.606851159108004`*^-6}, 100.`], 
                SymmetricHaploidFrequencies[{0.9566067938234153`, 
                    0.04042943629523327`, 0.002809376429596161`, 
                    0.00015439345175541258`}, 100.`], 
                SymmetricHaploidFrequencies[{0.8678248073915447`, 
                    0.11022979711968517`, 0.019207501397535024`, 
                    0.0027378940912353507`}, 100.`], 
                SymmetricHaploidFrequencies[{0.6731255963658009`, 
                    0.21569603225400052`, 0.08279105925044716`, 
                    0.028387312129751343`}, 100.`], 
                SymmetricHaploidFrequencies[{0.3896155218892274`, 
                    0.2684756703356003`, 0.19825769653315603`, 
                    0.14365111124201618`}, 100.`], 
                SymmetricHaploidFrequencies[{0.14365111124201613`, 
                    0.19825769653315597`, 0.2684756703356003`, 
                    0.38961552188922755`}, 100.`], 
                SymmetricHaploidFrequencies[{0.028387312129751312`, 
                    0.08279105925044711`, 0.21569603225400052`, 
                    0.673125596365801`}, 100.`], 
                SymmetricHaploidFrequencies[{0.0027378940912353472`, 
                    0.01920750139753501`, 0.11022979711968514`, 
                    0.8678248073915444`}, 100.`], 
                SymmetricHaploidFrequencies[{0.00015439345175541236`, 
                    0.0028093764295961587`, 0.04042943629523326`, 
                    0.956606793823415`}, 100.`], 
                SymmetricHaploidFrequencies[{6.606851159107995`*^-6, 
                    0.0003329156158761176`, 0.01393684305327815`, 
                    0.9857236344796866`}, 100.`]}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[10]//MatrixForm="]
}, Closed]],

Cell["\<\
Note that the time taken to do the calculation includes a \
substantial overhead in calculating the fitness table; this is not compiled.  \
Discounting this overhead, there is an order of magnitude increase in speed \
on compiling.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Varying deme size", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            FormBox[\(DemeSize -> F\),
              
              "TraditionalForm"], \(sets\ deme\ size\ to\ \(F[deme]\)[n, 
                W\&_]\)},
          {
            RowBox[{
              FormBox[\(DemeSize -> \(n\^*\)\),
                "TraditionalForm"], 
              "&"}], \(fixes\ deme\ size\ at\ \(n\^*\), \ 
            a\ fixed\ \(\(number\)\(.\)\)\)},
          {\(DemeSize -> ExponentialF[r, \[Beta], \[Lambda]]\), 
            RowBox[{
              RowBox[{
              "sets", " ", "deme", " ", "size", " ", "to", " ", "r", " ", "n",
                 
                
                FormBox[\(\(\(\(W\&_\)\(\ \)\)\^\[Beta]\) \(\(Exp\)\([\)\(-\
\[Lambda]\)\)\),
                  "TraditionalForm"], "n"}], "]"}]},
          {\(DemeSize -> PowerF[r, \[Beta], \[Lambda]]\), 
            RowBox[{
            "sets", " ", "deme", " ", "size", " ", "to", " ", "r", 
              " ", \(n\^\(1 - \[Lambda]\)\), 
              FormBox[\(\(\(W\&_\)\(\ \)\)\^\[Beta]\),
                "TraditionalForm"]}]},
          {\(DemeSize -> {{r\_1, \[Beta]\_1, \[Gamma]\_1, \[Lambda]\_1}, \
\[Ellipsis]}\), 
            RowBox[{
            "sets", " ", "the", " ", "new", " ", "size", " ", "of", " ", 
              "deme", " ", "i", " ", "to", " ", \(r\_i\), 
              " ", \(n\_i\%\(1 - \[Lambda]\_i\)\), 
              FormBox[\(\(\(W\&_\_i\)\(\ \)\)\^\[Beta]\_i\),
                "TraditionalForm"], \(Exp[\(-\[Lambda]\_i\) n\_i]\)}]}
          }], TraditionalForm]],
  CellTags->{"DemeSize", "ExponentialF", "PowerF"}]], "DefinitionBox"],

Cell["\<\
DemeSize->F is a general form which allows deme size to change as a \
function of location, current numbers immediately before selection, and mean \
fitness.  \
\>", "Text"],

Cell[TextData[{
  "Compiled code can only be used with certain definite versions of DemeSize: \
arbitrary functions cannot be supplied.  The general form is  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"r", " ", \(n\^\(1 - \[Lambda]\)\), 
            
            FormBox[\(\(\(\(W\&_\)\(\ \)\)\^\[Beta]\) \(\(Exp\)\([\)\(-\
\[Lambda]\)\)\),
              "TraditionalForm"], "n"}], "]"}], TraditionalForm]]],
  " or ",
  Cell[BoxData[
      FormBox[
        RowBox[{"r", " ", \(n\^\(1 - \[Lambda]\)\), 
          FormBox[\(\(\(W\&_\)\(\ \)\)\^\[Beta]\),
            "TraditionalForm"]}], TraditionalForm]]],
  ".   If these functions are the same in every deme, they can be supplied in \
forms such as DemeSize\[Rule]ExponentialF[r, \[Beta], \[Lambda]]. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[
        Nest[IterateExact[#, w[0.2], 0.5, 
              DemeSize -> ExponentialF[2, 1, 0.01]] &, hp[3], 10]], 
      Timing[Nest[
          IterateExact[#, w[0.2], 0.5, DemeSize -> ExponentialF[2, 1, 0.01], 
              Compiled -> True] &, hp[3], 10]]}\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \({{1.51666666666668`\ Second, \
{SymmetricHaploidFrequencies[{0.9920087261316627`, 0.00786359472823745`, 
              0.00012576810516063926`, 1.9110349392991693`*^-6}, 
            68.85160501501775`], 
          SymmetricHaploidFrequencies[{0.9770079377220885`, 
              0.02189503011254177`, 0.001050499657206587`, 
              0.00004653250816328339`}, 67.94119401763845`], 
          SymmetricHaploidFrequencies[{0.9288491271896022`, 
              0.061968517470006895`, 0.008140267895351673`, 
              0.0010420874450393597`}, 64.99334363596284`], 
          SymmetricHaploidFrequencies[{0.7965211612328104`, 
              0.13999947898279114`, 0.04585924946194921`, 
              0.017620110322449357`}, 58.17616551486647`], 
          SymmetricHaploidFrequencies[{0.49776084082038813`, 
              0.2069865787982599`, 0.14540431754215766`, 
              0.14984826283919445`}, 50.15928199782555`], 
          SymmetricHaploidFrequencies[{0.1498482628391945`, 
              0.14540431754215766`, 0.20698657879825985`, 
              0.497760840820388`}, 50.15928199782555`], 
          SymmetricHaploidFrequencies[{0.017620110322449357`, 
              0.04585924946194921`, 0.13999947898279114`, 
              0.7965211612328105`}, 58.17616551486648`], 
          SymmetricHaploidFrequencies[{0.0010420874450393597`, 
              0.008140267895351673`, 0.06196851747000687`, 
              0.9288491271896021`}, 64.99334363596284`], 
          SymmetricHaploidFrequencies[{0.00004653250816328344`, 
              0.0010504996572065874`, 0.021895030112541763`, 
              0.9770079377220883`}, 67.94119401763845`], 
          SymmetricHaploidFrequencies[{1.91103493929917`*^-6, 
              0.00012576810516063924`, 0.007863594728237446`, 
              0.9920087261316626`}, 
            68.85160501501774`]}}, {0.11666666666667425`\ Second, \
{SymmetricHaploidFrequencies[{0.9920087261316627`, 0.007863594728237453`, 
              0.0001257681051606392`, 1.9110349392991684`*^-6}, 
            68.85160501501774`], 
          SymmetricHaploidFrequencies[{0.9770079377220884`, 
              0.02189503011254177`, 0.0010504996572065868`, 
              0.00004653250816328339`}, 67.94119401763845`], 
          SymmetricHaploidFrequencies[{0.9288491271896021`, 
              0.061968517470006874`, 0.008140267895351671`, 
              0.0010420874450393592`}, 64.99334363596286`], 
          SymmetricHaploidFrequencies[{0.7965211612328104`, 
              0.13999947898279105`, 0.045859249461949185`, 
              0.017620110322449332`}, 58.176165514866504`], 
          SymmetricHaploidFrequencies[{0.4977608408203882`, 
              0.20698657879825985`, 0.14540431754215755`, 
              0.1498482628391944`}, 50.15928199782557`], 
          SymmetricHaploidFrequencies[{0.14984826283919453`, 
              0.14540431754215766`, 0.20698657879825988`, 
              0.49776084082038796`}, 50.15928199782555`], 
          SymmetricHaploidFrequencies[{0.01762011032244936`, 
              0.04585924946194923`, 0.13999947898279114`, 
              0.7965211612328104`}, 58.1761655148665`], 
          SymmetricHaploidFrequencies[{0.0010420874450393605`, 
              0.008140267895351674`, 0.061968517470006874`, 
              0.928849127189602`}, 64.99334363596286`], 
          SymmetricHaploidFrequencies[{0.00004653250816328347`, 
              0.001050499657206588`, 0.02189503011254177`, 
              0.9770079377220884`}, 67.94119401763845`], 
          SymmetricHaploidFrequencies[{1.9110349392991697`*^-6, 
              0.00012576810516063924`, 0.00786359472823745`, 
              0.9920087261316627`}, 68.85160501501775`]}}}\)], "Output",
  CellLabel->"Out[13]="]
}, Closed]],

Cell["\<\
In these examples, deme size is lower in the centre, where mean \
fitness is reduced.\
\>", "Text"],

Cell["\<\
 A list of parameters can be given; this allows for variation in \
population regulation across demes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tbl = Array[{2, 1, 0, 0.01} &, 10];\)\), "\n", 
    \(Timing[
      Nest[IterateExact[#, w[0.2], 0.5, DemeSize -> tbl, Compiled -> True] &, 
        hp[3], 10]]\)}], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \({0.283333333333303`\ Second, \
{SymmetricHaploidFrequencies[{0.9920087261316627`, 0.007863594728237453`, 
            0.0001257681051606392`, 1.9110349392991684`*^-6}, 
          68.85160501501774`], 
        SymmetricHaploidFrequencies[{0.9770079377220884`, 
            0.02189503011254177`, 0.0010504996572065868`, 
            0.00004653250816328339`}, 67.94119401763845`], 
        SymmetricHaploidFrequencies[{0.9288491271896021`, 
            0.061968517470006874`, 0.008140267895351671`, 
            0.0010420874450393592`}, 64.99334363596286`], 
        SymmetricHaploidFrequencies[{0.7965211612328104`, 
            0.13999947898279105`, 0.045859249461949185`, 
            0.017620110322449332`}, 58.176165514866504`], 
        SymmetricHaploidFrequencies[{0.4977608408203882`, 
            0.20698657879825985`, 0.14540431754215755`, 0.1498482628391944`}, 
          50.15928199782557`], 
        SymmetricHaploidFrequencies[{0.14984826283919453`, 
            0.14540431754215766`, 0.20698657879825988`, 
            0.49776084082038796`}, 50.15928199782555`], 
        SymmetricHaploidFrequencies[{0.01762011032244936`, 
            0.04585924946194923`, 0.13999947898279114`, 0.7965211612328104`}, 
          58.1761655148665`], 
        SymmetricHaploidFrequencies[{0.0010420874450393605`, 
            0.008140267895351674`, 0.061968517470006874`, 
            0.928849127189602`}, 64.99334363596286`], 
        SymmetricHaploidFrequencies[{0.00004653250816328347`, 
            0.001050499657206588`, 0.02189503011254177`, 
            0.9770079377220884`}, 67.94119401763845`], 
        SymmetricHaploidFrequencies[{1.9110349392991697`*^-6, 
            0.00012576810516063924`, 0.00786359472823745`, 
            0.9920087261316627`}, 68.85160501501775`]}}\)], "Output",
  CellLabel->"Out[15]="]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{861, 695},
WindowMargins->{{40, Automatic}, {Automatic, 0}},
Visible->True,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "IterateExact"->{
    Cell[2045, 64, 925, 20, 70, "DefinitionBox",
      CellTags->{"IterateExact", "StoreExact"}]},
  "StoreExact"->{
    Cell[2045, 64, 925, 20, 70, "DefinitionBox",
      CellTags->{"IterateExact", "StoreExact"}]},
  "Compiled"->{
    Cell[48627, 1114, 855, 20, 56, "DefinitionBox",
      CellTags->"Compiled"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"IterateExact", 142373, 4137},
  {"StoreExact", 142490, 4140},
  {"Compiled", 142605, 4143}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 43, 0, 36, "SubsectionIcon"],
Cell[1785, 53, 82, 1, 28, "MathCaption"],
Cell[1870, 56, 102, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[1997, 62, 45, 0, 24, "SubsubsectionIcon"],
Cell[2045, 64, 925, 20, 70, "DefinitionBox",
  CellTags->{"IterateExact", "StoreExact"}],
Cell[2973, 86, 161, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3159, 94, 472, 9, 72, "Input"],
Cell[3634, 105, 20357, 457, 184, 3496, 244, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[24006, 565, 104, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[24135, 572, 437, 9, 72, "Input"],
Cell[24575, 583, 23560, 510, 184, 3696, 260, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[48150, 1096, 159, 3, 22, "Text"],
Cell[48312, 1101, 237, 6, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[48586, 1112, 38, 0, 20, "SubsubsectionIcon"],
Cell[48627, 1114, 855, 20, 56, "DefinitionBox",
  CellTags->"Compiled"],
Cell[49485, 1136, 421, 9, 37, "Text"],
Cell[49909, 1147, 64, 0, 22, "Text"],
Cell[49976, 1149, 251, 6, 24, "Text"],

Cell[CellGroupData[{
Cell[50252, 1159, 467, 10, 72, "Input"],
Cell[50722, 1171, 3940, 65, 53, "Output"]
}, Closed]],
Cell[54677, 1239, 111, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[54813, 1246, 327, 7, 42, "Input"],
Cell[55143, 1255, 3987, 67, 53, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[59167, 1327, 328, 7, 42, "Input"],
Cell[59498, 1336, 3949, 66, 53, "Output"]
}, Closed]],
Cell[63462, 1405, 255, 5, 36, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[63754, 1415, 46, 0, 20, "SubsubsectionIcon"],
Cell[63803, 1417, 1630, 37, 136, "DefinitionBox"],
Cell[65436, 1456, 183, 4, 22, "Text"],
Cell[65622, 1462, 793, 19, 39, "Text"],

Cell[CellGroupData[{
Cell[66440, 1485, 323, 7, 42, "Input"],
Cell[66766, 1494, 3753, 63, 276, "Output"]
}, Closed]],
Cell[70534, 1560, 109, 3, 22, "Text"],
Cell[70646, 1565, 133, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[70804, 1572, 222, 5, 42, "Input"],
Cell[71029, 1579, 1836, 32, 142, "Output"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

