(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    217300,       6525]*)
(*NotebookOutlinePosition[    289429,       9120]*)
(*  CellTagsIndexPosition[    289225,       9110]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Including a neutral marker", "SubsectionIcon"],

Cell["This loads this package, as well as the Graphics package:", \
"MathCaption"],

Cell[BoxData[
    \(<< NumericalModels`ExactModel`; << Graphics`;\)], "Input",
  CellLabel->"In[1]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Iterating a single deme", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[SymmetricNeutralHaploidFrequencies[{\[Phi], u}, n], 
              W, m]\), \(gives\ the\ frequency\ of\ the\ selected\ classes, \ 
            and\ the\ frequency\ of\ a\ neutral\ marker\ within\ those\ \
classes, \ 
            after\ one\ generation . \ \ Selection\ is\ followed\ by\ \
immigration\ from\ a\ source\ population\ fixed\ for\ ' 
              1'\ alleles . \ \ The\ array\ u\ gives\ the\ frequency\ of\ the\
\ neutral\ allele\ within\ each\ class\ defined\ by\ the\ selected\ \
\(\(loci\)\(.\)\)\)},
          {\(StoreExact[\[Psi], p0, W, 
              m, {t, dt}]\), \(stores\ results\ in\ \[Psi][
                t]\ for\ t\ generations\ at\ intervals\ dt\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"IterateExact", "StoreExact"}],

Cell[TextData[{
  "This example is for a single deme, initially fixed for '0' alleles at 3 \
selected loci, and 1 neutral locus.  There is 10% selection at each of the 3 \
loci against incoming genes.  It receives immigrants from a source fixed for \
'1' alleles, at a rate 0.05.  The top panels show allele frequency at \
selected loci (which equilibrates at \[Tilde]24%), and the ",
  StyleBox["neutral",
    FontColor->RGBColor[1, 0, 0]],
  " marker (which increases towards 1).  The lower panels show linkage \
disequilibrium amongst selected loci, and between the selected loci and the \
neutral locus."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p0 = 
        MakePopulation[3, {0, 0}, 
          NumericalModel \[Rule] 
            SymmetricNeutralHaploidFrequencies];\)\), "\n", 
    \(\(popList = 
        NestList[IterateExact[#, 0.9\^\((#1 + #2)\) &, 0.05] &, p0, 
          100];\)\), "\n", 
    \(\(pj = \((PlotJoined -> True)\);\)\), "\n", 
    \(\(pr1 = \((PlotRange \[Rule] {{0, 100}, {0, 1}})\);\)\), "\n", 
    \(\(pr2 = \((PlotRange \[Rule] {{0, 100}, {0, 0.05}})\);\)\), "\n", 
    \(\(tp = Transpose[AlleleFrequencyMean[popList]];\)\), "\n", 
    \(\(td = Transpose[DisequilibriumMean[popList]];\)\), "\n", 
    \(\(Show[
        GraphicsArray[\[IndentingNewLine]{{ListPlot[
                tp\[LeftDoubleBracket]1\[RightDoubleBracket], pj, pr1], 
              ListPlot[tp\[LeftDoubleBracket]2\[RightDoubleBracket], pj, 
                PlotStyle \[Rule] Red, pr1]}, {ListPlot[
                td\[LeftDoubleBracket]1\[RightDoubleBracket], pj, pr2], 
              ListPlot[td\[LeftDoubleBracket]2\[RightDoubleBracket], pj, 
                PlotStyle \[Rule] Red, pr2]}}]];\)\)}], "Input",
  CellLabel->"In[64]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.01 0 12.3607 [
[.2 -0.0125 -6 -9 ]
[.2 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.6 -0.0125 -6 -9 ]
[.6 -0.0125 6 0 ]
[.8 -0.0125 -6 -9 ]
[.8 -0.0125 6 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -24 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -24 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -24 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(20)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(40)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(60)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(80)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(100)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.01)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.02)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.03)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.04)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.05)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.01 0 m
.02 .32718 L
.03 .43635 L
.04 .47232 L
.05 .48172 L
.06 .48124 L
.07 .47719 L
.08 .47201 L
.09 .46665 L
.1 .46147 L
.11 .45659 L
.12 .45205 L
.13 .44783 L
.14 .44392 L
.15 .4403 L
.16 .43694 L
.17 .43382 L
.18 .43093 L
.19 .42825 L
.2 .42576 L
.21 .42344 L
.22 .42128 L
.23 .41927 L
.24 .4174 L
.25 .41566 L
.26 .41404 L
.27 .41253 L
.28 .41112 L
.29 .4098 L
.3 .40858 L
.31 .40743 L
.32 .40636 L
.33 .40536 L
.34 .40443 L
.35 .40356 L
.36 .40274 L
.37 .40198 L
.38 .40127 L
.39 .4006 L
.4 .39998 L
.41 .3994 L
.42 .39885 L
.43 .39834 L
.44 .39787 L
.45 .39742 L
.46 .397 L
.47 .39661 L
.48 .39624 L
.49 .3959 L
.5 .39558 L
Mistroke
.51 .39528 L
.52 .395 L
.53 .39473 L
.54 .39449 L
.55 .39426 L
.56 .39404 L
.57 .39384 L
.58 .39365 L
.59 .39347 L
.6 .3933 L
.61 .39315 L
.62 .393 L
.63 .39286 L
.64 .39273 L
.65 .39261 L
.66 .3925 L
.67 .3924 L
.68 .3923 L
.69 .3922 L
.7 .39212 L
.71 .39203 L
.72 .39196 L
.73 .39189 L
.74 .39182 L
.75 .39176 L
.76 .3917 L
.77 .39164 L
.78 .39159 L
.79 .39154 L
.8 .3915 L
.81 .39145 L
.82 .39141 L
.83 .39138 L
.84 .39134 L
.85 .39131 L
.86 .39128 L
.87 .39125 L
.88 .39122 L
.89 .3912 L
.9 .39117 L
.91 .39115 L
.92 .39113 L
.93 .39111 L
.94 .39109 L
.95 .39107 L
.96 .39106 L
.97 .39104 L
.98 .39103 L
.99 .39101 L
1 .391 L
Mistroke
Mfstroke
1 .391 m
1 .391 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.01 0 12.3607 [
[.2 -0.0125 -6 -9 ]
[.2 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.6 -0.0125 -6 -9 ]
[.6 -0.0125 6 0 ]
[.8 -0.0125 -6 -9 ]
[.8 -0.0125 6 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -24 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -24 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -24 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(20)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(40)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(60)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(80)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(100)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.01)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.02)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.03)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.04)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.05)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.01 0 m
.02 .32718 L
.03 .43635 L
.04 .47433 L
.05 .48515 L
.06 .48477 L
.07 .47959 L
.08 .47237 L
.09 .4643 L
.1 .45591 L
.11 .44745 L
.12 .43904 L
.13 .43072 L
.14 .42251 L
.15 .41443 L
.16 .40649 L
.17 .39869 L
.18 .39102 L
.19 .3835 L
.2 .37611 L
.21 .36885 L
.22 .36173 L
.23 .35475 L
.24 .3479 L
.25 .34117 L
.26 .33458 L
.27 .32811 L
.28 .32176 L
.29 .31554 L
.3 .30944 L
.31 .30345 L
.32 .29758 L
.33 .29182 L
.34 .28617 L
.35 .28064 L
.36 .27521 L
.37 .26988 L
.38 .26466 L
.39 .25954 L
.4 .25452 L
.41 .2496 L
.42 .24477 L
.43 .24003 L
.44 .23539 L
.45 .23084 L
.46 .22637 L
.47 .22199 L
.48 .2177 L
.49 .21349 L
.5 .20936 L
Mistroke
.51 .20531 L
.52 .20134 L
.53 .19745 L
.54 .19363 L
.55 .18989 L
.56 .18622 L
.57 .18262 L
.58 .17908 L
.59 .17562 L
.6 .17223 L
.61 .1689 L
.62 .16563 L
.63 .16243 L
.64 .15929 L
.65 .15621 L
.66 .15319 L
.67 .15023 L
.68 .14733 L
.69 .14448 L
.7 .14169 L
.71 .13895 L
.72 .13626 L
.73 .13363 L
.74 .13105 L
.75 .12851 L
.76 .12603 L
.77 .12359 L
.78 .12121 L
.79 .11886 L
.8 .11657 L
.81 .11431 L
.82 .1121 L
.83 .10994 L
.84 .10781 L
.85 .10573 L
.86 .10369 L
.87 .10168 L
.88 .09972 L
.89 .09779 L
.9 .0959 L
.91 .09405 L
.92 .09223 L
.93 .09045 L
.94 .0887 L
.95 .08698 L
.96 .0853 L
.97 .08366 L
.98 .08204 L
.99 .08045 L
1 .0789 L
Mistroke
Mfstroke
1 .0789 m
1 .0789 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.01 0 0.618034 [
[.2 -0.0125 -6 -9 ]
[.2 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.6 -0.0125 -6 -9 ]
[.6 -0.0125 6 0 ]
[.8 -0.0125 -6 -9 ]
[.8 -0.0125 6 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(20)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(40)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(60)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(80)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(100)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.01 0 m
.02 .01682 L
.03 .02907 L
.04 .03909 L
.05 .04776 L
.06 .05548 L
.07 .06245 L
.08 .06879 L
.09 .07458 L
.1 .07988 L
.11 .08474 L
.12 .08921 L
.13 .09333 L
.14 .09712 L
.15 .10063 L
.16 .10386 L
.17 .10686 L
.18 .10963 L
.19 .11219 L
.2 .11458 L
.21 .11678 L
.22 .11884 L
.23 .12074 L
.24 .12252 L
.25 .12417 L
.26 .1257 L
.27 .12713 L
.28 .12846 L
.29 .12971 L
.3 .13086 L
.31 .13194 L
.32 .13295 L
.33 .13389 L
.34 .13477 L
.35 .13559 L
.36 .13635 L
.37 .13707 L
.38 .13774 L
.39 .13836 L
.4 .13894 L
.41 .13949 L
.42 .14 L
.43 .14048 L
.44 .14093 L
.45 .14134 L
.46 .14174 L
.47 .1421 L
.48 .14244 L
.49 .14276 L
.5 .14306 L
Mistroke
.51 .14335 L
.52 .14361 L
.53 .14386 L
.54 .14409 L
.55 .1443 L
.56 .1445 L
.57 .14469 L
.58 .14487 L
.59 .14504 L
.6 .14519 L
.61 .14534 L
.62 .14548 L
.63 .1456 L
.64 .14572 L
.65 .14584 L
.66 .14594 L
.67 .14604 L
.68 .14613 L
.69 .14622 L
.7 .1463 L
.71 .14638 L
.72 .14645 L
.73 .14652 L
.74 .14658 L
.75 .14664 L
.76 .14669 L
.77 .14674 L
.78 .14679 L
.79 .14684 L
.8 .14688 L
.81 .14692 L
.82 .14696 L
.83 .14699 L
.84 .14703 L
.85 .14706 L
.86 .14708 L
.87 .14711 L
.88 .14714 L
.89 .14716 L
.9 .14718 L
.91 .1472 L
.92 .14722 L
.93 .14724 L
.94 .14726 L
.95 .14728 L
.96 .14729 L
.97 .1473 L
.98 .14732 L
.99 .14733 L
1 .14734 L
Mistroke
Mfstroke
1 .14734 m
1 .14734 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.01 0 0.618034 [
[.2 -0.0125 -6 -9 ]
[.2 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.6 -0.0125 -6 -9 ]
[.6 -0.0125 6 0 ]
[.8 -0.0125 -6 -9 ]
[.8 -0.0125 6 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(20)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(40)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(60)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(80)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(100)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.01 0 m
.02 .01682 L
.03 .02907 L
.04 .03961 L
.05 .04943 L
.06 .05893 L
.07 .06826 L
.08 .07747 L
.09 .08661 L
.1 .09566 L
.11 .10464 L
.12 .11353 L
.13 .12234 L
.14 .13105 L
.15 .13966 L
.16 .14818 L
.17 .15658 L
.18 .16489 L
.19 .17308 L
.2 .18115 L
.21 .18912 L
.22 .19697 L
.23 .2047 L
.24 .21232 L
.25 .21982 L
.26 .2272 L
.27 .23447 L
.28 .24162 L
.29 .24865 L
.3 .25556 L
.31 .26236 L
.32 .26905 L
.33 .27562 L
.34 .28208 L
.35 .28842 L
.36 .29466 L
.37 .30079 L
.38 .3068 L
.39 .31271 L
.4 .31852 L
.41 .32422 L
.42 .32981 L
.43 .33531 L
.44 .3407 L
.45 .346 L
.46 .3512 L
.47 .3563 L
.48 .36131 L
.49 .36623 L
.5 .37105 L
Mistroke
.51 .37579 L
.52 .38043 L
.53 .38499 L
.54 .38947 L
.55 .39386 L
.56 .39816 L
.57 .40239 L
.58 .40654 L
.59 .4106 L
.6 .41459 L
.61 .41851 L
.62 .42235 L
.63 .42612 L
.64 .42981 L
.65 .43344 L
.66 .437 L
.67 .44048 L
.68 .44391 L
.69 .44726 L
.7 .45056 L
.71 .45378 L
.72 .45695 L
.73 .46006 L
.74 .46311 L
.75 .46609 L
.76 .46903 L
.77 .4719 L
.78 .47472 L
.79 .47749 L
.8 .4802 L
.81 .48286 L
.82 .48547 L
.83 .48803 L
.84 .49054 L
.85 .493 L
.86 .49541 L
.87 .49778 L
.88 .5001 L
.89 .50238 L
.9 .50461 L
.91 .50681 L
.92 .50895 L
.93 .51106 L
.94 .51313 L
.95 .51515 L
.96 .51714 L
.97 .51909 L
.98 .521 L
.99 .52287 L
1 .52471 L
Mistroke
Mfstroke
1 .52471 m
1 .52471 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[66]:=",
  ImageSize->{456.562, 282.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007800016R000`400?l00000o`00003oo`3oooo9
0?ooo`00o`3oooo90?ooo`00o`3oooo90?ooo`00o`3oooo90?ooo`00o`3oooo90?ooo`00o`3oooo9
0?ooo`00o`3oooo90?ooo`00o`3oooo90?ooo`00o`3oooo90?ooo`00o`3oooo90?ooo`00o`3oooo9
0?ooo`00@@3oool5000000<0oooo0P00000J0?ooo`<000000`3oool2000001T0oooo0`0000040?oo
o`8000006P3oool3000000@0oooo0P00000F0?ooo`<00000103oool2000000@0oooo0P00001=0?oo
o`D000000`3oool2000001X0oooo0`0000030?ooo`8000006@3oool3000000@0oooo0P00000J0?oo
o`<00000103oool2000001H0oooo0`0000040?ooo`800000103oool2000000h0oooo00120?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000006P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool00000603oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000005P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000C@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
01X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000001P0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo000001H0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000d0oooo00130?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000005`3oool500000080oooo00@000000?ooo`3oool00000
5`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000603oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000005P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000CP3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000001L0oooo1@0000020?ooo`040000003oool0oooo
000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000001P0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000001H0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000d0oooo0014
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`040000003o
ool0oooo000000<0oooo00@000000?ooo`3oool000005`3oool4000000<0oooo00@000000?ooo`3o
ool000006@3oool3000000<0oooo00@000000?ooo`3oool000005P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000C`3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool05@3oool010000000oooo0?ooo`0000030?oo
o`040000003oool0oooo000001L0oooo100000030?ooo`040000003oool0oooo000001T0oooo0`00
00030?ooo`040000003oool0oooo000001H0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000d0oooo00110?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`00000H0?ooo`030000003oool0000000<0oooo00@00000
0?ooo`3oool000005`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000001P0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000001H0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000004`0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000001P0oooo00<000000?ooo`00
00000`3oool010000000oooo0?ooo`00000G0?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`3oool00000603oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
5P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000003@3oool00440oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
000001T0oooo0P0000030?ooo`040000003oool0oooo000001P0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`00000H0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`00000E0?ooo`800000103oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000004`0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000001T0
oooo0P0000030?ooo`040000003oool0oooo000001P0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`00000H0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`00000E0?ooo`800000103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00d0oooo00120?ooo`<00000103oool2000001/0oooo00<000000?ooo`3oool00P3oool2000001X0
oooo0P0000040?ooo`8000006P3oool3000000@0oooo0P00000G0?ooo`030000003oool0oooo00<0
oooo0P0000040?ooo`800000CP3oool3000000@0oooo0P00000K0?ooo`030000003oool0oooo0080
oooo0P00000J0?ooo`800000103oool2000001X0oooo0`0000040?ooo`8000005`3oool00`000000
oooo0?ooo`030?ooo`800000103oool2000000h0oooo003o0?ooolT0oooo003o0?ooolT0oooo003o
0?ooolT0oooo000U0?oooj`00000=`3oool00`000000o`000000002Y000001@0oooo000U0?ooo`80
00001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03D0oooo00<000000?l0003o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo000U0?ooo`800000
h@3oool00`000000o`000?ooo`2m0?ooo`009@3oool200000>40oooo00<000000?l0003oool0_@3o
ool002D0oooo0P00003Q0?ooo`030000003o0000oooo0;d0oooo000U0?ooo`800000h@3oool00`00
0000o`000?ooo`2m0?ooo`009@3oool200000>40oooo00<000000?l0003oool0_@3oool002D0oooo
0P00003Q0?ooo`030000003o0000oooo0;d0oooo000U0?ooo`800000h@3oool00`000000o`000?oo
o`2m0?ooo`009@3oool200000>40oooo00<000000?l0003oool0_@3oool002D0oooo0P00003Q0?oo
o`030000003o0000oooo0;d0oooo000U0?ooo`800000h@3oool00`000000o`000?ooo`2m0?ooo`00
9@3oool200000>40oooo00<000000?l0003oool0_@3oool002D0oooo0P00003Q0?ooo`030000003o
0000oooo0:P0oooo00<0o`000?ooo`3oool04P3oool002D0oooo0P00003Q0?ooo`030000003o0000
oooo0:@0oooo1@3o000D0?ooo`009@3oool00`000000oooo0000003P0?ooo`030000003oool0o`00
09d0oooo1`3o000I0?ooo`009@3oool00`000000oooo0000003P0?ooo`030000003oool0o`0009P0
oooo1@3o000P0?ooo`009@3oool00`000000oooo0000003P0?ooo`030000003oool0o`0009<0oooo
1@3o000U0?ooo`009@3oool00`000000oooo0000003P0?ooo`030000003oool0o`0008d0oooo1P3o
000Z0?ooo`003@3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`000004
0?ooo`030000003oool000000<P0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P000003
0?ooo`<00000103oool00`000000oooo0?l000280?ooo`D0o`00<03oool000`0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`000000a`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?l000250?ooo`<0o`00=@3oool000`0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00<0oooo0`0000370?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`030?ooo`80000000<0o`000?ooo`3oool0OP3oool50?l003P0oooo000<
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool000000<L0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o0000O03oool40?l0
03d0oooo000<0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool000000<L0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o0000
N@3oool30?l00440oooo000<0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000P3oool2000000D0oooo00<000000?ooo`000000a`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo00000080oooo0P0000050?ooo`030000003oool0o`0007@0oooo1@3o0014
0?ooo`003@3oool2000000X0oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`000000b03oool2000000X0oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3o0000L03oool40?l004T0oooo000U0?ooo`030000003oool000000>00oooo00<000000?ooo`3o
0000K@3oool30?l004d0oooo000U0?ooo`030000003oool000000>00oooo00<000000?ooo`3o0000
J`3oool20?l00500oooo000U0?ooo`030000003oool000000>00oooo00<000000?ooo`3o0000J03o
ool30?l00580oooo000U0?ooo`030000003oool000000>00oooo00<000000?ooo`3o0000I03oool4
0?l005D0oooo000U0?ooo`030000003oool000000>00oooo00<000000?ooo`3o0000H@3oool30?l0
05T0oooo000U0?ooo`030000003oool000000>00oooo00<000000?ooo`3o0000GP3oool30?l005`0
oooo000U0?ooo`030000003oool000000>00oooo00<000000?ooo`3o0000G03oool20?l005l0oooo
000U0?ooo`030000003oool000000>00oooo00<000000?ooo`3o0000F03oool40?l00640oooo000U
0?ooo`030000003oool000000>00oooo00<000000?ooo`3o0000E`3oool00`3o0000oooo0?ooo`1S
0?ooo`009@3oool00`000000oooo0000003P0?ooo`030000003oool0o`0005<0oooo103o001V0?oo
o`009@3oool00`000000oooo0000003P0?ooo`030000003oool0o`000580oooo00<0o`000?ooo`3o
ool0J03oool002D0oooo00<000000?ooo`000000h03oool00`000000oooo0?l0001>0?ooo`@0o`00
J`3oool002D0oooo00<000000?ooo`000000h03oool00`000000oooo0?l0001<0?ooo`80o`00K`3o
ool002D0oooo00<000000?ooo`000000h03oool00`000000oooo0?l0001;0?ooo`030?l0003oool0
oooo06l0oooo000=0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000000P3oool50000
00<0oooo00<000000?ooo`000000b03oool2000000@0oooo00<000000?ooo`3oool00`3oool20000
0080oooo1@0000030?ooo`030000003oool0o`0004T0oooo0P3o001b0?ooo`00303oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo000000370?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0o`0004H0oooo0`3o001d0?oo
o`00303oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000370?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0o`0004@0oooo
0P3o001g0?ooo`00303oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00P3oool2000000030?ooo`000000oooo0<D0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo0P000000
0`3oool0o`000?ooo`100?ooo`80o`00N@3oool000`0oooo00@000000?ooo`3oool00000203oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0<@0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000
oooo000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030?l0003oool0oooo03d0oooo
0P3o001k0?ooo`00303oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003o
ool000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0a03oool0
10000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool000000`3oool01@000000
oooo0?ooo`3oool000000080oooo00<0o`000?ooo`3oool0?03oool00`3o0000oooo0?ooo`1k0?oo
o`003@3oool2000000X0oooo0P0000030?ooo`<00000103oool010000000oooo0?ooo`0000370?oo
o`8000002P3oool2000000<0oooo0`0000040?ooo`040000003oool0oooo0?l003X0oooo103o001n
0?ooo`009@3oool010000000oooo0?ooo`00003O0?ooo`040000003oool0oooo0?l003T0oooo00<0
o`000?ooo`3oool0P03oool002D0oooo00@000000?ooo`3oool00000g`3oool010000000oooo0?oo
o`3o000g0?ooo`80o`00P`3oool002D0oooo00@000000?ooo`3oool00000g`3oool010000000oooo
0?ooo`3o000e0?ooo`80o`00Q@3oool002D0oooo00@000000?ooo`3oool00000g`3oool010000000
oooo0?ooo`3o000c0?ooo`80o`00Q`3oool002D0oooo00@000000?ooo`3oool00000g`3oool01000
0000oooo0?ooo`3o000b0?ooo`030?l0003oool0oooo08L0oooo000U0?ooo`040000003oool0oooo
00000=l0oooo00@000000?ooo`3oool0o`00<03oool20?l008X0oooo000U0?ooo`040000003oool0
oooo00000=l0oooo00@000000?ooo`3oool0o`00;P3oool20?l008`0oooo000U0?ooo`040000003o
ool0oooo00000=l0oooo00@000000?ooo`3oool0o`00;@3oool00`3o0000oooo0?ooo`2<0?ooo`00
9@3oool010000000oooo0?ooo`00003O0?ooo`040000003oool0oooo0?l002/0oooo0P3o002?0?oo
o`009@3oool010000000oooo0?ooo`00003O0?ooo`040000003oool0oooo0?l002X0oooo00<0o`00
0?ooo`3oool0S`3oool002D0oooo00@000000?ooo`3oool00000g`3oool010000000oooo0?ooo`3o
000Y0?ooo`030?l0003oool0oooo0900oooo000U0?ooo`040000003oool0oooo00000=l0oooo00@0
00000?ooo`3oool0o`009`3oool20?l009<0oooo000U0?ooo`040000003oool0oooo00000=l0oooo
00@000000?ooo`3oool0o`009P3oool00`3o0000oooo0?ooo`2C0?ooo`009@3oool010000000oooo
0?ooo`00003O0?ooo`040000003oool0oooo0?l002@0oooo0P3o002F0?ooo`003@3oool2000000@0
oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`0000040?ooo`040000003oool0oooo0000
0<L0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<00000103oool01000
0000oooo0?ooo`3o000R0?ooo`80o`00V03oool000`0oooo00@000000?ooo`3oool00000203oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo0<<0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000
oooo000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030?l0003oool0oooo01h0oooo
00<0o`000?ooo`3oool0V03oool000`0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000050?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`330?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool01@000000oooo0?oo
o`3oool0000000<0oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?ooo`2I0?ooo`00303o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P0000040?ooo`80
00000P3oool00`000000oooo0?ooo`330?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000`3oool2000000@0oooo0P0000020?ooo`030?l0003oool0oooo01`0oooo00<0o`00
0?ooo`3oool0VP3oool000`0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00050?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`330?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<0o`000?ooo`3oool06P3oool20?l009d0oooo000<0?ooo`040000003oool0oooo
000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`330?ooo`040000003oool0oooo000000P0oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`3o0000oooo
0?ooo`0I0?ooo`030?l0003oool0oooo09d0oooo000=0?ooo`8000002P3oool2000000<0oooo0`00
00040?ooo`050000003oool0oooo0?ooo`000000IP3ooom1000001l0oooo0P00000:0?ooo`800000
0`3oool3000000@0oooo00D000000?ooo`3oool0oooo0?l0000I0?ooo`80o`00X03oool002D0oooo
00D000000?ooo`3oool0oooo000000140?ooob800000N03oool01@000000oooo0?ooo`3oool0o`00
01P0oooo00<0o`000?ooo`3oool0X03oool002D0oooo00D000000?ooo`3oool0oooo0000000d0?oo
oa000000VP3oool01@000000oooo0?ooo`3oool0o`0001L0oooo00<0o`000?ooo`3oool0X@3oool0
02D0oooo00D000000?ooo`3oool0oooo0000000/0?ooo`P00000ZP3oool01@000000oooo0?ooo`3o
ool0o`0001D0oooo0P3o002T0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0280oooo1`00002b0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`2T0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01d0oooo1@00002i0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool04@3oool00`3o
0000oooo0?ooo`2T0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0
oooo1000002n0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool03`3oool20?l00:L0
oooo000U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0503oool500000<80oooo
00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0=0?ooo`80o`00Z@3oool002D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`800000a`3oool00`000000oooo0?oo
o`020?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool0Z@3oool002D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`<00000b@3oool00`000000oooo0?ooo`02
0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool0Z@3oool002D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`800000c03oool00`000000oooo0?ooo`030?oo
o`030?l0003oool0oooo00T0oooo0P3o002/0?ooo`009@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00T0oooo0`00003>0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`2/0?ooo`009@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo0P00003A0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`2]0?ooo`009@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo0P00003C0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool20?l00;00oooo000U0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`2`0?ooo`003@3oool2000000@0oooo00<000000?ooo`3oool00`3oool20000
00@0oooo0`0000030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P00002n
0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000103oool3000000<0oooo00<00000
0?ooo`3oool0103oool0103o0000oooo0?ooo`3oool20?l00;<0oooo000<0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo0`00002o0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0`3o002e0?oo
o`00303oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0000003oool01@000003
0?ooo`030000003oool0oooo0<L0oooo00@000000?ooo`3oool00000203oool01@000000oooo0?oo
o`000000oooo00D000000`3oool00`000000oooo0?ooo`2m0?ooo`00303oool010000000oooo0?oo
o`0000080?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`020?oo
o`800000b03oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool00000
0P3oool00`000000oooo0?ooo`020?ooo`800000_P3oool000`0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool0a`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`000000103oool00`000000oooo0?ooo`2m0?ooo`00303oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000<0oooo0P0000040?ooo`030000003oool0oooo0<L0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`800000103oool00`000000
oooo0?ooo`2m0?ooo`003@3oool2000000X0oooo0P0000050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0b03oool2000000X0oooo0P0000050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0_@3oool002D0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?oo
o`2m0?ooo`009@3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo0;d0oooo000U0?oo
o`030000003oool0oooo0>00oooo00<000000?ooo`3oool0_@3oool002D0oooo00<000000?ooo`3o
ool0h03oool00`000000oooo0?ooo`2m0?ooo`009@3oool00`000000oooo0?ooo`3P0?ooo`030000
003oool0oooo0;d0oooo000U0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool0_@3o
ool002D0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`2m0?ooo`009@3oool00`00
0000oooo0?ooo`3P0?ooo`030000003oool0oooo0;d0oooo000U0?ooo`030000003oool0oooo0>00
oooo00<000000?ooo`3oool0_@3oool002D0oooo00<000000?ooo`3oool0h03oool00`000000oooo
0?ooo`2m0?ooo`009@3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo0;d0oooo000U
0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool0_@3oool002D0oooo00<000000?oo
o`3oool0h03oool00`000000oooo0?ooo`2m0?ooo`009@3oool00`000000oooo0?ooo`3P0?ooo`03
0000003oool0oooo0;d0oooo000U0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool0
_@3oool000d0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<00000103o
ool00`000000oooo0?ooo`380?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000000`3o
ool3000000@0oooo00<000000?ooo`3oool0_@3oool000`0oooo00@000000?ooo`3oool00000203o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo000000390?oo
o`040000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000
003oool0oooo0?ooo`000000_`3oool000`0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000050?ooo`040000003oool0oooo0?ooo`800000b03oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool0oooo0P00002n0?ooo`00
303oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool0b`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool0`@3oool000`0oooo00@000000?ooo`3oool00000203oool01@000000oooo0?oo
o`000000oooo00@00000cP3oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0000
003oool0100000340?ooo`00303oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo
0000003oool00000d@3oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003o
ool00000a`3oool000d0oooo0P00000:0?ooo`8000000P3oool500000<h0oooo0P00000:0?ooo`80
00000P3oool500000<<0oooo003o0?ooolT0oooo003o0?ooolT0oooo003o0?ooolT0oooo003o0?oo
olT0oooo003o0?ooolT0oooo003o0?ooolT0oooo003o0?ooolT0oooo003o0?ooolT0oooo003o0?oo
olT0oooo003o0?ooolT0oooo003o0?ooolT0oooo003o0?ooolT0oooo003o0?ooolT0oooo003o0?oo
olT0oooo003o0?ooolT0oooo003o0?ooolT0oooo003o0?ooolT0oooo000l0?ooo`D000000`3oool2
000001`0oooo0`0000030?ooo`8000006P3oool3000000@0oooo0P00000K0?ooo`<00000103oool2
000001L0oooo0`0000040?ooo`800000103oool2000004P0oooo1@0000030?ooo`800000703oool3
000000<0oooo0P00000J0?ooo`<00000103oool2000001X0oooo0`0000040?ooo`800000603oool3
000000@0oooo0P0000040?ooo`8000003P3oool003d0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`00000L0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000I0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000G0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000180?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000703oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool00000603oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool00000603oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000003@3oool003h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00000I0?ooo`D000000P3oool010000000oooo0?ooo`00000H0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`00000I0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`00000G0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000190?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000006@3oool500000080oooo00@000000?ooo`3oool00000603oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool00000603oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000003@3oool003l0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool000000`3oool010000000
oooo0?ooo`00000H0?ooo`@000000`3oool010000000oooo0?ooo`00000J0?ooo`<000000`3oool0
10000000oooo0?ooo`00000G0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00001:0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0G0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000603o
ool4000000<0oooo00@000000?ooo`3oool000006@3oool3000000<0oooo00@000000?ooo`3oool0
0000603oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000003@3oool003`0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo000001X0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`00000H0?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool000006@3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000A`3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000006P3oool00`000000oooo000000030?ooo`040000003oool0oooo
000001P0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000H0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000=0?ooo`00?03oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000006`3oool2000000<0oooo00@0
00000?ooo`3oool000006@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000001T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000001H0oooo0P000004
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000A`3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000006`3oool2000000<0oooo00@000000?oo
o`3oool000006@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000001P0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000001L0oooo0P0000040?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000003@3oool003d0oooo0`0000040?oo
o`8000007@3oool00`000000oooo0?ooo`020?ooo`8000006`3oool2000000@0oooo0P00000K0?oo
o`<00000103oool2000001P0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000190?oo
o`<00000103oool2000001d0oooo00<000000?ooo`3oool00P3oool2000001/0oooo0P0000040?oo
o`8000006P3oool3000000@0oooo0P00000I0?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000003P3oool00?l0oooob@3oool00?l0oooob@3oool00?l0oooob@3oool00?l0oooob@3oool0
01l0oooo/P00000a0?ooo`80000000<0o`00000000000000[@00000D0?ooo`007`3oool00`000000
oooo0000000P0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?l0000P0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool04P3oool001l0oooo
00@000000?ooo`3oool00000g`3oool010000000oooo0?ooo`3o00320?ooo`007`3oool010000000
oooo0?ooo`00003O0?ooo`040000003oool0oooo0?l00<80oooo000O0?ooo`050000003oool0oooo
0?ooo`000000gP3oool01@000000oooo0?ooo`3oool0o`000<40oooo000O0?ooo`8000000`3oool0
0`000000oooo0?ooo`3K0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool0_P3oool0
01l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo
00<0oooo00<0o`000?ooo`3oool0_@3oool001l0oooo00<000000?ooo`3oool0103oool200000=X0
oooo00<000000?ooo`3oool0103oool20?l00;d0oooo000O0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo0;X0oooo
000O0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?oo
o`060?ooo`030?l0003oool0oooo0;X0oooo000O0?ooo`030000003oool0oooo00L0oooo0P00003G
0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool0^@3oool001l0oooo0P00000:0?oo
o`800000e@3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo0;P0oooo000O0?ooo`03
0000003oool0oooo00/0oooo0P00003C0?ooo`030000003oool0oooo00T0oooo0P3o002h0?ooo`00
7`3oool00`000000oooo0?ooo`0=0?ooo`800000d@3oool00`000000oooo0?ooo`0;0?ooo`030?l0
003oool0oooo0;D0oooo000O0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0cP3o
ool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0;@0oooo000O0?ooo`030000003oool0
oooo0100oooo1000003<0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool0/`3oool0
01l0oooo0P00000E0?ooo`800000bP3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo
0;<0oooo000O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0a`3oool00`000000
oooo0?ooo`0>0?ooo`80o`00/`3oool001l0oooo00<000000?ooo`3oool05`3oool400000<D0oooo
00<000000?ooo`3oool0403oool00`3o0000oooo0?ooo`2`0?ooo`003@3oool2000000@0oooo00@0
00000?ooo`3oool0oooo1@0000030?ooo`030000003oool0oooo01/0oooo0`00002`0?ooo`800000
103oool010000000oooo0?ooo`3oool5000000<0oooo00<000000?ooo`3oool04@3oool00`3o0000
oooo0?ooo`2_0?ooo`00303oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool07P3oool600000:T0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo0180oooo0P3o002_0?ooo`00303oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0903o
ool500000:@0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01@0oooo00<0o`000?ooo`3oool0[03oool000`0oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`020?ooo`800000:P3oool7000009d0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`020?ooo`8000005P3oool00`3o0000oooo0?ooo`2[0?ooo`00
303oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`0`0?ooo`T00000U03oool010000000oooo0?ooo`0000070?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo0:X0oooo000<
0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo03T0oooo400000240?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool0Z@3oool000d0
oooo0P0000090?ooo`<00000103oool00`000000oooo0?ooo`190?ooobL00000GP3oool2000000T0
oooo0`0000040?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0Z03oool001l0oooo
00<000000?ooo`3oool0L03ooolo00000340oooo00<000000?ooo`3oool06@3oool20?l00:P0oooo
000O0?ooo`800000h@3oool00`000000oooo0?ooo`0K0?ooo`030?l0003oool0oooo0:D0oooo000O
0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`2T
0?ooo`007`3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo01d0oooo00<0o`000?oo
o`3oool0X`3oool001l0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`0N0?ooo`03
0?l0003oool0oooo0:80oooo000O0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool0
7`3oool00`3o0000oooo0?ooo`2Q0?ooo`007`3oool00`000000oooo0?ooo`3P0?ooo`030000003o
ool0oooo0200oooo0P3o002Q0?ooo`007`3oool200000>40oooo00<000000?ooo`3oool08P3oool0
0`3o0000oooo0?ooo`2N0?ooo`007`3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo
02<0oooo00<0o`000?ooo`3oool0W@3oool001l0oooo00<000000?ooo`3oool0h03oool00`000000
oooo0?ooo`0T0?ooo`80o`00W@3oool001l0oooo00<000000?ooo`3oool0h03oool00`000000oooo
0?ooo`0V0?ooo`030?l0003oool0oooo09X0oooo000O0?ooo`030000003oool0oooo0>00oooo00<0
00000?ooo`3oool09`3oool00`3o0000oooo0?ooo`2I0?ooo`007`3oool200000>40oooo00<00000
0?ooo`3oool0:03oool00`3o0000oooo0?ooo`2H0?ooo`007`3oool00`000000oooo0?ooo`3P0?oo
o`030000003oool0oooo02T0oooo0P3o002H0?ooo`007`3oool00`000000oooo0?ooo`3P0?ooo`03
0000003oool0oooo02/0oooo0P3o002F0?ooo`003@3oool2000000@0oooo00<000000?ooo`3oool0
0`3oool3000000<0oooo00<000000?ooo`3oool0cP3oool2000000@0oooo00<000000?ooo`3oool0
0`3oool3000000<0oooo00<000000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`2C0?ooo`00303o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
c@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0;P3oool00`3o0000oooo0?ooo`2B0?ooo`00303oool010000000oooo0?ooo`0000070?ooo`D0
00000`3oool200000<h0oooo00@000000?ooo`3oool000001`3oool5000000<0oooo0P00000`0?oo
o`030?l0003oool0oooo0940oooo000<0?ooo`040000003oool0oooo000000L0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3=0?ooo`040000003oool0oooo000000L0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0`0?ooo`80o`00T@3oool000`0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo000000040?ooo`030000003oool0oooo0<d0oooo
00@000000?ooo`3oool00000203oool00`000000oooo000000040?ooo`030000003oool0oooo0380
oooo0P3o002?0?ooo`00303oool010000000oooo0?ooo`0000090?ooo`800000103oool00`000000
oooo0?ooo`3=0?ooo`040000003oool0oooo000000T0oooo0P0000040?ooo`030000003oool0oooo
03@0oooo00<0o`000?ooo`3oool0S03oool000d0oooo0P00000;0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0cP3oool2000000/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0e0?ooo`030?l0003oool0oooo08/0oooo000O0?ooo`030000003oool0oooo0>00oooo
00<000000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`2:0?ooo`007`3oool200000>40oooo00<0
00000?ooo`3oool0=`3oool20?l008X0oooo000O0?ooo`030000003oool0oooo0>00oooo00<00000
0?ooo`3oool0>@3oool20?l008P0oooo000O0?ooo`030000003oool0oooo0>00oooo00<000000?oo
o`3oool0>`3oool20?l008H0oooo000O0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3o
ool0?@3oool00`3o0000oooo0?ooo`230?ooo`007`3oool00`000000oooo0?ooo`3P0?ooo`030000
003oool0oooo03h0oooo0P3o00230?ooo`007`3oool200000>40oooo00<000000?ooo`3oool0@03o
ool20?l00840oooo000O0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool0@P3oool2
0?l007l0oooo000O0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool0A03oool00`3o
0000oooo0?ooo`1l0?ooo`007`3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo04D0
oooo0P3o001l0?ooo`007`3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo04L0oooo
0P3o001j0?ooo`007`3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo04T0oooo0P3o
001h0?ooo`007`3oool200000>40oooo00<000000?ooo`3oool0B`3oool00`3o0000oooo0?ooo`1e
0?ooo`007`3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo04`0oooo0P3o001e0?oo
o`007`3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo04h0oooo0P3o001c0?ooo`00
3@3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000@0oooo00<000000?ooo`3oool0
cP3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000@0oooo00<000000?ooo`3oool0
D03oool20?l00740oooo000<0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo0<d0oooo00@000000?ooo`3oool000001`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0DP3oool20?l006l0oooo000<0?oo
o`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000030?ooo`800000cP3o
ool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000`3oool2000005D0
oooo0`3o001/0?ooo`00303oool010000000oooo0?ooo`0000070?ooo`@00000103oool00`000000
oooo0?ooo`3=0?ooo`040000003oool0oooo000000L0oooo100000040?ooo`030000003oool0oooo
05L0oooo0P3o001Z0?ooo`00303oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0c@3oool010000000oooo0?ooo`0000070?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0F@3oool20?l006P0oooo000<0?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3=0?ooo`040000003oool0
oooo000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1K0?ooo`030?l0003o
ool0oooo06D0oooo000=0?ooo`8000002P3oool2000000@0oooo00<000000?ooo`3oool0cP3oool2
000000X0oooo0P0000040?ooo`030000003oool0oooo05`0oooo103o001S0?ooo`007`3oool00`00
0000oooo0?ooo`3P0?ooo`030000003oool0oooo0600oooo0P3o001Q0?ooo`007`3oool200000>40
oooo00<000000?ooo`3oool0HP3oool00`3o0000oooo0?ooo`1N0?ooo`007`3oool00`000000oooo
0?ooo`3P0?ooo`030000003oool0oooo06<0oooo103o001L0?ooo`007`3oool00`000000oooo0?oo
o`3P0?ooo`030000003oool0oooo06L0oooo0P3o001J0?ooo`007`3oool00`000000oooo0?ooo`3P
0?ooo`030000003oool0oooo06T0oooo0`3o001G0?ooo`007`3oool00`000000oooo0?ooo`3P0?oo
o`030000003oool0oooo06`0oooo0P3o001E0?ooo`007`3oool200000>40oooo00<000000?ooo`3o
ool0KP3oool40?l00540oooo000O0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool0
LP3oool00`3o0000oooo0?ooo`1>0?ooo`007`3oool00`000000oooo0?ooo`3P0?ooo`030000003o
ool0oooo07<0oooo103o001<0?ooo`007`3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0
oooo07L0oooo103o00180?ooo`007`3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo
07/0oooo00<0o`000?ooo`3oool0A@3oool001l0oooo00<000000?ooo`3oool0h03oool00`000000
oooo0?ooo`1l0?ooo`@0o`00@`3oool001l0oooo0P00003Q0?ooo`030000003oool0oooo0800oooo
0`3o00100?ooo`007`3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo08<0oooo103o
000l0?ooo`007`3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo08L0oooo0`3o000i
0?ooo`003@3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000@0oooo00<000000?oo
o`3oool0cP3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000@0oooo00<000000?oo
o`3oool0RP3oool40?l003D0oooo000<0?ooo`040000003oool0oooo000000L0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0<d0oooo00@000000?ooo`3oool000001`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0SP3oool40?l00340oooo
000<0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000030?ooo`80
0000cP3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000`3oool2
000009<0oooo1@3o000/0?ooo`00303oool010000000oooo0?ooo`0000080?ooo`<00000103oool0
0`000000oooo0?ooo`3=0?ooo`040000003oool0oooo000000P0oooo0`0000040?ooo`030000003o
ool0oooo09L0oooo0`3o000Y0?ooo`00303oool010000000oooo0?ooo`0000070?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`3=0?ooo`040000003oool0oooo000000L0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo09X0oooo1P3o000S0?oo
o`00303oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`3=0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo0:00oooo0`3o000P0?ooo`003@3oool2000000T0oooo0`00
00040?ooo`030000003oool0oooo0<h0oooo0P0000090?ooo`<00000103oool00`000000oooo0?oo
o`2S0?ooo`H0o`006P3oool001l0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`2Y
0?ooo`H0o`00503oool001l0oooo0P00003Q0?ooo`030000003oool0oooo0:h0oooo00<0o`000?oo
o`3oool04P3oool001l0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`330?ooo`00
7`3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo0<<0oooo000O0?ooo`030000003o
ool0oooo0>00oooo00<000000?ooo`3oool0``3oool001l0oooo00<000000?ooo`3oool0h03oool0
0`000000oooo0?ooo`330?ooo`007`3oool200000>40oooo00<000000?ooo`3oool0``3oool001l0
oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`330?ooo`007`3oool00`000000oooo
0?ooo`3P0?ooo`030000003oool0oooo0<<0oooo000O0?ooo`030000003oool0oooo0>00oooo00<0
00000?ooo`3oool0``3oool001l0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`33
0?ooo`007`3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo0<<0oooo000O0?ooo`80
0000h@3oool00`000000oooo0?ooo`330?ooo`007`3oool00`000000oooo0?ooo`3P0?ooo`030000
003oool0oooo0<<0oooo000O0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool0``3o
ool001P0oooo0`0000040?ooo`030000003oool0oooo0=T0oooo0`0000040?ooo`030000003oool0
oooo0<<0oooo000I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0fP3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0<<0oooo000I0?ooo`030000003oool0oooo00<0
oooo0P00003K0?ooo`030000003oool0oooo00<0oooo0P0000340?ooo`006@3oool00`000000oooo
0?ooo`3P0?ooo`030000003oool0oooo0<T0oooo000I0?ooo`030000003oool0oooo0>00oooo00<0
00000?ooo`3oool0b@3oool001P0oooo0P00003Q0?ooo`800000b`3oool001T0oooo00<000000?oo
o`3oool0h03oool00`000000oooo0?ooo`390?ooo`00o`3oooo90?ooo`00o`3oooo90?ooo`00o`3o
ooo90?ooo`00o`3oooo90?ooo`00o`3oooo90?ooo`00o`3oooo90?ooo`00o`3oooo90?ooo`00o`3o
ooo90?ooo`00\
\>"],
  ImageRangeCache->{{{0, 455.562}, {281.188, 0}} -> {-0.051369, -0.0309082, \
0.0046157, 0.0046157}, {{11.125, 217.438}, {274.438, 146.938}} -> {-21.7709, \
-0.00989008, 0.584211, 0.000472636}, {{238.062, 444.375}, {274.438, 146.938}} -> \
{-154.35, -0.00989008, 0.584211, 0.000472636}, {{11.125, 217.438}, {134.188, \
6.6875}} -> {-17.6963, -1.45618, 0.564662, 0.00913643}, {{238.062, 444.375}, \
{134.188, 6.6875}} -> {-145.839, -1.45618, 0.564662, 0.00913643}}]
}, Open  ]],

Cell["\<\
The left panel shows the equilibrium frequency of classes 0,\
\[Ellipsis],3; the right panel, the frequency of the neutral marker within \
those classes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pr = {{1, 4}, {0, 1}};\)\), "\n", 
    \(\(Show[
        GraphicsArray[{BarChart[
              popList\[LeftDoubleBracket]\(-1\), 1, 1\[RightDoubleBracket], 
              PlotRange \[Rule] pr], \n\t\t\tBarChart[
              popList\[LeftDoubleBracket]\(-1\), 1, 2\[RightDoubleBracket], 
              PlotRange \[Rule] pr]}]];\)\)}], "Input",
  CellLabel->"In[76]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 0.333333 0 0.618034 [
[0 -0.0125 -3 -9 ]
[0 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.2125 .12361 -18 -4.5 ]
[-0.2125 .12361 0 4.5 ]
[-0.2125 .24721 -18 -4.5 ]
[-0.2125 .24721 0 4.5 ]
[-0.2125 .37082 -18 -4.5 ]
[-0.2125 .37082 0 4.5 ]
[-0.2125 .49443 -18 -4.5 ]
[-0.2125 .49443 0 4.5 ]
[-0.2125 .61803 -6 -4.5 ]
[-0.2125 .61803 0 4.5 ]
[ -0.2 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(1)] 0 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(2)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(3)] .66667 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
-0.2 .12361 m
-0.19375 .12361 L
s
[(0.2)] -0.2125 .12361 1 0 Mshowa
-0.2 .24721 m
-0.19375 .24721 L
s
[(0.4)] -0.2125 .24721 1 0 Mshowa
-0.2 .37082 m
-0.19375 .37082 L
s
[(0.6)] -0.2125 .37082 1 0 Mshowa
-0.2 .49443 m
-0.19375 .49443 L
s
[(0.8)] -0.2125 .49443 1 0 Mshowa
-0.2 .61803 m
-0.19375 .61803 L
s
[(1)] -0.2125 .61803 1 0 Mshowa
.125 Mabswid
-0.2 .0309 m
-0.19625 .0309 L
s
-0.2 .0618 m
-0.19625 .0618 L
s
-0.2 .09271 m
-0.19625 .09271 L
s
-0.2 .15451 m
-0.19625 .15451 L
s
-0.2 .18541 m
-0.19625 .18541 L
s
-0.2 .21631 m
-0.19625 .21631 L
s
-0.2 .27812 m
-0.19625 .27812 L
s
-0.2 .30902 m
-0.19625 .30902 L
s
-0.2 .33992 m
-0.19625 .33992 L
s
-0.2 .40172 m
-0.19625 .40172 L
s
-0.2 .43262 m
-0.19625 .43262 L
s
-0.2 .46353 m
-0.19625 .46353 L
s
-0.2 .52533 m
-0.19625 .52533 L
s
-0.2 .55623 m
-0.19625 .55623 L
s
-0.2 .58713 m
-0.19625 .58713 L
s
.25 Mabswid
-0.2 0 m
-0.2 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
-0.13333 0 m
-0.13333 .3076 L
.13333 .3076 L
.13333 0 L
F
0 g
.5 Mabswid
0 .3076 m
.13333 .3076 L
.13333 0 L
s
1 0 0 r
.2 0 m
.2 .21122 L
.46667 .21122 L
.46667 0 L
F
0 g
.2 0 m
.2 .21122 L
.46667 .21122 L
.46667 0 L
.2 0 L
s
1 0 0 r
.53333 0 m
.53333 .0668 L
.8 .0668 L
.8 0 L
F
0 g
.53333 0 m
.53333 .0668 L
.8 .0668 L
.8 0 L
.53333 0 L
s
1 0 0 r
.86667 0 m
.86667 .03242 L
1.13333 .03242 L
1.13333 0 L
F
0 g
.86667 0 m
.86667 .03242 L
s
.86667 .03242 m
1 .03242 L
s
.86667 0 m
0 0 rlineto s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 0.333333 0 0.618034 [
[0 -0.0125 -3 -9 ]
[0 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.2125 .12361 -18 -4.5 ]
[-0.2125 .12361 0 4.5 ]
[-0.2125 .24721 -18 -4.5 ]
[-0.2125 .24721 0 4.5 ]
[-0.2125 .37082 -18 -4.5 ]
[-0.2125 .37082 0 4.5 ]
[-0.2125 .49443 -18 -4.5 ]
[-0.2125 .49443 0 4.5 ]
[-0.2125 .61803 -6 -4.5 ]
[-0.2125 .61803 0 4.5 ]
[ -0.2 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(1)] 0 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(2)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(3)] .66667 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
-0.2 .12361 m
-0.19375 .12361 L
s
[(0.2)] -0.2125 .12361 1 0 Mshowa
-0.2 .24721 m
-0.19375 .24721 L
s
[(0.4)] -0.2125 .24721 1 0 Mshowa
-0.2 .37082 m
-0.19375 .37082 L
s
[(0.6)] -0.2125 .37082 1 0 Mshowa
-0.2 .49443 m
-0.19375 .49443 L
s
[(0.8)] -0.2125 .49443 1 0 Mshowa
-0.2 .61803 m
-0.19375 .61803 L
s
[(1)] -0.2125 .61803 1 0 Mshowa
.125 Mabswid
-0.2 .0309 m
-0.19625 .0309 L
s
-0.2 .0618 m
-0.19625 .0618 L
s
-0.2 .09271 m
-0.19625 .09271 L
s
-0.2 .15451 m
-0.19625 .15451 L
s
-0.2 .18541 m
-0.19625 .18541 L
s
-0.2 .21631 m
-0.19625 .21631 L
s
-0.2 .27812 m
-0.19625 .27812 L
s
-0.2 .30902 m
-0.19625 .30902 L
s
-0.2 .33992 m
-0.19625 .33992 L
s
-0.2 .40172 m
-0.19625 .40172 L
s
-0.2 .43262 m
-0.19625 .43262 L
s
-0.2 .46353 m
-0.19625 .46353 L
s
-0.2 .52533 m
-0.19625 .52533 L
s
-0.2 .55623 m
-0.19625 .55623 L
s
-0.2 .58713 m
-0.19625 .58713 L
s
.25 Mabswid
-0.2 0 m
-0.2 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
-0.13333 0 m
-0.13333 .51913 L
.13333 .51913 L
.13333 0 L
F
0 g
.5 Mabswid
0 .51913 m
.13333 .51913 L
.13333 0 L
s
1 0 0 r
.2 0 m
.2 .52424 L
.46667 .52424 L
.46667 0 L
F
0 g
.2 0 m
.2 .52424 L
.46667 .52424 L
.46667 0 L
.2 0 L
s
1 0 0 r
.53333 0 m
.53333 .53563 L
.8 .53563 L
.8 0 L
F
0 g
.53333 0 m
.53333 .53563 L
.8 .53563 L
.8 0 L
.53333 0 L
s
1 0 0 r
.86667 0 m
.86667 .5927 L
1.13333 .5927 L
1.13333 0 L
F
0 g
.86667 0 m
.86667 .5927 L
s
.86667 .5927 m
1 .5927 L
s
.86667 0 m
0 0 rlineto s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[76]:=",
  ImageSize->{417.062, 122.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006Q0000NR000`400?l00000o`00003oo`3ooonR
0?ooo`00o`3ooonR0?ooo`00o`3ooonR0?ooo`00o`3ooonR0?ooo`00o`3ooonR0?ooo`00o`3ooonR
0?ooo`00o`3ooonR0?ooo`00o`3ooonR0?ooo`00o`3ooonR0?ooo`00o`3ooonR0?ooo`00o`3ooonR
0?ooo`00o`3ooonR0?ooo`00>03oool3000002X0oooo1@00000Y0?ooo`<00000;03oool300000440
oooo0`00000Z0?ooo`D00000:P3oool3000002/0oooo0`00000>0?ooo`00>@3oool00`000000oooo
0?ooo`0Z0?ooo`040000003oool0oooo000002P0oooo00D000000?ooo`3oool0oooo0000000/0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0:P3oool010000000oooo0?ooo`00000Y
0?ooo`050000003oool0oooo0?ooo`000000:`3oool00`000000oooo0?ooo`0=0?ooo`00>@3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool09`3oool5
00000480oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo02H0oooo1@00000>0?ooo`00>@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
02T0oooo0P00000Z0?ooo`040000003oool0oooo000004<0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0Z0?ooo`800000:@3oool010000000oooo0?ooo`00000?0?ooo`00>@3oool0
0`000000oooo0?ooo`0Y0?ooo`050000003oool0oooo0?ooo`000000;03oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0000004<0oooo00<000000?ooo`3oool0:@3oool01@000000oooo0?oo
o`3oool0000002d0oooo00<000000?ooo`3oool09`3oool00`000000oooo0000000?0?ooo`00>03o
ool2000002/0oooo00D000000?ooo`3oool0oooo0000000X0?ooo`050000003oool0oooo0?ooo`00
0000:`3oool200000480oooo0P00000[0?ooo`050000003oool0oooo0?ooo`000000:@3oool01@00
0000oooo0?ooo`3oool0000002X0oooo0P00000?0?ooo`00>@3oool00`000000oooo0?ooo`0Z0?oo
o`<00000:P3oool3000002d0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0Z0?oo
o`<00000:`3oool3000002`0oooo00<000000?ooo`3oool03@3oool00?l0ooooXP3oool00?l0oooo
XP3oool001h0oooo00<000000?ooo`3oool06@3ooon:000002T0oooo00<000000?ooo`3oool0603o
oon:000000l0oooo000N0?ooo`030000003oool0oooo00H0oooo9@3o00000`000000oooo0?ooo`06
0?ooo`030000003o0000o`000280o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000R
0?l000030000003oool0oooo00H0oooo00<000000?l0003o00008@3o000H0?ooo`030000003oool0
oooo00H0oooo903o00000`000000oooo0?ooo`070?ooo`030000003o0000o`000240o`0000<00000
0?ooo`3oool01P3oool00`000000o`000?l0000R0?l000030000003oool0oooo00H0oooo00<00000
0?l0003o00007`3o000001h0oooo00<000000?ooo`3oool01P3ooolU0?l000030000003oool0oooo
00H0oooo00<000000?l0003o00008P3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`00
0280o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000Q0?l001P0oooo00<000000?oo
o`3oool01P3ooolT0?l000030000003oool0oooo00L0oooo00<000000?l0003o00008@3o00000`00
0000oooo0?ooo`060?ooo`030000003o0000o`000280o`0000<000000?ooo`3oool01P3oool00`00
0000o`000?l0000O0?l000007P3oool00`000000oooo0?ooo`060?ooobD0o`0000<000000?ooo`3o
ool01P3oool00`000000o`000?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o
00008P3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`000240o`00603oool00`000000
oooo0?ooo`060?ooob@0o`0000<000000?ooo`3oool01`3oool00`000000o`000?l0000Q0?l00003
0000003oool0oooo00H0oooo00<000000?l0003o00008P3o00000`000000oooo0?ooo`060?ooo`03
0000003o0000o`0001l0o`00000N0?ooo`030000003oool0oooo00H0oooo9@3o00000`000000oooo
0?ooo`060?ooo`030000003o0000o`000280o`0000<000000?ooo`3oool01P3oool00`000000o`00
0?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o00008@3o000H0?ooo`030000
003oool0oooo00H0oooo903o00000`000000oooo0?ooo`070?ooo`030000003o0000o`000240o`00
00<000000?ooo`3oool01P3oool00`000000o`000?l0000R0?l000030000003oool0oooo00H0oooo
00<000000?l0003o00007`3o000001h0oooo0P0000070?ooobD0o`0000<000000?ooo`3oool01P3o
ool00`000000o`000?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o00008P3o
00000`000000oooo0?ooo`060?oooa<000004@3o000H0?ooo`030000003oool0oooo00H0oooo903o
00000`000000oooo0?ooo`070?ooo`030000003o0000o`000240o`0000<000000?ooo`3oool01P3o
ool00`000000o`000?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o00007`3o
000001h0oooo00<000000?ooo`3oool01P3ooolU0?l000030000003oool0oooo00H0oooo00<00000
0?l0003o00008P3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`000280o`0000<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`060?ooob@0o`0000<000000?ooo`3oool01`3oool0
0`000000o`000?l0000Q0?l000030000003oool0oooo00H0oooo00<000000?l0003o00008P3o0000
0`000000oooo0?ooo`060?ooo`030000003o0000o`0001l0o`00000N0?ooo`030000003oool0oooo
00H0oooo9@3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`000280o`0000<000000?oo
o`3oool01P3oool00`000000o`000?l0000R0?l000030000003oool0oooo0480oooo00<000000?oo
o`3oool01P3ooolT0?l000030000003oool0oooo00L0oooo00<000000?l0003o00008@3o00000`00
0000oooo0?ooo`060?ooo`030000003o0000o`000280o`0000<000000?ooo`3oool01P3oool00`00
0000o`000?l0000O0?l000007P3oool00`000000oooo0?ooo`060?ooobD0o`0000<000000?ooo`3o
ool01P3oool00`000000o`000?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o
00008P3o00000`000000oooo0?ooo`120?ooo`030000003oool0oooo00H0oooo903o00000`000000
oooo0?ooo`070?ooo`030000003o0000o`000240o`0000<000000?ooo`3oool01P3oool00`000000
o`000?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o00007`3o000001h0oooo
0P0000070?ooobD0o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000R0?l000030000
003oool0oooo00H0oooo00<000000?l0003o00008P3o00000`000000oooo0?ooo`120?ooo`030000
003oool0oooo00H0oooo903o00000`000000oooo0?ooo`070?ooo`030000003o0000o`000240o`00
00<000000?ooo`3oool01P3oool00`000000o`000?l0000R0?l000030000003oool0oooo00H0oooo
00<000000?l0003o00007`3o000001h0oooo00<000000?ooo`3oool01P3ooolU0?l000030000003o
ool0oooo00H0oooo00<000000?l0003o00008P3o00000`000000oooo0?ooo`060?ooobH00000A03o
ool00`000000oooo0?ooo`060?ooob@0o`0000<000000?ooo`3oool01`3oool00`000000o`000?l0
000Q0?l000030000003oool0oooo00H0oooo00<000000?l0003o00008P3o00000`000000oooo0?oo
o`060?ooo`030000003o0000o`0001l0o`00000N0?ooo`030000003oool0oooo00H0oooo9@3o0000
0`000000oooo0?ooo`060?ooo`030000003o0000o`000280o`0000<000000?ooo`3oool0L03oool0
0`000000oooo0?ooo`060?ooob@0o`0000<000000?ooo`3oool01`3oool00`000000o`000?l0000Q
0?l000030000003oool0oooo00H0oooo00<000000?l0003o00008P3o00000`000000oooo0?ooo`06
0?ooo`030000003o0000o`0001l0o`00000N0?ooo`030000003oool0oooo00H0oooo9@3o00000`00
0000oooo0?ooo`060?ooo`030000003o0000o`000280o`0000<000000?ooo`3oool0L03oool00`00
0000oooo0?ooo`060?ooob@0o`0000<000000?ooo`3oool01`3oool00`000000o`000?l0000Q0?l0
00030000003oool0oooo00H0oooo00<000000?l0003o00008P3o00000`000000oooo0?ooo`060?oo
o`030000003o0000o`0001l0o`00000N0?ooo`8000001`3ooolU0?l000030000003oool0oooo00H0
oooo00<000000?l0003o00008P3o00000`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00H0
oooo903o00000`000000oooo0?ooo`070?ooo`030000003o0000o`000240o`0000<000000?ooo`3o
ool01P3oool00`000000o`000?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o
00007`3o000001h0oooo00<000000?ooo`3oool01P3ooolU0?l000030000003oool0oooo00H0oooo
00<000000?l0003o00008P3o00000`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00H0oooo
903o00000`000000oooo0?ooo`070?ooo`030000003o0000o`000240o`0000<000000?ooo`3oool0
1P3oool00`000000o`000?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o0000
7`3o000000d0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D000000P3oool00`000000oooo
0?ooo`060?ooobD0o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000R0?l000030000
003oool0oooo05h0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D000000`3oool00`000000
oooo0?ooo`060?ooob@0o`0000<000000?ooo`3oool01`3oool00`000000o`000?l0000Q0?l00003
0000003oool0oooo00H0oooo00<000000?l0003o00008P3o00000`000000oooo0?ooo`060?ooo`03
0000003o0000o`0001l0o`00000<0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`060?ooobD0o`0000<000000?ooo`3oool01P3oool00`00
0000o`000?l0000R0?l000030000003oool0oooo05d0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00H0oooo903o00000`000000oooo0?oo
o`070?ooo`030000003o0000o`000240o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0
000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o00007`3o000000`0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`8000001`3ooolU0?l000030000003o
ool0oooo00H0oooo00<000000?l0003o00008P3o00000`000000oooo0?ooo`1M0?ooo`040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooob@0o`00
00<000000?ooo`3oool01`3oool00`000000o`000?l0000Q0?l000030000003oool0oooo00H0oooo
00<000000?l0003o00008P3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`0001l0o`00
000<0?ooo`040000003oool0oooo000000X0oooo00D000000?ooo`3oool0oooo000000080?ooobD0
o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000R0?l000030000003oool0oooo05d0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo903o00000`000000oooo0?ooo`070?ooo`030000003o0000o`000240o`0000<000000?oo
o`3oool01P3oool00`000000o`000?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0
003o00007`3o000000`0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool01P3ooolU0?l000030000003oool0oooo00H0oooo00<00000
0?l0003o00008P3o00000`000000oooo0?ooo`1M0?ooo`040000003oool0oooo000000L0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00H0oooo903o00000`000000oooo
0?ooo`070?ooo`030000003o0000o`000240o`0000<000000?ooo`3oool01P3oool00`000000o`00
0?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o00007`3o000000`0oooo00@0
00000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool01P3ooolU0?l000030000003oool0oooo00H0oooo00<000000?l0003o00008P3o00000`000000
oooo0?ooo`1M0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00H0oooo903o00000`000000oooo0?ooo`070?ooo`030000003o0000
o`000240o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000R0?l000030000003oool0
oooo00H0oooo00<000000?l0003o00007`3o000000d0oooo0P0000090?ooo`<000000`3oool00`00
0000oooo0?ooo`060?ooobD0o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000R0?l0
00030000003oool0oooo05h0oooo0P0000090?ooo`<00000103oool00`000000oooo0?ooo`060?oo
ob@0o`0000<000000?ooo`3oool01`3oool00`000000o`000?l0000Q0?l000030000003oool0oooo
00H0oooo00<000000?l0003o00008P3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`00
01l0o`00000N0?ooo`8000001`3ooolU0?l000030000003oool0oooo00H0oooo00<000000?l0003o
00008P3o00000`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00H0oooo903o00000`000000
oooo0?ooo`070?ooo`030000003o0000o`000240o`0000<000000?ooo`3oool01P3oool00`000000
o`000?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o00007`3o000001h0oooo
00<000000?ooo`3oool01P3ooolU0?l000030000003oool0oooo00H0oooo00<000000?l0003o0000
8P3o00000`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00H0oooo903o00000`000000oooo
0?ooo`070?ooo`030000003o0000o`000240o`0000<000000?ooo`3oool01P3oool00`000000o`00
0?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o00007`3o000001h0oooo00<0
00000?ooo`3oool01P3ooolU0?l000030000003oool0oooo00H0oooo00<000000?l0003o00008P3o
00000`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00H0oooo903o00000`000000oooo0?oo
o`070?ooo`030000003o0000o`000240o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0
000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o00007`3o000001h0oooo00<00000
0?ooo`3oool01P3ooolU0?l000030000003oool0oooo00H0oooo00<000000?l0003o00008P3o0000
0`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00H0oooo903o00000`000000oooo0?ooo`07
0?ooo`030000003o0000o`000240o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000R
0?l000030000003oool0oooo00H0oooo00<000000?l0003o00007`3o000001h0oooo0P0000070?oo
obD0o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000R0?l000030000003oool0oooo
0700oooo00<000000?ooo`3oool01P3ooolT0?l000030000003oool0oooo00L0oooo00<000000?l0
003o00008@3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`000280o`0000<000000?oo
o`3oool01P3oool00`000000o`000?l0000O0?l000007P3oool00`000000oooo0?ooo`060?ooobD0
o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000R0?l000030000003oool0oooo0700
oooo00<000000?ooo`3oool01P3ooolT0?l000030000003oool0oooo00L0oooo00<000000?l0003o
00008@3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`000280o`0000<000000?ooo`3o
ool01P3oool00`000000o`000?l0000O0?l000007P3oool00`000000oooo0?ooo`060?ooobD0o`00
00<000000?ooo`3oool01P3oool00`000000o`000?l0000R0?l000030000003oool0oooo0700oooo
00<000000?ooo`3oool01P3ooolT0?l000030000003oool0oooo00L0oooo00<000000?l0003o0000
8@3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`000280o`0000<000000?ooo`3oool0
1P3oool00`000000o`000?l0000O0?l000007P3oool00`000000oooo0?ooo`060?ooobD0o`0000<0
00000?ooo`3oool01P3ooolV00000780oooo00<000000?ooo`3oool01P3ooolT0?l000030000003o
ool0oooo00L0oooo00<000000?l0003o00008@3o00000`000000oooo0?ooo`060?ooo`030000003o
0000o`000280o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000O0?l000007P3oool2
000000L0oooo9@3o00000`000000oooo0?ooo`2N0?ooo`030000003oool0oooo00H0oooo903o0000
0`000000oooo0?ooo`070?ooo`030000003o0000o`000240o`0000<000000?ooo`3oool01P3oool0
0`000000o`000?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o00007`3o0000
01h0oooo00<000000?ooo`3oool01P3ooolU0?l000030000003oool0oooo09h0oooo00<000000?oo
o`3oool01P3ooolT0?l000030000003oool0oooo00L0oooo00<000000?l0003o00008@3o00000`00
0000oooo0?ooo`060?ooo`030000003o0000o`000280o`0000<000000?ooo`3oool01P3oool00`00
0000o`000?l0000O0?l000003@3oool2000000@0oooo00<000000?ooo`3oool00`3oool300000080
oooo00<000000?ooo`3oool01P3ooolU0?l000030000003oool0oooo08`0oooo0P0000040?ooo`03
0000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo00H0oooo903o00000`000000
oooo0?ooo`070?ooo`030000003o0000o`000240o`0000<000000?ooo`3oool01P3oool00`000000
o`000?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o00007`3o000000`0oooo
00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool0000000P0oooo9@3o00000`00
0000oooo0?ooo`2;0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooob@0o`0000<000000?ooo`3oool01`3oool00`000000o`000?l0000Q
0?l000030000003oool0oooo00H0oooo00<000000?l0003o00008P3o00000`000000oooo0?ooo`06
0?ooo`030000003o0000o`0001l0o`00000<0?ooo`040000003oool0oooo000000L0oooo1@000002
0?ooo`8000001`3ooolU0?l000030000003oool0oooo08/0oooo00@000000?ooo`3oool000001`3o
ool5000000<0oooo00<000000?ooo`3oool01P3ooolT0?l000030000003oool0oooo00L0oooo00<0
00000?l0003o00008@3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`000280o`0000<0
00000?ooo`3oool01P3oool00`000000o`000?l0000O0?l00000303oool010000000oooo0?ooo`00
00070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01P3ooolU0?l000030000
003oool0oooo08/0oooo00@000000?ooo`3oool000001`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00H0oooo903o00000`000000oooo0?ooo`070?ooo`030000003o0000o`00
0240o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000R0?l000030000003oool0oooo
00H0oooo00<000000?l0003o00007`3o000000`0oooo00@000000?ooo`3oool00000203oool00`00
0000oooo000000030?ooo`030000003oool0oooo00H0oooo9@3o00000`000000oooo0?ooo`2;0?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`06
0?ooob@0o`0000<000000?ooo`3oool01`3oool00`000000o`000?l0000Q0?l000030000003oool0
oooo00H0oooo00<000000?l0003o00008P3o00000`000000oooo0?ooo`060?ooo`030000003o0000
o`0001l0o`00000<0?ooo`040000003oool0oooo000000T0oooo0P0000030?ooo`030000003oool0
oooo00H0oooo9@3o00000`000000oooo0?ooo`2;0?ooo`040000003oool0oooo000000T0oooo0P00
00040?ooo`030000003oool0oooo00H0oooo903o00000`000000oooo0?ooo`070?ooo`030000003o
0000o`000240o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000R0?l000030000003o
ool0oooo00H0oooo00<000000?l0003o00007`3o000000d0oooo0P00000;0?ooo`050000003oool0
oooo0?ooo`000000203ooolU0?l000030000003oool0oooo08`0oooo0P00000;0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01P3ooolT0?l000030000003oool0oooo00L0oooo00<0
00000?l0003o00008@3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`000280o`0000<0
00000?ooo`3oool01P3oool00`000000o`000?l0000O0?l000007P3oool2000000L0oooo9@3o0000
0`000000oooo0?ooo`2N0?ooo`030000003oool0oooo00H0oooo903o00000`000000oooo0?ooo`07
0?ooo`030000003o0000o`000240o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000R
0?l000030000003oool0oooo00H0oooo00<000000?l0003o00007`3o000001h0oooo00<000000?oo
o`3oool01P3ooolU0?l000030000003oool0oooo09h0oooo00<000000?ooo`3oool01P3ooolT0?l0
00030000003oool0oooo00L0oooo00<000000?l0003o00008@3o00000`000000oooo0?ooo`060?oo
o`030000003o0000o`000280o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000O0?l0
00007P3oool00`000000oooo0?ooo`060?ooobD0o`0000<000000?ooo`3oool0WP3oool00`000000
oooo0?ooo`060?ooob@0o`0000<000000?ooo`3oool01`3oool00`000000o`000?l0000Q0?l00003
0000003oool0oooo00H0oooo00<000000?l0003o00008P3o00000`000000oooo0?ooo`060?ooo`03
0000003o0000o`0001l0o`00000N0?ooo`030000003oool0oooo00H0oooo9@3o00000`000000oooo
0?ooo`2N0?ooo`030000003oool0oooo00H0oooo903o00000`000000oooo0?ooo`070?ooo`030000
003o0000o`000240o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000R0?l000030000
003oool0oooo00H0oooo00<000000?l0003o00007`3o000001h0oooo0P0000070?oooa<0o`004`00
002P0?ooo`030000003oool0oooo00H0oooo903o00000`000000oooo0?ooo`070?ooo`030000003o
0000o`000240o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000R0?l000030000003o
ool0oooo00H0oooo00<000000?l0003o00007`3o000001h0oooo00<000000?ooo`3oool0c03oool0
0`000000oooo0?ooo`060?ooob@0o`0000<000000?ooo`3oool01`3oool00`000000o`000?l0000Q
0?l000030000003oool0oooo00H0oooo00<000000?l0003o00008P3o00000`000000oooo0?ooo`06
0?ooo`030000003o0000o`0001l0o`00000N0?ooo`030000003oool0oooo0<`0oooo00<000000?oo
o`3oool01P3ooolT0?l000030000003oool0oooo00L0oooo00<000000?l0003o00008@3o00000`00
0000oooo0?ooo`060?ooo`030000003o0000o`000280o`0000<000000?ooo`3oool01P3oool00`00
0000o`000?l0000O0?l000007P3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00H0
oooo903o00000`000000oooo0?ooo`070?ooo`030000003o0000o`000240o`0000<000000?ooo`3o
ool01P3oool00`000000o`000?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o
00007`3o000001h0oooo0P00003=0?ooo`030000003oool0oooo00H0oooo903o00000`000000oooo
0?ooo`070?ooo`030000003o0000o`000240o`0000<000000?ooo`3oool01P3oool00`000000o`00
0?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o00007`3o000001h0oooo00<0
00000?ooo`3oool0c03oool00`000000oooo0?ooo`060?ooob@0o`0000<000000?ooo`3oool01`3o
ool00`000000o`000?l0000Q0?l000030000003oool0oooo00H0oooo00<000000?l0003o00008P3o
00000`000000oooo0?ooo`060?ooo`030000003o0000o`0001l0o`00000=0?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`<000000`3oool00`000000oooo0?ooo`2j0?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`<00000103oool00`000000oooo0?ooo`060?ooob@0o`0000<00000
0?ooo`3oool01`3oool00`000000o`000?l0000Q0?l000030000003oool0oooo00H0oooo00<00000
0?l0003o00008P3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`0001l0o`00000<0?oo
o`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0;T0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool01P3ooolT0?l000030000003oool0oooo00L0oooo00<000000?l0003o
00008@3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`000280o`0000<000000?ooo`3o
ool01P3oool00`000000o`000?l0000O0?l00000303oool010000000oooo0?ooo`0000070?ooo`05
0000003oool0oooo0?ooo`0000000P3oool200000;X0oooo00@000000?ooo`3oool000001`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3ooolT0?l000030000003o
ool0oooo00L0oooo00<000000?l0003o00008@3o00000`000000oooo0?ooo`060?ooo`030000003o
0000o`000280o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000O0?l00000303oool0
10000000oooo0?ooo`0000070?ooo`@000000`3oool00`000000oooo0?ooo`2i0?ooo`040000003o
ool0oooo000000L0oooo100000040?ooo`030000003oool0oooo00H0oooo903o00000`000000oooo
0?ooo`070?ooo`030000003o0000o`000240o`0000<000000?ooo`3oool01P3oool00`000000o`00
0?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o00007`3o000000`0oooo00@0
00000?ooo`3oool000001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0;T0oooo
00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo903o00000`000000oooo0?ooo`070?ooo`030000003o0000o`000240o`0000<000000?ooo`3o
ool01P3oool00`000000o`000?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o
00007`3o000000`0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0;T0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo903o00000`000000oooo0?ooo`070?ooo`030000003o0000o`00
0240o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000R0?l000030000003oool0oooo
00H0oooo00<000000?l0003o00007`3o000000d0oooo0P00000:0?ooo`8000000`3oool00`000000
oooo0?ooo`2j0?ooo`8000002P3oool2000000@0oooo00<000000?ooo`3oool01P3ooolT0?l00003
0000003oool0oooo00L0oooo00<000000?l0003o00008@3o00000`000000oooo0?ooo`060?ooo`03
0000003o0000o`000280o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000O0?l00000
7P3oool200000<d0oooo00<000000?ooo`3oool01P3ooolT0?l000030000003oool0oooo00L0oooo
00<000000?l0003o00008@3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`000280o`00
00<000000?ooo`3oool01P3oool00`000000o`000?l0000O0?l000007P3oool00`000000oooo0?oo
o`3<0?ooo`030000003oool0oooo00H0oooo903o00000`000000oooo0?ooo`070?ooo`030000003o
0000o`000240o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000R0?l000030000003o
ool0oooo00H0oooo00<000000?l0003o00007`3o000001h0oooo00<000000?ooo`3oool0c03oool0
0`000000oooo0?ooo`060?ooob@0o`0000<000000?ooo`3oool01`3oool00`000000o`000?l0000Q
0?l000030000003oool0oooo00H0oooo00<000000?l0003o00008P3o00000`000000oooo0?ooo`06
0?ooo`030000003o0000o`0001l0o`00000N0?ooo`030000003oool0oooo0<`0oooo00<000000?oo
o`3oool01P3ooolT0?l000030000003oool0oooo00L0oooo00<000000?l0003o00008@3o00000`00
0000oooo0?ooo`060?ooo`030000003o0000o`000280o`0000<000000?ooo`3oool01P3oool00`00
0000o`000?l0000O0?l000007P3oool200000<d0oooo00<000000?ooo`3oool01P3ooolT0?l00003
0000003oool0oooo00L0oooo00<000000?l0003o00008@3o00000`000000oooo0?ooo`060?ooo`03
0000003o0000o`000280o`0000<000000?ooo`3oool01P3oool00`000000o`000?l0000O0?l00000
7P3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00H0oooo903o00000`000000oooo
0?ooo`070?ooo`030000003o0000o`000240o`0000<000000?ooo`3oool01P3oool00`000000o`00
0?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o00007`3o000001h0oooo00<0
00000?ooo`3oool0c03oool00`000000oooo0?ooo`060?ooob@0o`0000<000000?ooo`3oool01`3o
ool00`000000o`000?l0000Q0?l000030000003oool0oooo00H0oooo00<000000?l0003o00008P3o
00000`000000oooo0?ooo`060?ooo`030000003o0000o`0001l0o`00000N0?ooo`030000003oool0
oooo0<`0oooo00<000000?ooo`3oool01P3ooolT0?l000030000003oool0oooo00L0oooo00<00000
0?l0003o00008@3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`000280o`0000<00000
0?ooo`3oool01P3oool00`000000o`000?l0000O0?l000007P3oool200000<d0oooo00<000000?oo
o`3oool01P3ooolT0?l000030000003oool0oooo00L0oooo00<000000?l0003o00008@3o00000`00
0000oooo0?ooo`060?ooo`030000003o0000o`000280o`0000<000000?ooo`3oool01P3oool00`00
0000o`000?l0000O0?l000007P3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00H0
oooo903o00000`000000oooo0?ooo`070?ooo`030000003o0000o`000240o`0000<000000?ooo`3o
ool01P3oool00`000000o`000?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o
00007`3o000000d0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000030?ooo`030000
003oool0oooo0;X0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000040?ooo`030000
003oool0oooo00H0oooo903o00000`000000oooo0?ooo`070?ooo`030000003o0000o`000240o`00
00<000000?ooo`3oool01P3oool00`000000o`000?l0000R0?l000030000003oool0oooo00H0oooo
00<000000?l0003o00007`3o000000`0oooo00@000000?ooo`3oool000001`3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0^@3oool010000000oooo0?ooo`0000070?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooob@0o`0000<00000
0?ooo`3oool01`3oool00`000000o`000?l0000Q0?l000030000003oool0oooo00H0oooo00<00000
0?l0003o00008P3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`0001l0o`00000<0?oo
o`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000020?ooo`800000^P3o
ool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`060?ooob@0o`0000<000000?ooo`3oool01`3oool00`000000o`000?l0000Q0?l00003
0000003oool0oooo00H0oooo00<000000?l0003o00008P3o00000`000000oooo0?ooo`060?ooo`03
0000003o0000o`0001l0o`00000<0?ooo`040000003oool0oooo000000P0oooo0`0000030?ooo`03
0000003oool0oooo0;T0oooo00@000000?ooo`3oool00000203oool3000000@0oooo00<000000?oo
o`3oool01P3ooolT0?l000030000003oool0oooo00L0oooo00<000000?l0003o00008@3o00000`00
0000oooo0?ooo`060?ooo`030000003o0000o`000280o`0000<000000?ooo`3oool01P3oool00`00
0000o`000?l0000O0?l00000303oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`2i0?ooo`040000003oool0oooo000000L0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00H0oooo903o00000`000000oooo
0?ooo`070?ooo`030000003o0000o`000240o`0000<000000?ooo`3oool01P3oool00`000000o`00
0?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o00007`3o000000`0oooo00@0
00000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0^@3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`060?ooob@0o`0000<000000?ooo`3oool01`3oool00`000000o`000?l0000Q
0?l000030000003oool0oooo00H0oooo00<000000?l0003o00008P3o00000`000000oooo0?ooo`06
0?ooo`030000003o0000o`0001l0o`00000=0?ooo`8000002@3oool3000000<0oooo0P00002k0?oo
o`8000002@3oool3000000@0oooo00<000000?ooo`3oool01P3ooolB0?l001<000002@3ooolU0000
00P0oooo00<000000?l0003o00008P3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`00
01l0o`00000N0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0H@3oool00`000000
o`000?l0000R0?l000030000003oool0oooo00H0oooo00<000000?l0003o00007`3o000001h0oooo
00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`1Q0?ooobH00000203oool00`000000o`00
0?l0000O0?l000007P3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo08l0oooo00<0
00000?l0003o00007`3o000001h0oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`2?
0?ooo`030000003o0000o`0001l0o`00000N0?ooo`800000c@3oool00`000000oooo0?ooo`2?0?oo
o`030000003o0000o`0001l0o`00000N0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3o
ool0S`3oool00`000000o`000?l0000O0?l000007P3oool00`000000oooo0?ooo`3<0?ooo`030000
003oool0oooo08l0oooo00<000000?l0003o00007`3o000001h0oooo00<000000?ooo`3oool0c03o
ool00`000000oooo0?ooo`2?0?ooo`030000003o0000o`0001l0o`00000N0?ooo`800000c@3oool0
0`000000oooo0?ooo`2?0?ooo`030000003o0000o`0001l0o`00000N0?ooo`030000003oool0oooo
0<`0oooo00<000000?ooo`3oool0S`3ooolC000000l0o`00000H0?ooo`<000000`3oool00`000000
oooo0?ooo`350?ooo`<00000103oool00`000000oooo0?ooo`2a0?ooo`006@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`2a0?ooo`006@3oool00`000000oooo0?ooo`020?ooo`800000a`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0;40oooo000I0?ooo`030000003oool0oooo0</0oooo00<00000
0?ooo`3oool0]`3oool001T0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`2g0?oo
o`00603oool200000<`0oooo0P00002i0?ooo`006@3oool00`000000oooo0?ooo`3;0?ooo`030000
003oool0oooo0;L0oooo003o0?oooj80oooo003o0?oooj80oooo003o0?oooj80oooo003o0?oooj80
oooo003o0?oooj80oooo003o0?oooj80oooo003o0?oooj80oooo003o0?oooj80oooo003o0?oooj80
oooo003o0?oooj80oooo003o0?oooj80oooo0000\
\>"],
  ImageRangeCache->{{{0, 416.062}, {121.688, 0}} -> {-0.0565657, -0.0147182, \
0.00507888, 0.00507888}, {{11.125, 198.625}, {118.75, 2.875}} -> {-0.273815, \
-0.253924, 0.0218471, 0.0117831}, {{217.375, 404.875}, {118.75, 2.875}} -> \
{-4.77978, -0.253924, 0.0218471, 0.0117831}}]
}, Open  ]],

Cell["\<\
Options can be used in the same way as for \
SymmetricHaploidFrequencies.  For example, MigrationOrder\[Rule]MUS gives the \
life cycle migration \[Rule] random union \[Rule]selection\[Rule] meiosis,  \
instead of the default UMS:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IterateExact[p0, 0.9\^\((#1 + #2)\) &, 0.05, 
      MigrationOrder \[Rule] MUS]\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(SymmetricNeutralHaploidFrequencies[{{0.9363603216199504`, 
          0.026688996642505857`, 0.026688996642505857`, 
          0.010261685095037868`}, {0.004750485474853056`, 0.5`, 0.5`, 
          0.5665267384559226`}}, 1.`]\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell["Compiled code is substantially faster:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[
          Nest[IterateExact[#, 0.9\^\((#1 + #2)\) &, 0.05] &, p0, 
            100]], \[IndentingNewLine]Timing[
          Nest[IterateExact[#, 0.9\^\((#1 + #2)\) &, 0.05, 
                Compiled \[Rule] True] &, p0, 100]]} // MatrixForm\)], "Input",\

  CellLabel->"In[17]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(2.25`\ Second\), \
\(SymmetricNeutralHaploidFrequencies[{{0.49771443296495`, 
                    0.3417573627905046`, 0.1080774495111435`, 
                    0.052450754733401904`}, {0.8399632432531984`, 
                    0.8482343961401766`, 0.86666336394446`, 
                    0.959015934957061`}}, 1.`]\)},
            {\(0.5166666666666515`\ Second\), \
\(SymmetricNeutralHaploidFrequencies[{{0.49771443296495`, 
                    0.34175736279050456`, 0.10807744951114345`, 
                    0.05245075473340186`}, {0.8399632432531969`, 
                    0.848234396140175`, 0.8666633639444592`, 
                    0.9590159349570606`}}, 1.`]\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[17]//MatrixForm="]
}, Open  ]],

Cell["Compiled code gives the same results for other life cycles:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[
          Nest[IterateExact[#, 0.9\^\((#1 + #2)\) &, 0.05, 
                MigrationOrder \[Rule] MUS] &, p0, 
            100]], \[IndentingNewLine]Timing[
          Nest[IterateExact[#, 0.9\^\((#1 + #2)\) &, 0.05, 
                Compiled \[Rule] True, MigrationOrder \[Rule] MUS] &, p0, 
            100]]} // MatrixForm\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1.6333333333336668`\ Second\), \
\(SymmetricNeutralHaploidFrequencies[{{0.28136983790798403`, 
                    0.4087034163637093`, 0.2410001920146688`, 
                    0.06892655371363811`}, {0.9622156308859057`, 
                    0.9641518488593538`, 0.9676353572165004`, 
                    0.9739782341571017`}}, 1.`]\)},
            {\(0.533333333333303`\ Second\), \
\(SymmetricNeutralHaploidFrequencies[{{0.28136983790798387`, 
                    0.4087034163637092`, 0.2410001920146688`, 
                    0.06892655371363812`}, {0.9622156308859067`, 
                    0.9641518488593546`, 0.967635357216501`, 
                    0.9739782341571022`}}, 1.`]\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[35]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[
          Nest[IterateExact[#, 0.9\^\((#1 + #2)\) &, 0.05, 
                MigrationOrder \[Rule] USM] &, p0, 
            100]], \[IndentingNewLine]Timing[
          Nest[IterateExact[#, 0.9\^\((#1 + #2)\) &, 0.05, 
                Compiled \[Rule] True, MigrationOrder \[Rule] USM] &, p0, 
            100]]} // MatrixForm\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1.599999999999909`\ Second\), \
\(SymmetricNeutralHaploidFrequencies[{{0.26735671922841037`, 
                    0.388267367482203`, 0.22891214140664412`, 
                    0.11546377188274247`}, {0.9608969259849631`, 
                    0.9629009483561559`, 0.9665065299837465`, 
                    0.9847325027081182`}}, 1.`]\)},
            {\(0.4166666666665151`\ Second\), \
\(SymmetricNeutralHaploidFrequencies[{{0.2673567192284103`, 
                    0.388267367482203`, 0.22891214140664418`, 
                    0.11546377188274248`}, {0.9608969259849641`, 
                    0.9629009483561562`, 0.9665065299837473`, 
                    0.9847325027081185`}}, 1.`]\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[32]//MatrixForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Iterating a cline", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(\(IterateExactl[{SymmetricNeutralHaploidFrequencies[{\[Psi]\_1, 
                    u\_1}, n\_1], \[Ellipsis]}, W, 
              m]\)\(\ \ \ \)\), \(iterates\ a\ linear\ cline\ under\ the\ \
symmetric\ model, \ including\ a\ neutral\ marker\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"IterateNeutral", "Cline"}],

Cell[TextData[{
  "This example is for a cline for 3 selected loci, and 1 neutral locus; \
initially, set to a step and run  for 100 generations.  Migration is the \
maximum sensible value, ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0.5\)]],
  ".  There is 10% selection at each of the 3 loci against heterozygotes.  \
The top panel shows cline width for selected and ",
  StyleBox["neutral",
    FontColor->RGBColor[1, 0, 0]],
  " loci; the selected cline equilibrates at ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  "=5.75, whilst the neutral cline gets ever wider.  The middle row shows  \
allele frequency at t=25, 50, 75 and 100 generations, and the lower row the \
same for linkage disequilibrium."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p0 = 
        MakeCline[10, 3, 1, 
          NumericalModel \[Rule] 
            SymmetricNeutralHaploidFrequencies];\)\), "\n", 
    \(\(\(\(hetW[s_]\)[_]\)[_, _, h_] := \((1 - s)\)\^h;\)\), "\n", 
    \(\(popList = 
        NestList[IterateExact[#, hetW[0.1], 0.5] &, p0, 100];\)\), "\n", 
    \(\(tw = Transpose[\(ClineWidth[#] &\) /@ popList];\)\), "\n", 
    \(\(tc[t_] := \(tc[t] = 
          Transpose[
            AlleleFrequencyMean[
              popList\[LeftDoubleBracket]
                t\[RightDoubleBracket]]]\);\)\), "\n", 
    \(\(td[t_] := \(td[t] = 
          Transpose[
            DisequilibriumMean[
              popList\[LeftDoubleBracket]
                t\[RightDoubleBracket]]]\);\)\), "\n", 
    \(\(Show[
        GraphicsArray[{\n\t\t\t{Show[
                ListPlot[tw\[LeftDoubleBracket]1\[RightDoubleBracket]], 
                ListPlot[tw\[LeftDoubleBracket]2\[RightDoubleBracket], 
                  PlotStyle \[Rule] Red], 
                PlotRange \[Rule] {{0, 100}, {0, 30}}]}, \n\t\tTable[
              Show[ListPlot[\(tc[
                      t]\)\[LeftDoubleBracket]1\[RightDoubleBracket], 
                  PlotJoined -> True], 
                ListPlot[\(tc[t]\)\[LeftDoubleBracket]2\[RightDoubleBracket], 
                  PlotStyle \[Rule] Red, PlotJoined -> True], 
                PlotRange \[Rule] {{0, 10}, {0, 1}}], {t, 25, 100, 25}], \t
            Table[Show[
                ListPlot[\(td[t]\)\[LeftDoubleBracket]1\[RightDoubleBracket], 
                  PlotJoined -> True], 
                ListPlot[\(td[t]\)\[LeftDoubleBracket]2\[RightDoubleBracket], 
                  PlotStyle \[Rule] Red, PlotJoined -> True], 
                PlotRange \[Rule] {{0, 10}, {0, 0.05}}], {t, 25, 100, 
                25}]}]];\)\), "\n", 
    \(ClineWidth[popList // Last, Neutral \[Rule] True]\)}], "Input",
  CellLabel->"In[48]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45993 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0109508 0.238095 [
[ 0 0 0 0 ]
[ 1 .45993 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45993 L
0 .45993 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0109508 0.245293 0.147835 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.1 0 12.3607 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -24 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -24 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -24 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.01)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.02)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.03)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.04)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.05)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.1 .00592 m
.2 .02749 L
.3 .09977 L
.4 .26404 L
.5 .45474 L
.6 .45474 L
.7 .26404 L
.8 .09977 L
.9 .02749 L
1 .00592 L
s
1 0 0 r
.1 .00744 m
.2 .02962 L
.3 .09126 L
.4 .21097 L
.5 .33809 L
.6 .33809 L
.7 .21097 L
.8 .09126 L
.9 .02962 L
1 .00744 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0109508 0.488926 0.147835 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.1 0 12.3607 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -24 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -24 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -24 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.01)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.02)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.03)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.04)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.05)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.1 .0066 m
.2 .02861 L
.3 .09549 L
.4 .23278 L
.5 .38045 L
.6 .38045 L
.7 .23278 L
.8 .09549 L
.9 .02861 L
1 .0066 L
s
1 0 0 r
.1 .00529 m
.2 .01995 L
.3 .05734 L
.4 .12314 L
.5 .18779 L
.6 .18779 L
.7 .12314 L
.8 .05734 L
.9 .01995 L
1 .00529 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0109508 0.732558 0.147835 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.1 0 12.3607 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -24 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -24 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -24 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.01)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.02)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.03)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.04)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.05)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.1 .00672 m
.2 .02871 L
.3 .09418 L
.4 .22561 L
.5 .36464 L
.6 .36464 L
.7 .22561 L
.8 .09418 L
.9 .02871 L
1 .00672 L
s
1 0 0 r
.1 .00334 m
.2 .01249 L
.3 .03545 L
.4 .07507 L
.5 .11338 L
.6 .11338 L
.7 .07507 L
.8 .03545 L
.9 .01249 L
1 .00334 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0109508 0.97619 0.147835 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.1 0 12.3607 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -24 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -24 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -24 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.01)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.02)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.03)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.04)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.05)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.1 .00675 m
.2 .02873 L
.3 .09382 L
.4 .22376 L
.5 .36061 L
.6 .36061 L
.7 .22376 L
.8 .09382 L
.9 .02873 L
1 .00675 L
s
1 0 0 r
.1 .00207 m
.2 .00774 L
.3 .0219 L
.4 .04621 L
.5 .06963 L
.6 .06963 L
.7 .04621 L
.8 .0219 L
.9 .00774 L
1 .00207 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.161524 0.245293 0.298408 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.1 0 0.618034 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.1 .02676 m
.2 .04177 L
.3 .07776 L
.4 .14507 L
.5 .24848 L
.6 .36955 L
.7 .47296 L
.8 .54027 L
.9 .57627 L
1 .59127 L
s
1 0 0 r
.1 .06835 m
.2 .08625 L
.3 .12353 L
.4 .18278 L
.5 .26362 L
.6 .35441 L
.7 .43526 L
.8 .4945 L
.9 .53178 L
1 .54968 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.161524 0.488926 0.298408 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.1 0 0.618034 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.1 .04048 m
.2 .05622 L
.3 .09269 L
.4 .1578 L
.5 .25378 L
.6 .36426 L
.7 .46023 L
.8 .52534 L
.9 .56181 L
1 .57755 L
s
1 0 0 r
.1 .15794 m
.2 .16989 L
.3 .1943 L
.4 .23191 L
.5 .28155 L
.6 .33648 L
.7 .38613 L
.8 .42373 L
.9 .44814 L
1 .4601 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.161524 0.732558 0.298408 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.1 0 0.618034 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.1 .04391 m
.2 .05976 L
.3 .09624 L
.4 .16073 L
.5 .25497 L
.6 .36306 L
.7 .4573 L
.8 .5218 L
.9 .55827 L
1 .57412 L
s
1 0 0 r
.1 .21536 m
.2 .22284 L
.3 .23807 L
.4 .26143 L
.5 .29209 L
.6 .32594 L
.7 .3566 L
.8 .37996 L
.9 .39519 L
1 .40267 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.161524 0.97619 0.298408 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.1 0 0.618034 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.1 .04481 m
.2 .06069 L
.3 .09716 L
.4 .16149 L
.5 .25528 L
.6 .36275 L
.7 .45654 L
.8 .52087 L
.9 .55734 L
1 .57322 L
s
1 0 0 r
.1 .25111 m
.2 .25574 L
.3 .26518 L
.4 .27963 L
.5 .29857 L
.6 .31946 L
.7 .33841 L
.8 .35286 L
.9 .36229 L
1 .36693 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.312097 0.245293 0.448982 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.01 0 0.0206011 [
[.2 -0.0125 -6 -9 ]
[.2 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.6 -0.0125 -6 -9 ]
[.6 -0.0125 6 0 ]
[.8 -0.0125 -6 -9 ]
[.8 -0.0125 6 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[-0.0125 .10301 -6 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -12 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -12 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -12 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(20)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(40)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(60)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(80)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(100)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10301 m
.00625 .10301 L
s
[(5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(10)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(15)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(20)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(25)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(30)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.01 .0206 Mdot
.02 .0412 Mdot
.03 .05075 Mdot
.04 .05794 Mdot
.05 .06373 Mdot
.06 .06863 Mdot
.07 .07287 Mdot
.08 .07659 Mdot
.09 .07989 Mdot
.1 .08283 Mdot
.11 .08547 Mdot
.12 .08784 Mdot
.13 .08998 Mdot
.14 .09192 Mdot
.15 .09369 Mdot
.16 .09529 Mdot
.17 .09677 Mdot
.18 .09812 Mdot
.19 .09937 Mdot
.2 .10052 Mdot
.21 .10158 Mdot
.22 .10258 Mdot
.23 .1035 Mdot
.24 .10436 Mdot
.25 .10516 Mdot
.26 .10592 Mdot
.27 .10662 Mdot
.28 .10729 Mdot
.29 .10791 Mdot
.3 .10849 Mdot
.31 .10904 Mdot
.32 .10956 Mdot
.33 .11005 Mdot
.34 .11052 Mdot
.35 .11095 Mdot
.36 .11136 Mdot
.37 .11175 Mdot
.38 .11212 Mdot
.39 .11247 Mdot
.4 .11279 Mdot
.41 .1131 Mdot
.42 .1134 Mdot
.43 .11368 Mdot
.44 .11394 Mdot
.45 .11419 Mdot
.46 .11442 Mdot
.47 .11465 Mdot
.48 .11486 Mdot
.49 .11506 Mdot
.5 .11525 Mdot
.51 .11543 Mdot
.52 .1156 Mdot
.53 .11576 Mdot
.54 .11591 Mdot
.55 .11606 Mdot
.56 .11619 Mdot
.57 .11632 Mdot
.58 .11645 Mdot
.59 .11656 Mdot
.6 .11667 Mdot
.61 .11678 Mdot
.62 .11688 Mdot
.63 .11697 Mdot
.64 .11706 Mdot
.65 .11715 Mdot
.66 .11723 Mdot
.67 .11731 Mdot
.68 .11738 Mdot
.69 .11745 Mdot
.7 .11751 Mdot
.71 .11757 Mdot
.72 .11763 Mdot
.73 .11769 Mdot
.74 .11774 Mdot
.75 .11779 Mdot
.76 .11784 Mdot
.77 .11788 Mdot
.78 .11793 Mdot
.79 .11797 Mdot
.8 .118 Mdot
.81 .11804 Mdot
.82 .11807 Mdot
.83 .11811 Mdot
.84 .11814 Mdot
.85 .11817 Mdot
.86 .1182 Mdot
.87 .11822 Mdot
.88 .11825 Mdot
.89 .11827 Mdot
.9 .11829 Mdot
.91 .11832 Mdot
.92 .11834 Mdot
.93 .11836 Mdot
.94 .11837 Mdot
.95 .11839 Mdot
.96 .11841 Mdot
.97 .11842 Mdot
.98 .11844 Mdot
.99 .11845 Mdot
1 .11847 Mdot
1 0 0 r
.01 .0206 Mdot
.02 .0412 Mdot
.03 .05075 Mdot
.04 .05825 Mdot
.05 .06466 Mdot
.06 .07042 Mdot
.07 .07572 Mdot
.08 .08067 Mdot
.09 .08532 Mdot
.1 .0897 Mdot
.11 .09387 Mdot
.12 .09783 Mdot
.13 .10161 Mdot
.14 .10524 Mdot
.15 .10874 Mdot
.16 .11213 Mdot
.17 .11542 Mdot
.18 .11864 Mdot
.19 .1218 Mdot
.2 .12491 Mdot
.21 .128 Mdot
.22 .13106 Mdot
.23 .13412 Mdot
.24 .13717 Mdot
.25 .14023 Mdot
.26 .14331 Mdot
.27 .14641 Mdot
.28 .14953 Mdot
.29 .15269 Mdot
.3 .15589 Mdot
.31 .15912 Mdot
.32 .1624 Mdot
.33 .16572 Mdot
.34 .1691 Mdot
.35 .17253 Mdot
.36 .17601 Mdot
.37 .17955 Mdot
.38 .18315 Mdot
.39 .18682 Mdot
.4 .19054 Mdot
.41 .19434 Mdot
.42 .1982 Mdot
.43 .20213 Mdot
.44 .20614 Mdot
.45 .21022 Mdot
.46 .21437 Mdot
.47 .2186 Mdot
.48 .22291 Mdot
.49 .2273 Mdot
.5 .23178 Mdot
.51 .23633 Mdot
.52 .24098 Mdot
.53 .24571 Mdot
.54 .25053 Mdot
.55 .25545 Mdot
.56 .26045 Mdot
.57 .26556 Mdot
.58 .27076 Mdot
.59 .27606 Mdot
.6 .28146 Mdot
.61 .28697 Mdot
.62 .29258 Mdot
.63 .2983 Mdot
.64 .30414 Mdot
.65 .31008 Mdot
.66 .31614 Mdot
.67 .32231 Mdot
.68 .3286 Mdot
.69 .33502 Mdot
.7 .34156 Mdot
.71 .34822 Mdot
.72 .35502 Mdot
.73 .36194 Mdot
.74 .369 Mdot
.75 .3762 Mdot
.76 .38354 Mdot
.77 .39101 Mdot
.78 .39864 Mdot
.79 .40641 Mdot
.8 .41433 Mdot
.81 .4224 Mdot
.82 .43063 Mdot
.83 .43902 Mdot
.84 .44758 Mdot
.85 .4563 Mdot
.86 .46519 Mdot
.87 .47425 Mdot
.88 .48348 Mdot
.89 .4929 Mdot
.9 .5025 Mdot
.91 .51228 Mdot
.92 .52226 Mdot
.93 .53243 Mdot
.94 .54279 Mdot
.95 .55336 Mdot
.96 .56414 Mdot
.97 .57512 Mdot
.98 .58631 Mdot
.99 .59773 Mdot
1 .60936 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[64]:=",
  ImageSize->{573, 263.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008m00011b000`400?l00000o`00003oo`3ooooo
0?ooocl0oooo003o0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo
003o0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo003o0?ooool0
oooo?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo000g0?ooo`D00000403oool3
000000l0oooo0`00000@0?ooo`<000003@3oool3000000@0oooo0P00000h0?ooo`D00000403oool3
000000l0oooo0`00000@0?ooo`<000003@3oool3000000@0oooo0P00000h0?ooo`D00000403oool3
000000l0oooo0`00000@0?ooo`<000003@3oool3000000@0oooo0P00000h0?ooo`D00000403oool3
000000l0oooo0`00000@0?ooo`<000003@3oool3000000@0oooo0P00000B0?ooo`00>03oool01000
0000oooo0?ooo`00000A0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo0000
000>0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000003P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0=0?oo
o`050000003oool0oooo0?ooo`0000003P3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000h0?ooo`040000003oool0oooo00000140
oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000h0oooo00D000000?oo
o`3oool0oooo0000000=0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000>03o
ool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0
oooo0000000>0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000140oooo000i0?ooo`030000003oool0oooo00h0oooo1@00000>0?oo
o`050000003oool0oooo0?ooo`0000003P3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000i0?ooo`030000003oool0oooo00h0oooo
1@00000>0?ooo`050000003oool0oooo0?ooo`0000003P3oool01@000000oooo0?ooo`3oool00000
00d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000i0?ooo`030000003oool0
oooo00h0oooo1@00000>0?ooo`050000003oool0oooo0?ooo`0000003P3oool01@000000oooo0?oo
o`3oool0000000d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000i0?ooo`03
0000003oool0oooo00h0oooo1@00000>0?ooo`050000003oool0oooo0?ooo`0000003P3oool01@00
0000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
000A0?ooo`00>P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000l0oooo1000
000@0?ooo`<000003P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000003X0oooo
00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000?0?ooo`@00000403oool3000000h0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000j0?ooo`030000003oool0oooo
00d0oooo00@000000?ooo`3oool000003`3oool400000100oooo0`00000>0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000>P3oool00`000000oooo0?ooo`0=0?ooo`040000003o
ool0oooo000000l0oooo1000000@0?ooo`<000003P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000140oooo000g0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000
oooo0000000?0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000=0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000=`3oool01@000000oooo0?ooo`3o
ool0000000l0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`0@0?ooo`050000003o
ool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000003L0
oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0000000l0oooo00<000000?oo
o`3oool0403oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`00000g0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo
0000000?0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000=0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000004@3oool003L0oooo00D000000?ooo`3o
ool0oooo0000000@0?ooo`800000403oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo
0?ooo`000000303oool2000000@0oooo00@000000?ooo`3oool00000=`3oool01@000000oooo0?oo
o`3oool000000100oooo0P00000@0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0
oooo0000000<0?ooo`800000103oool010000000oooo0?ooo`00000g0?ooo`050000003oool0oooo
0?ooo`000000403oool200000100oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3o
ool0000000`0oooo0P0000040?ooo`040000003oool0oooo000003L0oooo00D000000?ooo`3oool0
oooo0000000@0?ooo`800000403oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?oo
o`000000303oool2000000@0oooo00@000000?ooo`3oool000004@3oool003P0oooo0`00000B0?oo
o`030000003oool0oooo00l0oooo0P00000@0?ooo`<000003P3oool00`000000oooo0?ooo`030?oo
o`800000>@3oool300000180oooo00<000000?ooo`3oool03`3oool200000100oooo0`00000>0?oo
o`030000003oool0oooo00<0oooo0P00000i0?ooo`<000004P3oool00`000000oooo0?ooo`0?0?oo
o`800000403oool3000000h0oooo00<000000?ooo`3oool00`3oool2000003T0oooo0`00000B0?oo
o`030000003oool0oooo00l0oooo0P00000@0?ooo`<000003P3oool00`000000oooo0?ooo`030?oo
o`8000004P3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo000W0?ooo`T000000`3o
001B00000080o`00:`3oool9000000@0o`00D00000030?l002/0oooo2P0000060?l004/000001@3o
000[0?ooo`X000003@3o000m000000`0o`005@3oool002L0oooo00<000000?ooo`3oool02@3oool3
0?l000<00000AP3oool3000000<0o`00;@3oool00`000000oooo0?ooo`0:0?ooo`D0o`00AP3oool5
0?l002h0oooo00<000000?ooo`3oool02P3oool3000000L0o`00?@3oool70?l000800000;P3oool0
0`000000oooo0?ooo`0:0?ooo`D000001@3oool50?l003<0oooo1@3o00040?ooo`D00000603oool0
02L0oooo00<000000?ooo`3oool0303oool30?l000<00000@03oool3000000<0o`00<03oool00`00
0000oooo0?ooo`0?0?ooo`@0o`00?P3oool40?l003<0oooo00<000000?ooo`3oool03`3oool30000
0080oooo1@3o000c0?ooo`D0o`0000@0oooo0000000000000000<`3oool00`000000oooo0?ooo`0?
0?ooo`<000001`3oool40?l002X0oooo1@3o00060?ooo`<000007@3oool002L0oooo00<000000?oo
o`3oool03`3oool30?l000030000003oool0oooo03`0oooo00@000000?l0003o0000o`00<`3oool0
0`000000oooo0?ooo`0B0?ooo`040000003o0000o`000?l003P0oooo0`3o00000`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool30?l002`0oooo103o
00050?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`080?ooo`D0o`00803oool50?l000X0oooo00<000000?ooo`3oool07P3oool002L0oooo00<00000
0?ooo`3oool04P3oool20?l003/0oooo00<000000?l0003o0000=P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00<0o`00<P3oool30?l000030?ooo`000000000003L0oooo00<00000
0?ooo`3oool04`3oool2000000L0oooo0P3o000X0?ooo`80o`001`3oool2000003L0oooo00<00000
0?ooo`3oool04`3oool2000000d0oooo1@3o000G0?ooo`@0o`003@3oool200000240oooo000W0?oo
o`030000003oool0oooo01@0oooo0P3o000h0?ooo`80o`00>03oool00`000000oooo0?ooo`0D0?oo
o`8000000`3oool20?l002d0oooo0`3o00030?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`060?ooo`<0o`008P3oool30?l000P0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo1@3o000=0?oo
o`D0o`00403oool00`000000oooo0?ooo`0Q0?ooo`009`3oool00`000000oooo0?ooo`0F0?ooo`03
0?l0003oool0oooo03<0oooo0P3o000j0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool00P3oool20?l002X0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0203oool20?l001h0oooo0P3o000:0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0C0?ooo`d0
o`00503oool00`000000oooo0?ooo`0R0?ooo`009`3oool00`000000oooo0?ooo`0G0?ooo`80o`00
<@3oool20?l000030000003oool0oooo03T0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`030?ooo`030?l0003oool0oooo02D0oooo0P3o00040?ooo`800000>`3oool00`000000oooo
0?ooo`0G0?ooo`8000002P3oool20?l001X0oooo0P3o000:0?ooo`800000>`3oool00`000000oooo
0?ooo`0G0?ooo`800000<P3oool2000002D0oooo000W0?ooo`030000003oool0oooo01P0oooo00<0
00000?l0003oool0;P3oool00`3o000000000?ooo`0l0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool00`3oool20?l002@0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool30?l001@0oooo0`3o
000;0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo02D0oooo000@0?ooo`800000103oool00`000000oooo0?ooo`03
0?ooo`8000000`3oool3000000<0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0]
0?ooo`030?l0003oool0oooo02D0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P000003
0?ooo`<000000`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo0P3o000P
0?ooo`80o`001@3oool00`000000oooo0?ooo`0U0?ooo`800000103oool00`000000oooo0?ooo`03
0?ooo`8000000`3oool3000000<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0;
0?ooo`80o`00403oool20?l000d0oooo00<000000?ooo`3oool09@3oool2000000@0oooo00<00000
0?ooo`3oool00`3oool2000000<0oooo0`0000030?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0V0?ooo`003`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0I0?ooo`030000003o0000oooo02`0oooo00<0o`000000003oool09@3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool0703oool00`3o0000
oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0=0?ooo`<0o`002P3oool30?l000l0oooo00<000000?ooo`3oool0903oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
9P3oool000l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool00`000000o`000?ooo`0Z0?ooo`03
0?l000000000oooo02H0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`06
0?ooo`80o`006P3oool20?l000L0oooo00<000000?ooo`3oool09@3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool2000001`0oooo
00<000000?ooo`3oool03`3oool:0?l00140oooo00<000000?ooo`3oool09@3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool20000
01`0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0W0?ooo`003`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0K0?ooo`030000003o0000oooo02P0oooo00<0o`000000003oool09`3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool0
5P3oool00`3o0000oooo0?ooo`060?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02H0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo000?
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o00009`3oool00`3o0000oooo
0000000X0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01`3oool20?l0
01@0oooo0P3o00090?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02T0oooo000?0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool2000000@0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?l0000U0?ooo`030?l0003oool0000002T0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000020?ooo`800000103oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?oo
o`080?ooo`030000003oool0oooo02L0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000020?ooo`800000103oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool09`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
00000080oooo0P0000040?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0Y0?ooo`00403oool2000000X0oooo0P0000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?l0000U0?ooo`030?l0003oool00000
02X0oooo0P00000:0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00P0oooo00<000000?ooo`3oool0:@3oool2000000X0oooo0P0000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
02T0oooo0P00000:0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Z0?ooo`009`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0o`0002<0oooo00<0o`000?ooo`000000@P3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo0P3o000<0?ooo`80o`002P3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0[0?ooo`009`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0o`000240oooo
00<0o`000?ooo`000000@`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00X0oooo
00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02`0oooo
000W0?ooo`030000003oool0oooo01h0oooo00@000000?ooo`3oool0o`007`3oool0103o0000oooo
0?ooo`0000130?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02P3oool:0?l000`0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0;03oool002L0oooo00<000000?ooo`3oool07`3oool010000000oooo
0?ooo`3o000M0?ooo`040?l0003oool0oooo000004@0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo02d0oooo000W0?ooo`030000003oool0oooo0200
oooo00@000000?ooo`3oool0o`006`3oool0103o0000oooo0?ooo`0000150?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0^0?ooo`00403oool20000
00@0oooo00<000000?ooo`3oool00`3oool200000080oooo1@0000020?ooo`030000003oool0oooo
0200oooo00@000000?ooo`3oool0o`006`3oool0103o0000oooo0?ooo`00000^0?ooo`800000103o
ool00`000000oooo0?ooo`030?ooo`8000000P3oool500000080oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02d0oooo0P0000040?ooo`030000003o
ool0oooo00<0oooo0P0000020?ooo`D000000P3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0;P3oool2000000@0oooo00<000000?ooo`3oool00`3o
ool200000080oooo1@0000020?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0_0?ooo`003`3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Q0?ooo`04
0000003oool0oooo0?l001T0oooo00@0o`000?ooo`3oool00000;P3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0;@3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0;@3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0;`3oool000l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool01@000000oooo0?ooo`3o
ool0o`0001L0oooo00D0o`000?ooo`3oool0oooo0000000^0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0]0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`8000009@3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02h0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo0P00000U0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0<03oool000l0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000903oool0
1@000000oooo0?ooo`3oool0o`0001D0oooo00D0o`000?ooo`3oool0oooo0000000_0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0
000002H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0^0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000002L0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0_0?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000002L0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0a0?ooo`003`3oool010000000oooo0?ooo`00
00080?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00000U0?oo
o`040000003oool0oooo0?l001D0oooo00@0o`000?ooo`3oool00000<03oool010000000oooo0?oo
o`0000080?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00000W
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;`3oool010000000oooo0?ooo`00
00080?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00000X0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0<03oool010000000oooo0?ooo`000008
0?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00000X0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0<P3oool000l0oooo00@000000?ooo`3oool0
0000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000009@3o
ool01@000000oooo0?ooo`3oool0o`0001<0oooo00D0o`000?ooo`3oool0oooo0000000`0?ooo`04
0000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003o
ool0oooo000002P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0`0?ooo`040000
003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0
oooo000002P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0`0?ooo`040000003o
ool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo
000002P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0b0?ooo`00403oool20000
00X0oooo0P0000030?ooo`<000000`3oool00`000000oooo0?ooo`0T0?ooo`050000003oool0oooo
0?ooo`3o00004@3oool01@3o0000oooo0?ooo`3oool000000380oooo0P00000:0?ooo`8000000`3o
ool3000000<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0340oooo0P00000:0?ooo`8000000`3oool3000000<0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0380oooo0P00000:0?ooo`8000000`3o
ool3000000<0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo03<0oooo000W0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0=03oool0
02L0oooo00<000000?ooo`3oool09@3oool01@000000oooo0?ooo`3oool0o`0000l0oooo00D0o`00
0?ooo`3oool0oooo0000001:0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0e0?ooo`009`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo0080oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo03H0oooo000W0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`090?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0=P3oool002L0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`030?ooo`/0o`001@3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0g0?ooo`00403oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000<0oooo
0`0000030?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0c0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000000`3oool3000000<0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03H0oooo
0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<000000`3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=`3oool2000000@0oooo
00<000000?ooo`3oool00`3oool2000000<0oooo0`0000030?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0h0?ooo`003`3oool010000000oooo0?oo
o`0000080?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00000Y
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<P3oool010000000oooo0?ooo`00
00080?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00000]0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0=@3oool010000000oooo0?ooo`000008
0?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00000_0?ooo`X0
0000>@3oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool000000`3o
ool010000000oooo0?ooo`00000_0?ooo`X00000>`3oool000l0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000002X0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0c0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000001@3oool010000000oooo0?ooo`00000^0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0=P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool00P00001a0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`02000007<0oooo000?0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000`3oool2000000<0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03<0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000030?ooo`8000000`3oool00`000000oooo0?ooo`0]0?oo
o`X00000>@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P00
00030?ooo`030000003oool0oooo0700oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000030?ooo`8000000`3oool00`000000oooo0?ooo`1b0?ooo`003`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool00000:`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03@0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo00000780oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo00000780oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo0000
07@0oooo000?0?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0d0?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`000003
0?ooo`040000003oool0oooo00000780oooo00@000000?ooo`3oool00000203oool01P000000oooo
0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool00000LP3oool010000000oooo0?ooo`00
00080?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00001d0?oo
o`00403oool2000000X0oooo0P0000030?ooo`<000000`3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0=P3oool2000000X0oooo0P0000030?ooo`<0
00000`3oool00`000000oooo0?ooo`1a0?ooo`8000002P3oool2000000<0oooo0`0000030?ooo`03
0000003oool0oooo0740oooo0P00000:0?ooo`8000000`3oool3000000<0oooo00<000000?ooo`3o
ool0LP3oool002L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo0780oooo000W0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`1b0?ooo`009`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`280?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0LP3oool002L0oooo00<000000?ooo`3oool0;03oool;0000
0540oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo
0780oooo000@0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000103oool300000080
oooo00<000000?ooo`3oool0L@3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0
oooo0`0000020?ooo`030000003oool0oooo0740oooo0P0000040?ooo`030000003oool0oooo00<0
oooo0P0000040?ooo`<000000P3oool00`000000oooo0?ooo`1a0?ooo`800000103oool00`000000
oooo0?ooo`030?ooo`800000103oool300000080oooo00<000000?ooo`3oool0LP3oool000l0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo
0?ooo`000000LP3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo
00D000000?ooo`3oool0oooo0000001b0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool01@000000oooo0?ooo`3oool000000780oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000M03oool000l0
oooo00@000000?ooo`3oool00000203oool01@000000oooo0?ooo`000000oooo00D000000P3oool0
0`000000oooo0?ooo`1`0?ooo`040000003oool0oooo000000P0oooo00D000000?ooo`3oool00000
0?ooo`0500000080oooo00<000000?ooo`3oool0L03oool010000000oooo0?ooo`0000080?ooo`05
0000003oool0oooo0000003oool01@0000020?ooo`030000003oool0oooo0700oooo00@000000?oo
o`3oool00000203oool01@000000oooo0?ooo`000000oooo00D000000P3oool00`000000oooo0?oo
o`1b0?ooo`003`3oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool0
00000P3oool01@000000oooo0?ooo`3oool000000780oooo00@000000?ooo`3oool00000203oool0
1P000000oooo0?ooo`000000oooo00000080oooo00D000000?ooo`3oool0oooo0000001b0?ooo`04
0000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`040000003o
ool0oooo0?ooo`800000L@3oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000
003oool000000P3oool010000000oooo0?ooo`3oool2000007<0oooo000?0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000030?ooo`030000
003oool0oooo0700oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool0L03oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`1`0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo000000030?ooo`030000003oool0oooo0780oooo000?0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000`3oool2000000<0oooo00<000000?ooo`3oool0L03oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P0000030?ooo`030000003o
ool0oooo0700oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`80
00000`3oool00`000000oooo0?ooo`1`0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000`3oool2000000<0oooo00<000000?ooo`3oool0LP3oool00100oooo0P00000:0?oo
o`8000001@3oool01@000000oooo0?ooo`3oool0000007<0oooo0P00000:0?ooo`8000001@3oool0
1@000000oooo0?ooo`3oool0000007<0oooo0P00000:0?ooo`8000001@3oool01@000000oooo0?oo
o`3oool0000007<0oooo0P00000:0?ooo`8000001@3oool01@000000oooo0?ooo`3oool0000007@0
oooo000W0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo0780oooo000W0?ooo`030000003oool0oooo08P0oooo00<0
00000?ooo`3oool0R03oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0780oooo000W
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`28
0?ooo`030000003oool0oooo0780oooo000W0?ooo`030000003oool0oooo08P0oooo00<000000?oo
o`3oool0R03oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0780oooo000W0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`280?ooo`03
0000003oool0oooo0780oooo000@0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000
0`3oool3000000<0oooo00<000000?ooo`3oool0L@3oool2000000@0oooo00<000000?ooo`3oool0
0`3oool2000000<0oooo0`0000030?ooo`030000003oool0oooo0740oooo0P0000040?ooo`030000
003oool0oooo00<0oooo0P0000030?ooo`<000000`3oool00`000000oooo0?ooo`1a0?ooo`800000
103oool00`000000oooo0?ooo`030?ooo`8000000`3oool3000000<0oooo00<000000?ooo`3oool0
LP3oool000l0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00@000000?ooo`3oool00000LP3oool010000000oooo0?ooo`0000080?ooo`060000003o
ool0oooo0000003oool000000`3oool010000000oooo0?ooo`00001b0?ooo`040000003oool0oooo
000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo00000780
oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00@0
00000?ooo`3oool00000M03oool000l0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000050?ooo`040000003oool0oooo00000780oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000050?ooo`040000003oool0oooo00000780oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo00000780oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000007@0
oooo000?0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool01000
0000oooo0?ooo`00001b0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
1@3oool010000000oooo0?ooo`00001b0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`0200000740oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00800000L`3oool000l0oooo00@0
00000?ooo`3oool00000203oool01@000000oooo0?ooo`000000oooo00@00000MP3oool010000000
oooo0?ooo`0000080?ooo`050000003oool0oooo0000003oool01000001f0?ooo`040000003oool0
oooo000000P0oooo00D000000?ooo`3oool000000?ooo`04000007H0oooo00@000000?ooo`3oool0
0000203oool01@000000oooo0?ooo`000000oooo00@00000N03oool000l0oooo00@000000?ooo`3o
ool00000203oool01P000000oooo0?ooo`000000oooo000007T0oooo00@000000?ooo`3oool00000
203oool01P000000oooo0?ooo`000000oooo000007T0oooo00@000000?ooo`3oool00000203oool0
1P000000oooo0?ooo`000000oooo000007T0oooo00@000000?ooo`3oool00000203oool01P000000
oooo0?ooo`000000oooo000007/0oooo000@0?ooo`8000002P3oool200000080oooo1@00001f0?oo
o`8000002P3oool200000080oooo1@00001f0?ooo`8000002P3oool200000080oooo1@00001f0?oo
o`8000002P3oool200000080oooo1@00001g0?ooo`00o`3ooooo0?ooocl0oooo003o0?ooool0oooo
?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo003o0?ooool0oooo?`3oool00?l0
ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo003o0?ooool0oooo?`3oool00?l0ooooo`3ooolo
0?ooo`00o`3ooooo0?ooocl0oooo003o0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?ooo`00<P3o
ool500000140oooo0`00000A0?ooo`<000004@3oool3000000h0oooo0`0000040?ooo`800000<`3o
ool500000140oooo0`00000A0?ooo`<000004@3oool3000000h0oooo0`0000040?ooo`800000<`3o
ool500000180oooo0`00000@0?ooo`<000004@3oool3000000h0oooo0`0000040?ooo`800000<`3o
ool500000180oooo0`00000@0?ooo`<000004@3oool3000000h0oooo0`0000040?ooo`8000004P3o
ool003<0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0?0?ooo`050000003o
ool0oooo0?ooo`0000003`3oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`00000c0?ooo`040000003oool0oooo00000180oooo00<00000
0?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0000000l0oooo00D000000?ooo`3oool0oooo
0000000>0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000<`3oool010000000
oooo0?ooo`00000C0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000?
0?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000003<0oooo00@000000?ooo`3oool000004`3oool00`000000oooo0?ooo`0>0?ooo`05
0000003oool0oooo0?ooo`0000003`3oool01@000000oooo0?ooo`3oool0000000h0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`00000A0?ooo`00=03oool00`000000oooo0?ooo`0?
0?ooo`D00000403oool01@000000oooo0?ooo`3oool0000000l0oooo00D000000?ooo`3oool0oooo
0000000>0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000=03oool00`000000
oooo0?ooo`0?0?ooo`D00000403oool01@000000oooo0?ooo`3oool0000000l0oooo00D000000?oo
o`3oool0oooo0000000>0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000=03o
ool00`000000oooo0?ooo`0@0?ooo`D000003`3oool01@000000oooo0?ooo`3oool0000000l0oooo
00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000=03oool00`000000oooo0?ooo`0@0?ooo`D000003`3oool01@000000oooo0?ooo`3oool0
000000l0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000004@3oool003D0oooo00<000000?ooo`3oool03P3oool010000000oooo0?oo
o`00000A0?ooo`@000004@3oool3000000l0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000e0?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000004@3oool40000
0140oooo0`00000?0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000=@3oool0
0`000000oooo0?ooo`0?0?ooo`040000003oool0oooo00000100oooo1000000A0?ooo`<000003`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000003D0oooo00<000000?ooo`3oool0
3`3oool010000000oooo0?ooo`00000@0?ooo`@000004@3oool3000000l0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`00000A0?ooo`00<P3oool01@000000oooo0?ooo`3oool00000
0100oooo00<000000?ooo`0000004@3oool00`000000oooo0?ooo`0A0?ooo`050000003oool0oooo
0?ooo`0000003P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000380oooo00D0
00000?ooo`3oool0oooo0000000@0?ooo`030000003oool000000140oooo00<000000?ooo`3oool0
4@3oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`00000b0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0000000@
0?ooo`030000003oool0oooo0140oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000<P3oool01@000000oooo0?ooo`3oool000000140
oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`0A0?ooo`050000003oool0oooo0?oo
o`0000003P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000140oooo000b0?oo
o`050000003oool0oooo0?ooo`0000004@3oool200000180oooo00<000000?ooo`3oool0403oool0
1@000000oooo0?ooo`3oool0000000d0oooo0P0000040?ooo`040000003oool0oooo00000380oooo
00D000000?ooo`3oool0oooo0000000A0?ooo`8000004P3oool00`000000oooo0?ooo`0@0?ooo`05
0000003oool0oooo0?ooo`0000003@3oool2000000@0oooo00@000000?ooo`3oool00000<P3oool0
1@000000oooo0?ooo`3oool000000180oooo0P00000A0?ooo`030000003oool0oooo0100oooo00D0
00000?ooo`3oool0oooo0000000=0?ooo`800000103oool010000000oooo0?ooo`00000b0?ooo`05
0000003oool0oooo0?ooo`0000004P3oool200000140oooo00<000000?ooo`3oool0403oool01@00
0000oooo0?ooo`3oool0000000d0oooo0P0000040?ooo`040000003oool0oooo00000140oooo000c
0?ooo`<000004`3oool00`000000oooo0?ooo`0A0?ooo`8000004@3oool3000000l0oooo00<00000
0?ooo`3oool00`3oool2000003@0oooo0`00000C0?ooo`030000003oool0oooo0140oooo0P00000A
0?ooo`<000003`3oool00`000000oooo0?ooo`030?ooo`800000=03oool3000001@0oooo00<00000
0?ooo`3oool0403oool200000140oooo0`00000?0?ooo`030000003oool0oooo00<0oooo0P00000d
0?ooo`<00000503oool00`000000oooo0?ooo`0@0?ooo`8000004@3oool3000000l0oooo00<00000
0?ooo`3oool00`3oool200000180oooo003o0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?ooo`00
8@3ooomV000002D0ooooIP00000U0?ooofH000009@3ooomV000001D0oooo000Q0?ooo`030000003o
ool0oooo08P0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`280?ooo`030000003o
ool0oooo07P0oooo000Q0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0R03oool0
0`000000oooo0?ooo`280?ooo`030000003oool0oooo07P0oooo000Q0?ooo`030000003oool0oooo
00L0oooo1P00001k0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0R03oool20000
07T0oooo000Q0?ooo`030000003oool0oooo00d0oooo1P00001e0?ooo`030000003oool0oooo00L0
oooo1000001m0?ooo`030000003oool0oooo00L0oooo1000001m0?ooo`030000003oool0oooo00L0
oooo1000001]0?ooo`008@3oool00`000000oooo0?ooo`0C0?ooo`<00000LP3oool00`000000oooo
0?ooo`0;0?ooo`D00000N03oool00`000000oooo0?ooo`0;0?ooo`D00000N03oool00`000000oooo
0?ooo`0;0?ooo`D00000J03oool00240oooo00<000000?ooo`3oool05P3oool200000700oooo00<0
00000?ooo`3oool0403oool4000007@0oooo00<000000?ooo`3oool0403oool3000007D0oooo0P00
000A0?ooo`<00000I@3oool00240oooo00<000000?ooo`3oool01`3oool40?l000d0oooo0`00001]
0?ooo`030000003oool0oooo01@0oooo0`00001a0?ooo`030000003oool0oooo01<0oooo0`00001b
0?ooo`030000003oool0oooo01<0oooo0`00001R0?ooo`008@3oool00`000000oooo0?ooo`0;0?oo
o`D0o`002`3oool2000006/0oooo00<000000?ooo`3oool05`3oool3000006h0oooo00<000000?oo
o`3oool05P3oool200000700oooo00<000000?ooo`3oool05P3oool200000600oooo000Q0?ooo`03
0000003oool0oooo0100oooo103o00090?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3o
ool06P3oool3000006/0oooo00<000000?ooo`3oool0603oool3000006d0oooo0P00000I0?ooo`<0
0000G@3oool00100oooo0P0000040?ooo`040000003oool0oooo0?ooo`D000000P3oool00`000000
oooo0?ooo`0D0?ooo`<0o`001`3oool2000005L0oooo0P0000040?ooo`040000003oool0oooo0?oo
o`D000000P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05L0oooo0P0000040?oo
o`040000003oool0oooo0?ooo`D000000P3oool00`000000oooo0?ooo`0K0?ooo`800000FP3oool2
000000@0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`030000003oool0oooo01/0oooo0P00
001K0?ooo`003`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool05`3oool30?l000H0oooo00<000000?ooo`3oool0D`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool07P3oool20000
05H0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo01d0oooo0P00001G0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0M0?ooo`800000F@3oool000l0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`020?ooo`8000006`3oool30?l000@0oooo00<000000?ooo`3o
ool0DP3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo0P00000Q0?oo
o`030000003oool0oooo05<0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`02
0?ooo`800000803oool2000005D0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`020?ooo`800000803oool2000005L0oooo000?0?ooo`040000003oool0oooo000000X0oooo00D0
00000?ooo`3oool0oooo0000000O0?ooo`80o`000`3oool200000580oooo00@000000?ooo`3oool0
00002P3oool01@000000oooo0?ooo`3oool0000002<0oooo00<000000?ooo`3oool0DP3oool01000
0000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000008`3oool00`000000oooo0?oo
o`1B0?ooo`040000003oool0oooo000000X0oooo00D000000?ooo`3oool0oooo0000000S0?ooo`03
0000003oool0oooo05@0oooo000?0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo01l0oooo00<0o`000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1?0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0280oooo0P00001B0?ooo`040000003oool0oooo000000L0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0280oooo0P00001B0?ooo`04
0000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0280oooo0P00001D0?ooo`003`3oool010000000oooo0?ooo`0000070?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0P0?ooo`80o`000`3oool00`000000oooo0?oo
o`1>0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0C`3oool010000000oooo0?ooo`0000070?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0T0?ooo`800000D03oool0
10000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000P3oool2000002D0oooo
0P00001B0?ooo`00403oool2000000T0oooo0`0000030?ooo`030000003oool0oooo0280oooo0P3o
00020?ooo`030000003oool0oooo04h0oooo0P0000090?ooo`<000000`3oool00`000000oooo0?oo
o`070?ooo`H0o`00603oool200000500oooo0P0000090?ooo`<000000`3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo04h0oooo0P0000090?ooo`<000000`3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo04l0oooo000Q0?ooo`030000003oool0oooo02@0oooo00@0o`00
0?ooo`3oool00000H03oool00`000000oooo0?ooo`0=0?ooo`L0o`004`3oool00`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo04h0oooo000Q0?ooo`030000003oool0oooo02D0oooo0P3o0000
0`3oool000000?ooo`1N0?ooo`030000003oool0oooo01@0oooo0`3o000A0?ooo`030000003oool0
oooo05d0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0C@3oool00240oooo00<000000?ooo`3oool09`3oool00`3o
0000oooo0000001N0?ooo`030000003oool0oooo01L0oooo0`3o000?0?ooo`030000003oool0oooo
05`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1L0?ooo`800000:P3oool00`00
0000oooo0?ooo`1<0?ooo`008@3oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0000005d0
oooo00<000000?ooo`3oool06P3oool40?l000`0oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`1;0?ooo`008@3oool00`000000oooo0?ooo`0Y0?ooo`030?l0003oool0000005`0oooo
00<000000?ooo`3oool07P3oool30?l000X0oooo00<000000?ooo`3oool0FP3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`1:0?ooo`00403oool2000000@0oooo00<000000?ooo`3oool00`3oool300000080oooo00<0
00000?ooo`3oool0:P3oool00`3o0000oooo0000001:0?ooo`800000103oool00`000000oooo0?oo
o`030?ooo`<000000P3oool00`000000oooo0?ooo`0Q0?ooo`<0o`00203oool00`000000oooo0?oo
o`180?ooo`800000103oool00`000000oooo0?ooo`030?ooo`<000000P3oool00`000000oooo0?oo
o`070?ooo`h0o`005`3oool00`000000oooo0?ooo`180?ooo`800000103oool00`000000oooo0?oo
o`030?ooo`<000000P3oool2000002d0oooo00<000000?ooo`3oool0B@3oool000l0oooo00@00000
0?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool0000002d0oooo00<0o`000?ooo`000000
B03oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000009P3oool30?l0
00H0oooo00<000000?ooo`3oool0AP3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0
oooo0?ooo`0000005`3oool50?l001<0oooo00<000000?ooo`3oool0AP3oool010000000oooo0?oo
o`00000:0?ooo`050000003oool0oooo0?ooo`000000;`3oool00`000000oooo0?ooo`180?ooo`00
3`3oool010000000oooo0?ooo`0000070?ooo`D000000P3oool00`000000oooo0?ooo`0/0?ooo`03
0?l0003oool0000004L0oooo00@000000?ooo`3oool000001`3oool500000080oooo00<000000?oo
o`3oool09`3oool20?l000D0oooo00<000000?ooo`3oool0A@3oool010000000oooo0?ooo`000007
0?ooo`D000000P3oool00`000000oooo0?ooo`0J0?ooo`D0o`003`3oool00`000000oooo0?ooo`15
0?ooo`040000003oool0oooo000000L0oooo1@0000020?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0A`3oool000l0oooo00@000000?ooo`3oool000001`3oool010000000oooo0?oo
o`0000030?ooo`800000;P3oool00`3o0000oooo000000160?ooo`040000003oool0oooo000000L0
oooo00@000000?ooo`3oool000000`3oool2000002X0oooo0`3o00030?ooo`030000003oool0oooo
04@0oooo00@000000?ooo`3oool000001`3oool010000000oooo0?ooo`0000030?ooo`800000803o
ool50?l000/0oooo00<000000?ooo`3oool0A03oool010000000oooo0?ooo`0000070?ooo`040000
003oool0oooo000000<0oooo0P0000080?ooo`H0o`008P3oool00`000000oooo0?ooo`160?ooo`00
3`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool0;P3oool00`3o000000000?ooo`150?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`0/0?ooo`80o`000P3oool00`000000oooo0?ooo`130?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0T
0?ooo`D0o`001`3oool00`000000oooo0?ooo`130?ooo`040000003oool0oooo000000P0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`0=0?ooo`X0o`006@3oool00`000000oooo0?oo
o`150?ooo`003`3oool010000000oooo0?ooo`0000090?ooo`8000000`3oool00`000000oooo0?oo
o`0_0?ooo`80o`00A@3oool010000000oooo0?ooo`0000090?ooo`8000000`3oool00`000000oooo
0?ooo`0^0?ooo`80o`0000<000000?ooo`3oool0@`3oool010000000oooo0?ooo`0000090?ooo`80
00000`3oool00`000000oooo0?ooo`0Y0?ooo`<0o`00103oool00`000000oooo0?ooo`130?ooo`04
0000003oool0oooo000000T0oooo0P0000030?ooo`030000003oool0oooo01L0oooo2`3o000>0?oo
o`030000003oool0oooo04D0oooo000@0?ooo`8000002`3oool01@000000oooo0?ooo`3oool00000
03<0oooo00<0o`000?ooo`3oool0@`3oool2000000/0oooo00D000000?ooo`3oool0oooo0000000b
0?ooo`80o`00A@3oool2000000/0oooo00D000000?ooo`3oool0oooo0000000^0?ooo`<0o`000P3o
ool00`000000oooo0?ooo`130?ooo`8000002`3oool010000000oooo0?ooo`3oool2000002<0oooo
203o00070?ooo`030000003oool0oooo04@0oooo000Q0?ooo`030000003oool0oooo0380oooo00<0
o`000?ooo`3oool0D`3oool00`000000oooo0?ooo`0b0?ooo`80o`00E03oool00`000000oooo0?oo
o`0_0?ooo`<0o`0000<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0Z0?ooo`D0o`000`3o
ool00`000000oooo0?ooo`130?ooo`008@3oool00`000000oooo0?ooo`0c0?ooo`030?l0003oool0
oooo0580oooo00<000000?ooo`3oool0<`3oool00`000000o`000?ooo`1B0?ooo`030000003oool0
oooo0380oooo0`3o001C0?ooo`030000003oool0oooo02l0oooo1@3o00140?ooo`008@3oool00`00
0000oooo0?ooo`0d0?ooo`80o`00DP3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`00
0540oooo00<000000?ooo`3oool0=03oool00`000000o`000?l0001A0?ooo`800000=@3oool50?l0
03l0oooo000Q0?ooo`030000003oool0oooo03D0oooo00<000000?l0003oool0D03oool00`000000
oooo0?ooo`0e0?ooo`040000003oool0o`000?l004l0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?l000020?l004h0oooo00<000000?ooo`3oool0=@3oool010000000oooo0?ooo`3oool5
0?l003X0oooo000Q0?ooo`030000003oool0oooo03H0oooo00<000000?l0003oool0C`3oool00`00
0000oooo0?ooo`0f0?ooo`040000003oool0oooo0?l004h0oooo00<000000?ooo`3oool0=P3oool0
10000000oooo0?ooo`3oool30?l004/0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`050?ooo`D0o`00=@3oool00240oooo00<000000?ooo`3oool0=`3oool00`000000o`000?ooo`1>
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3o001<0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool00`3oool30?l004P0oooo0P00000h0?ooo`030000003oool0
oooo00T0oooo1@3o000`0?ooo`00403oool2000000@0oooo00<000000?ooo`3oool00P3oool30000
00<0oooo00<000000?ooo`3oool0>03oool00`000000o`000?ooo`0l0?ooo`800000103oool00`00
0000oooo0?ooo`020?ooo`<000000`3oool00`000000oooo0?ooo`0h0?ooo`040000003oool0oooo
0?ooo`80o`00>@3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000<0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`050?ooo`<0o`00=03oool2000000@0oooo00<00000
0?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=
0?ooo`D0o`00:`3oool000l0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000j0?ooo`040000003o
ool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool00P3oool20?l003H0oooo00@000000?ooo`3oool000001`3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`07
0?ooo`D0o`00;P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0140oooo1`3o000T0?ooo`003`3o
ool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000P3oool2000003/0
oooo00<000000?ooo`3o0000>@3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo
0?ooo`0000000P3oool2000003/0oooo0P0000040?ooo`80o`00=03oool010000000oooo0?ooo`00
00070?ooo`050000003oool0oooo0?ooo`0000000P3oool2000003/0oooo0P00000<0?ooo`D0o`00
:@3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000P3oool20000
03/0oooo0P00000H0?ooo`l0o`005@3oool000l0oooo00@000000?ooo`3oool000001`3oool40000
00<0oooo00<000000?ooo`3oool0>P3oool010000000oooo0?ooo`3o000h0?ooo`040000003oool0
oooo000000L0oooo100000030?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool00`3o
ool20?l00380oooo00@000000?ooo`3oool000001`3oool4000000<0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0>0?ooo`D0o`00903oool010000000oooo0?ooo`0000070?ooo`@0
00000`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03T0oooo000?0?ooo`040000
003oool0oooo000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0k0?ooo`04
0000003oool0oooo0?l003L0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0103oool20?l00300oooo00@00000
0?ooo`3oool000001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool04P3oool50?l001l0oooo00@000000?ooo`3oool000001`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0>03oool000l0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool00P3o000e0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00D0oooo0`3o000]0?ooo`04
0000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo01H0oooo1`3o000H0?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03L0oooo000@0?oo
o`8000002P3oool2000000<0oooo00<000000?ooo`3oool0?@3oool01@000000oooo0?ooo`3oool0
o`0003D0oooo0P00000:0?ooo`8000000`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo00L0oooo0P3o000/0?ooo`8000002P3oool2000000<0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0L0?ooo`D0o`00503oool2000000X0oooo0P0000030?ooo`800000@03oool0
0`000000oooo0?ooo`0f0?ooo`008@3oool00`000000oooo0?ooo`0n0?ooo`050000003oool0oooo
0?ooo`3o0000A@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00P0oooo0`3o000j
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo03D0oooo000Q0?ooo`030000003oool0oooo03l0oooo00D000000?oo
o`3oool0oooo0?l000140?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool02P3oool4
0?l003H0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0=03oool00240oooo00<000000?ooo`3oool0@03oool01000
0000oooo0?ooo`3oool20?l00480oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0=
0?ooo`D0o`00<@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo04<0oooo0P000013
0?ooo`030000003oool0oooo03<0oooo000Q0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool00P3oool20?l00400oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0A0?oo
o`L0o`00:P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`0b0?ooo`008@3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo00<0oooo00<0o`000?ooo`3oool0?@3oool00`000000oooo0?ooo`140?ooo`80
0000603oool50?l002D0oooo00<000000?ooo`3oool0A03oool200000480oooo00<000000?ooo`3o
ool0A03oool200000380oooo000@0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<00000
0`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00<0oooo0P3o000/0?ooo`800000
103oool00`000000oooo0?ooo`020?ooo`<000000`3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo02h0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000030?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool0;P3oool2000000@0oooo00<000000?ooo`3oool0
0P3oool3000000<0oooo0P0000170?ooo`030000003oool0oooo02l0oooo000?0?ooo`040000003o
ool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo04@0
oooo0P0000050?ooo`80o`00:@3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`170?ooo`800000;@3oool010000000oooo0?ooo`00
00070?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`170?ooo`800000
;@3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`170?ooo`800000;`3oool000l0oooo00@000000?ooo`3oool000001`3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`04
0?ooo`030?l0003oool0oooo02H0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0:P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02`0oooo000?
0?ooo`040000003oool0oooo000000P0oooo0`0000030?ooo`800000B03oool2000000D0oooo0P3o
000V0?ooo`040000003oool0oooo000000P0oooo0`0000030?ooo`800000B`3oool00`000000oooo
0?ooo`0Y0?ooo`040000003oool0oooo000000P0oooo0`0000030?ooo`800000B`3oool00`000000
oooo0?ooo`0Y0?ooo`040000003oool0oooo000000P0oooo0`0000030?ooo`800000B`3oool00`00
0000oooo0?ooo`0[0?ooo`003`3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00@0oooo0`3o000S
0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo04/0oooo0P00000Y0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo04/0oooo0P00000Y0?ooo`040000003oool0oooo
000000L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo04/0oooo0P00
000[0?ooo`003`3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00H0oooo0P3o000Q0?ooo`040000
003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo02H0oooo00@0
00000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`0X0?ooo`00403oool2000000T0oooo0`0000030?ooo`030000
003oool0oooo04/0oooo0P0000080?ooo`<0o`007`3oool2000000T0oooo0`0000030?ooo`030000
003oool0oooo04h0oooo0P00000W0?ooo`8000002@3oool3000000<0oooo00<000000?ooo`3oool0
CP3oool3000002H0oooo0P0000090?ooo`<000000`3oool2000004l0oooo0`00000W0?ooo`008@3o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00P0oooo1P3o000Z0?ooo`030000003o
ool0oooo0500oooo0`00000e0?ooo`030000003oool0oooo0540oooo0`00000d0?ooo`030000003o
ool0oooo0540oooo0`00000T0?ooo`008@3oool00`000000oooo0?ooo`1>0?ooo`<000003@3oool5
0?l002D0oooo00<000000?ooo`3oool0D`3oool2000003<0oooo00<000000?ooo`3oool0E03oool3
00000340oooo00<000000?ooo`3oool0E03oool300000240oooo000Q0?ooo`030000003oool0oooo
0540oooo0`00000d0?ooo`030000003oool0oooo05D0oooo0`00000`0?ooo`030000003oool0oooo
05L0oooo1@00000/0?ooo`800000F03oool5000001`0oooo000Q0?ooo`030000003oool0oooo05@0
oooo0`00000a0?ooo`030000003oool0oooo05P0oooo1P00000Z0?ooo`030000003oool0oooo05`0
oooo1@00000W0?ooo`030000003oool0oooo05`0oooo1@00000G0?ooo`008@3oool00`000000oooo
0?ooo`1G0?ooo`D00000;03oool00`000000oooo0?ooo`1N0?ooo`D000009@3oool00`000000oooo
0?ooo`1Q0?ooo`8000009@3oool00`000000oooo0?ooo`1Q0?ooo`8000005@3oool00240oooo00<0
00000?ooo`3oool0G03oool5000002L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?oo
o`280?ooo`800000N@3oool001/0oooo0`0000030?ooo`030000003oool0oooo0640oooo0P00000O
0?ooo`<000000`3oool00`000000oooo0?ooo`220?ooo`<000000`3oool00`000000oooo0?ooo`22
0?ooo`<000000`3oool00`000000oooo0?ooo`1h0?ooo`00703oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo08<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`230?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo07P0oooo000L0?ooo`030000003oool0oooo0080oooo0P0000240?ooo`03
0000003oool0oooo0080oooo0P0000240?ooo`030000003oool0oooo0080oooo0P0000240?ooo`03
0000003oool0oooo0080oooo0P00001i0?ooo`00703oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`1m0?ooo`00703o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`1m0?ooo`006`3oool2000008T0oooo0P0000290?ooo`800000R@3oool2
000007l0oooo000L0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`280?ooo`030000003oool0oooo07d0oooo003o0?ooool0oooo?`3oool00?l0oooo
o`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo003o0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?oo
o`00o`3ooooo0?ooocl0oooo003o0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo
0?ooocl0oooo000Z0?ooo`D000000`3oool2000000d0oooo0`0000030?ooo`8000002`3oool30000
00@0oooo0P00000<0?ooo`<00000103oool2000000P0oooo0`0000040?ooo`800000103oool20000
0?l0oooo]@3oool002/0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000=
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00003o0?oook@0oooo000/0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000002P3oool500000080oooo00@000000?ooo`3oool0
00002@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000002P3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000o`3ooond0?oo
o`00;@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo000000T0oooo100000030?ooo`040000003o
ool0oooo000000/0oooo0`0000030?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?l0oooo]03oool0
02X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`0000000`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000o`3ooond0?ooo`00:P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool00000303oool2000000<0oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo000000X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo000000L0oooo0P0000040?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000o`3ooond0?ooo`00:`3oool3000000@0oooo0P00000>0?ooo`03
0000003oool0oooo0080oooo0P00000<0?ooo`800000103oool2000000`0oooo0`0000040?ooo`80
00002@3oool00`000000oooo0?ooo`030?ooo`800000103oool200000?l0oooo]@3oool00?l0oooo
o`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo000L0?ooofL00000o`3ooonk0?ooo`00703oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oooni0?oo
o`00703oool00`000000o`000?ooo`3o0?ooool0oooo803oool001`0oooo00<000000?ooo`3oool0
o`3ooooo0?ooob00oooo000L0?ooo`030000003oool0oooo0?l0ooooo`3ooolP0?ooo`00703oool0
10000000oooo0?l0003o003o0?ooool0oooo7`3oool001`0oooo00D000000?ooo`3oool0oooo0?l0
003o0?ooool0oooo7P3oool001`0oooo00<000000?ooo`3oool00P3oool20?l00?l0ooooo`3ooolL
0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0103oool00`3o000000000000003o0?oo
ool0oooo6@3oool001@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00D0oooo0`3o000200000?l0ooooo`3ooolF0?ooo`00603oool01@000000oooo0?ooo`3oool00000
00X0oooo0P3o000700000?l0ooooo`3oool?0?ooo`00603oool01@000000oooo0?ooo`3oool00000
00`0oooo0`3o00040?ooo`H0000000<0oooo0000000000001000003o0?ooool0oooo0P3oool001@0
oooo100000040?ooo`030000003oool0oooo00d0oooo0`3o000>0?ooob80000000<0oooo00000000
00008@00003o0?oook/0oooo000D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
403oool30?l00?l0ooooo`3oool=0?ooo`00503oool5000000<0oooo00<000000?ooo`3oool04`3o
ool30?l00?l0ooooo`3oool:0?ooo`00703oool00`000000oooo0?ooo`0F0?ooo`040?l0003oool0
o`000?l00?l0ooooo`3oool60?ooo`00703oool00`000000oooo0?ooo`0J0?ooo`<0o`00o`3ooooo
0?ooo`<0oooo000L0?ooo`030000003oool0oooo01d0oooo0`3o003o0?ooool0oooo000L0?ooo`03
0000003oool0oooo0200oooo0`3o003o0?oooo`0oooo000?0?ooo`<00000103oool2000000@0oooo
00<000000?ooo`3oool08`3oool30?l00?l0oooon@3oool00100oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02H0oooo0P3o003o0?ooooL0oooo
000@0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`0X0?ooo`<0o`00o`3ooood0?ooo`00403oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0:`3oool20?l00?l0oooolP3oool00100oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02d0oooo
0P3o003o0?oooo00oooo000?0?ooo`800000103oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo02l0oooo0P3o003o0?ooonh0oooo000@0?ooo`030000003oool0oooo00<0oooo0P00
00040?ooo`030000003oool0oooo0340oooo0`3o003o0?ooon/0oooo000L0?ooo`030000003oool0
oooo03@0oooo0P3o003o0?ooonT0oooo000L0?ooo`030000003oool0oooo03H0oooo0P3o003o0?oo
onL0oooo000L0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool0o`3ooooT0?ooo`00
703oool00`000000oooo0?ooo`0i0?ooo`80o`00o`3ooooT0?ooo`003`3oool3000000<0oooo0`00
00040?ooo`030000003oool0oooo03/0oooo0P3o003o0?ooon80oooo000@0?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000003l0oooo0P3o003o0?ooon00oooo
000@0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000110?ooo`030?l0
003oool0oooo0?l0oooog@3oool00100oooo00<000000?ooo`3oool01@3oool01@000000oooo0?oo
o`3oool0000004<0oooo0P3o003o0?ooom`0oooo000@0?ooo`040000003oool0oooo0?ooo`@00000
103oool00`000000oooo0?ooo`130?ooo`030?l0003oool0oooo0?l0oooof@3oool000l0oooo0P00
00030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0A03oool20?l00?l0oooof@3o
ool00100oooo00@000000?ooo`3oool0oooo1@0000030?ooo`030000003oool0oooo04H0oooo00<0
o`000?ooo`3oool0o`3ooooF0?ooo`00703oool00`000000oooo0?ooo`170?ooo`80o`00o`3ooooF
0?ooo`00703oool00`000000oooo0?ooo`190?ooo`030?l0003oool0oooo0?l0ooood`3oool001`0
oooo00<000000?ooo`3oool0BP3oool00`3o0000oooo0?ooo`3o0?ooom80oooo000>0?ooo`D00000
0`3oool2000000@0oooo00<000000?ooo`3oool0B`3oool20?l00?l0oooodP3oool000l0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo04d0
oooo00<0o`000?ooo`3oool0o`3oooo?0?ooo`00403oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0CP3oool00`3o0000oooo0?ooo`3o0?ooolh0
oooo000A0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0540oooo00<0o`000?ooo`3oool0o`3oooo=0?ooo`003P3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`1@0?ooo`80o`00o`3oooo=
0?ooo`003P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`1B0?ooo`030?l0003oool0oooo0?l0oooobP3oool000l0oooo0`000004
0?ooo`800000103oool00`000000oooo0?ooo`1C0?ooo`030?l0003oool0oooo0?l0oooob@3oool0
01`0oooo00<000000?ooo`3oool0E03oool00`3o0000oooo0?ooo`3o0?ooolP0oooo000L0?ooo`03
0000003oool0oooo05D0oooo00<0o`000?ooo`3oool0o`3oooo70?ooo`00703oool00`000000oooo
0?ooo`1F0?ooo`030?l0003oool0oooo0?l0ooooaP3oool001`0oooo00<000000?ooo`3oool0E`3o
ool00`3o0000oooo0?ooo`3o0?ooolD0oooo000>0?ooo`D000000P3oool3000000@0oooo00<00000
0?ooo`3oool0F03oool00`3o0000oooo0?ooo`3o0?oool@0oooo000?0?ooo`060000003oool0oooo
0000003oool000000`3oool01@000000oooo0?ooo`3oool0000005/0oooo00<0o`000?ooo`3oool0
o`3oooo30?ooo`00403oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000
G03oool00`3o0000oooo0?ooo`3o0?oool80oooo000A0?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`3oool0oooo0000001M0?ooo`030?l0003oool0oooo0?l0oooo`@3oool000h0oooo00H0
00000?ooo`3oool0oooo0000003oool4000000@0oooo00<000000?ooo`3oool0G03oool00`3o0000
oooo0?ooo`3o0?oool00oooo000>0?ooo`070000003oool0oooo0?ooo`000000oooo000000070?oo
o`030000003oool0oooo05d0oooo00<0o`000?ooo`3oool0o`3ooono0?ooo`003`3oool300000080
oooo1@0000030?ooo`030000003oool0oooo05h0oooo00<0o`000?ooo`3oool0o`3ooonn0?ooo`00
703oool00`000000oooo0?ooo`1O0?ooo`030?l0003oool0oooo0?l0oooo_@3oool001`0oooo00<0
00000?ooo`3oool0H03oool00`3o0000oooo0?ooo`3o0?oook`0oooo000L0?ooo`030000003oool0
oooo0640oooo00<0o`000?ooo`3oool0o`3ooonk0?ooo`003`3oool3000000@0oooo0P0000040?oo
o`030000003oool0oooo0?l0ooooo`3ooolP0?ooo`003P3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`1R0?ooo`030?l0003oool0
oooo0?l0oooo^P3oool00180oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3o
ool0000006D0oooo00<0o`000?ooo`3oool0o`3oooni0?ooo`00403oool2000000<0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`3o0?ooool0oooo803oool00180oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?ooool0oooo903oool000h0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000?l0ooooo`3ooolV0?ooo`003`3o
ool3000000@0oooo0P00003o0?ooool0oooo9`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?oo
ocl0oooo003o0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo003o
0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 572}, {262.562, 0}} -> {-0.10416, -0.0460031, \
0.00735721, 0.00735721}, {{14.125, 140.562}, {256.25, 178.125}} -> {-4.12784, \
-0.0159583, 0.104991, 0.000849396}, {{153.188, 279.625}, {256.25, 178.125}} -> \
{-18.7282, -0.0159583, 0.104991, 0.000849396}, {{292.312, 418.75}, {256.25, \
178.125}} -> {-33.3351, -0.0159583, 0.104991, 0.000849396}, {{431.375, \
557.812}, {256.25, 178.125}} -> {-47.9355, -0.0159583, 0.104991, \
0.000849396}, {{14.125, 140.562}, {170.312, 92.1875}} -> {-3.30034, -1.64617, \
0.0988417, 0.0159929}, {{153.188, 279.625}, {170.312, 92.1875}} -> {-17.0455, \
-1.64617, 0.0988417, 0.0159929}, {{292.312, 418.75}, {170.312, 92.1875}} -> \
{-30.7969, -1.64617, 0.0988417, 0.0159929}, {{431.375, 557.812}, {170.312, \
92.1875}} -> {-44.5421, -1.64617, 0.0988417, 0.0159929}, {{14.125, 140.562}, \
{84.375, 6.25}} -> {-27.5516, -89.2604, 0.975685, 0.473608}}],

Cell[BoxData[
    \({5.7510732992873015`, 30.154760044946226`}\)], "Output",
  CellLabel->"Out[68]="]
}, Open  ]],

Cell["Using compiled code is much faster:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[popList = Nest[IterateExact[#, hetW[0.1], 0.5] &, p0, 400]; \n\t
          AlleleFrequencyMean[popList]], \[IndentingNewLine]Timing[
          popList = 
            Nest[IterateExact[#, hetW[0.1], 0.5, Compiled \[Rule] True] &, 
              p0, 400]; \n\tAlleleFrequencyMean[popList]]} // 
      MatrixForm\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(78.15000000000009`\ Second\), \({{0.07304290346342841`, 
                  0.49971593105415396`}, {0.09875566422069378`, 
                  0.49973868750885125`}, {0.15775848843780643`, 
                  0.49978499773383483`}, {0.26174615578355037`, 
                  0.49985588697351`}, {0.41323208343074364`, 
                  0.4999487810782125`}, {0.586767916569255`, 
                  0.5000512189217884`}, {0.7382538442164485`, 
                  0.500144113026491`}, {0.8422415115621926`, 
                  0.5002150022661661`}, {0.9012443357793057`, 
                  0.50026131249115`}, {0.9269570965365711`, 
                  0.500284068945847`}}\)},
            {\(20.799999999999955`\ Second\), \({{0.07304290346342854`, 
                  0.4997159310541542`}, {0.09875566422069393`, 
                  0.49973868750885136`}, {0.15775848843780668`, 
                  0.49978499773383506`}, {0.26174615578355076`, 
                  0.49985588697351013`}, {0.41323208343074397`, 
                  0.49994878107821256`}, {0.5867679165692553`, 
                  0.5000512189217884`}, {0.7382538442164486`, 
                  0.5001441130264906`}, {0.8422415115621927`, 
                  0.5002150022661659`}, {0.9012443357793058`, 
                  0.5002613124911496`}, {0.9269570965365711`, 
                  0.5002840689458466`}}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[23]//MatrixForm="]
}, Open  ]],

Cell["\<\
Compiled code agrees with uncompiled code for other life \
cycles:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[
          popList = 
            Nest[IterateExact[#, hetW[0.1], 0.5, 
                  MigrationOrder \[Rule] MUS] &, p0, 400]; \n\t
          AlleleFrequencyMean[popList]], \[IndentingNewLine]Timing[
          popList = 
            Nest[IterateExact[#, hetW[0.1], 0.5, Compiled \[Rule] True, 
                  MigrationOrder \[Rule] MUS] &, p0, 400]; \n\t
          AlleleFrequencyMean[popList]]} // MatrixForm\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(61.81666666666666`\ Second\), \({{0.07965904929199548`, 
                  0.49989421497131215`}, {0.10661362421456792`, 
                  0.49990355294879213`}, {0.1671623278602459`, 
                  0.4999219505712158`}, {0.2706150923437823`, 
                  0.49994871367822535`}, {0.41707541929996833`, 
                  0.4999820308456999`}, {0.5829245807000336`, 
                  0.5000179691543005`}, {0.7293849076562194`, 
                  0.5000512863217753`}, {0.8328376721397551`, 
                  0.5000780494287849`}, {0.8933863757854329`, 
                  0.500096447051209`}, {0.920340950708005`, 
                  0.5001057850286889`}}\)},
            {\(8.933333333333337`\ Second\), \({{0.07965904929199484`, 
                  0.4998942149713108`}, {0.10661362421456716`, 
                  0.499903552948791`}, {0.16716232786024476`, 
                  0.49992195057121475`}, {0.2706150923437808`, 
                  0.49994871367822474`}, {0.41707541929996633`, 
                  0.4999820308456993`}, {0.5829245807000317`, 
                  0.5000179691543001`}, {0.7293849076562178`, 
                  0.5000512863217748`}, {0.8328376721397541`, 
                  0.5000780494287846`}, {0.8933863757854322`, 
                  0.5000964470512085`}, {0.9203409507080046`, 
                  0.5001057850286886`}}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[6]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[
          popList = 
            Nest[IterateExact[#, hetW[0.1], 0.5, 
                  MigrationOrder \[Rule] USM] &, p0, 400]; \n\t
          AlleleFrequencyMean[popList]], \[IndentingNewLine]Timing[
          popList = 
            Nest[IterateExact[#, hetW[0.1], 0.5, Compiled \[Rule] True, 
                  MigrationOrder \[Rule] USM] &, p0, 400]; \n\t
          AlleleFrequencyMean[popList]]} // MatrixForm\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(64.76666666666642`\ Second\), \({{0.08639769301710194`, 
                  0.4998942728135727`}, {0.11501215638980004`, 
                  0.4999037451789244`}, {0.17788834306449686`, 
                  0.4999223703214924`}, {0.28136698295797596`, 
                  0.4999492595862854`}, {0.4219226279094188`, 
                  0.4999823051019545`}, {0.5780773720905831`, 
                  0.500017694898046`}, {0.7186330170420256`, 
                  0.5000507404137153`}, {0.8221116569355043`, 
                  0.5000776296785084`}, {0.8849878436102007`, 
                  0.5000962548210768`}, {0.9136023069828988`, 
                  0.5001057271864285`}}\)},
            {\(7.850000000000364`\ Second\), \({{0.08639769301710125`, 
                  0.49989427281357124`}, {0.11501215638979918`, 
                  0.49990374517892294`}, {0.17788834306449575`, 
                  0.49992237032149117`}, {0.2813669829579744`, 
                  0.4999492595862842`}, {0.421922627909417`, 
                  0.4999823051019535`}, {0.5780773720905813`, 
                  0.5000176948980454`}, {0.718633017042024`, 
                  0.5000507404137147`}, {0.8221116569355033`, 
                  0.5000776296785078`}, {0.8849878436102`, 
                  0.5000962548210762`}, {0.9136023069828981`, 
                  0.500105727186428`}}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[62]//MatrixForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["A barrier to gene flow", "SubsectionIcon",
  CellTags->"Barrier"],

Cell[TextData[{
  "The flow of a neutral gene will be impeded by clines maintained by \
selection at linked loci.  This barrier to gene flow is reflected in a local \
steepening of the neutral cline.  The gradient steepens inversely with the \
decline in mean fitness, as ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_x u\ ~\ \(W\&_\^\(2/r\)\)\)]],
  "; this applies for any form of selection with constant genotypic \
fitnesses, but is derived as a weak selection limit.  The simulations below \
test this prediction.  (See Barton, ",
  ButtonBox["1986",
    ButtonData:>{"Symmetric model: references", "Barton 1986"},
    ButtonStyle->"AddOnsLink"],
  "; Kruuk et al., ",
  ButtonBox["1999",
    ButtonData:>{"Symmetric model: references", "Kruuk et al 1999"},
    ButtonStyle->"AddOnsLink"],
  ")."
}], "Text"],

Cell["\<\
This sets up a cline, maintained across 20 demes by 5% selection \
against heterozygotes:\
\>", "MathCaption"],

Cell[BoxData[{
    \(\(p0 = 
        MakeCline[20, 3, 1, 
          NumericalModel \[Rule] 
            SymmetricNeutralHaploidFrequencies];\)\), "\n", 
    \(\[Psi]0 = 
      MakePopulation[3, {0, 0}, 1, 
        NumericalModel \[Rule] 
          SymmetricNeutralHaploidFrequencies]; \), "\n", 
    \(\[Psi]1 = 
      MakePopulation[3, {1, 1}, 1, 
        NumericalModel \[Rule] 
          SymmetricNeutralHaploidFrequencies]; \), "\n", 
    \(\(\(\(hetW[s_]\)[_]\)[_, _, h_] := \((1 - s)\)\^h;\)\), "\n", 
    \(\(popList = 
        NestList[
          IterateExact[#, hetW[0.05], 0.5, 
              FixedEnds \[Rule] {\[Psi]0, \[Psi]1}] &, p0, 
          800];\)\)}], "Input",
  CellLabel->"In[66]:="],

Cell[TextData[{
  "This graph compares the gradient observed with that predicted by the \
relation ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_x u\ ~\ \(W\&_\^\(2/r\)\)\)]],
  ":  "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pu = AlleleFrequencyMean[popList // Last];\)\), "\n", 
    \(\(gr = 
        ClineGradient[pu, FixedEnds \[Rule] {{0, 0}, {1, 1}}];\)\), "\n", 
    \(\(ww = 
        MeanW[MakeDiploid[
            popList\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]], 
          hetW[0.05]];\)\), "\n", 
    \(\(Show[
        ListPlot[Transpose[{Range[21] - 0.5, Transpose[gr] // Last}], 
          PlotJoined \[Rule] True], \n\t
        ListPlot[gr\[LeftDoubleBracket]1, 2\[RightDoubleBracket] ww\^\(-4\), 
          PlotJoined \[Rule] True, PlotStyle \[Rule] Red], 
        PlotRange \[Rule] {{0, 21}, {0, 0.1}}];\)\)}], "Input",
  CellLabel->"In[72]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-17 0.047619 0 6.18034 [
[.2381 -0.0125 -3 -9 ]
[.2381 -0.0125 3 0 ]
[.47619 -0.0125 -6 -9 ]
[.47619 -0.0125 6 0 ]
[.71429 -0.0125 -6 -9 ]
[.71429 -0.0125 6 0 ]
[.95238 -0.0125 -6 -9 ]
[.95238 -0.0125 6 0 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -24 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -24 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -24 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(5)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(10)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(15)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(20)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.02)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.04)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.06)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.08)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26168 m
.07143 .26368 L
.11905 .26665 L
.16667 .2709 L
.21429 .27709 L
.2619 .28603 L
.30952 .29839 L
.35714 .31407 L
.40476 .33114 L
.45238 .34517 L
.5 .35071 L
.54762 .34517 L
.59524 .33114 L
.64286 .31407 L
.69048 .29839 L
.7381 .28603 L
.78571 .27709 L
.83333 .2709 L
.88095 .26665 L
.92857 .26368 L
.97619 .26168 L
s
1 0 0 r
.04762 .26381 m
.09524 .26638 L
.14286 .26987 L
.19048 .27491 L
.2381 .28228 L
.28571 .29281 L
.33333 .30706 L
.38095 .32438 L
.42857 .34165 L
.47619 .353 L
.52381 .353 L
.57143 .34165 L
.61905 .32438 L
.66667 .30706 L
.71429 .29281 L
.7619 .28228 L
.80952 .27491 L
.85714 .26987 L
.90476 .26638 L
.95238 .26381 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[75]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00E`3oool3000003L0oooo0`0000040?ooo`800000=@3oool3000000<0oooo0`00000d0?oo
o`D000000`3oool2000000X0oooo001F0?ooo`050000003oool0oooo0?ooo`000000=`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000003D0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo0380oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000090?ooo`00FP3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000=@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000090?ooo`00FP3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000=@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo03@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00L0oooo001F0?ooo`@00000>03oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000003D0oooo00@000000?ooo`3oool0oooo1000000d0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000090?ooo`00EP3oool00`000000oooo
0?ooo`0h0?ooo`800000103oool010000000oooo0?ooo`00000d0?ooo`8000000`3oool00`000000
oooo0?ooo`0e0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000009
0?ooo`00EP3oool5000003L0oooo00<000000?ooo`3oool00`3oool2000003H0oooo00@000000?oo
o`3oool0oooo1@00000d0?ooo`<00000103oool2000000X0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo000K0?ooool000001@0000010?ooo`006`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool001/0
oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0
oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0
o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0
oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0
oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?oo
o`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?oo
o`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000
003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0
oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000
oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool00080oooo0P00
00040?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`D00000103oool00`000000oooo0?oo
o`3o0?ooo`<0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo0`3oool000050?oo
o`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0o`3oool30?ooo`0000D0oooo0000003oool0oooo000000080?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool300000?l0oooo0`3oool0
00050?ooo`000000oooo0?ooo`000000203oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00001@3oool000000?oo
o`3oool0000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0o`3oool30?ooo`000P3oool2000000X0oooo0P0000030?ooo`<0
00001@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo
0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o
0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`03
0000003oool0oooo0?l0oooo0`3oool00080oooo0P0000040?ooo`030000003oool0oooo00<0oooo
0P0000040?ooo`<00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00001@3oool000000?oo
o`3oool0000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0?l0oooo0`3oool000050?ooo`000000oooo0?ooo`000000203oool01@000000
oooo0?ooo`000000oooo00D00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00001@3oool0
00000?ooo`3oool0000000P0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003o
ool0oooo00<0oooo0`00003o0?ooo`<0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo0?l0oooo
0`3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?ooo`80
00001@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00020?ooo`8000002P3oool2000000D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo00<0oooo1P0000080?l000H00000d@3oool6000000L0o`001P0000070?ooo`006`3oool0
0`000000oooo0?ooo`0A0?ooo``0o`001P00002h0?ooo`L00000303o000D0?ooo`006`3oool00`00
0000oooo0?ooo`0M0?ooo``0o`000`00002V0?ooo`<000003@3o000P0?ooo`006`3oool00`000000
oooo0?ooo`0Y0?ooo`T0o`0000<000000?ooo`3oool0U`3oool90?l002d0oooo000K0?ooo`800000
<`3oool70?l008d0oooo1P3o000f0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`D0o`0000<0
00000?ooo`3oool0OP3oool2000000D0o`00?03oool001/0oooo00<000000?ooo`3oool0?P3oool4
0?l000800000MP3oool2000000D0o`00@@3oool001/0oooo00<000000?ooo`3oool0@P3oool40?l0
00800000KP3oool2000000@0o`00AP3oool001/0oooo00<000000?ooo`3oool0AP3oool40?l00080
0000IP3oool2000000@0o`00BP3oool001/0oooo00<000000?ooo`3oool0BP3oool40?l000800000
G`3oool00`000000o`000?l000020?l004h0oooo000K0?ooo`030000003oool0oooo04h0oooo103o
00000`000000oooo0?ooo`1G0?ooo`@0o`00DP3oool001/0oooo00<000000?ooo`3oool0DP3oool3
0?l000030000003oool0oooo0540oooo0`3o001F0?ooo`006`3oool2000005H0oooo0`3o00000`00
0000oooo0?ooo`1;0?ooo`<0o`00F@3oool001/0oooo00<000000?ooo`3oool0F03oool30?l00003
0000003oool0oooo04D0oooo0`3o001L0?ooo`006`3oool00`000000oooo0?ooo`1K0?ooo`80o`00
0P0000110?ooo`030000003o0000o`0005l0oooo000K0?ooo`030000003oool0oooo05d0oooo0`3o
00000`000000oooo0?ooo`0j0?ooo`040000003o0000o`000?l00640oooo000K0?ooo`030000003o
ool0oooo0600oooo0`3o000h0?ooo`030000003o0000o`0006@0oooo000K0?ooo`030000003oool0
oooo06<0oooo0`3o000b0?ooo`040000003o0000o`000?l006H0oooo000K0?ooo`030000003oool0
oooo06H0oooo0`3o000/0?ooo`040000003o0000o`000?l006T0oooo000K0?ooo`030000003oool0
oooo06T0oooo0`3o00000`000000oooo0?ooo`0R0?ooo`8000000`3o001/0?ooo`006`3oool20000
06d0oooo0`3o0002000001`0oooo0P0000040?l006l0oooo000K0?ooo`030000003oool0oooo06l0
oooo103o000300000180oooo0`0000040?l007<0oooo000K0?ooo`030000003oool0oooo07<0oooo
103o0006000000D0oooo1@0000040?l007L0oooo000K0?ooo`030000003oool0oooo07L0oooo403o
001k0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00020?ooo`800000103oool00`00
0000oooo0?ooo`030?ooo`8000000`3oool3000000D0oooo00<000000?ooo`3oool0o`3oool30?oo
o`0000D0oooo0000003oool0oooo000000080?ooo`060000003oool0oooo0000003oool000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo0`3oool000050?ooo`000000
oooo0?ooo`000000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00001@3oool000000?ooo`3oool0000000P0
oooo00D000000?ooo`3oool000000?ooo`04000000D0oooo0`00003o0?ooo`<0oooo00001@3oool0
00000?ooo`3oool0000000P0oooo00H000000?ooo`3oool000000?ooo`0000080?ooo`030000003o
ool0oooo0?l0oooo0`3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool30?ooo`000P3o
ool2000000X0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?oo
o`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool0
01/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo
0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo
0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool00080oooo0P000004
0?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo00001@3oool000000?ooo`3oool0000000P0oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool30?ooo`0000D0
oooo0000003oool0oooo000000080?ooo`060000003oool0oooo0000003oool000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo0`3oool000050?ooo`000000oooo0?oo
o`000000203oool010000000oooo0?ooo`0000020?ooo`<000001@3oool300000?l0oooo0`3oool0
00050?ooo`000000oooo0?ooo`000000203oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00001@3oool000000?oo
o`3oool0000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0o`3oool30?ooo`000P3oool2000000X0oooo0P0000030?ooo`<0
00001@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo
0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o
0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`03
0000003oool0oooo0?l0oooo0`3oool000P0oooo0P0000040?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`030000003oool0oooo0?l0oooo0`3oool000L0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo0`3oool000L0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo
0`3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`<00000
o`3oool30?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0oooo
2P3oool000L0oooo00@000000?ooo`3oool00000203oool200000?l0oooo303oool000P0oooo0P00
000:0?ooo`030000003oool0oooo0?l0oooo2P3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.22944, -0.00764114, \
0.0810174, 0.000624232}}]
}, Open  ]],

Cell["\<\
There is a very close fit.  The long run of 800 generations is \
needed to equilibrate the neutral cline: the selected cline equilibrates much \
faster.\
\>", "Text"],

Cell[TextData[{
  "The barrier strength of 2.62 is also close to the value 2.74 predicted \
from  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\((W\&_\^\(2/r\) - 
              1)\) \[DifferentialD]x\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(wwi = Interpolation[ww];\)\), "\n", 
    \({\(BarrierStrength[pu, 
          FixedEnds \[Rule] {{0, 0}, {1, 
                1}}]\)\[LeftDoubleBracket]1\[RightDoubleBracket], 
      NIntegrate[wwi[x]\^\(-4\) - 1, {x, 1, 20}]}\)}], "Input",
  CellLabel->"In[79]:="],

Cell[BoxData[
    \({2.6174791805370026`, 2.739352717080516`}\)], "Output",
  CellLabel->"Out[80]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Saving results", "SubsectionIcon"],

Cell[TextData[{
  "StoreExact[\[Psi][pars],\[Ellipsis]] stores results in a function \
\[Psi][pars][t].  If evaluation is slow, it may be useful to store a set of \
results using Save[",
  StyleBox["filename",
    FontSlant->"Italic"],
  ",",
  StyleBox["symbol",
    FontSlant->"Italic"],
  "]:"
}], "MathCaption"],

Cell[BoxData[
    \(Save["\<temp\>", \ \[Psi]]\)], "Input",
  CellLabel->"In[61]:="],

Cell["\<\
This retrieves the definitions of \[Psi] from the file \
\"temp\":\
\>", "MathCaption"],

Cell[BoxData[
    \(<< temp\)], "Input",
  CellLabel->"In[63]:="]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{985, 670},
WindowMargins->{{52, Automatic}, {Automatic, 0}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "IterateExact"->{
    Cell[2070, 65, 851, 15, 88, "DefinitionBox",
      CellTags->{"IterateExact", "StoreExact"}]},
  "StoreExact"->{
    Cell[2070, 65, 851, 15, 88, "DefinitionBox",
      CellTags->{"IterateExact", "StoreExact"}]},
  "IterateNeutral"->{
    Cell[95831, 2745, 401, 7, 37, "DefinitionBox",
      CellTags->{"IterateNeutral", "Cline"}]},
  "Cline"->{
    Cell[95831, 2745, 401, 7, 37, "DefinitionBox",
      CellTags->{"IterateNeutral", "Cline"}]},
  "Barrier"->{
    Cell[197391, 5987, 71, 1, 26, "SubsectionIcon",
      CellTags->"Barrier"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"IterateExact", 288657, 9091},
  {"StoreExact", 288774, 9094},
  {"IterateNeutral", 288895, 9097},
  {"Cline", 289006, 9100},
  {"Barrier", 289119, 9103}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 52, 0, 36, "SubsectionIcon"],
Cell[1794, 53, 82, 1, 28, "MathCaption"],
Cell[1879, 56, 102, 2, 26, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2018, 63, 49, 0, 36, "SubsectionIcon"],
Cell[2070, 65, 851, 15, 88, "DefinitionBox",
  CellTags->{"IterateExact", "StoreExact"}],
Cell[2924, 82, 620, 11, 50, "Text"],

Cell[CellGroupData[{
Cell[3569, 97, 1107, 21, 175, "Input"],
Cell[4679, 120, 53132, 1722, 289, 15458, 1252, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[57826, 1845, 184, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[58035, 1853, 394, 8, 58, "Input"],
Cell[58432, 1863, 32586, 752, 129, 5598, 414, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[91033, 2618, 261, 5, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[91319, 2627, 136, 3, 30, "Input"],
Cell[91458, 2632, 282, 5, 20, "Output"]
}, Open  ]],
Cell[91755, 2640, 61, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[91841, 2644, 308, 7, 50, "Input"],
Cell[92152, 2653, 865, 17, 47, "Output"]
}, Open  ]],
Cell[93032, 2673, 84, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[93141, 2678, 392, 8, 50, "Input"],
Cell[93536, 2688, 884, 17, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[94457, 2710, 392, 8, 50, "Input"],
Cell[94852, 2720, 884, 17, 47, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[95785, 2743, 43, 0, 26, "SubsectionIcon"],
Cell[95831, 2745, 401, 7, 37, "DefinitionBox",
  CellTags->{"IterateNeutral", "Cline"}],
Cell[96235, 2754, 729, 16, 50, "Text"],

Cell[CellGroupData[{
Cell[96989, 2774, 1904, 39, 220, "Input"],
Cell[98896, 2815, 92075, 3026, 270, 27524, 2224, "GraphicsData", \
"PostScript", "Graphics"],
Cell[190974, 5843, 101, 2, 20, "Output"]
}, Open  ]],
Cell[191090, 5848, 58, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[191173, 5852, 375, 7, 74, "Input"],
Cell[191551, 5861, 1553, 27, 47, "Output"]
}, Open  ]],
Cell[193119, 5891, 97, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[193241, 5898, 481, 10, 74, "Input"],
Cell[193725, 5910, 1550, 27, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[195312, 5942, 482, 10, 74, "Input"],
Cell[195797, 5954, 1545, 27, 47, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[197391, 5987, 71, 1, 26, "SubsectionIcon",
  CellTags->"Barrier"],
Cell[197465, 5990, 824, 18, 54, "Text"],
Cell[198292, 6010, 120, 3, 28, "MathCaption"],
Cell[198415, 6015, 705, 19, 92, "Input"],
Cell[199123, 6036, 213, 6, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[199361, 6046, 665, 14, 97, "Input"],
Cell[200029, 6062, 15752, 400, 184, 3262, 241, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[215796, 6465, 176, 4, 22, "Text"],
Cell[215975, 6471, 232, 6, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[216232, 6481, 287, 6, 46, "Input"],
Cell[216522, 6489, 100, 2, 20, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[216671, 6497, 40, 0, 26, "SubsectionIcon"],
Cell[216714, 6499, 315, 10, 30, "MathCaption"],
Cell[217032, 6511, 84, 2, 26, "Input"],
Cell[217119, 6515, 97, 3, 28, "MathCaption"],
Cell[217219, 6520, 65, 2, 26, "Input"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

