(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4291,        156]*)
(*NotebookOutlinePosition[      6314,        219]*)
(*  CellTagsIndexPosition[      5985,        206]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["References", "SubsectionIcon"],

Cell[TextData[{
  "Barton, N.  (1986).  The effects of linkage and density-dependent \
regulation on gene flow. ",
  StyleBox["Heredity",
    FontSlant->"Italic"],
  " ",
  StyleBox["57",
    FontWeight->"Bold"],
  ", 415-426."
}], "Text",
  CellTags->"Barton 1986"],

Cell[TextData[{
  "Barton, N.H. (1992).  On the spread of new gene combinations in the third \
phase of Wright's shifting balance.  ",
  StyleBox["Evolution",
    FontSlant->"Italic"],
  " ",
  StyleBox["46",
    FontWeight->"Bold"],
  ", 551-55."
}], "Text",
  CellTags->"Barton 1992"],

Cell[TextData[{
  "Barton, N.H. and Shpak, M. (2000). The stability of symmetrical solutions \
to polygenic models.  ",
  StyleBox["Theor. Pop. Biol.",
    FontSlant->"Italic"],
  StyleBox["57, ",
    FontWeight->"Bold"],
  "249-264",
  StyleBox[".",
    FontWeight->"Bold"]
}], "Text",
  CellTags->"Barton & Shpak 2000"],

Cell[TextData[{
  "Doebeli, M. (1996).  A quantitative genetic competition model for \
sympatric speciation.  ",
  StyleBox["J. Evol. Biol.",
    FontSlant->"Italic"],
  " ",
  StyleBox["9",
    FontWeight->"Bold"],
  ", 893-910."
}], "Text",
  CellTags->"Doebeli 1996"],

Cell[TextData[{
  "Falush, D.P. (1999). ",
  StyleBox["Strings and pots: the evolution of crossing over",
    FontSlant->"Italic"],
  ".  Ph.D. thesis, University College London. "
}], "Text",
  CellTags->"Falush 1999"],

Cell[TextData[{
  "Kondrashov, A. S. and F. A. Kondrashov (1999). Interactions among \
quantitative traits in the course of sympatric speciation. ",
  StyleBox["Nature",
    FontSlant->"Italic"],
  " ",
  StyleBox["400",
    FontWeight->"Bold"],
  ": 351-354."
}], "Text",
  CellTags->"Kondrashov & Kondrashov 1999"],

Cell[TextData[{
  "Kruuk, L. E. B., S. J. E. Baird, K. S. Gale, and N. H. Barton.  (1999).  A \
comparison of multilocus clines maintained by environmental adaptation or by \
selection against hybrids. ",
  StyleBox["Genetics ",
    FontSlant->"Italic"],
  StyleBox["153",
    FontWeight->"Bold"],
  ",",
  StyleBox[" ",
    FontWeight->"Bold"],
  "1959-1971."
}], "Text",
  CellTags->"Kruuk et al 1999"],

Cell[TextData[{
  "S",
  StyleBox["HPAK",
    FontSize->9],
  ", M., and A. S. K",
  StyleBox["ONDRASHOV",
    FontSize->9],
  " (1999) Applicability of the hypergeometric phenotypic model to haploid \
and diploid populations. ",
  StyleBox["Evolution",
    FontSlant->"Italic"],
  " ",
  StyleBox["53:",
    FontWeight->"Bold"],
  " 600-604."
}], "Text",
  CellTags->"Shpak & Kondrashov 1999"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{715, 546},
WindowMargins->{{Automatic, 43}, {Automatic, 13}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Barton 1986"->{
    Cell[1778, 53, 266, 10, 24, "Text",
      CellTags->"Barton 1986"]},
  "Barton 1992"->{
    Cell[2047, 65, 286, 10, 24, "Text",
      CellTags->"Barton 1992"]},
  "Barton & Shpak 2000"->{
    Cell[2336, 77, 321, 11, 24, "Text",
      CellTags->"Barton & Shpak 2000"]},
  "Doebeli 1996"->{
    Cell[2660, 90, 270, 10, 24, "Text",
      CellTags->"Doebeli 1996"]},
  "Falush 1999"->{
    Cell[2933, 102, 219, 6, 24, "Text",
      CellTags->"Falush 1999"]},
  "Kondrashov & Kondrashov 1999"->{
    Cell[3155, 110, 316, 10, 38, "Text",
      CellTags->"Kondrashov & Kondrashov 1999"]},
  "Kruuk et al 1999"->{
    Cell[3474, 122, 404, 13, 38, "Text",
      CellTags->"Kruuk et al 1999"]},
  "Shpak & Kondrashov 1999"->{
    Cell[3881, 137, 394, 16, 40, "Text",
      CellTags->"Shpak & Kondrashov 1999"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Barton 1986", 5154, 178},
  {"Barton 1992", 5246, 181},
  {"Barton & Shpak 2000", 5346, 184},
  {"Doebeli 1996", 5447, 187},
  {"Falush 1999", 5540, 190},
  {"Kondrashov & Kondrashov 1999", 5649, 193},
  {"Kruuk et al 1999", 5764, 196},
  {"Shpak & Kondrashov 1999", 5874, 199}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 36, 0, 36, "SubsectionIcon"],
Cell[1778, 53, 266, 10, 24, "Text",
  CellTags->"Barton 1986"],
Cell[2047, 65, 286, 10, 24, "Text",
  CellTags->"Barton 1992"],
Cell[2336, 77, 321, 11, 24, "Text",
  CellTags->"Barton & Shpak 2000"],
Cell[2660, 90, 270, 10, 24, "Text",
  CellTags->"Doebeli 1996"],
Cell[2933, 102, 219, 6, 24, "Text",
  CellTags->"Falush 1999"],
Cell[3155, 110, 316, 10, 38, "Text",
  CellTags->"Kondrashov & Kondrashov 1999"],
Cell[3474, 122, 404, 13, 38, "Text",
  CellTags->"Kruuk et al 1999"],
Cell[3881, 137, 394, 16, 40, "Text",
  CellTags->"Shpak & Kondrashov 1999"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

