(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     32020,        985]*)
(*NotebookOutlinePosition[    102806,       3549]*)
(*  CellTagsIndexPosition[    102452,       3535]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Reproduction", "SubsectionIcon"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< NumericalModels`ExactModel`;\)\)], "Input",
  CellLabel->"In[13]:="],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(Gametes[i, j, 
              n]\), \(gives\ the\ distribution\ of\ gamete\ classes\ after\ \
meiosis, \ given\ that\ the\ diploid\ parent\ is\ of\ genotype\ {i, j}, \ 
            and\ there\ are\ n\ loci\)},
          {\(Gametes[i, j, n, W]\), \(is\ just\ multiplied\ by\ W[i, j]; \ 
            not\ normalised\)}
          }], TraditionalForm]],
  CellTags->"Gametes"]], "DefinitionBox",
  CellTags->{"Gametes", "Linkage"}],

Cell["\<\
Assume three loci; the diploid genotype has one genome in class 1 \
({0,0,1}, {0,1,0} or {1,0,0}), and one in class 2.  This gives the \
distribution of gametes produced,assuming that all genotypes within a class \
are equally frequent:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gametes[1, 2, 3]\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \({1\/24, 11\/24, 11\/24, 1\/24}\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell["\<\
This just gives the offspring distribution, weighted by the \
parental fitness W[i,j,h]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gametes[1, 2, 3, W]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \({1\/24\ W[1, 2, 3], 1\/24\ \((8\ W[1, 2, 1] + 3\ W[1, 2, 3])\), 
      1\/24\ \((8\ W[1, 2, 1] + 3\ W[1, 2, 3])\), 
      1\/24\ W[1, 2, 3]}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell["\<\
Fitness is a function of the classes of the maternal and paternal \
genomnes (i, j) and also of the # of heterozygous loci, h.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Related functions:",
    FontWeight->"Bold"],
  " ",
  ButtonBox["GenotypeProbability[o,p]",
    ButtonData:>{"Genotype probabilities", "GenotypeProbability"},
    ButtonStyle->"AddOnsLink"],
  " performs a similar function, but is more general: it allows for multiple \
alleles."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(GameteTable[n, 
              NumericalModel \[Rule] 
                SymmetricDiploidFrequencies]\), \(stores\ a\ matrix\ showing\ \
the\ distribution\ of\ genotypes\ among\ gametes, \ \(\(for\)\(\ \)\(each\)\(\
\ \)\(diploid\)\(\ \)\(\(genotype\)\(.\)\)\(\ \)\)\)},
          {\(GameteTable[n, W, 
              NumericalModel \[Rule] 
                SymmetricDiploidFrequencies]\), \(is\ also\ defined; \ 
            it\ allows\ for\ selection\ W[i, j, h]\)},
          {\(GameteTable[n, StoreResults -> False, 
              NumericalModel \[Rule] 
                SymmetricDiploidFrequencies]\), \(does\ not\ store\ \
results\)}
          }], TraditionalForm]],
  CellTags->"GameteTable"]], "DefinitionBox",
  CellTags->{"StoreResults", "GameteTable"}],

Cell["\<\
This array lists the offspring distributions from all 4\[Times]4 \
diploid genotypes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GameteTable[3, NumericalModel \[Rule] SymmetricDiploidFrequencies] // 
      MatrixForm\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/2\)},
                    {\(1\/2\)},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/2\)},
                    {\(1\/4\)},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/8\)},
                    {\(3\/8\)},
                    {\(3\/8\)},
                    {\(1\/8\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/2\)},
                    {\(1\/2\)},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/6\)},
                    {\(2\/3\)},
                    {\(1\/6\)},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/24\)},
                    {\(11\/24\)},
                    {\(11\/24\)},
                    {\(1\/24\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {\(1\/4\)},
                    {\(1\/2\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/2\)},
                    {\(1\/4\)},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/24\)},
                    {\(11\/24\)},
                    {\(11\/24\)},
                    {\(1\/24\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {\(1\/6\)},
                    {\(2\/3\)},
                    {\(1\/6\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {\(1\/2\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/8\)},
                    {\(3\/8\)},
                    {\(3\/8\)},
                    {\(1\/8\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {\(1\/4\)},
                    {\(1\/2\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {\(1\/2\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{1, 0, 0, 0}, {
        Rational[ 1, 2], 
        Rational[ 1, 2], 0, 0}, {
        Rational[ 1, 4], 
        Rational[ 1, 2], 
        Rational[ 1, 4], 0}, {
        Rational[ 1, 8], 
        Rational[ 3, 8], 
        Rational[ 3, 8], 
        Rational[ 1, 8]}}, {{
        Rational[ 1, 2], 
        Rational[ 1, 2], 0, 0}, {
        Rational[ 1, 6], 
        Rational[ 2, 3], 
        Rational[ 1, 6], 0}, {
        Rational[ 1, 24], 
        Rational[ 11, 24], 
        Rational[ 11, 24], 
        Rational[ 1, 24]}, {0, 
        Rational[ 1, 4], 
        Rational[ 1, 2], 
        Rational[ 1, 4]}}, {{
        Rational[ 1, 4], 
        Rational[ 1, 2], 
        Rational[ 1, 4], 0}, {
        Rational[ 1, 24], 
        Rational[ 11, 24], 
        Rational[ 11, 24], 
        Rational[ 1, 24]}, {0, 
        Rational[ 1, 6], 
        Rational[ 2, 3], 
        Rational[ 1, 6]}, {0, 0, 
        Rational[ 1, 2], 
        Rational[ 1, 2]}}, {{
        Rational[ 1, 8], 
        Rational[ 3, 8], 
        Rational[ 3, 8], 
        Rational[ 1, 8]}, {0, 
        Rational[ 1, 4], 
        Rational[ 1, 2], 
        Rational[ 1, 4]}, {0, 0, 
        Rational[ 1, 2], 
        Rational[ 1, 2]}, {0, 0, 0, 1}}}]]], "Output",
  CellLabel->"Out[5]//MatrixForm="]
}, Closed]],

Cell["\<\
This weights each offspring distribution by the fitness of the \
diploid parent, assuming 10% selection against heterozygotes:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gt = 
      GameteTable[3, 0.9\^#3 &, 
        NumericalModel \[Rule] SymmetricDiploidFrequencies]; 
    gt // MatrixForm\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.45`"},
                    {"0.45`"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.2025`"},
                    {"0.405`"},
                    {"0.2025`"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.09112500000000001`"},
                    {"0.27337500000000003`"},
                    {"0.27337500000000003`"},
                    {"0.09112500000000001`"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.45`"},
                    {"0.45`"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.135`"},
                    {"0.6033333333333334`"},
                    {"0.135`"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.030375000000000003`"},
                    {"0.391125`"},
                    {"0.391125`"},
                    {"0.030375000000000003`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0.2025`"},
                    {"0.405`"},
                    {"0.2025`"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.2025`"},
                    {"0.405`"},
                    {"0.2025`"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.030375000000000003`"},
                    {"0.391125`"},
                    {"0.391125`"},
                    {"0.030375000000000003`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0.135`"},
                    {"0.6033333333333334`"},
                    {"0.135`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0.45`"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.09112500000000001`"},
                    {"0.27337500000000003`"},
                    {"0.27337500000000003`"},
                    {"0.09112500000000001`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0.2025`"},
                    {"0.405`"},
                    {"0.2025`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0.45`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{1, 0, 0, 0}, {0.45000000000000001, 0.45000000000000001, 
        0, 0}, {0.20250000000000001, 0.40500000000000003, 0.20250000000000001,
         0}, {0.091125000000000012, 0.27337500000000003, 0.27337500000000003, 
        0.091125000000000012}}, {{0.45000000000000001, 0.45000000000000001, 0,
         0}, {0.13500000000000001, 0.60333333333333339, 0.13500000000000001, 
        0}, {0.030375000000000003, 0.391125, 0.391125, 
        0.030375000000000003}, {0, 0.20250000000000001, 0.40500000000000003, 
        0.20250000000000001}}, {{0.20250000000000001, 0.40500000000000003, 
        0.20250000000000001, 0}, {0.030375000000000003, 0.391125, 0.391125, 
        0.030375000000000003}, {0, 0.13500000000000001, 0.60333333333333339, 
        0.13500000000000001}, {0, 0, 0.45000000000000001, 
        0.45000000000000001}}, {{0.091125000000000012, 0.27337500000000003, 
        0.27337500000000003, 0.091125000000000012}, {0, 0.20250000000000001, 
        0.40500000000000003, 0.20250000000000001}, {0, 0, 0.45000000000000001,
         0.45000000000000001}, {0, 0, 0, 1}}}]]], "Output",
  CellLabel->"Out[7]//MatrixForm="]
}, Closed]],

Cell[TextData[{
  "Multiplying by the distribution of diploid genotype frequencies, \[Phi], \
and summing gives the ",
  StyleBox["unnormalised",
    FontSlant->"Italic"],
  " genotype distribution after selection, new\[Phi]:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Phi] = 
        MakePopulation[3, 0.2, 
          NumericalModel \[Rule] SymmetricDiploidFrequencies];\)\), "\n", 
    \(new\[Phi] = 
      Plus @@ \(Plus @@ \((gt\ \[Phi]\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ )\)\)\)}], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \({0.4818903040000002`, 0.33929011200000025`, 0.07962931200000006`, 
      0.006229504000000004`}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell["\<\
The sum of this unnormalised distribution is just the mean fitness:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Plus @@ new\[Phi], MeanW[\[Phi], 0.9\^#3 &]}\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \({0.9070392320000005`, 0.9070392320000005`}\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell["\<\
The normalised distribution of gametes after selection on diploids \
is found by dividing by the mean fitmess; this is the algorithm used by \
NewGametes[]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(new\[Phi]\/Plus @@ new\[Phi]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \({0.5312783471751749`, 0.3740633260723171`, 0.08779037244554382`, 
      0.006867954306964311`}\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Note",
    FontWeight->"Bold"],
  ": by default, GameteTable stores results; this is efficient if fitnesses \
are constant.  However, it can use a great deal of memory if genotypic \
fitnesses are continually changing.  StoreResults->False prevents results \
being stored."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(NewGametes[\[Phi]]\), \(gives\ the\ gametes\ produced\ by\ the\ \
diploid\ representation\ \[Phi]; \ deme\ size\ is\ doubled\)},
          {\(NewGametes[\[Phi], W]\), \(does\ the\ same, \ 
            but\ assuming\ selection\ W[i, j, h]\)}
          }], TraditionalForm]],
  CellTags->"NewGametes"]], "DefinitionBox",
  CellTags->"NewGametes"],

Cell["\<\
\[Phi] is a diploid population in linkage equilibrium, with allele \
frequencies 0.2.  NewGametes[\[Phi]] gives the distribution of gametic \
genotypes in the absence of selection:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NewGametes[\[Phi]]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \(SymmetricHaploidFrequencies[{0.512`, 0.3840000000000001`, 
        0.09600000000000003`, 0.008`}, 2]\)], "Output",
  CellLabel->"Out[21]=",
  CellEditDuplicate->False,
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell["\<\
Deme size stays the same, at the default value of 1 that was \
specified for \[Phi].\
\>", "Text"],

Cell["\<\
This gives the distribution of gametic genotypes with 10% selection \
against heterozygotes at each locus:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NewGametes[\[Phi], 0.9\^#3 &]\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \(SymmetricHaploidFrequencies[{0.5312783471751749`, 0.3740633260723171`, 
        0.08779037244554382`, 0.006867954306964311`}, 2]\)], "Output",
  CellLabel->"Out[22]=",
  CellEditDuplicate->False,
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(NewGametes[\[Phi], 
              Mutation \[Rule] {{\[Mu]\_1, \[Nu]\_1}, {\[Mu]\_2, \[Nu]\_2}, \
\[Ellipsis]}]\), \(allows\ for\ mutation\ at\ \ a\ rate\ \[Mu]\_i\ from\ 0\ \
to\ 1, \ and\ \[Nu]\_i\ from\ 1\ to\ 0\)},
          {\(NewGametes[\[Phi], 
              Mutation \[Rule] {{\[Mu]\_1}, {\[Mu]\_2}, \[Ellipsis]}]\), \
\(allows\ for\ mutation\ at\ \ a\ rate\ \[Mu]\_i\ in\ each\ direction\)},
          {\(NewGametes[\[Phi], 
              Mutation \[Rule] {\[Mu]}]\), \(allows\ for\ mutation\ at\ \ a\ \
rate\ \[Mu]\ in\ each\ direction\ at\ all\ loci\)},
          {\(NewGametes[\[Phi], 
              Mutation \[Rule] {\[Mu], \[Nu]}]\), \(allows\ for\ mutation\ \
at\ \ a\ rate\ \[Mu]\ from\ 0\ to\ 1, \ and\ \[Nu]\ from\ 1\ to\ 0\)}
          }], TraditionalForm]],
  CellTags->"NewGametes"]], "DefinitionBox",
  CellTags->"Mutation"],

Cell["\<\
This specifies a population of 10 individuals, all in class \
zero\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi]0 = 
      MakePopulation[3, 0, 10, 
        NumericalModel \[Rule] SymmetricDiploidFrequencies]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(SymmetricDiploidFrequencies[{{1, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
          0}, {0, 0, 0, 0}}, 5]\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell["\<\
This specifies that 50% of 0 alleles mutate to 1 alleles at each \
locus:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NewGametes[\[Psi]0, Mutation \[Rule] {0.5, 0.1}]\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \(SymmetricHaploidFrequencies[{0.125`, 0.375`, 0.375`, 0.125`}, 
      10]\)], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell[TextData[{
  "NewGametes[\[Ellipsis],Mutation\[Rule]\[Ellipsis]] applies ",
  ButtonBox["Mutate",
    ButtonData:>{"Symmetric model: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"],
  "[] to the population.  This can be compiled:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NewGametes[\[Psi]0, Mutation \[Rule] {0.5, 0.1}, 
      Compiled \[Rule] True]\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \(SymmetricHaploidFrequencies[{0.125`, 0.375`, 0.375`, 0.125`}, 
      10]\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell[TextData[{
  "Mutation is implemented by using ",
  ButtonBox["ConstructMutateMatrix",
    ButtonData:>{"Symmetric model: mutation", "ConstructMutateMatrix"},
    ButtonStyle->"AddOnsLink"],
  "[] to calculate and store a transformation matrix.  This could become slow \
and memory intensive with large numbers of loci, if mutation rates keep \
changing."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(NewGametes[\[Phi], W, 
              DemeSize \[Rule] F]\), \(changes\ deme\ size\ to\ 2 
               F[n, W\&_]\)},
          {\(NewGametes[\[Phi], W, 
              StoreResults -> False]\), \(does\ not\ store\ results\)}
          }], TraditionalForm]],
  CellTags->"NewGametes"]], "DefinitionBox",
  CellTags->"DemeSize"],

Cell[TextData[{
  "This changes deme size to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(2  F[n, W\&_]\)\(:\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NewGametes[\[Phi], 2\ 0.9\^#3 &, 
      DemeSize -> \((#1\ Exp[\(-#1\)] #2 &)\)]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \(SymmetricHaploidFrequencies[{0.5312783471751749`, 0.3740633260723171`, 
        0.08779037244554382`, 0.006867954306964311`}, 1.33]\)], "Output",
  CellLabel->"Out[23]=",
  CellEditDuplicate->False,
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[{
  "In this example, the pure function #1 Exp[-#1]#2& represents n ",
  Cell[BoxData[
      \(TraditionalForm\`Exp[\(-n\)] W\&_; \ 
      this\ leads\ to\ an\ equilibrium\ at\ n\_eq = Log[W\&_]\)]],
  ", provided ",
  Cell[BoxData[
      \(TraditionalForm\`W\&_ > 1. \)]],
  "  The same can be achieved using DemeSize->",
  Cell[BoxData[
      StyleBox["ExponentialF",
        FontWeight->"Plain"]], "Input",
    GeneratedCell->True],
  "[1,0,1]"
}], "Text"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " RandomDrift->True cannot be used with symmetric models, because drift \
would violate the assumption of symmetry."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"NewGametes", "[", GridBox[{
            {\(\(SymmetricNeutralDiploidFrequencies[{\[Psi], u}, n], 
                W\)\(]\)\), \(gives\ the\ new\ gamete\ frequencies, \ 
              including\ a\ neutral\ marker\ locus\)}
            }]}], TraditionalForm]]]], "DefinitionBox",
  CellTags->"SymmetricNeutralDiploidFrequencies"],

Cell["\<\
This generates a diploid population, including a neuutral marker:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pp = 
      MakePopulation[3, {0.1, 0.3}, 
        NumericalModel \[Rule] SymmetricNeutralDiploidFrequencies]\)], "Input",\

  CellLabel->"In[2]:="],

Cell[BoxData[
    \(SymmetricNeutralDiploidFrequencies[{{{0.5314410000000002`, 
            0.17714700000000005`, 0.01968300000000001`, 
            0.0007290000000000003`}, {0.17714700000000005`, 
            0.059049000000000025`, 0.0065610000000000035`, 
            0.0002430000000000001`}, {0.01968300000000001`, 
            0.0065610000000000035`, 0.0007290000000000006`, 
            0.000027000000000000016`}, {0.0007290000000000003`, 
            0.0002430000000000001`, 0.000027000000000000016`, 
            1.0000000000000004`*^-6}}, {{0.3`, 0.3`, 0.3`, 0.3`}, {0.3`, 
            0.3`, 0.3`, 0.3`}, {0.3`, 0.3`, 0.3`, 0.3`}, {0.3`, 0.3`, 0.3`, 
            0.3`}}}, 1]\)], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell["\<\
The first matrix gives the frequencies of each diploid combination \
of classes, \[Psi], and the second, the frequencies of a neutral marker \
within each class.\
\>", "Text"],

Cell["\<\
This gives the frequencies of each class after meiosis, followed by \
the frequency of the marker within each class:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NewGametes[pp]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(SymmetricNeutralHaploidFrequencies[{{0.7290000000000001`, 
          0.24300000000000002`, 0.027000000000000003`, 
          0.0010000000000000002`}, {0.30000000000000004`, 
          0.29999999999999993`, 0.3`, 0.3`}}, 2]\)], "Output",
  CellLabel->"Out[28]=",
  CellEditDuplicate->False,
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell["This includes 10% selection against '1' alleles:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NewGametes[pp, 0.9\^#3 &]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(SymmetricNeutralHaploidFrequencies[{{0.7469622409995115`, 
          0.22886721862274595`, 0.023374766436217605`, 
          0.0007957739415248044`}, {0.3000000000000001`, 0.3`, 
          0.30000000000000004`, 0.30000000000000004`}}, 2]\)], "Output",
  CellLabel->"Out[29]=",
  CellEditDuplicate->False,
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"HeterozygoteB", "[", 
              RowBox[{"i", ",", "j", ",", 
                StyleBox["ngenes",
                  FontSlant->"Italic"]}], 
              "]"}], \(stores\ the\ distribution\ of\ the\ #\ of\ \
heterozygous\ loci\ among\ gametes\ from\ a\ parent\ of\ genotype\ \(\({i, 
                  j}\)\(.\)\)\)},
          {
            RowBox[{"HeterozygoteB", "[", 
              StyleBox["ngenes",
                FontSlant->"Italic"], 
              "]"}], \(stores\ the\ distribution\ of\ the\ #\ of\ \
heterozygous\ loci\ among\ all\ diploid\ \(\(genotypes\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"HeterozygoteB"],

Cell[TextData[{
  "With 3 loci, there is a 1/3 chance that the parent has no heterozygous \
loci ",
  Cell[BoxData[
      \(TraditionalForm\`\((h\)\)]],
  "=0, giving an offspring distribution of {0,1,0,0}), and a 2/3 chance that \
it is heterozygous at two loci ",
  Cell[BoxData[
      \(TraditionalForm\`\((h\)\)]],
  "=2, giving an offspring distribution ",
  Cell[BoxData[
      \(TraditionalForm\`{1\/4, 1\/2, 1\/4, 0}\)]],
  ")."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(HeterozygoteB[1, 1, 3]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \({1\/3, 0, 2\/3, 0}\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell["This gives a table of all the heterozygosities:  ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(HeterozygoteB[3] // MatrixForm\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"1"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/3\)},
                    {"0"},
                    {\(2\/3\)},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {\(2\/3\)},
                    {"0"},
                    {\(1\/3\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"1"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"1"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {\(2\/3\)},
                    {"0"},
                    {\(1\/3\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/3\)},
                    {"0"},
                    {\(2\/3\)},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"1"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{1, 0, 0, 0}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 
        1}}, {{0, 1, 0, 0}, {
        Rational[ 1, 3], 0, 
        Rational[ 2, 3], 0}, {0, 
        Rational[ 2, 3], 0, 
        Rational[ 1, 3]}, {0, 0, 1, 0}}, {{0, 0, 1, 0}, {0, 
        Rational[ 2, 3], 0, 
        Rational[ 1, 3]}, {
        Rational[ 1, 3], 0, 
        Rational[ 2, 3], 0}, {0, 1, 0, 0}}, {{0, 0, 0, 1}, {0, 0, 1, 0}, {0, 
        1, 0, 0}, {1, 0, 0, 0}}}]]], "Output",
  CellLabel->"Out[13]//MatrixForm="]
}, Closed]],

Cell["\<\
HeterozygoteB[] stores results, speeding up other calculations.  \
However, this does limit the number of loci that can be simulated.  \
\>", \
"Text"],

Cell["For example, 50 loci take up ~2Mb.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m0 = MemoryInUse[];\)\), "\n", 
    \(\(t = Timing[\(HeterozygoteB[50];\)];\)\), "\n", 
    \({t, MemoryInUse[\ ] - m0}\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \({{7.43333333333333357`\ Second, Null}, 2210488}\)], "Output",
  CellLabel->"Out[2]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{773, 690},
WindowMargins->{{6, Automatic}, {Automatic, 2}},
Visible->True,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Gametes"->{
    Cell[1925, 59, 489, 10, 70, "DefinitionBox",
      CellTags->{"Gametes", "Linkage"}]},
  "Linkage"->{
    Cell[1925, 59, 489, 10, 70, "DefinitionBox",
      CellTags->{"Gametes", "Linkage"}]},
  "StoreResults"->{
    Cell[3800, 123, 822, 17, 118, "DefinitionBox",
      CellTags->{"StoreResults", "GameteTable"}]},
  "GameteTable"->{
    Cell[3800, 123, 822, 17, 118, "DefinitionBox",
      CellTags->{"StoreResults", "GameteTable"}]},
  "NewGametes"->{
    Cell[17104, 509, 407, 8, 56, "DefinitionBox",
      CellTags->"NewGametes"]},
  "Mutation"->{
    Cell[18728, 565, 909, 17, 92, "DefinitionBox",
      CellTags->"Mutation"]},
  "DemeSize"->{
    Cell[21426, 651, 391, 9, 58, "DefinitionBox",
      CellTags->"DemeSize"]},
  "SymmetricNeutralDiploidFrequencies"->{
    Cell[23079, 707, 384, 7, 52, "DefinitionBox",
      CellTags->"SymmetricNeutralDiploidFrequencies"]},
  "HeterozygoteB"->{
    Cell[25879, 792, 746, 17, 72, "DefinitionBox",
      CellTags->"HeterozygoteB"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Gametes", 101439, 3504},
  {"Linkage", 101545, 3507},
  {"StoreResults", 101656, 3510},
  {"GameteTable", 101777, 3513},
  {"NewGametes", 101897, 3516},
  {"Mutation", 101995, 3519},
  {"DemeSize", 102092, 3522},
  {"SymmetricNeutralDiploidFrequencies", 102214, 3525},
  {"HeterozygoteB", 102341, 3528}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 38, 0, 36, "SubsectionIcon"],
Cell[1780, 53, 46, 0, 28, "MathCaption"],
Cell[1829, 55, 93, 2, 27, "Input"],
Cell[1925, 59, 489, 10, 70, "DefinitionBox",
  CellTags->{"Gametes", "Linkage"}],
Cell[2417, 71, 267, 5, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[2709, 80, 73, 2, 27, "Input"],
Cell[2785, 84, 88, 2, 36, "Output"]
}, Open  ]],
Cell[2888, 89, 119, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3032, 96, 76, 2, 27, "Input"],
Cell[3111, 100, 198, 4, 36, "Output"]
}, Open  ]],
Cell[3324, 107, 150, 3, 22, "Text"],
Cell[3477, 112, 320, 9, 24, "Text"],
Cell[3800, 123, 822, 17, 118, "DefinitionBox",
  CellTags->{"StoreResults", "GameteTable"}],
Cell[4625, 142, 116, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4766, 149, 144, 3, 27, "Input"],
Cell[4913, 154, 4936, 147, 415, "Output"]
}, Closed]],
Cell[9864, 304, 159, 4, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[10048, 312, 178, 5, 28, "Input"],
Cell[10229, 319, 5002, 119, 271, "Output"]
}, Closed]],
Cell[15246, 441, 245, 6, 34, "MathCaption"],

Cell[CellGroupData[{
Cell[15516, 451, 285, 7, 42, "Input"],
Cell[15804, 460, 153, 3, 20, "Output"]
}, Open  ]],
Cell[15972, 466, 100, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[16097, 473, 103, 2, 30, "Input"],
Cell[16203, 477, 101, 2, 20, "Output"]
}, Open  ]],
Cell[16319, 482, 187, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[16531, 490, 86, 2, 43, "Input"],
Cell[16620, 494, 153, 3, 20, "Output"]
}, Open  ]],
Cell[16788, 500, 313, 7, 38, "Text"],
Cell[17104, 509, 407, 8, 56, "DefinitionBox",
  CellTags->"NewGametes"],
Cell[17514, 519, 211, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[17750, 527, 76, 2, 26, "Input"],
Cell[17829, 531, 239, 6, 20, "Output"]
}, Open  ]],
Cell[18083, 540, 108, 3, 22, "Text"],
Cell[18194, 545, 137, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[18356, 552, 87, 2, 30, "Input"],
Cell[18446, 556, 267, 6, 20, "Output"]
}, Open  ]],
Cell[18728, 565, 909, 17, 92, "DefinitionBox",
  CellTags->"Mutation"],
Cell[19640, 584, 97, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[19762, 591, 160, 4, 26, "Input"],
Cell[19925, 597, 158, 3, 20, "Output"]
}, Open  ]],
Cell[20098, 603, 104, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[20227, 610, 106, 2, 26, "Input"],
Cell[20336, 614, 131, 3, 20, "Output"]
}, Open  ]],
Cell[20482, 620, 259, 6, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[20766, 630, 136, 3, 26, "Input"],
Cell[20905, 635, 131, 3, 20, "Output"]
}, Open  ]],
Cell[21051, 641, 372, 8, 37, "Text"],
Cell[21426, 651, 391, 9, 58, "DefinitionBox",
  CellTags->"DemeSize"],
Cell[21820, 662, 138, 4, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[21983, 670, 138, 3, 30, "Input"],
Cell[22124, 675, 270, 6, 20, "Output"]
}, Open  ]],
Cell[22409, 684, 473, 14, 38, "Text"],
Cell[22885, 700, 191, 5, 24, "Text"],
Cell[23079, 707, 384, 7, 52, "DefinitionBox",
  CellTags->"SymmetricNeutralDiploidFrequencies"],
Cell[23466, 716, 98, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[23589, 723, 168, 5, 26, "Input"],
Cell[23760, 730, 720, 12, 67, "Output"]
}, Open  ]],
Cell[24495, 745, 185, 4, 22, "Text"],
Cell[24683, 751, 147, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[24855, 758, 72, 2, 26, "Input"],
Cell[24930, 762, 361, 8, 20, "Output"]
}, Open  ]],
Cell[25306, 773, 71, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[25402, 777, 83, 2, 30, "Input"],
Cell[25488, 781, 376, 8, 35, "Output"]
}, Open  ]],
Cell[25879, 792, 746, 17, 72, "DefinitionBox",
  CellTags->"HeterozygoteB"],
Cell[26628, 811, 448, 13, 42, "Text"],

Cell[CellGroupData[{
Cell[27101, 828, 80, 2, 26, "Input"],
Cell[27184, 832, 77, 2, 36, "Output"]
}, Open  ]],
Cell[27276, 837, 72, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[27373, 841, 88, 2, 26, "Input"],
Cell[27464, 845, 3979, 115, 307, "Output"]
}, Closed]],
Cell[31458, 963, 161, 4, 18, "Text"],
Cell[31622, 969, 57, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[31704, 973, 180, 4, 58, "Input"],
Cell[31887, 979, 105, 2, 20, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

