(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5250,        178]*)
(*NotebookOutlinePosition[      6440,        216]*)
(*  CellTagsIndexPosition[      6320,        209]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Defining notation", "SubsectionIcon",
  CellTags->"Defining notation"],

Cell[TextData[{
  "These packages use special notations set up using the notation package, ",
  ButtonBox["Utilities`Notation`",
    ButtonData:>{"Notation Documentation", None},
    ButtonStyle->"AddOnsLink"],
  ".  This parses certain symbols into function names, and conversely, \
represents functions by abbreviated symbols.  For example, Join[U,V] appears \
as U\[Vee]V, but U\[Vee]V is treated by the kernel as Join[U,V]: "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({i, j, k}\[Vee]{l, m}\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \({i, j, k, l, m}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(U\[Vee]V // FullForm\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    TagBox[
      StyleBox[\(Join[U, V]\),
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[8]//FullForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Join[U, V]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(U\[Vee]V\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[TextData[{
  "Some of the special symbols are parsed by the Notation` package into \
corresponding full functions (for example, \[Sampi], \[CircleDot], ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\[DoubleStruckI], \ \
\[Zeta]\_\[DoubleStruckI]\)]],
  "):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(X\_\[DoubleStruckI] // FullForm\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    TagBox[
      StyleBox[\(AllelicState[\[DoubleStruckI]]\),
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[5]//FullForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setting up new packages", "SubsectionIcon",
  CellTags->"Setting up packages"],

Cell[TextData[{
  "Note that in order to set up these package files correctly, they ",
  StyleBox["must",
    FontWeight->"Bold"],
  " be saved by running PackageSaver_4.06.nb; this avoids generation of \
obscure error messages.  This is only a concern if you need to change or \
extend the packages.\n",
  StyleBox["Note: ",
    FontWeight->"Bold"],
  "If you open a package file (package.nb, say), and then save changes (even \
trivial ones) then the default ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " generated package.m will overwrite the version specially generated by \
PackageSaver.  There may then be obscure problems with the special notations. \
 If this happens,  open PackageSaver_4.06.nb; select and evaluate all cells; \
and in the browser dialog that opensd, select the required package.nb.  That \
will regenerate the correct package.m"
}], "Text"],

Cell[TextData[{
  "There can be problems in using the notation package with older versions of \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ": it is using the special features of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to the limit."
}], "Text"],

Cell[TextData[{
  "Further information can be found in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " documentation for ",
  ButtonBox["Utilities`Notation`",
    ButtonData:>{"Notation Documentation", None},
    ButtonStyle->"AddOnsLink"],
  ", or via ",
  ButtonBox["http://www.wolfram.com/",
    ButtonData:>{
      URL[ "http://www.wolfram.com/"], None},
    ButtonStyle->"Hyperlink"]
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{691, 618},
WindowMargins->{{14, Automatic}, {Automatic, 15}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Defining notation"->{
    Cell[1739, 51, 76, 1, 36, "SubsectionIcon",
      CellTags->"Defining notation"]},
  "Setting up packages"->{
    Cell[3569, 128, 84, 1, 36, "SubsectionIcon",
      CellTags->"Setting up packages"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Defining notation", 6091, 199},
  {"Setting up packages", 6205, 202}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 76, 1, 36, "SubsectionIcon",
  CellTags->"Defining notation"],
Cell[1818, 54, 441, 8, 51, "Text"],

Cell[CellGroupData[{
Cell[2284, 66, 78, 2, 27, "Input"],
Cell[2365, 70, 73, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2475, 77, 77, 2, 27, "Input"],
Cell[2555, 81, 182, 6, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2774, 92, 68, 2, 27, "Input"],
Cell[2845, 96, 67, 2, 20, "Output"]
}, Open  ]],
Cell[2927, 101, 275, 7, 22, "Text"],

Cell[CellGroupData[{
Cell[3227, 112, 88, 2, 27, "Input"],
Cell[3318, 116, 202, 6, 20, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3569, 128, 84, 1, 36, "SubsectionIcon",
  CellTags->"Setting up packages"],
Cell[3656, 131, 880, 18, 104, "Text"],
Cell[4539, 151, 277, 9, 38, "Text"],
Cell[4819, 162, 415, 13, 24, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

