(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10151,        472]*)
(*NotebookOutlinePosition[     10986,        501]*)
(*  CellTagsIndexPosition[     10898,        495]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Front End", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Help...", "SubsubsectionIcon"],

Cell[TextData[{
  "Use ?",
  StyleBox["name",
    FontSlant->"Italic"],
  " to find out about ",
  StyleBox["name",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?TakeAway\)\)], "Input",
  CellLabel->"In[121]:="],

Cell[BoxData[
    \("TakeAway[U,V] or U\[Backslash]V gives the set U, minus elements V. \
Note that this is not the same as Complement[U,V] if U contains repeated \
elements.  (\[Backslash] is entered as \
\[AliasIndicator]\\[AliasIndicator])"\)], "Print",
  CellTags->"Info3260120499-4921719"]
}, Open  ]],

Cell["\<\
Use \[CommandKey]K to complete names; \[CommandKey]\[ShiftKey]K to \
make a template:\
\>", "Text"],

Cell[BoxData[
    \(TakeAway[U, V]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grouping cells", "SubsubsectionIcon"],

Cell["\<\
Double-click on the icon in section headings, or on cell brackets, \
to open and close groups of cells\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(2 + 2\)], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    \(4\)], "Output",
  CellLabel->"Out[119]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Output", "SubsubsectionIcon"],

Cell["To suppress output, use a ; at the end of the line:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(2 + 2\)], "Input",
  CellLabel->"In[148]:="],

Cell[BoxData[
    \(4\)], "Output",
  CellLabel->"Out[148]="]
}, Open  ]],

Cell[BoxData[
    \(\(2 + 2;\)\)], "Input",
  CellLabel->"In[149]:="],

Cell[TextData[{
  "This is ",
  StyleBox["essential",
    FontWeight->"Bold"],
  " when structures are enormous - don't ask ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to display a million numbers!"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Mathematical notation", "SubsubsectionIcon"],

Cell["\<\
Greek letters etc are typed using \[AliasIndicator]a\
\[AliasIndicator] etc:\
\>", "Text"],

Cell[TextData[{
  "Superscripts etc are typed using the \[ControlKey] key:  2\[ControlKey]^3 \
gives ",
  Cell[BoxData[
      \(TraditionalForm\`2\^3\)]],
  ", 2\[ControlKey]/3 gives ",
  Cell[BoxData[
      \(TraditionalForm\`2\/3\)]],
  " etc.  \n\[ControlKey]\[VeryThinSpace]\[SpaceIndicator] gets out of \
special notation"
}], "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Kernel", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Evaluation", "SubsubsectionIcon"],

Cell[TextData[{
  "Use \[EnterKey] to evaluate commands in the kernel.  ",
  StyleBox["Beware:",
    FontWeight->"Bold"],
  " \[ReturnIndicator] does nothing"
}], "Text"],

Cell["To get numerical results, use N", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\[Pi], N[\[Pi]]}\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \({\[Pi], 3.141592653589793`}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Loading packages", "SubsubsectionIcon"],

Cell["To load a set of packages into the kernel:", "Text"],

Cell[BoxData[
    \(\(<< Graphics`;\)\)], "Input"],

Cell[TextData[{
  "Note: ",
  StyleBox[" When loading packages, ignore error messages such as this:",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \(Star::"shdw" \(\(:\)\(\ \)\) 
      "Symbol \!\(\"Star\"\) appears in multiple contexts \
\!\({\"DiscreteMath`Combinatorica`\", \"Graphics`MultipleListPlot`\"}\); \
definitions in context \!\(\"DiscreteMath`Combinatorica`\"\) may shadow or be \
shadowed by other definitions."\)], "Message",
  CellLabel->"From In[1]:="],

Cell[TextData[{
  "There is an obscure clash between two ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " packages, because they use the same symbols to mean different things.  \
This is not a problem here."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Patterns", "SubsubsectionIcon"],

Cell[TextData[{
  "Mathematica relies on matching ",
  StyleBox["patterns:",
    FontSlant->"Italic"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatchQ[{1, 2}, \ {_Integer, _Integer}]\)], "Input",
  CellLabel->"In[132]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[132]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DeleteCases[{{1, 2}, {\[Pi], 3}, {a, 
          b}}, {_Integer, _Integer}]\)], "Input",
  CellLabel->"In[133]:="],

Cell[BoxData[
    \({{\[Pi], 3}, {a, b}}\)], "Output",
  CellLabel->"Out[133]="]
}, Open  ]],

Cell[TextData[{
  "It is often convenient to ",
  StyleBox["transform ",
    FontSlant->"Italic"],
  "patterns by applying rules:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({{1, 2}, {\[Pi], 3}, {a, b}} /. {i_Integer, j_Integer} \[Rule] 
        i + j\)], "Input",
  CellLabel->"In[134]:="],

Cell[BoxData[
    \({3, {\[Pi], 3}, {a, b}}\)], "Output",
  CellLabel->"Out[134]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Mapping and applying functions", "SubsubsectionIcon"],

Cell["Applying a function:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus @@ {1, 2, 3}\)], "Input",
  CellLabel->"In[135]:="],

Cell[BoxData[
    \(6\)], "Output",
  CellLabel->"Out[135]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f @@ {a, b, c}\)], "Input",
  CellLabel->"In[136]:="],

Cell[BoxData[
    \(f[a, b, c]\)], "Output",
  CellLabel->"Out[136]="]
}, Open  ]],

Cell["Mapping a function:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(w /@ {a, b, c}\)], "Input",
  CellLabel->"In[139]:="],

Cell[BoxData[
    \({w[a], w[b], w[c]}\)], "Output",
  CellLabel->"Out[139]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Pure functions", "SubsubsectionIcon"],

Cell["Functions can be defined in two ways.  Most directly:", "Text"],

Cell[BoxData[
    \(\(f[x_] := x\^2;\)\)], "Input",
  CellLabel->"In[125]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[3]\)], "Input",
  CellLabel->"In[126]:="],

Cell[BoxData[
    \(9\)], "Output",
  CellLabel->"Out[126]="]
}, Open  ]],

Cell["It is often convenient to define a \"pure function\":", "Text"],

Cell[BoxData[
    \(\(ff = #\^2 &;\)\)], "Input",
  CellLabel->"In[127]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ff[2]\)], "Input",
  CellLabel->"In[128]:="],

Cell[BoxData[
    \(4\)], "Output",
  CellLabel->"Out[128]="]
}, Open  ]],

Cell["This can be sent as an argument to another function:", "Text"],

Cell[BoxData[
    \(\(h[g_] := {g[1], g[2]};\)\)], "Input",
  CellLabel->"In[129]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(h[ff]\)], "Input",
  CellLabel->"In[130]:="],

Cell[BoxData[
    \({1, 4}\)], "Output",
  CellLabel->"Out[130]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Parts of lists", "SubsubsectionIcon"],

Cell["To extract parts of lists:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b, c, d}\[LeftDoubleBracket]2\[RightDoubleBracket]\)], "Input",
  CellLabel->"In[122]:="],

Cell[BoxData[
    \(b\)], "Output",
  CellLabel->"Out[122]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b, c, d}\[LeftDoubleBracket]{2, 4}\[RightDoubleBracket]\)], "Input",\

  CellLabel->"In[123]:="],

Cell[BoxData[
    \({b, d}\)], "Output",
  CellLabel->"Out[123]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b, c, d}\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]\)], "Input",\

  CellLabel->"In[124]:="],

Cell[BoxData[
    \(d\)], "Output",
  CellLabel->"Out[124]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Describing data", "SubsubsectionIcon"],

Cell["Data are represented as lists:", "Text"],

Cell[BoxData[
    \(\(data = {1, 2, 8, 11, 7, 3, 3};\)\)], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
There are various functions which can be used to describe \
data:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Min[data], Max[data], Mean[data], Variance[data]}\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \({1, 11, 5, 41\/3}\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell["Lists can be sorted:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sort[data]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({1, 2, 3, 3, 7, 8, 11}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["\<\
To use Mean[] and Variance[] etc, Statistics` must be loaded:\
\>", \
"Text"],

Cell[BoxData[
    \(\(<< Statistics`;\)\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1276}, {0, 832}},
WindowSize->{973, 717},
WindowMargins->{{Automatic, -11}, {6, Automatic}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3260120499-4921719"->{
    Cell[2134, 75, 294, 5, 37, "Print",
      CellTags->"Info3260120499-4921719"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3260120499-4921719", 10789, 488}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 35, 0, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[1836, 57, 36, 0, 24, "SubsubsectionIcon"],
Cell[1875, 59, 159, 8, 24, "Text"],

Cell[CellGroupData[{
Cell[2059, 71, 72, 2, 26, "Input"],
Cell[2134, 75, 294, 5, 37, "Print",
  CellTags->"Info3260120499-4921719"]
}, Open  ]],
Cell[2443, 83, 109, 3, 24, "Text"],
Cell[2555, 88, 47, 1, 26, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2639, 94, 43, 0, 20, "SubsubsectionIcon"],
Cell[2685, 96, 126, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[2836, 103, 64, 2, 26, "Input"],
Cell[2903, 107, 61, 2, 21, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3013, 115, 35, 0, 20, "SubsubsectionIcon"],
Cell[3051, 117, 67, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[3143, 121, 64, 2, 26, "Input"],
Cell[3210, 125, 61, 2, 21, "Output"]
}, Open  ]],
Cell[3286, 130, 69, 2, 26, "Input"],
Cell[3358, 134, 225, 8, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3620, 147, 50, 0, 20, "SubsubsectionIcon"],
Cell[3673, 149, 100, 3, 24, "Text"],
Cell[3776, 154, 339, 10, 52, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4164, 170, 32, 0, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[4221, 174, 39, 0, 24, "SubsubsectionIcon"],
Cell[4263, 176, 170, 5, 24, "Text"],
Cell[4436, 183, 47, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[4508, 187, 74, 2, 26, "Input"],
Cell[4585, 191, 85, 2, 21, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4719, 199, 45, 0, 20, "SubsubsectionIcon"],
Cell[4767, 201, 58, 0, 24, "Text"],
Cell[4828, 203, 50, 1, 26, "Input"],
Cell[4881, 206, 160, 5, 24, "Text"],
Cell[5044, 213, 340, 6, 37, "Message"],
Cell[5387, 221, 229, 6, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5653, 232, 37, 0, 20, "SubsubsectionIcon"],
Cell[5693, 234, 113, 4, 24, "Text"],

Cell[CellGroupData[{
Cell[5831, 242, 97, 2, 26, "Input"],
Cell[5931, 246, 64, 2, 21, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6032, 253, 133, 3, 26, "Input"],
Cell[6168, 258, 80, 2, 21, "Output"]
}, Open  ]],
Cell[6263, 263, 142, 5, 24, "Text"],

Cell[CellGroupData[{
Cell[6430, 272, 136, 3, 26, "Input"],
Cell[6569, 277, 83, 2, 21, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6701, 285, 59, 0, 20, "SubsubsectionIcon"],
Cell[6763, 287, 36, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[6824, 291, 76, 2, 26, "Input"],
Cell[6903, 295, 61, 2, 21, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7001, 302, 73, 2, 26, "Input"],
Cell[7077, 306, 70, 2, 21, "Output"]
}, Open  ]],
Cell[7162, 311, 35, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[7222, 315, 73, 2, 26, "Input"],
Cell[7298, 319, 78, 2, 21, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[7425, 327, 43, 0, 20, "SubsubsectionIcon"],
Cell[7471, 329, 69, 0, 24, "Text"],
Cell[7543, 331, 77, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[7645, 337, 63, 2, 26, "Input"],
Cell[7711, 341, 61, 2, 21, "Output"]
}, Open  ]],
Cell[7787, 346, 69, 0, 24, "Text"],
Cell[7859, 348, 75, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[7959, 354, 64, 2, 26, "Input"],
Cell[8026, 358, 61, 2, 21, "Output"]
}, Open  ]],
Cell[8102, 363, 68, 0, 24, "Text"],
Cell[8173, 365, 85, 2, 26, "Input"],

Cell[CellGroupData[{
Cell[8283, 371, 64, 2, 26, "Input"],
Cell[8350, 375, 66, 2, 21, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[8465, 383, 43, 0, 20, "SubsubsectionIcon"],
Cell[8511, 385, 42, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[8578, 389, 113, 2, 26, "Input"],
Cell[8694, 393, 61, 2, 21, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8792, 400, 120, 3, 26, "Input"],
Cell[8915, 405, 66, 2, 21, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9018, 412, 120, 3, 26, "Input"],
Cell[9141, 417, 61, 2, 21, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[9251, 425, 44, 0, 20, "SubsubsectionIcon"],
Cell[9298, 427, 46, 0, 24, "Text"],
Cell[9347, 429, 91, 2, 26, "Input"],
Cell[9441, 433, 89, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[9555, 440, 107, 2, 26, "Input"],
Cell[9665, 444, 75, 2, 36, "Output"]
}, Open  ]],
Cell[9755, 449, 36, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[9816, 453, 67, 2, 26, "Input"],
Cell[9886, 457, 80, 2, 21, "Output"]
}, Open  ]],
Cell[9981, 462, 87, 3, 24, "Text"],
Cell[10071, 467, 52, 1, 26, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

