(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     21998,        742]*)
(*NotebookOutlinePosition[     25583,        842]*)
(*  CellTagsIndexPosition[     25351,        831]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Adding up over sets", "SubsectionIcon"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {
              RowBox[{"AddUp", "[", 
                RowBox[{
                  StyleBox["expr",
                    FontSlant->"Italic"], ",", "e", ",", "U"}], "]"}], 
              RowBox[{"gives", " ", "the", " ", "sum", " ", "of", " ", 
                StyleBox["expr",
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                StyleBox[
                  RowBox[{
                    StyleBox["o",
                      FontSlant->"Italic"], "ver"}]], " ", "all", " ", 
                StyleBox["e",
                  FontSlant->"Italic"], " ", "in", " ", "the", " ", "list", 
                " ", 
                RowBox[{
                  StyleBox["U",
                    FontSlant->"Italic"], "."}]}]},
            {
              RowBox[{\(\[Sum]\+\(e \[Element] U\)\), 
                StyleBox["expr",
                  FontSlant->"Italic"]}], \(is\ an\ alternative\ notation; \ 
              enter\  \[Element] \ 
                as\ \[AliasIndicator]elem\[AliasIndicator]\)}
            }], TraditionalForm]],
    CellTags->"AddUp"]
}], "DefinitionBox",
  CellTags->"AddUp"],

Cell["This reads in the package:", "MathCaption"],

Cell[BoxData[
    \(<< Utilities`SetManipulation`\)], "Input",
  CellLabel->"In[136]:=  (16:04:16 on 3/19/01)"],

Cell[TextData[{
  "It also automatically loads the package ",
  ButtonBox["Utilities`Notation`",
    ButtonData:>{"Notation Documentation", None},
    Active->True,
    ButtonStyle->"AddOnsLink"]
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"AddUp", "[", 
          RowBox[{
            StyleBox["expr",
              FontSlant->"Italic"], ",", "e", ",", "U"}], "]"}], 
        TraditionalForm]]],
  " sums over elements in the set U:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AddUp[f[e, c]\^2, e, {i, j, k}]\)], "Input",
  CellLabel->"In[125]:=  (15:39:49 on 3/19/01)"],

Cell[BoxData[
    \(f[i, c]\^2 + f[j, c]\^2 + f[k, c]\^2\)], "Output",
  CellLabel->"Out[125]=  (15:39:49 on 3/19/01)"]
}, Open  ]],

Cell["\<\
The same result can be achieved using a more compact \
notation:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(x \[Element] {i, j, k}\)x\^2\)], "Input",
  CellLabel->"In[126]:=  (15:39:51 on 3/19/01)"],

Cell[BoxData[
    \(i\^2 + j\^2 + k\^2\)], "Output",
  CellLabel->"Out[126]=  (15:39:51 on 3/19/01)"]
}, Open  ]],

Cell["\<\
Conversely, the function AddUp[] is represented using this \
notation:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AddUp[f, e, U]\)], "Input",
  CellLabel->"In[124]:=  (15:39:44 on 3/19/01)"],

Cell[BoxData[
    \(\[Sum]\+\(e \[Element] U\)f\)], "Output",
  CellLabel->"Out[124]=  (15:39:44 on 3/19/01)"]
}, Open  ]],

Cell[TextData[{
  "This extension uses the package ",
  ButtonBox["Utilities`Notation`",
    ButtonData:>{"Notation Documentation", None},
    Active->True,
    ButtonStyle->"AddOnsLink"]
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {
              RowBox[{"AddUp", "[", 
                RowBox[{
                  StyleBox["expr",
                    FontSlant->"Italic"], ",", "e", ",", "U", 
                  ",", \(Subsets -> True\)}], "]"}], 
              RowBox[{"gives", " ", "the", " ", "sum", " ", "of", " ", 
                StyleBox["expr",
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                StyleBox[
                  RowBox[{
                    StyleBox["o",
                      FontSlant->"Italic"], "ver"}]], " ", "all", " ", 
                "distinct", " ", "subsets", " ", "of", " ", "the", " ", 
                "list", " ", 
                RowBox[{
                  StyleBox["U",
                    FontSlant->"Italic"], "."}]}]},
            {\(\[Sum]\+\(x \[SubsetEqual] U\)expr\), \(is\ an\ alternative\ \
notation; \ enter\  \[SubsetEqual] \ 
                  as\ \[AliasIndicator]sub = \[AliasIndicator]\)}
            }], TraditionalForm]],
    CellTags->"AddUp"]
}], "DefinitionBox",
  CellTags->"Subsets"],

Cell["This sums over all distinct subsets of {i,j,j}:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(x \[SubsetEqual] {i, j, j}\)f[x]\^3\)], "Input",
  CellLabel->"In[70]:=  (15:51:22 on 3/19/01)"],

Cell[BoxData[
    \(f[{}]\^3 + f[{i}]\^3 + f[{j}]\^3 + f[{i, j}]\^3 + f[{j, j}]\^3 + 
      f[{i, j, j}]\^3\)], "Output",
  CellLabel->"Out[70]=  (15:51:22 on 3/19/01)"]
}, Open  ]],

Cell[TextData[{
  "Note that the sum is over ",
  StyleBox["distinct",
    FontSlant->"Italic"],
  " subsets.  Internally, this form is equivalent to ",
  Cell[BoxData[
      \(\[Sum]\+\(x \[Element] Union[Sort /@ Subsets[{i, j, j}]]\)\)]],
  "; Subsets[{i,j,j}] produces 8 elements, and counts {i,j} and {j} twice; \
Union[Subsets[{i,j,j}]] contains just 6 distinct elements.  This convention \
is used by Multilocus`Multilocus` to sum over the minimum number of relevant \
",
  ButtonBox["selection",
    ButtonData:>{"Selection", "Selection"},
    ButtonStyle->"AddOnsLink"],
  " coefficients."
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {"\<\"AddUp[x,{\\!\\(e\\_1\\),\\!\\(e\\_2\\)},{\\!\\(U\\_1\\),\\!\
\\(U\\_2\\)}]  \"\>", "\<\"is also defined  \"\>"}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->"Multiple sums"],

Cell["Multiple sums can be done:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AddUp[f[y, z], {y, z}, {{i, j, k}, {a, b, c}}]\)], "Input",
  CellLabel->"In[71]:=  (15:51:27 on 3/19/01)"],

Cell[BoxData[
    \(f[i, a] + f[i, b] + f[i, c] + f[j, a] + f[j, b] + f[j, c] + f[k, a] + 
      f[k, b] + f[k, c]\)], "Output",
  CellLabel->"Out[71]=  (15:51:27 on 3/19/01)"]
}, Open  ]],

Cell["The alternative notation extends as follows:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AddUp[f[y, z], {y, z}, {S, T}]\)], "Input",
  CellLabel->"In[129]:=  (15:40:16 on 3/19/01)"],

Cell[BoxData[
    \(\[Sum]\+\({y, z} \[Element] {S, T}\)f[y, z]\)], "Output",
  CellLabel->"Out[129]=  (15:40:16 on 3/19/01)"]
}, Open  ]],

Cell["There is a similar extension to sums over subsets:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\({y, z} \[SubsetEqual] {{i, j}, {a, b}}\)f[y, z]\)], "Input",
  CellLabel->"In[141]:=  (16:09:10 on 3/19/01)"],

Cell[BoxData[
    \(f[{}, {}] + f[{}, {a}] + f[{}, {b}] + f[{}, {a, b}] + f[{i}, {}] + 
      f[{i}, {a}] + f[{i}, {b}] + f[{i}, {a, b}] + f[{j}, {}] + f[{j}, {a}] + 
      f[{j}, {b}] + f[{j}, {a, b}] + f[{i, j}, {}] + f[{i, j}, {a}] + 
      f[{i, j}, {b}] + f[{i, j}, {a, b}]\)], "Output",
  CellLabel->"Out[141]=  (16:09:10 on 3/19/01)"]
}, Open  ]],

Cell["However, the two forms cannot be mixed in the same sum.", "Text"],

Cell["\<\
Note also that AddUp[] holds its arguments in unevaluated form, \
until the set is specified.Thus:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(x \[Element] S\)f[x + 2 + 3]\)], "Input",
  CellLabel->"In[130]:=  (15:40:23 on 3/19/01)"],

Cell[BoxData[
    \(\[Sum]\+\(x \[Element] S\)f[x + 2 + 3]\)], "Output",
  CellLabel->"Out[130]=  (15:40:23 on 3/19/01)"]
}, Open  ]],

Cell["Once the index is specified, the result is evaluated fully:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(x \[Element] {j, k}\)f[x + 2 + 3]\)], "Input",
  CellLabel->"In[131]:=  (15:40:26 on 3/19/01)"],

Cell[BoxData[
    \(f[5 + j] + f[5 + k]\)], "Output",
  CellLabel->"Out[131]=  (15:40:26 on 3/19/01)"]
}, Open  ]],

Cell["This behaviour can be overridden using Evaluate:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(x \[Element] S\)Evaluate[f[x + 2 + 3]]\)], "Input",
  CellLabel->"In[132]:=  (15:40:32 on 3/19/01)"],

Cell[BoxData[
    \(\[Sum]\+\(x \[Element] S\)f[5 + x]\)], "Output",
  CellLabel->"Out[132]=  (15:40:32 on 3/19/01)"]
}, Open  ]],

Cell["\<\
If some sets are specified, the sum will be evaluated for those \
alone:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\({x, y, z} \[Element] {S, {i, j, k}, T}\)f[x, y, z]\)], "Input",\

  CellLabel->"In[137]:=  (15:42:46 on 3/19/01)"],

Cell[BoxData[
    \(\[Sum]\+\({x, z} \[Element] {S, T}\)\((f[x, i, z] + f[x, j, z] + 
          f[x, k, z])\)\)], "Output",
  CellLabel->"Out[137]=  (15:42:46 on 3/19/01)"]
}, Open  ]],

Cell["The same holds for sums over subsets:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\({x, y, z} \[SubsetEqual] {S, {i, j}, T}\)f[x, y, 
        z]\)], "Input",
  CellLabel->"In[138]:=  (15:43:06 on 3/19/01)"],

Cell[BoxData[
    \(\[Sum]\+\({x, z} \[SubsetEqual] {S, T}\)\((f[x, {}, z] + f[x, {i}, z] + 
          f[x, {j}, z] + f[x, {i, j}, z])\)\)], "Output",
  CellLabel->"Out[138]=  (15:43:06 on 3/19/01)"]
}, Open  ]],

Cell[TextData[{
  "For details, see '",
  ButtonBox["Technicalities",
    ButtonData:>"Technicalities",
    ButtonStyle->"Hyperlink"],
  "'."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(SimplifyAddUp[
              expr]\), \(simplifies\ expressions\ involving\ AddUp[]\ or\ \
\[Sum]\+\(i \[Element] U\)\)}
          }], TraditionalForm]],
  CellTags->"SimplifyAddUp"]], "DefinitionBox",
  CellTags->"SimplifyAddUp"],

Cell["Polynomial expressions involving AddUp[] can be simplified:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SimplifyAddUp[\((1 + \[Sum]\+\(\[Alpha] \[Element] S\)\((x\_\[Alpha] + \
3)\))\)\^2]\)], "Input",
  CellLabel->"In[300]:="],

Cell[BoxData[
    \(1 + \[Sum]\+\({\[Alpha]} \[Element] {S}\)2\ \((x\_\[Alpha] + 
              3)\) + \[Sum]\+\({\[Alpha]$452, \[Alpha]$453} \[Element] {S, S}\
\)\((3 + x\_\[Alpha]$452)\)\ \((3 + x\_\[Alpha]$453)\)\)], "Output",
  CellLabel->"Out[300]="]
}, Open  ]],

Cell["Sums over subsets simplify in a similar way:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SimplifyAddUp[\((1 + \[Sum]\+\(\[Alpha] \[SubsetEqual] \
S\)\((x\_\[Alpha] + 3)\))\)\^2]\)], "Input",
  CellLabel->"In[137]:=  (16:04:22 on 3/19/01)"],

Cell[BoxData[
    \(1 + \[Sum]\+\({\[Alpha]} \[SubsetEqual] {S}\)2\ \((x\_\[Alpha] + 
              3)\) + \[Sum]\+\({\[Alpha]$11699, \[Alpha]$11700} \
\[SubsetEqual] {S, S}\)\((3 + x\_\[Alpha]$11699)\)\ \((3 + 
              x\_\[Alpha]$11700)\)\)], "Output",
  CellLabel->"Out[137]=  (16:04:22 on 3/19/01)"]
}, Open  ]],

Cell["\<\
Distinct dummy indices have been introduced to represent products \
or powers of sums.  These are constructed using Unique[\[Alpha]].  \
\>", \
"Text"],

Cell[TextData[{
  "SimplifyAddUp[expr] reduces polynomial expressions to sums of terms of the \
form ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\({\[Alpha], \[Ellipsis]} \[Element] {S, \
\[Ellipsis]}\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Note",
    FontWeight->"Bold"],
  ": SimplifyAddUp forces evaluation of the arguments of AddUp[], which may \
cause problems in some circumstances."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(SimplifyAddUpQ[
              expr]\), \(returns\ True\ if\ the\ expression\ is\ in\ the\ \
standard\ form\ generated\ by\ SimplifyAddUp[expr]\)}
          }], TraditionalForm]],
  CellTags->"SimplifyAddUpQ"]], "DefinitionBox",
  CellTags->"SimplifyAddUpQ"],

Cell["This is not in the standard form:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SimplifyAddUpQ[
      1 + \(\[Delta]\_\[Alpha]\) 
          Log[\[Zeta]\_\(i\_\[GothicCapitalM]\) + \[Zeta]\_\(i\_\
\[GothicCapitalF]\)] + 
        s \((\[Sum]\+\(\[Alpha] \[Element] S\)\(\[Gamma]\_\[Alpha]\) \((\
\[Zeta]\_\(j\_\[GothicCapitalM]\) + \[Zeta]\_\(j\_\[GothicCapitalF]\))\) \((a \
+ \[Zeta]\_\(\[Alpha]\_\[GothicCapitalM]\) + \[Zeta]\_\(\[Alpha]\_\
\[GothicCapitalF]\))\))\)\^3]\)], "Input",
  CellLabel->"In[74]:=  (15:52:06 on 3/19/01)"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[74]=  (15:52:06 on 3/19/01)"]
}, Open  ]],

Cell["Applying SimplifyAddUp[] turns it into the standard form:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SimplifyAddUp[
      1 + \(\[Delta]\_\[Alpha]\) 
          Log[\[Zeta]\_\(i\_\[GothicCapitalM]\) + \[Zeta]\_\(i\_\
\[GothicCapitalF]\)] + 
        s \((\[Sum]\+\(\[Alpha] \[Element] S\)\(\[Gamma]\_\[Alpha]\) \((\
\[Zeta]\_\(j\_\[GothicCapitalM]\) + \[Zeta]\_\(j\_\[GothicCapitalF]\))\) \((a \
+ \[Zeta]\_\(\[Alpha]\_\[GothicCapitalM]\) + \[Zeta]\_\(\[Alpha]\_\
\[GothicCapitalF]\))\))\)\^3]\)], "Input",
  CellLabel->"In[75]:=  (15:52:13 on 3/19/01)"],

Cell[BoxData[
    \(1 + \[Sum]\+\({\[Alpha]$5939, \[Alpha]$5940, \[Alpha]$5941} \[Element] \
{S, S, S}\)s\ \((\[Gamma]\_\[Alpha]$5939\ \[Gamma]\_\[Alpha]$5940\ \[Gamma]\_\
\[Alpha]$5941\ \((\[Zeta]\_\(j\_\[GothicCapitalF]\) + \[Zeta]\_\(j\_\
\[GothicCapitalM]\))\)\^3\ \((a + \[Zeta]\_\(\[Alpha]$5939\_\[GothicCapitalF]\
\) + \[Zeta]\_\(\[Alpha]$5939\_\[GothicCapitalM]\))\)\ \((a + \[Zeta]\_\(\
\[Alpha]$5940\_\[GothicCapitalF]\) + \[Zeta]\_\(\[Alpha]$5940\_\
\[GothicCapitalM]\))\)\ \((a + \[Zeta]\_\(\[Alpha]$5941\_\[GothicCapitalF]\) \
+ \[Zeta]\_\(\[Alpha]$5941\_\[GothicCapitalM]\))\))\) + 
      Log[\[Zeta]\_\(i\_\[GothicCapitalF]\) + \[Zeta]\_\(i\_\[GothicCapitalM]\
\)]\ \[Delta]\_\[Alpha]\)], "Output",
  CellLabel->"Out[75]=  (15:52:13 on 3/19/01)"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SimplifyAddUpQ[%]\)], "Input",
  CellLabel->"In[76]:=  (15:52:15 on 3/19/01)"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[76]=  (15:52:15 on 3/19/01)"]
}, Open  ]],

Cell["The indices must be given as lists:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({SimplifyAddUpQ[\[Sum]\+\(\[Alpha] \[Element] S\)\(\[Gamma]\_\[Alpha]\) \
\((\[Zeta]\_\(j\_\[GothicCapitalM]\) + \[Zeta]\_\(j\_\[GothicCapitalF]\))\) \
\((a + \[Zeta]\_\(\[Alpha]\_\[GothicCapitalM]\) + \[Zeta]\_\(\[Alpha]\_\
\[GothicCapitalF]\))\)], 
      SimplifyAddUpQ[\[Sum]\+\({\[Alpha]} \[Element] \
{S}\)\(\[Gamma]\_\[Alpha]\) \((\[Zeta]\_\(j\_\[GothicCapitalM]\) + \
\[Zeta]\_\(j\_\[GothicCapitalF]\))\) \((a + \[Zeta]\_\(\[Alpha]\_\
\[GothicCapitalM]\) + \[Zeta]\_\(\[Alpha]\_\[GothicCapitalF]\))\)]}\)], \
"Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \({False, True}\)], "Output",
  CellLabel->"Out[45]="]
}, Open  ]],

Cell[TextData[{
  "The standard form is a sum of expressions which are either free of any ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\({\[Alpha], \[Ellipsis]} \[Element] {S, \
\[Ellipsis]}\)\)]],
  ", or have the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\({\[Alpha], \[Ellipsis]} \[Element] {S, \
\[Ellipsis]}\)x\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "  is free of any ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\({\[Alpha], \[Ellipsis]} \[Element] {S, \
\[Ellipsis]}\)\)]],
  ". Functions such as Expectation[] and MakeSelectionCoefficient[] apply \
SimplifyAddUp[] only if SimplifyAddUpQ[] is False; this avoids infinite \
regress."
}], "Text"],

Cell[CellGroupData[{

Cell["Technicalities and a warning", "SubsubsectionIcon",
  CellTags->"Technicalities"],

Cell[TextData[{
  "AddUp[",
  StyleBox["expr",
    FontSlant->"Italic"],
  ",e,U] is based on  a simple scheme: Apply[Plus,Map[(",
  StyleBox["expr",
    FontSlant->"Italic"],
  "/.e\[RuleDelayed]#)&,U]].  The function (",
  StyleBox["expr",
    FontSlant->"Italic"],
  "/.e\[RuleDelayed]#)& replaces element e throughout ",
  StyleBox["expr",
    FontSlant->"Italic"],
  " by #; this is mapped onto the set U to give a list of elements which is \
then summed.  However, this method alone leads to trouble.  When ",
  StyleBox["e",
    FontSlant->"Italic"],
  " in",
  " ",
  StyleBox["expr",
    FontSlant->"Italic"],
  " is replaced by #, there may be errors, because # may not be recognised as \
an appropriate variable.  This is avoided by using ",
  "ReleaseHold[Apply[Plus,Map[(Hold[",
  StyleBox["expr",
    FontSlant->"Italic"],
  "]",
  "/.e\[RuleDelayed]#)&,U]]] and setting the attribute HoldFirst."
}], "Text"],

Cell[TextData[{
  "This method can make applying rules to AddUp[",
  StyleBox["expr",
    FontSlant->"Italic"],
  ",e,U] ",
  StyleBox["dangerous",
    FontWeight->"Bold"],
  ".  "
}], "Text"],

Cell[TextData[{
  "T",
  Cell[BoxData[
      \(TraditionalForm\`\(\(his\)\(\ \)\)\)]],
  "sorts the indices:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(U\_{i, k, j} /. U\_s_List \[RuleDelayed] U\_\(Sort[s]\)\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \(U\_{i, j, k}\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell["\<\
However, if the expression is inside AddUp, the expression is held \
unevaluated:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(i \[Element] \[DoubleStruckCapitalW]\)U\_{i, k, j} /. 
      U\_s_List \[RuleDelayed] U\_\(Sort[s]\)\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \(\[Sum]\+\(i \[Element] \[DoubleStruckCapitalW]\)U\_\(Sort[{i, k, \
j}]\)\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(i \[Element] \[DoubleStruckCapitalW]\)U\_{i, k, j} /. 
      U\_s_List \[RuleDelayed] U\_\(Sort[s]\)\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(\[Sum]\+\(i \[Element] \[DoubleStruckCapitalW]\)U\_\(Sort[{i, k, \
j}]\)\)], "Output",
  CellLabel->"Out[70]="]
}, Open  ]],

Cell["\<\
This will evaluate correctly when the set \[DoubleStruckCapitalW] \
is assigned:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(i \[Element] {i\_1, i\_2, i\_3}\)U\_{i, k, j} /. 
      U\_s_List \[RuleDelayed] U\_\(Sort[s]\)\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \(U\_{j, k, i\_1} + U\_{j, k, i\_2} + U\_{j, k, i\_3}\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]],

Cell[TextData[{
  "However, using //. with the set \[DoubleStruckCapitalW] unspecified will \
lead to an ",
  StyleBox["infinite recursion",
    FontWeight->"Bold"],
  ", of the form ",
  Cell[BoxData[
      \(\[Sum]\+\(i \[Element] \
\[DoubleStruckCapitalW]\)U\_\(Sort[Sort[Sort[{i, k, j}] \[Ellipsis]]]\)\)]],
  " "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\[Sum]\+\(i \[Element] \[DoubleStruckCapitalW]\)U\_{i, k, j})\) /. 
      U\_s_List \[RuleDelayed] U\_\(Sort[s]\)\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \(\[Sum]\+\(i \[Element] \[DoubleStruckCapitalW]\)U\_\(Sort[{i, k, \
j}]\)\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["\<\
The same result is obtained regardless of whether the rule is \
applied to the whole sum, or to the argument of the sum:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\[Sum]\+\(i \[Element] \[DoubleStruckCapitalW]\)U\_{i, k, j} /. 
        U\_s_List \[RuleDelayed] U\_\(Sort[s]\))\)\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(\[Sum]\+\(i \[Element] \[DoubleStruckCapitalW]\)U\_\(Sort[{i, k, \
j}]\)\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell["\<\
The problem can be avoided by using Evaluate[] to force evaluation:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(i \[Element] \[DoubleStruckCapitalW]\)Evaluate[
        U\_{i, k, j} //. U\_s_List \[RuleDelayed] U\_\(Sort[s]\)]\)], "Input",\

  CellLabel->"In[34]:="],

Cell[BoxData[
    \(\[Sum]\+\(i \[Element] \[DoubleStruckCapitalW]\)U\_{i, j, k}\)], \
"Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell[TextData[{
  "This is done automatically by ",
  ButtonBox["|. and ||.",
    ButtonData:>{"|., ||.", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"|. and ||."],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(i \[Element] \[DoubleStruckCapitalW]\)U\_{i, k, j} || \(\(.\)\
\((U\_s_List \[RuleDelayed] U\_\(Sort[s]\))\)\)\)], "Input",
  CellLabel->"In[121]:="],

Cell[BoxData[
    \(\[Sum]\+\(i \[Element] \[DoubleStruckCapitalW]\)U\_{i, j, k}\)], \
"Output",
  CellLabel->"Out[121]="]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{757, 670},
WindowMargins->{{110, Automatic}, {Automatic, 13}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "AddUp"->{
    Cell[1787, 53, 1237, 33, 58, "DefinitionBox",
      CellTags->"AddUp"]},
  "Subsets"->{
    Cell[4865, 164, 1162, 30, 60, "DefinitionBox",
      CellTags->"Subsets"]},
  "Multiple sums"->{
    Cell[7050, 227, 277, 8, 39, "DefinitionBox",
      CellTags->"Multiple sums"]},
  "SimplifyAddUp"->{
    Cell[10943, 366, 293, 7, 38, "DefinitionBox",
      CellTags->"SimplifyAddUp"]},
  "SimplifyAddUpQ"->{
    Cell[12944, 431, 320, 7, 50, "DefinitionBox",
      CellTags->"SimplifyAddUpQ"]},
  "Technicalities"->{
    Cell[16984, 545, 87, 1, 24, "SubsubsectionIcon",
      CellTags->"Technicalities"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"AddUp", 24724, 809},
  {"Subsets", 24816, 812},
  {"Multiple sums", 24917, 815},
  {"SimplifyAddUp", 25022, 818},
  {"SimplifyAddUpQ", 25129, 821},
  {"Technicalities", 25237, 824}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 45, 0, 36, "SubsectionIcon"],
Cell[1787, 53, 1237, 33, 58, "DefinitionBox",
  CellTags->"AddUp"],
Cell[3027, 88, 49, 0, 28, "MathCaption"],
Cell[3079, 90, 111, 2, 27, "Input"],
Cell[3193, 94, 207, 6, 23, "Text"],
Cell[3403, 102, 276, 9, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3704, 115, 113, 2, 28, "Input"],
Cell[3820, 119, 119, 2, 23, "Output"]
}, Open  ]],
Cell[3954, 124, 95, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4074, 131, 120, 2, 43, "Input"],
Cell[4197, 135, 101, 2, 23, "Output"]
}, Open  ]],
Cell[4313, 140, 101, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4439, 147, 96, 2, 27, "Input"],
Cell[4538, 151, 110, 2, 36, "Output"]
}, Open  ]],
Cell[4663, 156, 199, 6, 23, "Text"],
Cell[4865, 164, 1162, 30, 60, "DefinitionBox",
  CellTags->"Subsets"],
Cell[6030, 196, 70, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6125, 200, 126, 2, 43, "Input"],
Cell[6254, 204, 169, 3, 23, "Output"]
}, Open  ]],
Cell[6438, 210, 609, 15, 67, "Text"],
Cell[7050, 227, 277, 8, 39, "DefinitionBox",
  CellTags->"Multiple sums"],
Cell[7330, 237, 49, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7404, 241, 127, 2, 27, "Input"],
Cell[7534, 245, 176, 3, 20, "Output"]
}, Open  ]],
Cell[7725, 251, 67, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7817, 255, 112, 2, 27, "Input"],
Cell[7932, 259, 126, 2, 38, "Output"]
}, Open  ]],
Cell[8073, 264, 73, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8171, 268, 139, 2, 43, "Input"],
Cell[8313, 272, 341, 5, 33, "Output"]
}, Open  ]],
Cell[8669, 280, 71, 0, 22, "Text"],
Cell[8743, 282, 129, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8897, 289, 120, 2, 42, "Input"],
Cell[9020, 293, 121, 2, 36, "Output"]
}, Open  ]],
Cell[9156, 298, 84, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[9265, 303, 125, 2, 43, "Input"],
Cell[9393, 307, 102, 2, 20, "Output"]
}, Open  ]],
Cell[9510, 312, 71, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[9606, 316, 130, 2, 42, "Input"],
Cell[9739, 320, 117, 2, 36, "Output"]
}, Open  ]],
Cell[9871, 325, 103, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[9999, 332, 144, 3, 43, "Input"],
Cell[10146, 337, 172, 3, 38, "Output"]
}, Open  ]],
Cell[10333, 343, 60, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[10418, 347, 152, 3, 43, "Input"],
Cell[10573, 352, 199, 3, 38, "Output"]
}, Open  ]],
Cell[10787, 358, 153, 6, 22, "Text"],
Cell[10943, 366, 293, 7, 38, "DefinitionBox",
  CellTags->"SimplifyAddUp"],
Cell[11239, 375, 84, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11348, 380, 143, 3, 52, "Input"],
Cell[11494, 385, 255, 4, 39, "Output"]
}, Open  ]],
Cell[11764, 392, 67, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11856, 396, 170, 3, 54, "Input"],
Cell[12029, 401, 309, 5, 39, "Output"]
}, Open  ]],
Cell[12353, 409, 161, 4, 22, "Text"],
Cell[12517, 415, 233, 7, 38, "Text"],
Cell[12753, 424, 188, 5, 24, "Text"],
Cell[12944, 431, 320, 7, 50, "DefinitionBox",
  CellTags->"SimplifyAddUpQ"],
Cell[13267, 440, 56, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[13348, 444, 472, 9, 52, "Input"],
Cell[13823, 455, 87, 2, 20, "Output"]
}, Open  ]],
Cell[13925, 460, 82, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[14032, 465, 471, 9, 52, "Input"],
Cell[14506, 476, 761, 11, 58, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15304, 492, 98, 2, 27, "Input"],
Cell[15405, 496, 86, 2, 20, "Output"]
}, Open  ]],
Cell[15506, 501, 58, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[15589, 505, 569, 10, 42, "Input"],
Cell[16161, 517, 72, 2, 20, "Output"]
}, Open  ]],
Cell[16248, 522, 711, 19, 52, "Text"],

Cell[CellGroupData[{
Cell[16984, 545, 87, 1, 24, "SubsubsectionIcon",
  CellTags->"Technicalities"],
Cell[17074, 548, 922, 28, 70, "Text"],
Cell[17999, 578, 192, 8, 24, "Text"],
Cell[18194, 588, 128, 5, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[18347, 597, 113, 2, 28, "Input"],
Cell[18463, 601, 71, 2, 21, "Output"]
}, Open  ]],
Cell[18549, 606, 112, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[18686, 613, 168, 3, 42, "Input"],
Cell[18857, 618, 131, 3, 36, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19025, 626, 168, 3, 42, "Input"],
Cell[19196, 631, 131, 3, 36, "Output"]
}, Open  ]],
Cell[19342, 637, 111, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[19478, 644, 163, 3, 44, "Input"],
Cell[19644, 649, 110, 2, 22, "Output"]
}, Open  ]],
Cell[19769, 654, 336, 10, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[20130, 668, 174, 3, 51, "Input"],
Cell[20307, 673, 131, 3, 36, "Output"]
}, Open  ]],
Cell[20453, 679, 151, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[20629, 686, 176, 3, 51, "Input"],
Cell[20808, 691, 131, 3, 36, "Output"]
}, Open  ]],
Cell[20954, 697, 100, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[21079, 704, 183, 4, 42, "Input"],
Cell[21265, 710, 121, 3, 36, "Output"]
}, Open  ]],
Cell[21401, 716, 199, 7, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[21625, 727, 179, 3, 42, "Input"],
Cell[21807, 732, 122, 3, 36, "Output"]
}, Open  ]],
Cell[21944, 738, 26, 0, 27, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

