(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7728,        264]*)
(*NotebookOutlinePosition[      8893,        301]*)
(*  CellTagsIndexPosition[      8770,        294]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Applying rules inside AddUp and TimesUp", "SubsectionIcon"],

Cell[BoxData[
    StyleBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                StyleBox["expr",
                  FontSlant->"Italic"], "|", 
                RowBox[{".", 
                  StyleBox["rules",
                    FontSlant->"Italic"]}]}], "\n", 
              RowBox[{"or", " ", 
                RowBox[{"ReplaceAllSpecial", "[", 
                  RowBox[{
                    StyleBox["expr",
                      FontSlant->"Italic"], ",", 
                    StyleBox["rules",
                      FontSlant->"Italic"]}], "]"}]}]}], 
            RowBox[{
              RowBox[{"applies", " ", 
                StyleBox["rules",
                  FontSlant->"Italic"]}], ",", 
              " ", \(evaluating\ them\ inside\ AddUp[]\ and\ TimesUp[]\)}]}
          },
        ColumnAlignments->{Left},
        GridFrame->False],
      FontFamily->"Times"]], "DefinitionBox",
  CellTags->"ReplaceAllSpecial"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(<< Utilities`SetManipulation`\)], "Input",
  CellLabel->"In[1]:="],

Cell[TextData[{
  "It also automatically loads the package ",
  ButtonBox["Utilities`Notation`",
    ButtonData:>{"Notation Documentation", None},
    Active->True,
    ButtonStyle->"AddOnsLink"]
}], "Text"],

Cell[TextData[{
  "Usually, a set of rules can be applied using expr/.rules or ReplaceAll[",
  StyleBox["expr",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rules",
    FontSlant->"Italic"],
  "].  However, there are problems when expressions involve AddUp[] (",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(i \[Element] S\)\)]],
  ") or TimesUp[] ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Product]\+\(i \[Element] S\))\)\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(x \[Element] S\)f[x, 2. ] /. {f[x_, y_] \[RuleDelayed] 
          f[x, Sin[y]]}\)], "Input",
  CellLabel->"In[99]:="],

Cell[BoxData[
    \(\[Sum]\+\(x \[Element] S\)f[x, Sin[2.`]]\)], "Output",
  CellLabel->"Out[99]="]
}, Open  ]],

Cell[TextData[{
  "The replacement is carried out, but is not evaluated: AddUp[] and \
TimesUp[] hold their arguments.  WIth more complex rules, it is necessary to \
carry out evaluations. Then, ReplaceAllSpecial[",
  StyleBox["expr",
    FontSlant->"Italic"],
  ",",
  StyleBox["rules",
    FontSlant->"Italic"],
  "]  or ",
  StyleBox["expr",
    FontSlant->"Italic"],
  "|.",
  StyleBox["rules",
    FontSlant->"Italic"],
  " must be used:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(x \[Element] S\)f[x, 
          2. ] | \(\(.\)\({f[x_, y_] \[RuleDelayed] 
            f[x, Sin[y]]}\)\)\)], "Input",
  CellLabel->"In[100]:="],

Cell[BoxData[
    \(\[Sum]\+\(x \[Element] S\)f[x, 0.9092974268256817`]\)], "Output",
  CellLabel->"Out[100]="]
}, Open  ]],

Cell[BoxData[
    StyleBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                StyleBox["expr",
                  FontSlant->"Italic"], "||", 
                RowBox[{".", 
                  StyleBox["rules",
                    FontSlant->"Italic"]}]}], "\n", 
              RowBox[{"or", " ", 
                RowBox[{"ReplaceRepeatedSpecial", "[", 
                  RowBox[{
                    StyleBox["expr",
                      FontSlant->"Italic"], ",", 
                    StyleBox["rules",
                      FontSlant->"Italic"]}], "]"}]}]}], 
            RowBox[{"applies", " ", 
              StyleBox["rules",
                FontSlant->"Italic"], " ", "repeatedly", " ", "until", " ", 
              "there", " ", "is", " ", "no", " ", "further", 
              " ", \(change . \ \ Evaluates\), " ", "rules", " ", "inside", 
              " ", \(AddUp[]\), " ", "and", " ", \(TimesUp[]\)}]}
          },
        ColumnAlignments->{Left},
        GridFrame->False],
      FontFamily->"Times"]], "DefinitionBox",
  CellTags->"ReplacerepeatedSpecial"],

Cell["\<\
The same problem arises when rules are used repeatedly. Here, it \
can be more serious.  \
\>", "Text"],

Cell["This expression iterates indefinitely:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(x \[Element] S\)f\_{i, k, j} //. {f\_U_ \[RuleDelayed] 
          f\_\(Sort[U]\)}\)], "Input",
  CellLabel->"In[102]:="],

Cell[BoxData[
    \($Aborted\)], "Output",
  CellLabel->"Out[102]="]
}, Open  ]],

Cell["\<\
This is because Sort[U] is not evaluated, and so expressions like \
Sort[Sort[\[Ellipsis]]] build up:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(x \[Element] S\)f\_{i, k, j} /. {f\_U_ \[RuleDelayed] 
          f\_\(Sort[U]\)}\)], "Input",
  CellLabel->"In[101]:="],

Cell[BoxData[
    \(\[Sum]\+\(x \[Element] S\)f\_\(Sort[{i, k, j}]\)\)], "Output",
  CellLabel->"Out[101]="]
}, Open  ]],

Cell[TextData[{
  "The problem is avoided using ",
  StyleBox["expr",
    FontSlant->"Italic"],
  "||.",
  StyleBox["rules",
    FontSlant->"Italic"],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(x \[Element] S\)f\_{i, k, j} || \(\(.\)\({f\_U_ \
\[RuleDelayed] f\_\(Sort[U]\)}\)\)\)], "Input",
  CellLabel->"In[103]:="],

Cell[BoxData[
    \(\[Sum]\+\(x \[Element] S\)f\_{i, j, k}\)], "Output",
  CellLabel->"Out[103]="]
}, Open  ]],

Cell[TextData[{
  "|. and ||. just temporarily replace AddUp and TimesUp by a dummy fumction \
which does not hold its arguments.  That may lead to problems if the \
arguments should ",
  StyleBox["not",
    FontSlant->"Italic"],
  " in fact be evaluated.  (See ",
  ButtonBox["previous section",
    ButtonData:>{"AddUp", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"previous section"],
  ")"
}], "Text"],

Cell[TextData[{
  "|. and ||.  are defined using the package ",
  ButtonBox["Utilities`Notation`",
    ButtonData:>{"Notation Documentation", None},
    Active->True,
    ButtonStyle->"AddOnsLink"]
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{245, Automatic}, {Automatic, 46}},
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "ReplaceAllSpecial"->{
    Cell[1807, 53, 956, 26, 52, "DefinitionBox",
      CellTags->"ReplaceAllSpecial"]},
  "ReplacerepeatedSpecial"->{
    Cell[4643, 154, 1100, 27, 66, "DefinitionBox",
      CellTags->"ReplacerepeatedSpecial"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"ReplaceAllSpecial", 8532, 284},
  {"ReplacerepeatedSpecial", 8650, 287}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 65, 0, 36, "SubsectionIcon"],
Cell[1807, 53, 956, 26, 52, "DefinitionBox",
  CellTags->"ReplaceAllSpecial"],
Cell[2766, 81, 46, 0, 28, "MathCaption"],
Cell[2815, 83, 86, 2, 27, "Input"],
Cell[2904, 87, 207, 6, 23, "Text"],
Cell[3114, 95, 458, 14, 52, "Text"],

Cell[CellGroupData[{
Cell[3597, 113, 147, 3, 42, "Input"],
Cell[3747, 118, 99, 2, 36, "Output"]
}, Open  ]],
Cell[3861, 123, 455, 16, 54, "Text"],

Cell[CellGroupData[{
Cell[4341, 143, 173, 4, 50, "Input"],
Cell[4517, 149, 111, 2, 36, "Output"]
}, Open  ]],
Cell[4643, 154, 1100, 27, 66, "DefinitionBox",
  CellTags->"ReplacerepeatedSpecial"],
Cell[5746, 183, 113, 3, 22, "Text"],
Cell[5862, 188, 61, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5948, 192, 150, 3, 42, "Input"],
Cell[6101, 197, 68, 2, 20, "Output"]
}, Open  ]],
Cell[6184, 202, 132, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6341, 209, 149, 3, 42, "Input"],
Cell[6493, 214, 108, 2, 36, "Output"]
}, Open  ]],
Cell[6616, 219, 175, 8, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[6816, 231, 153, 3, 42, "Input"],
Cell[6972, 236, 98, 2, 36, "Output"]
}, Open  ]],
Cell[7085, 241, 415, 12, 53, "Text"],
Cell[7503, 255, 209, 6, 23, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

