(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10831,        337]*)
(*NotebookOutlinePosition[     12837,        397]*)
(*  CellTagsIndexPosition[     12616,        386]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Cumulants and moments", "SubsectionIcon"],

Cell[TextData[{
  "The cumulants of the distribution of the sum of independent variables are \
the sum of the corresponding cumulants.  They are defined through the \
cumulant generating function, which is the log of the moment generating \
function.  Cumulants generalise to the multilocus case by partial \
differentiation of the generating function. (See Barton & Turelli, ",
  StyleBox["Genetics",
    FontSlant->"Italic"],
  " 1994 for application of multilocus cumulants to population genetics)."
}], "Text"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          RowBox[{
            StyleBox[GridBox[{
                  {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Cumulant[m,i]\\\\\\\"\\\
\", \\\"MR\\\"]\\) \"\>", "\<\"gives the i'th cumulant in terms of the \
moments m[i] \"\>"},
                  {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Moment[c,i]\\\\\\\"\\\",\
 \\\"MR\\\"]\\) \"\>", "\<\"gives the i'th moment in terms of the cumulants \
c[i] \"\>"}
                  },
                ColumnAlignments->{Right, Left}],
              GridBoxOptions->{RowLines->False}], 
            StyleBox[GridBox[{
                  {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Cumulant[m,{i,j,k}]\\\\\
\\\"\\\", \\\"MR\\\"]\\) \"\>", "\<\"gives the multivariate cumulant \
c[{i,j,k}] \"\>"},
                  {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Moment[c,{i,j,k}]\\\\\\\
\"\\\", \\\"MR\\\"]\\) \"\>", "\<\"gives the multivariate moment m[{i,j,k}]  \
\"\>"}
                  },
                ColumnAlignments->{Right, Left}],
              GridBoxOptions->{RowLines->False}], GridBox[{
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Moment[c,{i,j,k},Centred->\
True]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", "\<\"gives the central moment \
m[{i,j,k}]  \"\>"}
                },
              ColumnAlignments->{Right, Left}]}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"SA.8.7", "7.2", "Cumulant", "Moment"}],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`Cumulants`;\)\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
This package automatically loads Statistics`DiscreteDistributions`, \
Statistics`ContinuousDistributions`.\
\>", "Text"],

Cell["The fourth cumulant:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cumulant[m, 4]\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(-6\)\ m[1]\^4 + 12\ m[1]\^2\ m[2] - 3\ m[2]\^2 - 4\ m[1]\ m[3] + 
      m[4]\)], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell["The fourth cumulant in terms of central moments:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cumulant[m, 4, Centred -> True]\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(\(-3\)\ m[2]\^2 + m[4]\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell["The tenth cumulant in terms of central moments:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cumulant[m, 10, Centred -> True]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(22680\ m[2]\^5 - 37800\ m[2]\^2\ m[3]\^2 - 18900\ m[2]\^3\ m[4] + 
      4200\ m[3]\^2\ m[4] + 3150\ m[2]\ m[4]\^2 + 5040\ m[2]\ m[3]\ m[5] - 
      126\ m[5]\^2 + 1260\ m[2]\^2\ m[6] - 210\ m[4]\ m[6] - 
      120\ m[3]\ m[7] - 45\ m[2]\ m[8] + m[10]\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell["Checking....", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cumulant[m, 10, Centred -> True] /. 
        m[i_] -> Moment[c, i, Centred -> True] // Expand\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(c[10]\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell["The multivariate fourth cumulant:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cumulant[m, {i, j, k, l}]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(\(-6\)\ m[{i}]\ m[{j}]\ m[{k}]\ m[{l}] + 2\ m[{k}]\ m[{l}]\ m[{i, j}] + 
      2\ m[{j}]\ m[{l}]\ m[{i, k}] + 2\ m[{j}]\ m[{k}]\ m[{i, l}] + 
      2\ m[{i}]\ m[{l}]\ m[{j, k}] - m[{i, l}]\ m[{j, k}] + 
      2\ m[{i}]\ m[{k}]\ m[{j, l}] - m[{i, k}]\ m[{j, l}] + 
      2\ m[{i}]\ m[{j}]\ m[{k, l}] - m[{i, j}]\ m[{k, l}] - 
      m[{l}]\ m[{i, j, k}] - m[{k}]\ m[{i, j, l}] - m[{j}]\ m[{i, k, l}] - 
      m[{i}]\ m[{j, k, l}] + m[{i, j, k, l}]\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell["Checking that this is the correct expression:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cumulant[m, {i, j, k, l}] /. m[U_] -> Moment[c, U] // Expand\)], "Input",\

  CellLabel->"In[8]:="],

Cell[BoxData[
    \(c[{i, j, k, l}]\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell[BoxData[
    StyleBox[
      FrameBox[GridBox[{
            {
              RowBox[{"Cumulant", "[", 
                RowBox[{
                  StyleBox["distribution",
                    FontSlant->"Italic"], ",", "i", 
                  ",", \(Distribution \[Rule] True\)}], "]"}], 
              RowBox[{
              "gives", " ", "the", " ", \(i'\), "th", " ", "cumulant", " ", 
                "of", " ", 
                StyleBox["distribution",
                  FontSlant->"Italic"]}]},
            {
              RowBox[{"Moment", "[", 
                RowBox[{
                  StyleBox["distribution",
                    FontSlant->"Italic"], ",", "i", 
                  ",", \(Distribution \[Rule] True\)}], "]"}], 
              RowBox[{
              "gives", " ", "the", " ", \(i'\), "th", " ", "moment", " ", 
                "of", " ", 
                StyleBox["distribution",
                  FontSlant->"Italic"]}]},
            {
              RowBox[{"Moment", "[", 
                RowBox[{
                  StyleBox["distribution",
                    FontSlant->"Italic"], ",", "i", 
                  ",", \(Distribution \[Rule] True\), 
                  ",", \(Centred \[Rule] True\)}], "]"}], 
              RowBox[{
              "gives", " ", "the", " ", \(i'\), "th", " ", "central", " ", 
                "moment", " ", "of", " ", 
                StyleBox["distribution",
                  FontSlant->"Italic"]}]}
            }]],
      "2ColumnBox"]], "DefinitionBox",
  CellFrame->False,
  CellTags->{"SA.8.7", "7.2", "Distribution"}],

Cell[TextData[{
  " The CharacteristicFunction[] is differentiated ",
  StyleBox["i",
    FontSlant->"Italic"],
  " times to give the moment; Log[CharacteristicFunction[]] is differentiated \
",
  StyleBox["i",
    FontSlant->"Italic"],
  " times to give the cumulant.  That allows algebraic expressions, but may \
be slow."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Moment[BinomialDistribution[10, 0.33], 4, Distribution \[Rule] True], 
      ExpectedValue[ii\^4, BinomialDistribution[10, 0.33], ii]}\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \({286.925258400000071`, 286.925258399999894`}\)], "Output",
  CellLabel->"Out[59]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({Moment[BinomialDistribution[10, 0.33], 4, Distribution \[Rule] True, 
        Centred \[Rule] True], 
      ExpectedValue[\((ii - 3.3)\)\^4, BinomialDistribution[10, 0.33], ii]}
      \)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \({13.943450399999997`, 13.943450399999997`}\)], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({Cumulant[BinomialDistribution[n, \ p], 2, Distribution \[Rule] True], 
      Variance[BinomialDistribution[n, \ p]]}\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \({n\ \((1 - p)\)\ p, n\ \((1 - p)\)\ p}\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[BoxData[
    \({Cumulant[BinomialDistribution[n, \ p], 6, Distribution \[Rule] True], 
      Variance[BinomialDistribution[n, \ p]]}\)], "Input",
  CellLabel->"In[26]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \({Cumulant[BinomialDistribution[10, 0.33], 6, 
        Distribution \[Rule] True], 
      Cumulant[ExpectedValue[ii\^#, BinomialDistribution[10, 0.33], ii]&, 6]}
      \)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \({0.515660917199990631`, 0.515660917106288252`}\)], "Output",
  CellLabel->"Out[45]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(GeneralizedTransform[m, \ i, \ g, \ 
              z\_0]\), \(gives\ the\ quantities\ defined\ by\ applyingthe\ \
function\ g[]\ to\ the\ generating\ function, \ at\ z\_0\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"GeneralizedTransform"],

Cell[TextData[{
  "The cumulants and moments are defined in terms of ",
  Cell[BoxData[
      StyleBox[\(GeneralizedTransform[]\),
        FontWeight->"Plain"]]],
  ".    Thus, cumulants are given by GeneralizedTransform[m,i,Log,1], and \
moments by  cumulants are given by ",
  Cell[BoxData[
      \(TraditionalForm\`GeneralizedTransform[c, i, Exp, 0]\)]],
  "."
}], "Text"],

Cell["\<\
Note: In the package, definitions for Differential[] and \
GeneratingFunction[] are given.  These are no longer used: the \
GeneralizedTransform[] is defined using D[].  That may be slower, but is more \
straightforward.\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
WindowSize->{653, 673},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
Visible->True,
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "SA.8.7"->{
    Cell[2306, 64, 1416, 31, 110, "Text",
      CellTags->{"SA.8.7", "7.2", "Cumulant", "Moment"}],
    Cell[6359, 198, 1585, 40, 139, "DefinitionBox",
      CellTags->{"SA.8.7", "7.2", "Distribution"}]},
  "7.2"->{
    Cell[2306, 64, 1416, 31, 110, "Text",
      CellTags->{"SA.8.7", "7.2", "Cumulant", "Moment"}],
    Cell[6359, 198, 1585, 40, 139, "DefinitionBox",
      CellTags->{"SA.8.7", "7.2", "Distribution"}]},
  "Cumulant"->{
    Cell[2306, 64, 1416, 31, 110, "Text",
      CellTags->{"SA.8.7", "7.2", "Cumulant", "Moment"}]},
  "Moment"->{
    Cell[2306, 64, 1416, 31, 110, "Text",
      CellTags->{"SA.8.7", "7.2", "Cumulant", "Moment"}]},
  "Distribution"->{
    Cell[6359, 198, 1585, 40, 139, "DefinitionBox",
      CellTags->{"SA.8.7", "7.2", "Distribution"}]},
  "GeneralizedTransform"->{
    Cell[9866, 309, 324, 6, 50, "DefinitionBox",
      CellTags->"GeneralizedTransform"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"SA.8.7", 11694, 360},
  {"7.2", 11910, 365},
  {"Cumulant", 12131, 370},
  {"Moment", 12246, 373},
  {"Distribution", 12367, 376},
  {"GeneralizedTransform", 12500, 379}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 47, 0, 36, "SubsectionIcon"],
Cell[1789, 53, 514, 9, 66, "Text"],
Cell[2306, 64, 1416, 31, 110, "Text",
  CellTags->{"SA.8.7", "7.2", "Cumulant", "Moment"}],
Cell[3725, 97, 46, 0, 28, "MathCaption"],
Cell[3774, 99, 85, 2, 27, "Input"],
Cell[3862, 103, 130, 3, 22, "Text"],
Cell[3995, 108, 43, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4063, 112, 71, 2, 27, "Input"],
Cell[4137, 116, 136, 3, 23, "Output"]
}, Open  ]],
Cell[4288, 122, 71, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4384, 126, 88, 2, 27, "Input"],
Cell[4475, 130, 80, 2, 23, "Output"]
}, Open  ]],
Cell[4570, 135, 70, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4665, 139, 89, 2, 27, "Input"],
Cell[4757, 143, 309, 5, 38, "Output"]
}, Open  ]],
Cell[5081, 151, 35, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5141, 155, 150, 3, 27, "Input"],
Cell[5294, 160, 63, 2, 20, "Output"]
}, Open  ]],
Cell[5372, 165, 56, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5453, 169, 82, 2, 27, "Input"],
Cell[5538, 173, 503, 8, 59, "Output"]
}, Open  ]],
Cell[6056, 184, 68, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6149, 188, 119, 3, 27, "Input"],
Cell[6271, 193, 73, 2, 20, "Output"]
}, Open  ]],
Cell[6359, 198, 1585, 40, 139, "DefinitionBox",
  CellTags->{"SA.8.7", "7.2", "Distribution"}],
Cell[7947, 240, 336, 10, 38, "Text"],

Cell[CellGroupData[{
Cell[8308, 254, 193, 3, 42, "Input"],
Cell[8504, 259, 103, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8644, 266, 243, 5, 42, "Input"],
Cell[8890, 273, 101, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9028, 280, 175, 3, 27, "Input"],
Cell[9206, 285, 97, 2, 20, "Output"]
}, Open  ]],
Cell[9318, 290, 175, 3, 27, "Input"],

Cell[CellGroupData[{
Cell[9518, 297, 225, 5, 42, "Input"],
Cell[9746, 304, 105, 2, 20, "Output"]
}, Open  ]],
Cell[9866, 309, 324, 6, 50, "DefinitionBox",
  CellTags->"GeneralizedTransform"],
Cell[10193, 317, 375, 10, 36, "Text"],
Cell[10571, 329, 244, 5, 36, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

