(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     21486,        704]*)
(*NotebookOutlinePosition[     22634,        741]*)
(*  CellTagsIndexPosition[     22526,        734]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Manipulating options", "SubsectionIcon"],

Cell[TextData[{
  "Note that these functions are equivalent to those provided by the standard \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package ",
  ButtonBox["Utilities`FilterOptions`",
    ButtonData:>{"Utilities`FilterOptions`", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Utilities`FilterOptions`"],
  "; it is better to use these."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"DropOptions", "[", 
              RowBox[{"f", ",", 
                StyleBox["opts",
                  FontSlant->"Italic"]}], 
              "]"}], \(drops\ those\ options\ defined\ for\ function\ f\ from\
\ the\ list . \ \ Returns\ a\ \(\(Sequence[]\)\(.\)\)\)},
          {
            RowBox[{"TakeOptions", "[", 
              RowBox[{"f", ",", 
                StyleBox["opts",
                  FontSlant->"Italic"]}], 
              "]"}], \(keeps\ only\ options\ defined\ for\ function\ f; \ 
            it\ is\ the\ complement\ of\ DropOptions[] . \ \ Returns\ a\ \
\(\(Sequence[]\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"DropOptions", "TakeOptions"}],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(<< Utilities`Miscellaneous`; \)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
DropOptions[] and TakeOptions[] are useful when we wish to pass \
only appropriate options on to a function.  \
\>", "Text"],

Cell["\<\
Suppose a function f[] takes various options, only some of which \
should be passed on to functions called within f[]: \
\>", "MathCaption"],

Cell[BoxData[
    \(<< Graphics`Colors`; \)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(f[a_, opts___] := 
      Plot[NIntegrate[Sin[a\ xx] Exp[\(-xx\^2\)], {xx, 0, x}, 
          TakeOptions[NIntegrate, opts] // Evaluate], {x, 0, \[Pi]}, 
        TakeOptions[Plot, opts] // Evaluate]; \)], "Input",
  CellLabel->"In[4]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[1, AccuracyGoal \[Rule] 4, PlotStyle \[Rule] Red]; \)], "Input",
  CellLabel->"In[5]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.303152 0.0147151 1.38679 [
[.17539 .00222 -9 -9 ]
[.17539 .00222 9 0 ]
[.32696 .00222 -3 -9 ]
[.32696 .00222 3 0 ]
[.47854 .00222 -9 -9 ]
[.47854 .00222 9 0 ]
[.63011 .00222 -3 -9 ]
[.63011 .00222 3 0 ]
[.78169 .00222 -9 -9 ]
[.78169 .00222 9 0 ]
[.93327 .00222 -3 -9 ]
[.93327 .00222 3 0 ]
[.01131 .15339 -18 -4.5 ]
[.01131 .15339 0 4.5 ]
[.01131 .29207 -18 -4.5 ]
[.01131 .29207 0 4.5 ]
[.01131 .43075 -18 -4.5 ]
[.01131 .43075 0 4.5 ]
[.01131 .56943 -18 -4.5 ]
[.01131 .56943 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .01472 m
.17539 .02097 L
s
[(0.5)] .17539 .00222 0 1 Mshowa
.32696 .01472 m
.32696 .02097 L
s
[(1)] .32696 .00222 0 1 Mshowa
.47854 .01472 m
.47854 .02097 L
s
[(1.5)] .47854 .00222 0 1 Mshowa
.63011 .01472 m
.63011 .02097 L
s
[(2)] .63011 .00222 0 1 Mshowa
.78169 .01472 m
.78169 .02097 L
s
[(2.5)] .78169 .00222 0 1 Mshowa
.93327 .01472 m
.93327 .02097 L
s
[(3)] .93327 .00222 0 1 Mshowa
.125 Mabswid
.05412 .01472 m
.05412 .01847 L
s
.08444 .01472 m
.08444 .01847 L
s
.11476 .01472 m
.11476 .01847 L
s
.14507 .01472 m
.14507 .01847 L
s
.2057 .01472 m
.2057 .01847 L
s
.23602 .01472 m
.23602 .01847 L
s
.26633 .01472 m
.26633 .01847 L
s
.29665 .01472 m
.29665 .01847 L
s
.35728 .01472 m
.35728 .01847 L
s
.38759 .01472 m
.38759 .01847 L
s
.41791 .01472 m
.41791 .01847 L
s
.44822 .01472 m
.44822 .01847 L
s
.50885 .01472 m
.50885 .01847 L
s
.53917 .01472 m
.53917 .01847 L
s
.56948 .01472 m
.56948 .01847 L
s
.5998 .01472 m
.5998 .01847 L
s
.66043 .01472 m
.66043 .01847 L
s
.69074 .01472 m
.69074 .01847 L
s
.72106 .01472 m
.72106 .01847 L
s
.75138 .01472 m
.75138 .01847 L
s
.81201 .01472 m
.81201 .01847 L
s
.84232 .01472 m
.84232 .01847 L
s
.87264 .01472 m
.87264 .01847 L
s
.90295 .01472 m
.90295 .01847 L
s
.96358 .01472 m
.96358 .01847 L
s
.9939 .01472 m
.9939 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .15339 m
.03006 .15339 L
s
[(0.1)] .01131 .15339 1 0 Mshowa
.02381 .29207 m
.03006 .29207 L
s
[(0.2)] .01131 .29207 1 0 Mshowa
.02381 .43075 m
.03006 .43075 L
s
[(0.3)] .01131 .43075 1 0 Mshowa
.02381 .56943 m
.03006 .56943 L
s
[(0.4)] .01131 .56943 1 0 Mshowa
.125 Mabswid
.02381 .04245 m
.02756 .04245 L
s
.02381 .07019 m
.02756 .07019 L
s
.02381 .09792 m
.02756 .09792 L
s
.02381 .12566 m
.02756 .12566 L
s
.02381 .18113 m
.02756 .18113 L
s
.02381 .20887 m
.02756 .20887 L
s
.02381 .2366 m
.02756 .2366 L
s
.02381 .26434 m
.02756 .26434 L
s
.02381 .31981 m
.02756 .31981 L
s
.02381 .34754 m
.02756 .34754 L
s
.02381 .37528 m
.02756 .37528 L
s
.02381 .40302 m
.02756 .40302 L
s
.02381 .45849 m
.02756 .45849 L
s
.02381 .48622 m
.02756 .48622 L
s
.02381 .51396 m
.02756 .51396 L
s
.02381 .54169 m
.02756 .54169 L
s
.02381 .59717 m
.02756 .59717 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02499 .01473 L
.02605 .01475 L
.02729 .01481 L
.02846 .01488 L
.03053 .01506 L
.03279 .01532 L
.03527 .0157 L
.0379 .01621 L
.04262 .01738 L
.04749 .01893 L
.05205 .0207 L
.06244 .02587 L
.07305 .03273 L
.08274 .04035 L
.10458 .06195 L
.14429 .11473 L
.18248 .17729 L
.22313 .25005 L
.26226 .32009 L
.30384 .38902 L
.34391 .44646 L
.38246 .49178 L
.42346 .52908 L
.44388 .54375 L
.46295 .55533 L
.50092 .57306 L
.52127 .5801 L
.53983 .58527 L
.56052 .58986 L
.57967 .59318 L
.59826 .5957 L
.618 .59777 L
.63747 .59931 L
.65575 .6004 L
.67593 .60129 L
.69444 .60189 L
.71336 .60233 L
.72409 .60253 L
.73406 .60267 L
.74459 .6028 L
.75452 .6029 L
.77311 .60305 L
.78283 .6031 L
.79312 .60315 L
.81158 .60321 L
.82101 .60324 L
.83115 .60326 L
.84065 .60327 L
.84946 .60328 L
Mistroke
.85959 .60329 L
.87064 .6033 L
.88037 .60331 L
.89074 .60331 L
.90105 .60331 L
.90647 .60331 L
.91219 .60331 L
.91721 .60332 L
.92271 .60332 L
.93237 .60332 L
.93763 .60332 L
.94261 .60332 L
.94707 .60332 L
.95192 .60332 L
.9572 .60332 L
.95986 .60332 L
.9628 .60332 L
.9653 .60332 L
.96661 .60332 L
.96799 .60332 L
.9692 .60332 L
.97053 .60332 L
.97173 .60332 L
.97285 .60332 L
.97375 .60332 L
.9746 .60332 L
.97536 .60332 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[5]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000gOol2
0004Ool00`00Oomoo`02Ool3000POol3000QOol30004Ool00`00Oomoo`02Ool3000OOol5000NOol5
0003Ool00`00Oomoo`02Ool3000POol3000COol003Ioo`04001oogoo0007Ool01@00Oomoogoo0000
87oo00<007ooOol08Goo00<007ooOol01goo00D007ooOomoo`0001moo`04001oogoo000OOol01000
Oomoo`001goo00D007ooOomoo`0001ioo`05001oogooOol0000BOol003Ioo`04001oogoo000;Ool0
0`00Oomoo`0NOol00`00Oomoo`0QOol00`00Oomoo`0;Ool00`00Oomoo`0NOol00`00Oomoo`0POol0
0`00Oomoo`0;Ool00`00Oomoo`0POol00`00Oomoo`0@Ool003Ioo`04001oogoo000;Ool00`00Oomo
o`0NOol00`00Oomoo`0QOol00`00Oomoo`0;Ool00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomo
o`0:Ool00`00Oomoo`0NOol2000COol003Ioo`04001oogoo0007Ool4000QOol00`00Oomoo`0QOol0
0`00Oomoo`07Ool4000OOol01@00Oomoogoo00007Woo00D007ooOomoo`0000Moo`@002=oo`03001o
ogoo011oo`00=Woo00@007ooOol000Moo`03001oogoo025oo`80029oo`8000Uoo`03001oogoo021o
o`05001oogooOol0000NOol01@00Oomoogoo00001goo00<007ooOol087oo00D007ooOomoo`00019o
o`00=goo0P0027oo1@0087oo00<007ooOol08Goo00<007ooOol01goo1@007goo0`0087oo0`0027oo
1@007goo0`004goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<0
07ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool000ioo`L000Al0?l000P000005Goo00@007oo
Oomoo`Al0003001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Ioo`03001oogoo00Eoo`40005oo`5oo`005Goo00<007ooOol01Goo0W`07goo00<007ooOol0
9Woo00<007ooOol09goo00<007ooOol09Woo00<007ooOol09Woo00<007ooOol09Woo00<007ooOol0
4Goo000EOol00`00Oomoo`07Ool2O03oOol001Eoo`03001oogoo00Uoo`03O01oogoo0?aoo`005Goo
00<007ooOol02Woo0W`0o7oo000EOol00`00Oomoo`0<Ool00g`0Oomoo`3iOol001Eoo`03001oogoo
00eoo`03O01oogoo0?Qoo`005Goo0P003goo00=l07ooOol0mgoo000EOol00`00Oomoo`0?Ool00g`0
Oomoo`3fOol001Eoo`03001oogoo011oo`03O01oogoo0?Eoo`005Goo00<007ooOol04Goo00=l07oo
Ool0m7oo000EOol00`00Oomoo`0BOol00g`0Oomoo`3cOol001Eoo`03001oogoo01=oo`03O01oogoo
0?9oo`005Goo00<007ooOol04goo00=l07ooOol0lWoo000EOol2000EOol00g`0Oomoo`3aOol001Eo
o`03001oogoo01Eoo`03O01oogoo0?1oo`005Goo00<007ooOol05Woo00=l07ooOol0kgoo000EOol0
0`00Oomoo`0GOol00g`0Oomoo`3^Ool001Eoo`03001oogoo01Moo`03O01oogoo0>ioo`005Goo00<0
07ooOol067oo00=l07ooOol0kGoo000EOol00`00Oomoo`0IOol00g`0Oomoo`3/Ool001Eoo`03001o
ogoo01Yoo`03O01oogoo0>]oo`005Goo0P006goo00=l07ooOol0jgoo000EOol00`00Oomoo`0KOol0
0g`0Oomoo`3ZOol001Eoo`03001oogoo01aoo`03O01oogoo0>Uoo`005Goo00<007ooOol07Goo00=l
07ooOol0j7oo000EOol00`00Oomoo`0NOol00g`0Oomoo`3WOol001Eoo`03001oogoo01ioo`03O01o
ogoo0>Moo`005Goo00<007ooOol07goo00=l07ooOol0iWoo000EOol2000POol00g`0Oomoo`3VOol0
01Eoo`03001oogoo021oo`03O01oogoo0>Eoo`005Goo00<007ooOol08Goo00=l07ooOol0i7oo000E
Ool00`00Oomoo`0QOol00g`0Oomoo`3TOol001Eoo`03001oogoo029oo`03O01oogoo0>=oo`000Woo
0P0017oo00<007ooOol00Woo0`001Goo00<007ooOol08Woo00=l07ooOol0hgoo00001Goo001oogoo
00002Goo00<007ooOol017oo00<007ooOol08goo00=l07ooOol0hWoo00001Goo001oogoo00002Goo
00<007ooOol017oo00<007ooOol097oo00=l07ooOol0hGoo00001Goo001oogoo00002Goo00<007oo
Ool017oo0`0097oo00=l07ooOol0hGoo00001Goo001oogoo00002Goo00<007ooOol017oo00<007oo
Ool09Goo00=l07ooOol0h7oo00001Goo001oogoo000027oo0P001Woo00<007ooOol09Goo00=l07oo
Ool0h7oo0002Ool2000:Ool00`00Oomoo`04Ool00`00Oomoo`0VOol00g`0Oomoo`3OOol001Eoo`03
001oogoo02Moo`03O01oogoo0=ioo`005Goo00<007ooOol09goo00=l07ooOol0gWoo000EOol00`00
Oomoo`0XOol00g`0Oomoo`3MOol001Eoo`8002Uoo`03O01oogoo0=eoo`005Goo00<007ooOol0:Goo
00=l07ooOol0g7oo000EOol00`00Oomoo`0YOol00g`0Oomoo`3LOol001Eoo`03001oogoo02Yoo`03
O01oogoo0=]oo`005Goo00<007ooOol0:Woo00=l07ooOol0fgoo000EOol00`00Oomoo`0[Ool00g`0
Oomoo`3JOol001Eoo`03001oogoo02aoo`03O01oogoo0=Uoo`005Goo00<007ooOol0;7oo00=l07oo
Ool0fGoo000EOol2000^Ool00g`0Oomoo`3HOol001Eoo`03001oogoo02eoo`03O01oogoo0=Qoo`00
5Goo00<007ooOol0;Woo00=l07ooOol0egoo000EOol00`00Oomoo`0^Ool00g`0Oomoo`3GOol001Eo
o`03001oogoo02moo`03O01oogoo0=Ioo`005Goo00<007ooOol0;goo00=l07ooOol0eWoo000EOol0
0`00Oomoo`0`Ool00g`0Oomoo`3EOol001Eoo`03001oogoo035oo`03O01oogoo0=Aoo`005Goo0P00
<Woo00=l07ooOol0e7oo000EOol00`00Oomoo`0bOol00g`0Oomoo`3COol001Eoo`03001oogoo039o
o`03O01oogoo0==oo`005Goo00<007ooOol0<goo00=l07ooOol0dWoo000EOol00`00Oomoo`0cOol0
0g`0Oomoo`3BOol001Eoo`03001oogoo03Aoo`03O01oogoo0=5oo`005Goo00<007ooOol0=7oo00=l
07ooOol0dGoo000EOol2000fOol00g`0Oomoo`3@Ool001Eoo`03001oogoo03Ioo`03O01oogoo0<mo
o`005Goo00<007ooOol0=Woo00=l07ooOol0cgoo000EOol00`00Oomoo`0gOol00g`0Oomoo`3>Ool0
01Eoo`03001oogoo03Moo`03O01oogoo0<ioo`000Woo0P0017oo00@007ooOomoo`D000Aoo`03001o
ogoo03Qoo`03O01oogoo0<eoo`0000Eoo`00Oomoo`0000Qoo`04001oogoo0004Ool00`00Oomoo`0i
Ool00g`0Oomoo`3<Ool00005Ool007ooOol00009Ool00`00Oomoo`04Ool00`00Oomoo`0iOol00g`0
Oomoo`3<Ool00005Ool007ooOol0000:Ool00`00Oomoo`03Ool3000jOol00g`0Oomoo`3;Ool00005
Ool007ooOol00007Ool01@00Oomoogoo000017oo00<007ooOol0>Woo00=l07ooOol0bgoo00001Goo
001oogoo00001goo00D007ooOomoo`0000Aoo`03001oogoo03]oo`03O01oogoo0<Yoo`000Woo0P00
2Goo0`001Goo00<007ooOol0>goo00=l07ooOol0bWoo000EOol00`00Oomoo`0lOol00g`0Oomoo`39
Ool001Eoo`03001oogoo03eoo`03O01oogoo0<Qoo`005Goo00<007ooOol0?Goo00=l07ooOol0b7oo
000EOol2000oOol00g`0Oomoo`37Ool001Eoo`03001oogoo03ioo`03O01oogoo0<Moo`005Goo00<0
07ooOol0?goo00=l07ooOol0aWoo000EOol00`00Oomoo`0oOol00g`0Oomoo`36Ool001Eoo`03001o
ogoo041oo`03O01oogoo0<Eoo`005Goo00<007ooOol0@Goo00=l07ooOol0a7oo000EOol00`00Oomo
o`11Ool00g`0Oomoo`34Ool001Eoo`03001oogoo049oo`03O01oogoo0<=oo`005Goo0P00@goo00=l
07ooOol0`goo000EOol00`00Oomoo`13Ool00g`0Oomoo`32Ool001Eoo`03001oogoo04Aoo`03O01o
ogoo0<5oo`005Goo00<007ooOol0A7oo00=l07ooOol0`Goo000EOol00`00Oomoo`15Ool00g`0Oomo
o`30Ool001Eoo`03001oogoo04Eoo`03O01oogoo0<1oo`005Goo00<007ooOol0AWoo00=l07ooOol0
_goo000EOol20017Ool00g`0Oomoo`2oOol001Eoo`03001oogoo04Moo`03O01oogoo0;ioo`005Goo
00<007ooOol0B7oo00=l07ooOol0_Goo000EOol00`00Oomoo`18Ool00g`0Oomoo`2mOol001Eoo`03
001oogoo04Uoo`03O01oogoo0;aoo`005Goo00<007ooOol0BGoo00=l07ooOol0_7oo000EOol00`00
Oomoo`1:Ool00g`0Oomoo`2kOol001Eoo`03001oogoo04]oo`03O01oogoo0;Yoo`005Goo0P00C7oo
00=l07ooOol0^Woo000EOol00`00Oomoo`1<Ool00g`0Oomoo`2iOol001Eoo`03001oogoo04eoo`03
O01oogoo0;Qoo`005Goo00<007ooOol0CGoo00=l07ooOol0^7oo000EOol00`00Oomoo`1>Ool00g`0
Oomoo`2gOol0009oo`8000Aoo`03001oogoo009oo`<000Eoo`03001oogoo04moo`03O01oogoo0;Io
o`0000Eoo`00Oomoo`0000Moo`05001oogooOol00004Ool00`00Oomoo`1@Ool00g`0Oomoo`2eOol0
0005Ool007ooOol0000;Ool00`00Oomoo`02Ool3001@Ool00g`0Oomoo`2eOol00005Ool007ooOol0
0009Ool20005Ool00`00Oomoo`1AOol00g`0Oomoo`2dOol00005Ool007ooOol0000;Ool00`00Oomo
o`02Ool00`00Oomoo`1BOol00g`0Oomoo`2cOol00005Ool007ooOol00007Ool01@00Oomoogoo0000
17oo00<007ooOol0DWoo00=l07ooOol0/goo0002Ool20009Ool30005Ool00`00Oomoo`1COol00g`0
Oomoo`2bOol001Eoo`03001oogoo05Aoo`03O01oogoo0;5oo`005Goo00<007ooOol0E7oo00=l07oo
Ool0/Goo000EOol00`00Oomoo`1EOol00g`0Oomoo`2`Ool001Eoo`8005Moo`03O01oogoo0:moo`00
5Goo00<007ooOol0Egoo00=l07ooOol0[Woo000EOol00`00Oomoo`1HOol00g`0Oomoo`2]Ool001Eo
o`03001oogoo05Uoo`03O01oogoo0:aoo`005Goo00<007ooOol0FGoo00=l07ooOol0[7oo000EOol0
0`00Oomoo`1JOol00g`0Oomoo`2[Ool001Eoo`03001oogoo05]oo`03O01oogoo0:Yoo`005Goo0P00
GGoo00=l07ooOol0ZGoo000EOol00`00Oomoo`1MOol00g`0Oomoo`2XOol001Eoo`03001oogoo05io
o`9l0:Qoo`005Goo00<007ooOol0H7oo00=l07ooOol0YGoo000EOol00`00Oomoo`1QOol00g`0Oomo
o`2TOol001Eoo`03001oogoo069oo`03O01oogoo0:=oo`005Goo00<007ooOol0Hgoo00=l07ooOol0
XWoo000EOol00`00Oomoo`1TOol2O02ROol001Eoo`8006Moo`03O01oogoo09moo`005Goo00<007oo
Ool0Igoo00=l07ooOol0WWoo000EOol00`00Oomoo`1XOol00g`0Oomoo`2MOol001Eoo`03001oogoo
06Uoo`03O01oogoo09aoo`005Goo00<007ooOol0JWoo0W`0W7oo000EOol00`00Oomoo`1/Ool00g`0
Oomoo`2IOol001Eoo`03001oogoo06eoo`03O01oogoo09Qoo`005Goo00<007ooOol0KWoo00=l07oo
Ool0Ugoo000EOol2001`Ool2O02GOol001Eoo`03001oogoo075oo`9l09Eoo`005Goo00<007ooOol0
Lgoo00=l07ooOol0TWoo000EOol00`00Oomoo`1dOol2O02BOol001Eoo`03001oogoo07Ioo`9l091o
o`000Woo0P0017oo00<007ooOol00goo0`0017oo00<007ooOol0N7oo0g`0SGoo00001Goo001oogoo
00002Woo00<007ooOol00goo00<007ooOol0Ngoo0W`0Rgoo00001Goo001oogoo00001goo1@0017oo
0`00OGoo0W`0RGoo00001Goo001oogoo00001goo00@007ooOol000Eoo`03001oogoo07moo`9l08Mo
o`0000Eoo`00Oomoo`0000Qoo`03001oo`0000Eoo`03001oogoo085oo`=l08Aoo`0000Eoo`00Oomo
o`0000Uoo`8000Eoo`03001oogoo08Aoo`Al081oo`000Woo0P002goo00<007ooOol00goo00<007oo
Ool0R7oo17`0O7oo000EOol00`00Oomoo`2<Ool3O01iOol001Eoo`03001oogoo08moo`Al07Eoo`00
5Goo00<007ooOol0Tgoo2W`0Jgoo000EOol2002NOol;O01POol001Eoo`03001oogoo0:QooeUl00Mo
o`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uo
o`005Goo00<007ooOol0ogoo2Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.259483, -0.0333817, \
0.0121242, 0.00265034}}]
}, Open  ]],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      FormBox[
        StyleBox["opts",
          FontSlant->"Italic"], TraditionalForm]]],
  " had been passed directly to Plot[] and NIntegrate[], error messages would \
have been generated.  Note that //Evaluate must be used, otherwise \
TakeOptions[] would be held unevaluated, and appear to be inappropriate as a \
list of options.  "
}], "Text"],

Cell["\<\
TakeOptions[] is also useful when storing values of functions.  \
\
\>", "Text"],

Cell[TextData[{
  "Suppose we wish to store values of g[x,opts].  Only values corresponding \
to ",
  StyleBox["distinct",
    FontSlant->"Italic"],
  " sets of options need be stored:"
}], "MathCaption"],

Cell[BoxData[{
    \(Options[g] = Options[NIntegrate]; \), "\n", 
    \(g[a_, x_, opts___] := 
      Module[{xx, 
          oo = TakeOptions[g, opts]}, \n\t\tIf[{oo} === {opts}, \n\t\t\tg[a, 
              x, opts] = 
            NIntegrate[Sin[a\ xx] Exp[\(-xx\^2\)], {xx, 0, x}, opts], \n\t\tg[
            a, x, oo]]]; \)}], "Input",
  CellLabel->"In[29]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[1, \[Infinity]]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(0.424436383502073866`\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[1, \[Infinity], AccuracyGoal \[Rule] 3]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(0.424436384010469147`\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[1, \[Infinity], AccuracyGoal \[Rule] 3, 
      PlotStyle \[Rule] Red]\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \(0.424436384010469147`\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["\<\
Only the values of g[] which differ by relevant options have been \
stored.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(?? g\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \("Global`g"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      StyleBox[\(\(g[1, \ Infinity]\  = \ 
            0.4244363835020738\)\n\ \n\(g[1, \ Infinity, \ 
              AccuracyGoal\  -> \ 3]\  = \ 
            0.4244363840104691\)\n\ \n\(g[a_, \ x_, \ opts___]\  := \ 
            Module[{xx, \ oo\  = \ TakeOptions[g, \ opts]}, \ 
              If[{oo}\  === \ {opts}, \ 
                g[a, \ x, \ opts]\  = \ 
                  NIntegrate[Sin[a*xx]*Exp[\(-xx^2\)], \ {xx, \ 0, \ x}, \ 
                    opts], \ g[a, \ x, \ oo]]]\)\n\ \n\(Options[
              g]\  = \ {AccuracyGoal\  -> \ Infinity, \ 
              Compiled\  -> \ True, \ GaussPoints\  -> \ Automatic, \ 
              MaxPoints\  -> \ Automatic, \ MaxRecursion\  -> \ 6, \ 
              Method\  -> \ Automatic, \ MinRecursion\  -> \ 0, \ 
              PrecisionGoal\  -> \ Automatic, \ SingularityDepth\  -> \ 4, \ 
              WorkingPrecision\  -> \ 16}\)\),
        ShowStringCharacters->True,
        NumberMarks->True],
      InputForm[ 
        Definition[ g]],
      Editable->True,
      AutoDelete->True]], "Print"]
}, Open  ]],

Cell["\<\
TakeOptions[] and DropOptions[] take a sequence of one or more \
options, rather than a single list of options, and correspondingly, generate \
a Sequence[] which can be passed on in a straightforward way:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TakeOptions[Plot, AccuracyGoal \[Rule] 4, 
      PlotStyle \[Rule] Red]\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    RowBox[{"Sequence", "[", 
      RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"RGBColor", "[", 
          RowBox[{
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1], ",", "0.`", ",", "0.`"}], "]"}]}], 
      "]"}]], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DropOptions[Plot, AccuracyGoal \[Rule] 4, 
      PlotStyle \[Rule] Red]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(Sequence[AccuracyGoal \[Rule] 4]\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{245, Automatic}, {Automatic, 46}},
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "DropOptions"->{
    Cell[2169, 66, 783, 18, 98, "DefinitionBox",
      CellTags->{"DropOptions", "TakeOptions"}]},
  "TakeOptions"->{
    Cell[2169, 66, 783, 18, 98, "DefinitionBox",
      CellTags->{"DropOptions", "TakeOptions"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"DropOptions", 22284, 724},
  {"TakeOptions", 22402, 727}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 46, 0, 36, "SubsectionIcon"],
Cell[1788, 53, 378, 11, 39, "Text"],
Cell[2169, 66, 783, 18, 98, "DefinitionBox",
  CellTags->{"DropOptions", "TakeOptions"}],
Cell[2955, 86, 46, 0, 28, "MathCaption"],
Cell[3004, 88, 86, 2, 27, "Input"],
Cell[3093, 92, 134, 3, 36, "Text"],
Cell[3230, 97, 150, 3, 42, "MathCaption"],
Cell[3383, 102, 78, 2, 27, "Input"],
Cell[3464, 106, 255, 5, 58, "Input"],

Cell[CellGroupData[{
Cell[3744, 115, 110, 2, 27, "Input"],
Cell[3857, 119, 13549, 436, 184, 4576, 320, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[17421, 558, 392, 10, 51, "Text"],
Cell[17816, 570, 90, 3, 70, "Text"],
Cell[17909, 575, 204, 6, 70, "MathCaption"],
Cell[18116, 583, 361, 8, 70, "Input"],

Cell[CellGroupData[{
Cell[18502, 595, 75, 2, 70, "Input"],
Cell[18580, 599, 80, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18697, 606, 99, 2, 70, "Input"],
Cell[18799, 610, 80, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18916, 617, 129, 3, 70, "Input"],
Cell[19048, 622, 80, 2, 70, "Output"]
}, Open  ]],
Cell[19143, 627, 106, 3, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[19274, 634, 62, 2, 70, "Input"],
Cell[19339, 638, 43, 1, 70, "Print"],
Cell[19385, 641, 1094, 22, 70, "Print"]
}, Open  ]],
Cell[20494, 666, 229, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[20748, 674, 128, 3, 70, "Input"],
Cell[20879, 679, 321, 9, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21237, 693, 128, 3, 70, "Input"],
Cell[21368, 698, 90, 2, 70, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

