(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     81134,       3138]*)
(*NotebookOutlinePosition[     83091,       3192]*)
(*  CellTagsIndexPosition[     82832,       3182]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Fourier transforms", "SubsectionIcon"],

Cell[TextData[{
  "The built-in function Fourier[] gives the fast Fourier transform of a list \
of numbers.  This package uses Fourier[] to give an approximation to the \
Fourier transform of a function.  The definition used is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(f\&~[\[Omega]]\),
            "TraditionalForm"], 
          "\[Congruent]", \(\(1\/\@\(2  \[Pi]\)\) \(\[Integral]\_\(-\
\[Infinity]\)\%\[Infinity] f[
                  x] \(\[ExponentialE]\^\(I\[VeryThinSpace]\[Omega]\
\[VeryThinSpace]x\)\) \[DifferentialD]x\)\)}], TraditionalForm]]],
  " ; this corresponds to FourierOverallConstant\[Rule]",
  Cell[BoxData[
      \(TraditionalForm\`1\/\@\(2  \[Pi]\)\)]],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            FormBox[\(FourierNormalised[f, x\_max, n]\),
              
              "TraditionalForm"], \(gives\ the\ Fourier\ transform\ of\ the\ \
function\ f, \ 
            as\ an\ interpolation\ \ function\ on\ the\ range\  | \[Omega] | \
\(\(<\)\(\((\[Pi] \((n - 1)\))\)\^2\/\(\(2  n\ x\_max\)\(.\)\)\)\)\)},
          {
            FormBox[\(InverseFourierNormalised[f, \[Omega]\_max, n]\),
              
              "TraditionalForm"], \(gives\ the\ inverse\ Fourier\ transform\ \
of\ the\ function\ f, \ 
            as\ an\ interpolation\ \ function\ on\ the\ range\  | 
              X | \(\(<\)\(\((\[Pi] \((n - 1)\))\)\^2\/\(2  
                      n\ \[Omega]\_max\)\)\)\)},
          {\(TransformedRange[X, 
              n]\), \(gives\ the\ maximum\ alue\ of\ the\ transformed\ \
variable, \ \ \(\(|\)\(\[Omega]\)\(|\)\(\(<\)\(\((\[Pi] \((n - 1)\))\)\^2\/\(\
\(2  n\ x\_max\)\(.\)\)\)\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{
  "FourierNormalised", "InverseFourierNormalised", "TransformedRange"}],

Cell["This loads the package, and also graphics routines:", "MathCaption"],

Cell[BoxData[
    \(<< Utilities`Calculus`; << Graphics`;\)], "Input",
  CellLabel->"In[20]:="],

Cell[TextData[{
  "Note that in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.0, Fourier transforms are built in; in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0, Calculus`FourierTransform` must be loaded."
}], "Text"],

Cell[TextData[{
  "fn is an interpolation function for the Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`f[x]\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[x_] := 
      \(Sin[x + 0.5] 
          \[ExponentialE]\^\(\(-\((x - 1)\)\^2\)/2\)\)\/\@\(2  \[Pi]\); 
    fn = FourierNormalised[f, 20, 256]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    TagBox[
      \(InterpolatingFunction[{{\(-19.9494201464527627`\), 
            19.9494201464527627`}}, "<>"]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[TextData[{
  "The interpolation function is defined on the range |\[Omega]|<",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Pi] \((n - 1)\))\)\^2\/\(2  n\ x\_max\)\)]],
  ".  That can be found using ",
  Cell[BoxData[
      \(TraditionalForm\`TransformedRange[X, n]\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Omega]max = TransformedRange[20. , 256]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(19.9494201464527627`\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell["This is the Fourier transform, calculated symbolically:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fx = 
      FourierTransform[
        \(Sin[t + 0.5] 
            \[ExponentialE]\^\(\(-\((t - 1)\)\^2\)/2\)\)\/\@\(2  \[Pi]\), \ 
        t, \ w, FourierOverallConstant \[Rule] 1\/\@\(2  \[Pi]\)]\)], "Input",\

  CellLabel->"In[5]:="],

Cell[BoxData[
    \(\(\((
            \(4.76434593312311704`\[InvisibleSpace]\) - 
              0.337862850051401819`\ I)\)\ 
          E\^\(1\/2\ \((\((\(-2\) + 2\ I)\) - w)\)\ w\) + 
        \((\(4.76434593312311704`\[InvisibleSpace]\) + 
              0.337862850051401819`\ I)\)\ 
          E\^\(1\/2\ \((\((2 + 2\ I)\) - w)\)\ w\)\)\/\(4\ \[Pi]\^2\)\)], 
  "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["\<\
FourierNormalised[] gives an accurate approximation to the true \
expression:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{fn[w] // Re, fx // Re, fn[w] // Im, fx // Im}, {w, 
        \(-\[Omega]max\), \[Omega]max}, 
      PlotRange \[Rule] {{\(-6\), 6}, {\(-0.3\), 0.3}}, 
      PlotStyle \[Rule] {Blue, Red}]; \)\)], "Input",
  CellLabel->"In[22]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.309017 1.03006 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.16667 .29652 -6 -9 ]
[.16667 .29652 6 0 ]
[.33333 .29652 -6 -9 ]
[.33333 .29652 6 0 ]
[.66667 .29652 -3 -9 ]
[.66667 .29652 3 0 ]
[.83333 .29652 -3 -9 ]
[.83333 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 .10301 -24 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -24 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-6)] 0 .29652 0 1 Mshowa
.16667 .30902 m
.16667 .31527 L
s
[(-4)] .16667 .29652 0 1 Mshowa
.33333 .30902 m
.33333 .31527 L
s
[(-2)] .33333 .29652 0 1 Mshowa
.66667 .30902 m
.66667 .31527 L
s
[(2)] .66667 .29652 0 1 Mshowa
.83333 .30902 m
.83333 .31527 L
s
[(4)] .83333 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(6)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04167 .30902 m
.04167 .31277 L
s
.08333 .30902 m
.08333 .31277 L
s
.125 .30902 m
.125 .31277 L
s
.20833 .30902 m
.20833 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.29167 .30902 m
.29167 .31277 L
s
.375 .30902 m
.375 .31277 L
s
.41667 .30902 m
.41667 .31277 L
s
.45833 .30902 m
.45833 .31277 L
s
.54167 .30902 m
.54167 .31277 L
s
.58333 .30902 m
.58333 .31277 L
s
.625 .30902 m
.625 .31277 L
s
.70833 .30902 m
.70833 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.79167 .30902 m
.79167 .31277 L
s
.875 .30902 m
.875 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.95833 .30902 m
.95833 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .10301 m
.50625 .10301 L
s
[(-0.2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-0.1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.2)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
0 .30902 m
.00286 .30902 L
.00664 .30902 L
.01076 .30902 L
.01825 .30902 L
.02316 .30902 L
.02778 .30902 L
.03642 .30902 L
.04571 .30902 L
.05575 .30903 L
.07374 .30904 L
.07826 .30904 L
.08253 .30904 L
.08636 .30904 L
.09052 .30904 L
.09457 .30904 L
.09887 .30904 L
.10254 .30904 L
.10659 .30903 L
.11086 .30902 L
.11547 .30901 L
.11981 .30899 L
.12379 .30896 L
.1282 .30893 L
.13229 .30888 L
.13678 .30881 L
.14157 .30872 L
.14662 .3086 L
.15137 .30845 L
.16027 .30805 L
.16453 .3078 L
.16921 .30746 L
.17866 .30656 L
.18742 .30538 L
.1956 .30393 L
.20525 .30166 L
.21405 .299 L
.23385 .2906 L
.2506 .28082 L
.2684 .26844 L
.28379 .25753 L
.29188 .25242 L
.3004 .248 L
.30482 .24624 L
.30715 .24549 L
.30965 .24484 L
.31405 .24411 L
.31814 .24395 L
.32263 .2444 L
.32688 .24549 L
Mistroke
.33069 .24706 L
.33482 .2494 L
.33939 .25283 L
.34442 .25766 L
.3546 .2708 L
.36402 .28697 L
.37284 .30538 L
.4042 .3884 L
.43761 .47959 L
.44751 .50182 L
.45684 .51968 L
.46592 .5339 L
.47426 .54409 L
.48221 .55117 L
.48621 .55375 L
.4906 .55583 L
.49502 .55713 L
.49749 .55751 L
.49974 .55764 L
.50412 .55729 L
.50827 .55624 L
.51251 .55444 L
.51492 .55308 L
.51719 .5516 L
.52665 .54311 L
.53483 .53285 L
.54365 .51883 L
.56372 .47638 L
.58211 .42761 L
.59969 .37723 L
.61846 .32616 L
.62757 .30444 L
.63617 .2866 L
.64384 .27323 L
.65226 .26143 L
.66029 .25311 L
.66467 .24974 L
.66878 .24732 L
.67261 .24567 L
.67612 .24465 L
.68016 .24404 L
.684 .24397 L
.68813 .2444 L
.69254 .2454 L
.69669 .24679 L
.70045 .24838 L
.71838 .25901 L
.73672 .27212 L
.75606 .28498 L
.77257 .29371 L
Mistroke
.78205 .29762 L
.79067 .3005 L
.79874 .30268 L
.80751 .30453 L
.81678 .30599 L
.82554 .307 L
.83374 .30768 L
.83823 .30797 L
.84244 .30819 L
.84986 .30849 L
.8538 .30861 L
.85804 .30871 L
.86255 .3088 L
.86735 .30888 L
.87262 .30893 L
.87752 .30897 L
.87992 .30899 L
.88251 .309 L
.8848 .30901 L
.88722 .30902 L
.89181 .30903 L
.89603 .30904 L
.90016 .30904 L
.9046 .30904 L
.90878 .30904 L
.9126 .30904 L
.91707 .30904 L
.9196 .30904 L
.92194 .30904 L
.9308 .30903 L
.94696 .30903 L
.95605 .30902 L
.96438 .30902 L
.97172 .30902 L
.97975 .30902 L
.9838 .30902 L
.98813 .30902 L
.99593 .30902 L
Mfstroke
.99593 .30902 m
1 .30902 L
s
1 0 0 r
0 .30902 m
.00389 .30902 L
.00813 .30902 L
.01669 .30902 L
.02149 .30902 L
.02585 .30902 L
.03416 .30902 L
.04182 .30902 L
.05024 .30903 L
.05915 .30903 L
.07528 .30904 L
.07913 .30904 L
.08323 .30904 L
.0871 .30904 L
.09061 .30904 L
.09484 .30904 L
.09883 .30904 L
.10314 .30904 L
.10557 .30903 L
.1078 .30903 L
.11144 .30902 L
.11544 .30901 L
.11962 .30899 L
.12351 .30896 L
.1281 .30893 L
.13245 .30888 L
.13635 .30882 L
.14059 .30874 L
.1452 .30863 L
.15009 .30849 L
.15468 .30832 L
.15888 .30812 L
.16643 .30767 L
.17456 .30699 L
.18173 .30619 L
.18927 .30509 L
.19757 .30351 L
.20529 .30165 L
.22279 .29572 L
.23199 .29155 L
.24045 .28703 L
.25958 .27475 L
.27611 .26288 L
.28488 .25681 L
.29429 .25105 L
.29866 .2488 L
.30281 .24699 L
.30653 .24567 L
.31059 .24463 L
.31442 .24407 L
Mistroke
.3185 .24395 L
.32235 .24434 L
.32583 .24515 L
.33014 .24679 L
.3341 .24894 L
.33845 .25205 L
.34303 .2562 L
.35075 .26528 L
.3592 .27823 L
.39726 .36855 L
.43324 .46885 L
.44892 .50473 L
.46554 .53339 L
.47422 .54405 L
.47915 .54875 L
.48377 .55225 L
.48801 .5547 L
.49188 .55629 L
.49636 .55736 L
.50061 .55763 L
.50502 .55712 L
.50917 .55592 L
.5129 .55423 L
.51694 .55177 L
.52135 .54832 L
.52601 .54381 L
.53435 .53353 L
.54929 .50832 L
.56568 .47155 L
.60284 .36827 L
.62044 .32121 L
.63672 .28556 L
.64484 .27164 L
.65347 .25999 L
.65764 .25554 L
.66213 .25158 L
.66706 .24824 L
.66946 .24697 L
.67169 .246 L
.67571 .24474 L
.68011 .24403 L
.6844 .24398 L
.68897 .24455 L
.69324 .24561 L
.69728 .24702 L
.70482 .25057 L
.74028 .27465 L
.75968 .2871 L
.76917 .29211 L
.77783 .29598 L
Mistroke
.79387 .30142 L
.80271 .30357 L
.8111 .30515 L
.82018 .30642 L
.8286 .30728 L
.83785 .30794 L
.84301 .30821 L
.84769 .30841 L
.85174 .30855 L
.856 .30867 L
.86364 .30882 L
.8679 .30888 L
.87187 .30893 L
.87622 .30896 L
.88088 .30899 L
.88491 .30901 L
.88928 .30902 L
.89341 .30903 L
.89722 .30904 L
.90066 .30904 L
.90445 .30904 L
.9084 .30904 L
.91211 .30904 L
.94337 .30903 L
.95237 .30903 L
.96086 .30902 L
.96848 .30902 L
.97673 .30902 L
.98114 .30902 L
.98599 .30902 L
.99072 .30902 L
.99578 .30902 L
Mfstroke
.99578 .30902 m
1 .30902 L
s
0 0 1 r
0 .30902 m
.00176 .30902 L
.00591 .30902 L
.01032 .30902 L
.01448 .30902 L
.01825 .30902 L
.02279 .30902 L
.02758 .30902 L
.03167 .30902 L
.03615 .30902 L
.04098 .30902 L
.04616 .30902 L
.05104 .30903 L
.05549 .30903 L
.05997 .30903 L
.06412 .30904 L
.06866 .30905 L
.07349 .30905 L
.08159 .30908 L
.0862 .30909 L
.09052 .30911 L
.09905 .30916 L
.10697 .30922 L
.11566 .30932 L
.12494 .30946 L
.1347 .30967 L
.14391 .30992 L
.16112 .31058 L
.17621 .31135 L
.19216 .3122 L
.19618 .31239 L
.2005 .31257 L
.20297 .31266 L
.20523 .31272 L
.20966 .31279 L
.21362 .3128 L
.21793 .31272 L
.222 .31254 L
.22577 .31227 L
.22986 .31185 L
.23418 .31124 L
.23787 .31055 L
.24191 .30961 L
.24626 .30835 L
.25092 .30668 L
.25932 .30271 L
.26781 .29725 L
.27583 .29059 L
.29085 .27376 L
.30878 .24603 L
Mistroke
.32533 .21423 L
.34336 .17626 L
.36274 .13799 L
.37179 .12328 L
.38039 .11217 L
.38412 .10836 L
.38811 .10504 L
.39247 .10235 L
.39653 .10077 L
.40063 .10006 L
.40507 .10038 L
.40927 .1017 L
.41312 .10378 L
.41661 .10638 L
.42044 .11002 L
.42816 .11971 L
.43757 .13554 L
.44615 .15335 L
.46542 .2027 L
.50019 .30962 L
.53253 .40949 L
.55024 .45634 L
.56687 .49048 L
.57549 .50328 L
.58033 .50881 L
.58478 .51277 L
.58937 .51569 L
.59198 .51683 L
.5944 .51754 L
.59697 .51795 L
.5993 .51798 L
.60199 .51763 L
.60453 .51694 L
.60876 .51503 L
.61323 .51196 L
.61705 .50854 L
.62125 .504 L
.63936 .47626 L
.67715 .39876 L
.69576 .36424 L
.71301 .33939 L
.7286 .32357 L
.73731 .31731 L
.7452 .31303 L
.75389 .30964 L
.75878 .30825 L
.76327 .30725 L
.76722 .30658 L
.77154 .30602 L
.77606 .30562 L
Mistroke
.78026 .30539 L
.78466 .30526 L
.78872 .30523 L
.79317 .30528 L
.79542 .30533 L
.79789 .30541 L
.80204 .30556 L
.8065 .30577 L
.81456 .30618 L
.82948 .30699 L
.84578 .30775 L
.8555 .30809 L
.86454 .30835 L
.87317 .30854 L
.88238 .30869 L
.89142 .3088 L
.89994 .30887 L
.9076 .30891 L
.91193 .30893 L
.91588 .30895 L
.92415 .30897 L
.92871 .30898 L
.93302 .30899 L
.94069 .309 L
.94503 .309 L
.94904 .30901 L
.95308 .30901 L
.95743 .30901 L
.96221 .30901 L
.96669 .30901 L
.97146 .30901 L
.97385 .30902 L
.97648 .30902 L
.98078 .30902 L
.98321 .30902 L
.98545 .30902 L
.99041 .30902 L
.99264 .30902 L
.9951 .30902 L
.99935 .30902 L
Mfstroke
.99935 .30902 m
1 .30902 L
s
1 0 0 r
0 .30902 m
.0002 .30902 L
.00432 .30902 L
.00823 .30902 L
.0124 .30902 L
.01701 .30902 L
.02182 .30902 L
.02634 .30902 L
.03055 .30902 L
.03441 .30902 L
.03865 .30902 L
.04312 .30902 L
.04766 .30903 L
.05251 .30903 L
.05709 .30903 L
.06125 .30904 L
.06614 .30904 L
.07145 .30905 L
.07647 .30906 L
.08109 .30907 L
.08546 .30909 L
.0896 .30911 L
.09738 .30915 L
.10576 .30921 L
.11489 .30931 L
.12284 .30942 L
.13131 .30959 L
.1393 .30979 L
.14654 .31001 L
.16479 .31075 L
.18407 .31177 L
.19201 .31219 L
.19638 .3124 L
.20052 .31257 L
.20286 .31265 L
.20541 .31272 L
.20986 .31279 L
.21438 .31279 L
.21857 .31269 L
.22242 .31251 L
.22657 .3122 L
.23049 .31177 L
.23408 .31125 L
.23807 .31051 L
.24242 .30948 L
.24702 .3081 L
.2512 .30657 L
.25988 .30239 L
.26915 .29625 L
.27773 .28879 L
Mistroke
.28583 .28004 L
.304 .25421 L
.32074 .22352 L
.33897 .18555 L
.35854 .14565 L
.36763 .12968 L
.37626 .1171 L
.384 .10846 L
.38838 .10484 L
.39243 .10236 L
.39659 .10073 L
.40049 .10006 L
.404 .10019 L
.40779 .1011 L
.41193 .10304 L
.4163 .10612 L
.42003 .10959 L
.42412 .11425 L
.43356 .12827 L
.44215 .14466 L
.46143 .19163 L
.4962 .29689 L
.52864 .39818 L
.5464 .44694 L
.56303 .48365 L
.57168 .49809 L
.57613 .5041 L
.58098 .50947 L
.58373 .51194 L
.58628 .51386 L
.58892 .51547 L
.59131 .51659 L
.59588 .51783 L
.59839 .51801 L
.60076 .51785 L
.60499 .5168 L
.60947 .51462 L
.61329 .51193 L
.61749 .50813 L
.62685 .49673 L
.63559 .48297 L
.66713 .41955 L
.68441 .38449 L
.70064 .35643 L
.71811 .33353 L
.72739 .32458 L
.73739 .31726 L
.74604 .31265 L
.75038 .31085 L
.75514 .30925 L
Mistroke
.75921 .30814 L
.76356 .3072 L
.76767 .30651 L
.77141 .30604 L
.77379 .3058 L
.77603 .30562 L
.77836 .30548 L
.78092 .30536 L
.78516 .30525 L
.7897 .30524 L
.79225 .30527 L
.79502 .30532 L
.79764 .3054 L
.80007 .30549 L
.80954 .30592 L
.82843 .30694 L
.84554 .30774 L
.85397 .30804 L
.86307 .30831 L
.87167 .30851 L
.87956 .30865 L
.88797 .30876 L
.89719 .30885 L
.90184 .30888 L
.90681 .30891 L
.91579 .30895 L
.92006 .30896 L
.92476 .30898 L
.92935 .30898 L
.93429 .30899 L
.9389 .309 L
.94311 .309 L
.94712 .30901 L
.95139 .30901 L
.95606 .30901 L
.9604 .30901 L
.96556 .30901 L
.97024 .30901 L
.97514 .30902 L
.97772 .30902 L
.98045 .30902 L
.98283 .30902 L
.98545 .30902 L
.99007 .30902 L
.99232 .30902 L
.99477 .30902 L
.99923 .30902 L
Mfstroke
.99923 .30902 m
1 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[22]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03
001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol2002=Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol2002=Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool007eoo`8000Aoo`8000=oo`@000Eoo`03001oogoo08aoo`00M7oo17`0
17oo00@007ooOol000=oo`8000Aoo`03001oogoo00Eoo`03001oogoo08aoo`00LGoo0g`00Woo0P00
00El0000001oo`00009oo`03001oogoo00Qoo`03001oogoo00Aoo`8008eoo`00L7oo00=l07ooOol0
1Woo00Al07ooOol0009oo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo08aoo`00Kgoo00<0
7g`0Ool027oo00=l000O00000Woo00<007ooOol01Woo00@007ooOol000Eoo`03001oogoo08aoo`00
Kgoo00=l07ooOol02Goo00Al000O000000Yoo`8000Ioo`03001oogoo08aoo`00KWoo00=l07ooOol0
2Woo00=l07oo01l04goo00<007ooOol0S7oo001]Ool00`0OO01oo`0<Ool00g`001moo`0BOol2002=
Ool006eoo`03O01oogoo00eoo`03O0007goo015oo`03001oogoo08aoo`00K7oo00=l07ooOol03goo
00=l07ooOol047oo00<007ooOol0S7oo001[Ool00`0OO01oo`0@Ool00g`0Oomoo`0@Ool00`00Oomo
o`2<Ool006Yoo`0301ml07oo019oo`03O01oogoo00moo`03001oogoo08aoo`00JWoo00=l07ooOol0
4Woo00=l07ooOol03goo00<007ooOol0S7oo001YOol00`0OO01oo`0DOol00g`0Oomoo`0>Ool2002=
Ool006Uoo`03O01oogoo01Aoo`03O0007goo00ioo`03001oogoo08aoo`00J7oo00<07g`0Ool05Woo
00=l07ooOol03Goo00<007ooOol0S7oo001XOol00g`0Oomoo`0FOol00g`001moo`0=Ool00`00Oomo
o`2<Ool006Moo`0301ml07oo01Qoo`03O01oogoo00aoo`03001oogoo08aoo`00Igoo00=l07ooOol0
67oo00=l000OOol037oo00<007ooOol0S7oo001WOol00g`0Oomoo`0IOol00g`0Oomoo`0;Ool2002=
Ool006Ioo`03O01oogoo01Yoo`03O01oogoo00]oo`03001oogoo08aoo`00IWoo00=l07ooOol06Woo
00=l000OOol02goo00<007ooOol0S7oo001UOol00`0OO01oo`0LOol00g`0Oomoo`0:Ool00`00Oomo
o`2<Ool006Eoo`03O01oogoo01aoo`03O0007goo00Yoo`03001oogoo08aoo`00I7oo00<07g`0Ool0
7Woo00=l07ooOol02Goo00<007ooOol0S7oo001TOol00g`0Oomoo`0NOol00g`0Oomoo`09Ool2002=
Ool006=oo`0301ml07oo021oo`03O01oogoo00Qoo`03001oogoo08aoo`00Hgoo00=l07ooOol087oo
00=l07ooOol027oo00<007ooOol0S7oo001ROol00`0OO01oo`0HOol20004Ool200000gooO01oo`03
0006Ool00`00Oomoo`2<Ool0069oo`03O01oogoo01Moo`04001oogoo0003Ool20002Ool00g`0Ool0
0007Ool00`00Oomoo`2<Ool0069oo`03O01oogoo015oo`D00005Ool007ooOol00007Ool00g`0Ool0
0007Ool2002=Ool0065oo`03O01oogoo01Qoo`04001oogoo0007Ool00g`001l00007Ool00`00Oomo
o`2<Ool0065oo`03O01oogoo01Qoo`04001oogoo0008Ool00g`0001oo`06Ool00`00Oomoo`2<Ool0
061oo`03O01oogoo01Yoo`8000Uoo`03O00007oo00Ioo`03001oogoo08aoo`00H7oo00=l07ooOol0
9Goo00=l000OOol01Woo00<007ooOol0S7oo001OOol00g`0Oomoo`0WOol00g`0Oomoo`05Ool00`00
Oomoo`2<Ool005moo`03O01oogoo02Moo`03O01oogoo00Eoo`8008eoo`00GWoo00=l07ooOol0:7oo
00=l000OOol01Goo00<007ooOol0S7oo001MOol00`0OO01oo`0YOol00g`001moo`05Ool00`00Oomo
o`2<Ool005eoo`03O01oogoo02Yoo`03O01oogoo00Aoo`03001oogoo08aoo`00G7oo00=l07ooOol0
:goo00=l000OOol017oo00<007ooOol0S7oo001KOol6O00YOol00g`001moo`04Ool00`00Oomoo`0/
Ool00`0OO01l0004O01IOol005Qoo`Al00Eoo`=l02Moo`03O01oogoo00=oo`8002aoo`9l00Ioo`9l
000301moogoo05Aoo`00EWoo00<07g`0Ool00Woo00=l07ooOol01Woo00=l07ooOol097oo00=l000O
Ool00goo00<007ooOol0:Goo0W`02Woo0W`000<07gooOol0DWoo001EOol00`0OO01oo`02Ool00g`0
Oomoo`07Ool00`0OO01oo`0TOol00g`001moo`03Ool00`00Oomoo`0XOol00g`001moo`0<Ool2O01C
Ool005=oo`0301ml07`000=oo`0301ml07oo00Uoo`03O01oogoo02Aoo`03O01oogoo009oo`03001o
ogoo02Moo`03O0007goo00moo`03O0007goo051oo`00DWoo0W`017oo00<07g`0Ool02goo00=l07oo
Ool08goo00=l000OOol00Woo00<007ooOol09goo00=l07ooOol047oo0W`0D7oo001AOol00g`0Oomo
o`04Ool00g`0Oomoo`0<Ool00g`0Oomoo`0ROol00g`001moo`02Ool00`00Oomoo`0VOol00g`0Oomo
o`0COol2O01>Ool004moo`0301ml07oo00Eoo`03O01oogoo00eoo`03O0007goo029oo`03O0007goo
009oo`8002Ioo`0301ml07oo01Eoo`0301ml07oo04aoo`0027oo0P00;7oo0`0057oo0P0O00=l07oo
Ool017oo00<07g`0Ool02Woo100000=oog`0Ool08goo00El000OOomoo`0002Ioo`0301ml07oo009o
o`@0015oo`0301ml07`001Moo`<002aoo`8000=oo`001goo00@007ooOol002aoo`03001oogoo019o
o`0301ml07`000Moo`03O01oogoo00]oo`03001oogoo009oo`03O01oogoo025oo`05O0007gooOol0
000VOol00`0OO01oo`03Ool00`00Oomoo`0COol00`0OO01oo`0FOol00`00Oomoo`0ZOol01000Oomo
o`000Woo00000goo0000000300001Goo001oogoo000097oo1@0000=oo`0000000P004Goo00<07g`0
O00027oo00=l07ooOol01Goo1@000goo00H007ooOomoog`001lROol01G`001moogoo00009Goo00<0
7g`0Ool01Goo00<007ooOol057oo0W`04goo1000:goo00@007ooOol0009oo`001goo0`00:goo00<0
07oo00004Goo0W`02Goo00=l07ooOol03goo00D007ooOomoog`002=oo`04O0007goo000UOol00`0O
O01oo`06Ool00`00Oomoo`0EOol00g`001moo`0@Ool00`00Ool0000/Ool30003Ool000Moo`03001o
ogoo02]oo`03001oo`0000moo`9l00Uoo`9l00moo`04001oogoo0003Ool00g`001moo`0QOol00g`0
01moo`02000SOol00`0OO01oo`04Ool01000Oomoo`0067oo0W`047oo00<007oo0000;7oo00<007oo
Ool00goo0008Ool3000[Ool2000=Ool2O0000`0OOomoo`07Ool00g`001moo`0@Ool20004Ool00g`0
01moo`0QOol017`001moo`0097oo00<07g`0Ool01Goo0P006goo0g`03Woo0P00;Goo0`000Woo0012
Ool3O0000`0OOomoo`08Ool00g`001moo`0HOol00g`001moo`0QOol00g`001l0000SOol00`0OO01o
o`0TOol201l2O010Ool0041oo`9l000301moogoo00Yoo`03O0007goo01Uoo`03O0007goo025oo`03
O0007`0002=oo`0301ml07oo02Moo`0301ml07`003ioo`00>goo1G`03Goo0W`07Goo00=l07ooOol0
87oo00=l000O00008goo00=l07ooOol0:Goo00D07g`0O01l000O03Yoo`00=Goo1W`00`0O3Goo0W`0
7goo00=l000OOol087oo00=l07oo01l08Woo00=l07ooOol097oo5G`0<7oo0006Ool/O00401lB0003
O00R00000g`00000000P00000g`001l0000Q00000g`00000000O00000`0OO01l0002O00A000aO003
Ool000Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00MooaIl00=o
o`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03O0007goo00Uoo`03001oogoo00Uo
o`03001oogoo00Qoo`03O0007goo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03O01oogoo00Uo
o`03001oogoo00Qoo`03001oogoo00Moo`=l00]oo`03001oogoo00Qoo`03001oogoo00Uoo`03001o
ogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo005oo`001Woo00<007ooOol0:goo
00<007ooOol0:goo00<007ooOol027oo00=l000OOol087oo00=l000OOol087oo00=l07ooOol02Goo
00<007ooOol047oo0W`06Goo00<007ooOol0;7oo00<007ooOol00Goo001^Ool00g`0Oomoo`0POol0
0g`001moo`0NOol00g`0Oomoo`0LOol00g`0Oomoo`1<Ool006ioo`03O0007goo021oo`03O0007goo
01ioo`03O01oogoo01]oo`03O01oogoo04eoo`00Kgoo00=l07ooOol07goo00=l000OOol07Goo00=l
07ooOol06goo00=l07ooOol0CWoo001_Ool00g`001moo`0OOol00`00O0007`0MOol00g`0Oomoo`0J
Ool00g`0Oomoo`1?Ool0071oo`03O01oogoo01ioo`03001l000O01aoo`0301ml07oo01Yoo`03O01o
ogoo051oo`00L7oo00=l07ooOol07Woo00<007`001l077oo00=l07ooOol06Goo00<07g`0Ool0DGoo
001`Ool00g`001moo`0NOol01000Ooml000O6goo00=l07ooOol06Goo00=l07ooOol0DGoo001aOol0
0g`0Oomoo`0MOol01000Ooml000O6Woo00<07g`0Ool06Goo00=l07ooOol0DWoo001aOol00g`001mo
o`0MOol200000g`001moo`0IOol00g`0Oomoo`0HOol00g`0Oomoo`1COol0079oo`03O01oogoo01ao
o`05001oogooO0007`0IOol00g`0Oomoo`0GOol00g`0Oomoo`1DOol0079oo`03O01oogoo01aoo`05
001oogooO0007`0HOol00`0OO01oo`0GOol00g`001moo`1EOol007=oo`03O01oogoo01]oo`05001o
ogooO0007`0HOol00g`0Oomoo`0GOol00g`0Oomoo`1EOol007=oo`03O01oogoo01]oo`06001oogoo
Ooml000O5goo00=l07ooOol05Woo00=l07ooOol0EWoo001cOol00g`0Oomoo`0KOol01P00Oomoogoo
O0007aIoo`0301ml07oo01Moo`03O01oogoo05Ioo`00M7oo00=l07ooOol06Woo0P000Woo00=l000O
Ool05Goo00=l07ooOol05Woo00=l07ooOol0Egoo001dOol00g`0Oomoo`0JOol00`00Oomoo`02Ool0
0g`001moo`0DOol00g`0Oomoo`0FOol00g`0Oomoo`1GOol007Eoo`03O01oogoo01Uoo`03001oogoo
009oo`03O0007goo01=oo`03O01oogoo01Ioo`03O01oogoo05Qoo`00MGoo00=l07ooOol06Goo00<0
07ooOol00Woo00=l000OOol04goo00=l07ooOol05Woo00=l07ooOol0F7oo001eOol00g`0Oomoo`0I
Ool00`00Oomoo`03Ool00g`001moo`0AOol00`0OO01oo`0FOol00g`0Oomoo`1IOol007Ioo`03O01o
ogoo01Qoo`03001oogoo00=oo`03O0007goo015oo`03O01oogoo01Ioo`03O01oogoo05Uoo`00MWoo
00=l07ooOol067oo0P0017oo00=l000OOol04Goo00=l07ooOol05Goo00=l07ooOol0FWoo001fOol0
0g`001moo`0HOol00`00Oomoo`04Ool00g`001moo`0?Ool00`0OO01oo`0FOol00g`0Oomoo`1JOol0
07Moo`03O01oogoo01Moo`03001oogoo00Aoo`03O0007goo00moo`03O01oogoo01Eoo`03O01oogoo
05]oo`00Mgoo00=l07ooOol05goo00<007ooOol017oo00=l000OOol03goo00=l07ooOol05Goo00=l
07ooOol0Fgoo001hOol00g`0Oomoo`02Ool20004Ool20003Ool30006Ool00`00Oomoo`05Ool00g`0
01moo`0=Ool00`0OO01oo`0EOol00g`0Oomoo`1LOol007Qoo`05O01oogooOol00002Ool01000Oomo
ogoo0P0017oo00<007ooOol01Goo00<007ooOol01Goo00=l000OOol03Goo00=l07ooOol05Goo00=l
07ooOol0G7oo001hOol01G`0Oomoogoo00000Woo00<007ooOol01goo00<007ooOol01Goo0P001Woo
00=l000OOol03Goo00=l07ooOol057oo00=l07ooOol0GGoo001iOol017`0Oomoo`000Woo00<007oo
Ool01goo00<007ooOol01Goo00<007ooOol01Woo00=l07ooOol02goo00<07g`0Ool05Goo00=l07oo
Ool0GGoo001iOol017`0Oomoo`000Woo00<007ooOol01goo00<007ooOol01Goo00<007ooOol01Woo
00=l000OOol02goo00=l07ooOol057oo00=l07ooOol0GWoo001iOol017`0Oomoogoo0P002Goo0P00
1goo00<007ooOol01goo00=l07ooOol02Woo00=l07ooOol057oo00=l07ooOol0GWoo001jOol00g`0
Oomoo`0DOol00`00Oomoo`07Ool00g`0Oomoo`09Ool00g`0Oomoo`0DOol00g`0Oomoo`1OOol007Yo
o`03O01oogoo01Aoo`8000Qoo`03O0007goo00Uoo`03O01oogoo01Aoo`03O01oogoo05moo`00NWoo
00=l000OOol057oo00<007ooOol027oo00=l07ooOol01goo00<07g`0Ool057oo00=l07ooOol0H7oo
001kOol00g`0Oomoo`0COol00`00Oomoo`08Ool00g`0Oomoo`07Ool00g`0Oomoo`0DOol00g`0Oomo
o`1POol007]oo`03O01oogoo01=oo`03001oogoo00Qoo`03O0007goo00Moo`03O01oogoo01=oo`03
O01oogoo065oo`00O7oo00=l07ooOol04Woo00<007ooOol02Goo00=l07ooOol01Goo00<07g`0Ool0
57oo00=l07ooOol0HGoo001lOol00g`0Oomoo`0BOol00`00Oomoo`09Ool00g`0Oomoo`05Ool00g`0
Oomoo`0COol00g`0Oomoo`1ROol007aoo`03O01oogoo019oo`8000]oo`03O01oogoo00Aoo`03O01o
ogoo019oo`03O0007goo06=oo`00OGoo00=l07ooOol04Goo00<007ooOol02Woo00=l07ooOol00goo
00<07g`0Ool04goo00=l07ooOol0Hgoo001mOol00g`0Oomoo`0AOol00`00Oomoo`0:Ool00`0OO01o
o`03Ool00g`0Oomoo`0BOol00g`001moo`1TOol007eoo`03O01oogoo015oo`03001oogoo00]oo`03
O01oogoo009oo`03O01oogoo019oo`03O01oogoo06Aoo`00OWoo00=l07ooOol047oo00<007ooOol0
2goo00H07g`0Oomoo`0OO00COol00g`001moo`1UOol007ioo`03O01oogoo011oo`03001oogoo00ao
o`04O01oogooO00DOol00g`0Oomoo`1UOol007ioo`0301ml07oo011oo`8000eoo`04O0007gooO00C
Ool00g`001moo`1VOol007moo`03O01oogoo00moo`03001oogoo00eoo`9l01Aoo`03O01oogoo06Io
o`00Ogoo00=l07ooOol03goo00<007ooOol03Goo00=l000OOol04Woo00=l000OOol0Igoo0020Ool0
0g`0Oomoo`0>Ool00`00Oomoo`0=Ool2O00COol00g`0Oomoo`1WOol0081oo`03O01oogoo00ioo`03
001oogoo00eoo`9l000301moogoo00moo`03O01oogoo06Qoo`00PGoo00=l07ooOol03Goo00<007oo
Ool037oo00Al07ooOoml011oo`0301ml07oo06Uoo`00PGoo00=l07ooOol03Goo0P003Goo00El07oo
Ooml000O00moo`03O01oogoo06Uoo`00PGoo00=l07ooOol03Goo00<007ooOol02goo00=l07ooOol0
0Woo0W`03Goo00=l07ooOol0JWoo0022Ool00g`0Oomoo`0<Ool00`00Oomoo`0;Ool00g`0Oomoo`03
Ool00`0OO01oo`0:Ool00g`0Oomoo`1[Ool007eoo`8000=oo`03O000000000=oo`@000Eoo`03001o
ogoo00Yoo`03O0007goo00Eoo`03O01oogoo00Qoo`03O01oogoo06aoo`00O7oo00@007ooOol000=o
o`03O00007oo00=oo`03001oogoo00Eoo`03001oogoo00Yoo`03O01oogoo00Ioo`9l00Moo`03O01o
ogoo06eoo`00O7oo00@007ooOol000Aoo`03O01oogoo00=oo`03001oogoo00Aoo`8000Yoo`03O000
7goo00Qoo`9l00Eoo`03O01oogoo06ioo`00O7oo00@007ooOol000Aoo`03O01oogoo00Aoo`03001o
ogoo00=oo`03001oogoo00Uoo`03O01oogoo00Yoo`El075oo`00O7oo00@007ooOol000Eoo`04O01o
ogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00g`001moo`21Ool007eoo`8000Ioo`04O01o
ogooOol20006Ool00`00Oomoo`07Ool00g`001moo`22Ool008Ioo`03O01oogoo00Qoo`03001oogoo
00Moo`03O01oogoo089oo`00QWoo00<07g`0Ool027oo00<007ooOol01Woo00=l07ooOol0Pgoo0027
Ool00g`0Oomoo`07Ool20007Ool00g`0Oomoo`23Ool008Qoo`03O01oogoo00Ioo`03001oogoo00Eo
o`03O01oogoo08Aoo`00RGoo00=l000OOol01Goo00<007ooOol00goo00<07g`0Ool0QWoo002:Ool0
0g`001moo`04Ool00`00Oomoo`02Ool00`0OO01oo`27Ool008]oo`03O0007goo00=oo`06001oogoo
Ool07g`0RGoo002<Ool2O003Ool00`00Oomoo`02O02:Ool008ioo`Il08aoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol2
002=Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol2002=Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.25906, -0.308951, 
  0.0431659, 0.00349218}}]
}, Open  ]],

Cell["This is the inverse transform:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fn2 = InverseFourierNormalised[fn, \[Omega]max, 256]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{\(-20.`\), 20.`}}, "<>"]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell["It is close to the original function:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{fn2[x], f[x]}, {x, \(-20\), 20}, 
      PlotRange \[Rule] {{\(-6\), 6}, {\(-0.1\), 0.5}}, 
      PlotStyle \[Rule] {Blue, Red}]; \)\)], "Input",
  CellLabel->"In[24]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.103006 1.03006 [
[0 .09051 -6 -9 ]
[0 .09051 6 0 ]
[.16667 .09051 -6 -9 ]
[.16667 .09051 6 0 ]
[.33333 .09051 -6 -9 ]
[.33333 .09051 6 0 ]
[.66667 .09051 -3 -9 ]
[.66667 .09051 3 0 ]
[.83333 .09051 -3 -9 ]
[.83333 .09051 3 0 ]
[1 .09051 -3 -9 ]
[1 .09051 3 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .10301 m
0 .10926 L
s
[(-6)] 0 .09051 0 1 Mshowa
.16667 .10301 m
.16667 .10926 L
s
[(-4)] .16667 .09051 0 1 Mshowa
.33333 .10301 m
.33333 .10926 L
s
[(-2)] .33333 .09051 0 1 Mshowa
.66667 .10301 m
.66667 .10926 L
s
[(2)] .66667 .09051 0 1 Mshowa
.83333 .10301 m
.83333 .10926 L
s
[(4)] .83333 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(6)] 1 .09051 0 1 Mshowa
.125 Mabswid
.04167 .10301 m
.04167 .10676 L
s
.08333 .10301 m
.08333 .10676 L
s
.125 .10301 m
.125 .10676 L
s
.20833 .10301 m
.20833 .10676 L
s
.25 .10301 m
.25 .10676 L
s
.29167 .10301 m
.29167 .10676 L
s
.375 .10301 m
.375 .10676 L
s
.41667 .10301 m
.41667 .10676 L
s
.45833 .10301 m
.45833 .10676 L
s
.54167 .10301 m
.54167 .10676 L
s
.58333 .10301 m
.58333 .10676 L
s
.625 .10301 m
.625 .10676 L
s
.70833 .10301 m
.70833 .10676 L
s
.75 .10301 m
.75 .10676 L
s
.79167 .10301 m
.79167 .10676 L
s
.875 .10301 m
.875 .10676 L
s
.91667 .10301 m
.91667 .10676 L
s
.95833 .10301 m
.95833 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
.5 0 m
.50625 0 L
s
[(-0.1)] .4875 0 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.1)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.3)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.4)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(0.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
0 .10301 m
.00098 .10301 L
.00447 .10301 L
.00819 .10301 L
.01227 .10301 L
.01606 .10301 L
.01833 .10301 L
.02074 .10301 L
.02504 .10301 L
.02966 .10301 L
.03229 .10301 L
.03475 .10301 L
.03911 .10301 L
.04324 .10301 L
.04552 .10301 L
.048 .10301 L
.05235 .10301 L
.05629 .10301 L
.06063 .10301 L
.06517 .10301 L
.06944 .10301 L
.07341 .10301 L
.07704 .10301 L
.08104 .10301 L
.08525 .10301 L
.08957 .10301 L
.09425 .10301 L
.09867 .10301 L
.10275 .10301 L
.11047 .10301 L
.11437 .10301 L
.11865 .10301 L
.12754 .10301 L
.13253 .10301 L
.13709 .10301 L
.14594 .10301 L
.15434 .10301 L
.16202 .10301 L
.16924 .10301 L
.17324 .10301 L
.17756 .10301 L
.18149 .10301 L
.1851 .10301 L
.18914 .10301 L
.19356 .10301 L
.19819 .10301 L
.2025 .103 L
.20657 .103 L
.21029 .103 L
.21457 .103 L
Mistroke
.21863 .103 L
.22263 .10299 L
.22694 .10299 L
.23101 .10298 L
.23474 .10298 L
.23888 .10297 L
.2434 .10295 L
.24812 .10293 L
.2525 .10291 L
.2572 .10288 L
.26162 .10284 L
.26989 .10274 L
.27453 .10266 L
.2788 .10257 L
.28346 .10246 L
.28845 .10231 L
.29617 .102 L
.30339 .10161 L
.31197 .10099 L
.31981 .10025 L
.32796 .09925 L
.33683 .09787 L
.35296 .09442 L
.37011 .08943 L
.3886 .08311 L
.39711 .08031 L
.40175 .07898 L
.40607 .07789 L
.40976 .07715 L
.41371 .07659 L
.4181 .07628 L
.42209 .07637 L
.42657 .07695 L
.4307 .07801 L
.43524 .07983 L
.43753 .08103 L
.44004 .08261 L
.44427 .08586 L
.44881 .09028 L
.45701 .10095 L
.46734 .11984 L
.47716 .14391 L
.49559 .20507 L
.52917 .35298 L
.5476 .43204 L
.55665 .46391 L
.56496 .48713 L
.56904 .49608 L
.57285 .50284 L
.57683 .5081 L
Mistroke
.58119 .51184 L
.58562 .51339 L
.58965 .5127 L
.59189 .51152 L
.59432 .50958 L
.59873 .50436 L
.6024 .4983 L
.60644 .49 L
.61463 .46829 L
.62933 .41579 L
.66235 .27056 L
.68036 .19889 L
.6971 .1472 L
.7059 .1267 L
.7153 .10981 L
.72066 .10234 L
.72573 .09661 L
.73033 .09242 L
.7352 .08897 L
.73935 .08673 L
.74392 .08493 L
.74807 .08384 L
.75196 .08323 L
.75653 .08295 L
.76071 .08304 L
.76302 .08321 L
.76554 .08349 L
.77011 .08418 L
.78865 .08853 L
.80867 .09373 L
.81786 .09578 L
.82756 .09762 L
.83595 .09892 L
.84492 .10003 L
.85368 .10088 L
.86164 .10146 L
.86965 .10191 L
.87723 .10223 L
.88151 .10237 L
.88605 .10249 L
.8942 .10267 L
.89872 .10274 L
.90296 .10279 L
.90797 .10284 L
.91262 .10288 L
.91706 .10291 L
.92108 .10293 L
.92555 .10295 L
.93031 .10296 L
.93447 .10297 L
Mistroke
.93897 .10298 L
.94322 .10299 L
.94713 .10299 L
.95092 .103 L
.95445 .103 L
.95833 .103 L
.96249 .103 L
.96684 .103 L
.97097 .103 L
.97468 .10301 L
.97871 .10301 L
.9831 .10301 L
.98722 .10301 L
.99175 .10301 L
.99429 .10301 L
.99662 .10301 L
Mfstroke
.99662 .10301 m
1 .10301 L
s
1 0 0 r
0 .10301 m
.00067 .10301 L
.00504 .10301 L
.00917 .10301 L
.01299 .10301 L
.01691 .10301 L
.02059 .10301 L
.02463 .10301 L
.02899 .10301 L
.03331 .10301 L
.03786 .10301 L
.04174 .10301 L
.04599 .10301 L
.0506 .10301 L
.05485 .10301 L
.05952 .10301 L
.06446 .10301 L
.06875 .10301 L
.07277 .10301 L
.07717 .10301 L
.08191 .10301 L
.08609 .10301 L
.09066 .10301 L
.09497 .10301 L
.09897 .10301 L
.10652 .10301 L
.11074 .10301 L
.11457 .10301 L
.11916 .10301 L
.12402 .10301 L
.13271 .10301 L
.13755 .10301 L
.14206 .10301 L
.15232 .10301 L
.16114 .10301 L
.16949 .10301 L
.17409 .10301 L
.1767 .10301 L
.1791 .10301 L
.18336 .10301 L
.18787 .10301 L
.19186 .10301 L
.19622 .10301 L
.20077 .10301 L
.20501 .103 L
.20899 .103 L
.2126 .103 L
.21678 .103 L
.22071 .103 L
.22501 .10299 L
Mistroke
.22955 .10299 L
.23343 .10298 L
.23769 .10297 L
.24228 .10296 L
.2472 .10294 L
.25185 .10291 L
.25609 .10288 L
.26004 .10285 L
.26425 .10281 L
.27181 .10271 L
.27644 .10262 L
.2808 .10253 L
.28893 .10229 L
.29675 .10197 L
.30392 .10158 L
.31179 .10101 L
.32009 .10022 L
.32906 .0991 L
.33753 .09774 L
.3534 .09431 L
.37049 .08931 L
.38904 .08296 L
.39741 .08023 L
.40525 .07809 L
.40919 .07726 L
.41343 .07662 L
.41584 .07639 L
.41813 .07629 L
.42244 .0764 L
.42614 .07687 L
.43008 .07781 L
.4338 .07917 L
.43718 .08084 L
.44116 .08339 L
.44547 .08692 L
.45327 .09563 L
.46157 .1085 L
.47047 .12685 L
.48653 .17249 L
.50563 .24604 L
.52305 .32469 L
.54118 .40611 L
.55074 .44379 L
.5609 .47664 L
.56516 .48766 L
.56976 .4975 L
.57239 .50211 L
.5748 .50567 L
.57725 .50861 L
.57953 .51073 L
Mistroke
.58354 .51298 L
.58793 .51326 L
.5922 .51136 L
.59677 .50698 L
.60108 .50067 L
.60582 .49141 L
.61541 .46591 L
.63261 .40234 L
.65134 .31946 L
.67147 .23252 L
.68123 .19576 L
.6905 .16557 L
.69953 .14104 L
.7079 .12267 L
.7158 .10904 L
.72421 .09819 L
.72902 .09352 L
.73354 .09003 L
.73761 .08759 L
.74199 .08561 L
.74636 .08424 L
.75033 .08345 L
.75491 .083 L
.75925 .08298 L
.76326 .08324 L
.76696 .08369 L
.77103 .08436 L
.77534 .08523 L
.79421 .09002 L
.8119 .09449 L
.8288 .09783 L
.83829 .09924 L
.84699 .10025 L
.856 .10106 L
.86584 .10171 L
.87082 .10197 L
.87612 .10219 L
.88067 .10234 L
.88567 .10248 L
.89476 .10268 L
.89973 .10275 L
.90438 .10281 L
.91269 .10288 L
.91735 .10291 L
.9216 .10293 L
.92657 .10295 L
.93117 .10297 L
.93621 .10298 L
.94157 .10299 L
.94621 .10299 L
Mistroke
.95057 .103 L
.95535 .103 L
.95804 .103 L
.96051 .103 L
.96462 .103 L
.969 .103 L
.97315 .103 L
.97691 .10301 L
.98134 .10301 L
.98384 .10301 L
.98615 .10301 L
.99038 .10301 L
.99487 .10301 L
.99916 .10301 L
Mfstroke
.99916 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[24]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool007eoo`8000Aoo`8000=oo`<009Eoo`00O7oo00@007ooOol000=oo`8000Aoo`03001oogoo09Ao
o`00MWoo1@0000Eoo`00Oomoo`0000Uoo`03001oogoo00Eoo`8008eoo`00O7oo00@007ooOol000Uo
o`03001oogoo00Eoo`03001oogoo08aoo`00O7oo00@007ooOol000Uoo`03001oogoo00Eoo`03001o
ogoo08aoo`00OGoo0P002Goo0P001goo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03
001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`8008eoo`002goo0P00:goo0`00:Goo1000:Goo00<007ooOol0:7oo1000:Woo0`00
:Woo0P001goo000:Ool01000Oomoo`00:goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0
:Goo00<007ooOol0:goo00<007ooOol0:7oo00@007ooOol000Ioo`0017oo1@0000Eoo`00Oomoo`00
02=oo`D00003Ool00000008002=oo`D000=oo`03001oogoo02Qoo`03001oogoo02Yoo`03001oogoo
02Qoo`@002Uoo`04001oogoo0006Ool000Yoo`<002Yoo`03001oo`0002eoo`03001oogoo00aoo`Ul
019oo`03001oogoo02]oo`03001oogoo02Moo`03001oo`0002Yoo`<000Moo`002Woo00<007ooOol0
:Woo00<007oo0000:Woo00@007ooOol000aoo`9l000301moogoo00Ioo`9l011oo`8002Uoo`04001o
ogoo000YOol00`00Ool0000ZOol00`00Oomoo`07Ool000]oo`<002Yoo`8002]oo`8000Uoo`Al00ao
o`0301ml07oo00ioo`03001oogoo02Uoo`8001=oo`]l000301moogoo00Yoo`8002]oo`<000Ioo`00
K7oo17`04Woo00=l07ooOol037oo00<007ooOol0?7oo00<07g`001l02Woo0g`000<07gooOol0?Goo
001ZOol2O00GOol00g`0Oomoo`0;Ool00`00Oomoo`0kOol2O00?Ool4O00lOol006Moo`=l01Yoo`03
O01oogoo00Yoo`03001oogoo03Yoo`03O01oogoo01=oo`El000301moogoo03Aoo`00Ggoo27`07Goo
00=l000OOol02Woo00<007ooOol0>Goo00=l07ooOol06Goo27`00P0O;Goo0009OomFO00V00000g`0
0000001400000`0OO000000R000XO007Ool000Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03O0007goo00Uoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`04001o
ogooO007Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`05Ool000Uoo`03001oogoo02Yoo`03001oogoo02Yo
o`03001oogoo021oo`03O01oogoo00Qoo`03001oogoo02Yoo`03001oogoo00Yoo`03O01oogoo01eo
o`03001oogoo02Yoo`03001oogoo00Eoo`00QWoo00=l000OOol027oo00<007ooOol0=goo00=l07oo
Ool0DWoo0027Ool00g`0Oomoo`07Ool00`00Oomoo`0fOol00g`0Oomoo`1COol008Moo`03O0007goo
00Moo`03001oogoo03Eoo`03O01oogoo05Aoo`00Qgoo00=l000OOol01goo0P00=Goo00<07g`0Ool0
EGoo0028Ool00g`001moo`06Ool00`00Oomoo`0dOol00g`0Oomoo`1EOol008Qoo`03O0007goo00Io
o`03001oogoo03=oo`0301ml07oo05Ioo`00RGoo00=l07ooOol01Goo00<007ooOol0<goo00<07g`0
Ool0EWoo0029Ool00g`001moo`05Ool00`00Oomoo`0cOol00g`0Oomoo`1FOol008Uoo`03O0007goo
00Eoo`8003=oo`0301ml07oo05Moo`00RWoo00=l07ooOol017oo00<007ooOol0<Woo00=l07ooOol0
Egoo002:Ool00g`0Oomoo`04Ool00`00Oomoo`0bOol00g`0Oomoo`1GOol008]oo`03O01oogoo00=o
o`03001oogoo035oo`03O0007goo05Qoo`00Rgoo00=l07ooOol00goo00<007ooOol0<Goo00=l07oo
Ool0F7oo002;Ool00`0OO01oo`03Ool00`00Oomoo`0aOol00g`0Oomoo`1HOol008aoo`03O01oogoo
009oo`80035oo`03O0007goo05Uoo`00S7oo00=l07ooOol00Woo00<007ooOol0<7oo00=l07ooOol0
FGoo002<Ool00`0OO01oo`02Ool00`00Oomoo`0`Ool00g`0Oomoo`1IOol008eoo`05O01oogooOol0
000aOol00g`001moo`1JOol008eoo`05O01oogooOol0000aOol00g`001moo`1JOol008eoo`0401ml
07ooOol2000`Ool00g`0Oomoo`1JOol008eoo`0501ml07ooOol0000aOol00g`0Oomoo`1JOol008io
o`04O01oogoo000`Ool00g`001moo`1KOol008ioo`04O01oogoo000`Ool00g`0Oomoo`1KOol007eo
o`8000Aoo`8000=oo`<000=oo`0401ml07oo000`Ool00g`0Oomoo`1KOol007aoo`04001oogoo0003
Ool20004Ool00`00Oomoo`03Ool00g`0Ool0000`Ool00g`0Oomoo`1KOol007aoo`04001oogoo0009
Ool00`00Oomoo`03Ool017`0Ool00000;Woo00=l000OOol0G7oo001lOol01000Oomoo`002Goo00<0
07ooOol00goo00=l07oo0000;goo00=l07ooOol0G7oo001lOol01000Oomoo`002Goo00<007ooOol0
0goo00<07g`00000;goo00=l07ooOol0G7oo001mOol20009Ool20006Ool00g`0001oo`0]Ool00g`0
01moo`1MOol0091oo`03O00007oo02eoo`03O0007goo05eoo`00T7oo00=l0000Ool0;Goo00=l07oo
Ool0GGoo002@Ool00`0OO000000/Ool00g`001moo`1NOol0091oo`0301ml07oo02aoo`03O0007goo
05ioo`00TGoo00=l07ooOol0:goo00=l000OOol0GWoo002AOol00g`0Oomoo`0[Ool00g`0Oomoo`1N
Ool0095oo`0301ml07oo02Yoo`03O0007goo05moo`00TGoo00<07g`0Ool0:Woo00=l000OOol0Ggoo
002AOol00`00O01oo`0ZOol00g`001moo`1OOol0095oo`03001l07oo02Yoo`03O01oogoo05moo`00
TGoo00<0000OO000:Woo00=l07ooOol0Ggoo002AOol00`0001ml000YOol00g`001moo`1POol0095o
o`0300007g`002Uoo`03O0007goo061oo`00TGoo0P0000=l07ooOol09goo00=l07ooOol0H7oo002A
Ool01000Ool07g`0:7oo00=l07ooOol0H7oo002AOol01000Ool07g`0:7oo00=l07ooOol0H7oo002A
Ool01000Ool07g`09goo00=l000OOol0HGoo002AOol01000Oomoog`09goo00=l07ooOol0HGoo002A
Ool200000goo01ml000VOol00g`0Oomoo`1QOol0095oo`05001oogoo01ml000VOol00g`0Oomoo`1Q
Ool0095oo`05001oogoo01ml000VOol00g`0Oomoo`1QOol0095oo`05001oogooOoml000UOol00g`0
Oomoo`1ROol007eoo`8000Aoo`8000=oo`@000Eoo`05001oogooOoml000UOol00g`0Oomoo`1ROol0
07aoo`04001oogoo0003Ool20004Ool00`00Oomoo`05Ool01P00Oomoogoo01ml02Aoo`03O01oogoo
069oo`00O7oo00@007ooOol000Yoo`03001oogoo00Aoo`80009oo`0301ml07oo02=oo`03O01oogoo
069oo`00O7oo00@007ooOol000]oo`03001oogoo00=oo`06001oogooOol07g`097oo00=l07ooOol0
HWoo001lOol01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo009oo`03O01oogoo025oo`03
O01oogoo06=oo`00OGoo0P002Woo0P001Woo00<007ooOol00Woo00<07g`0Ool08Goo00=l07ooOol0
Hgoo002AOol00`00Oomoo`02Ool00`0OO01oo`0QOol00g`0Oomoo`1SOol0095oo`03001oogoo009o
o`0301ml07oo025oo`03O01oogoo06=oo`00TGoo0P0017oo00=l07ooOol07goo00=l07ooOol0I7oo
002AOol00`00Oomoo`03Ool00`0OO01oo`0OOol00g`0Oomoo`1TOol0095oo`03001oogoo00=oo`03
01ml07oo01moo`03O01oogoo06Aoo`00TGoo00<007ooOol00goo00<07g`0Ool07goo00=l07ooOol0
I7oo002AOol00`00Oomoo`03Ool00`0OO01oo`0NOol00`0OO01oo`1UOol0095oo`8000Eoo`03O01o
ogoo01eoo`03O01oogoo06Eoo`00TGoo00<007ooOol017oo00<07g`0Ool07Goo00=l07ooOol0IGoo
002AOol00`00Oomoo`04Ool00`0OO01oo`0MOol00g`0Oomoo`1UOol0095oo`03001oogoo00Aoo`03
01ml07oo01eoo`03O01oogoo06Eoo`00TGoo00<007ooOol01Goo00=l07ooOol06goo00=l07ooOol0
IWoo002AOol00`00Oomoo`05Ool00`0OO01oo`0KOol00g`0Oomoo`1VOol0095oo`8000Ioo`0301ml
07oo01]oo`03O01oogoo06Ioo`00TGoo00<007ooOol01Goo00<07g`0Ool06goo00=l07ooOol0IWoo
002AOol00`00Oomoo`06Ool00g`0Oomoo`0IOol00g`0Oomoo`1WOol0095oo`03001oogoo00Ioo`03
01ml07oo01Uoo`03O01oogoo06Moo`00TGoo00<007ooOol01Woo00<07g`0Ool06Goo00=l07ooOol0
Igoo002AOol20007Ool00`0OO01oo`0IOol00g`0Oomoo`1WOol0095oo`03001oogoo00Moo`03O01o
ogoo01Moo`0301ml07oo06Qoo`00TGoo00<007ooOol01goo00=l07ooOol05goo00=l07ooOol0J7oo
002AOol00`00Oomoo`07Ool00`0OO01oo`0GOol00g`0Oomoo`1XOol007eoo`8000Aoo`8000=oo`<0
00Ioo`03001oogoo00Moo`0301ml07oo01Moo`03O01oogoo06Qoo`00O7oo00@007ooOol000=oo`80
00Ioo`03001oogoo00=oo`03001oogoo00Moo`0301ml07oo01Moo`03O01oogoo06Qoo`00O7oo00@0
07ooOol000]oo`03001oogoo00=oo`8000Uoo`03O01oogoo01Eoo`03O01oogoo06Uoo`00O7oo00@0
07ooOol000Uoo`8000Ioo`03001oogoo00Qoo`03O01oogoo01Eoo`03O01oogoo06Uoo`00O7oo00@0
07ooOol000]oo`03001oogoo00=oo`03001oogoo00Qoo`0301ml07oo01Eoo`03O01oogoo06Uoo`00
OGoo0P002Goo0`001Woo00<007ooOol027oo00<07g`0Ool057oo00=l000OOol0JWoo002AOol00`00
Oomoo`09Ool00g`0Oomoo`0COol00g`0Oomoo`1ZOol0095oo`03001oogoo00Uoo`03O01oogoo01=o
o`03O01oogoo06Yoo`00TGoo0P002Woo00=l07ooOol04goo00=l07ooOol0JWoo002AOol00`00Oomo
o`0:Ool00g`0Oomoo`0AOol00g`0Oomoo`1[Ool0095oo`03001oogoo00Yoo`03O01oogoo015oo`03
O01oogoo06]oo`00TGoo00<007ooOol02Woo00=l07ooOol04Goo00=l07ooOol0Jgoo002AOol00`00
Oomoo`0:Ool00g`001moo`0AOol00g`0Oomoo`1[Ool0095oo`8000aoo`03O01oogoo00moo`03O01o
ogoo06aoo`00TGoo00<007ooOol02goo00=l07ooOol03goo00=l07ooOol0K7oo002AOol00`00Oomo
o`0;Ool00g`001moo`0?Ool00g`0Oomoo`1/Ool0095oo`03001oogoo00aoo`03O01oogoo00eoo`03
O01oogoo06eoo`00TGoo00<007ooOol037oo00=l07ooOol03Goo00=l07ooOol0KGoo002AOol00`00
Oomoo`0<Ool00g`001moo`0=Ool00g`0Oomoo`1]Ool0095oo`8000ioo`03O01oogoo00]oo`03O01o
ogoo06ioo`00TGoo00<007ooOol03Goo00=l07ooOol02goo00=l07ooOol0KWoo002AOol00`00Oomo
o`0=Ool00g`001moo`0:Ool00g`0Oomoo`1_Ool0095oo`03001oogoo00ioo`03O01oogoo00Uoo`03
O01oogoo06moo`00TGoo00<007ooOol03Woo00=l07ooOol027oo00<07g`0Ool0L7oo002AOol2000?
Ool00g`001moo`08Ool00g`0Oomoo`1`Ool0095oo`03001oogoo00moo`03O01oogoo00Ioo`0301ml
07oo075oo`00TGoo00<007ooOol03goo00<07g`0Ool01Woo00=l07ooOol0LGoo002AOol00`00Oomo
o`0@Ool00`0OO01oo`04Ool00`0OO01oo`1bOol007eoo`8000Aoo`8000Aoo`<000Eoo`03001oogoo
015oo`03O0007goo00=oo`03O01oogoo079oo`00O7oo00@007ooOol000=oo`8000Eoo`03001oogoo
00Aoo`03001oogoo019oo`9l0003Ooml07`007Eoo`00O7oo00@007ooOol000Qoo`@000Eoo`8001Eo
o`03O01oogoo07Eoo`00O7oo00@007ooOol000Qoo`03001oo`0000Ioo`03001oogoo08aoo`00O7oo
00@007ooOol000Qoo`03001oo`0000Ioo`03001oogoo08aoo`00OGoo0P002Woo0P001Woo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol2
002=Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool007eo
o`8000Aoo`8000=oo`<000Ioo`03001oogoo08aoo`00O7oo00@007ooOol000=oo`8000Ioo`03001o
ogoo00=oo`03001oogoo08aoo`00O7oo00@007ooOol000]oo`03001oogoo00=oo`8008eoo`00O7oo
00@007ooOol000Qoo`<009Eoo`00O7oo00@007ooOol000Qoo`03001oogoo09Eoo`00OGoo0P002Goo
1000U7oo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.40347, -0.11608, 
  0.0441619, 0.00357276}}]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(FourierNormalisedTable[{f\_1, \[Ellipsis], f\_n}, \ 
              x\_max]\), \(gives\ the\ Fourier\ transform\ of\ the\ function\ \
f\ as\ a\ list\ on\ the\ range\  | \[Omega] | \(\(<\)\(\((\[Pi] \((n - \
1)\))\)\^2\/\(2  n\ x\_max\)\)\)\)},
          {\(InverseFourierNormalisedTable[{f\_1, \[Ellipsis], 
                f\_n}, \ \[Omega]\_max]\), \(gives\ the\ inverse\ Fourier\ \
transform\ of\ the\ function\ f\ as\ a\ list\ on\ the\ range\  | 
              x | \(\(<\)\(\((\[Pi] \((n - 1)\))\)\^2\/\(2  
                      n\ \[Omega]\_max\)\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"FourierNormalisedTable", "InverseFourierNormalisedTable"}],

Cell["\<\
This is the Fourier transform of the function, expressed as a list \
of values:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(xm = 20; dx = 2  xm/255; \nxl = Range[\(-xm\), xm, dx]; fl = f/@xl; \n
    ftl = FourierNormalisedTable[fl, xm]; \n
    DisplayTogether[
      Plot[{fn[w] // Re, fx // Re}, {w, \(-\[Omega]max\), \[Omega]max}], 
      ListPlot[Transpose[{xl, ftl // Re}], PlotJoined \[Rule] True], 
      PlotRange \[Rule] {{\(-5\), 5}, {\(-0.2\), 0.3}}]; \)], "Input",
  CellLabel->"In[16]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.247214 1.23607 [
[.1 .23471 -6 -9 ]
[.1 .23471 6 0 ]
[.3 .23471 -6 -9 ]
[.3 .23471 6 0 ]
[.7 .23471 -3 -9 ]
[.7 .23471 3 0 ]
[.9 .23471 -3 -9 ]
[.9 .23471 3 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 .24721 m
.1 .25346 L
s
[(-4)] .1 .23471 0 1 Mshowa
.3 .24721 m
.3 .25346 L
s
[(-2)] .3 .23471 0 1 Mshowa
.7 .24721 m
.7 .25346 L
s
[(2)] .7 .23471 0 1 Mshowa
.9 .24721 m
.9 .25346 L
s
[(4)] .9 .23471 0 1 Mshowa
.125 Mabswid
.15 .24721 m
.15 .25096 L
s
.2 .24721 m
.2 .25096 L
s
.25 .24721 m
.25 .25096 L
s
.35 .24721 m
.35 .25096 L
s
.4 .24721 m
.4 .25096 L
s
.45 .24721 m
.45 .25096 L
s
.55 .24721 m
.55 .25096 L
s
.6 .24721 m
.6 .25096 L
s
.65 .24721 m
.65 .25096 L
s
.75 .24721 m
.75 .25096 L
s
.8 .24721 m
.8 .25096 L
s
.85 .24721 m
.85 .25096 L
s
.05 .24721 m
.05 .25096 L
s
.95 .24721 m
.95 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-0.2)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.1)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.1)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.2)] .4875 .49443 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .24724 m
.00363 .24724 L
.00862 .24724 L
.01349 .24725 L
.01865 .24724 L
.02305 .24724 L
.02791 .24723 L
.03304 .24722 L
.03856 .2472 L
.04378 .24718 L
.04855 .24715 L
.05384 .2471 L
.05875 .24705 L
.06414 .24697 L
.06989 .24686 L
.07594 .24671 L
.08165 .24653 L
.09232 .24605 L
.09743 .24575 L
.10305 .24535 L
.11439 .24426 L
.1249 .24285 L
.13472 .2411 L
.1463 .23839 L
.15686 .23519 L
.18062 .22512 L
.20072 .21337 L
.22208 .19852 L
.24055 .18543 L
.25025 .17929 L
.26048 .17399 L
.26578 .17188 L
.26858 .17098 L
.27158 .1702 L
.27686 .16932 L
.28177 .16913 L
.28716 .16967 L
.29225 .17098 L
.29682 .17286 L
.30178 .17568 L
.30727 .17979 L
.31331 .18558 L
.32551 .20136 L
.33682 .22076 L
.34741 .24285 L
.38504 .34247 L
.42513 .4519 L
.43702 .47858 L
.44821 .50001 L
.4591 .51708 L
Mistroke
.46912 .5293 L
.47865 .53779 L
.48346 .54089 L
.48873 .54339 L
.49402 .54495 L
.49699 .5454 L
.49969 .54556 L
.50495 .54514 L
.50993 .54388 L
.51501 .54172 L
.51791 .54009 L
.52062 .53831 L
.53198 .52813 L
.5418 .51582 L
.55238 .49899 L
.57646 .44805 L
.59853 .38953 L
.61963 .32907 L
.64215 .26778 L
.65309 .24172 L
.66341 .22032 L
.6726 .20427 L
.68271 .19011 L
.69234 .18013 L
.69761 .17608 L
.70253 .17318 L
.70714 .1712 L
.71134 .16997 L
.71619 .16924 L
.7208 .16915 L
.72576 .16967 L
.73104 .17087 L
.73603 .17254 L
.74054 .17445 L
.76205 .1872 L
.78406 .20294 L
.80727 .21837 L
.82709 .22884 L
.83845 .23354 L
.8488 .237 L
.85849 .23961 L
.86902 .24183 L
.88014 .24358 L
.89065 .24479 L
.90049 .24561 L
.90588 .24595 L
.91093 .24622 L
.91984 .24658 L
.92456 .24672 L
.92965 .24685 L
Mistroke
.93506 .24696 L
.94082 .24704 L
.94715 .24711 L
.95302 .24716 L
.9559 .24718 L
.95902 .24719 L
.96176 .24721 L
.96467 .24722 L
.97017 .24723 L
.97524 .24724 L
.9802 .24724 L
.98552 .24724 L
.99054 .24725 L
.99512 .24724 L
Mfstroke
.99512 .24724 m
1 .24724 L
s
0 .24724 m
.00453 .24724 L
.00873 .24724 L
.01381 .24724 L
.0186 .24724 L
.02377 .24724 L
.02668 .24723 L
.02936 .24723 L
.03373 .24722 L
.03853 .2472 L
.04354 .24718 L
.04822 .24715 L
.05372 .2471 L
.05894 .24705 L
.06362 .24698 L
.06871 .24688 L
.07424 .24676 L
.08011 .24658 L
.08562 .24637 L
.09066 .24614 L
.09972 .24559 L
.10947 .24478 L
.11808 .24382 L
.12713 .2425 L
.13709 .24061 L
.14635 .23838 L
.16735 .23126 L
.17838 .22625 L
.18854 .22083 L
.2115 .20609 L
.23134 .19185 L
.24185 .18457 L
.25315 .17766 L
.25839 .17495 L
.26337 .17278 L
.26784 .1712 L
.27271 .16995 L
.27731 .16927 L
.2822 .16913 L
.28682 .16961 L
.291 .17058 L
.29617 .17254 L
.30092 .17512 L
.30614 .17885 L
.31164 .18383 L
.3209 .19473 L
.33104 .21027 L
.37671 .31866 L
.41989 .43901 L
.4387 .48206 L
Mistroke
.45865 .51646 L
.46906 .52925 L
.47498 .53489 L
.48053 .5391 L
.48561 .54203 L
.49026 .54394 L
.49563 .54523 L
.50073 .54555 L
.50602 .54494 L
.51101 .54349 L
.51549 .54147 L
.52033 .53852 L
.52562 .53437 L
.53121 .52896 L
.54122 .51663 L
.55915 .48637 L
.57882 .44225 L
.62341 .31831 L
.64453 .26185 L
.66407 .21906 L
.67381 .20236 L
.68417 .18838 L
.68917 .18304 L
.69456 .17829 L
.70047 .17428 L
.70335 .17276 L
.70603 .1716 L
.71085 .17008 L
.71613 .16923 L
.72127 .16917 L
.72677 .16985 L
.73189 .17112 L
.73673 .17282 L
.74579 .17707 L
.78834 .20598 L
.81162 .22092 L
.823 .22693 L
.8334 .23157 L
.85264 .2381 L
.86325 .24068 L
.87332 .24257 L
.88422 .2441 L
.89433 .24513 L
.90542 .24592 L
.91162 .24625 L
.91723 .24649 L
.92208 .24665 L
.92721 .24679 L
.93637 .24698 L
.94148 .24705 L
Mistroke
.94624 .2471 L
.95146 .24715 L
.95706 .24718 L
.96189 .24721 L
.96713 .24722 L
.97209 .24723 L
.97667 .24724 L
.98079 .24724 L
.98534 .24724 L
.99008 .24724 L
.99453 .24724 L
Mfstroke
.99453 .24724 m
1 .24724 L
s
0 .24724 m
.00588 .24724 L
.02157 .24724 L
.03725 .2472 L
.05294 .2471 L
.06863 .24686 L
.08431 .24638 L
.1 .2455 L
.11569 .24399 L
.13137 .24158 L
.14706 .23794 L
.16275 .23276 L
.17843 .22582 L
.19412 .21707 L
.2098 .20676 L
.22549 .19556 L
.24118 .18458 L
.25686 .17539 L
.27255 .16987 L
.28824 .16999 L
.30392 .17751 L
.31961 .19362 L
.33529 .21865 L
.35098 .25192 L
.36667 .29173 L
.38235 .33559 L
.39804 .38056 L
.41373 .42367 L
.42941 .46236 L
.4451 .49471 L
.46078 .51951 L
.47647 .53617 L
.49216 .54451 L
.50784 .54451 L
.52353 .53617 L
.53922 .51951 L
.5549 .49471 L
.57059 .46236 L
.58627 .42367 L
.60196 .38056 L
.61765 .33559 L
.63333 .29173 L
.64902 .25192 L
.66471 .21865 L
.68039 .19362 L
.69608 .17751 L
.71176 .16999 L
.72745 .16987 L
.74314 .17539 L
.75882 .18458 L
Mistroke
.77451 .19556 L
.7902 .20676 L
.80588 .21707 L
.82157 .22582 L
.83725 .23276 L
.85294 .23794 L
.86863 .24158 L
.88431 .24399 L
.9 .2455 L
.91569 .24638 L
.93137 .24686 L
.94706 .2471 L
.96275 .2472 L
.97843 .24724 L
.99412 .24724 L
Mfstroke
.99412 .24724 m
1 .24724 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[16]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool007aoo`8000Aoo`8000=oo`@009Eoo`00Ngoo00@007ooOol000=oo`8000Aoo`03001oogoo09Eo
o`00MGoo1@0000Eoo`00Oomoo`0000Yoo`03001oogoo00=oo`<008ioo`00Ngoo00@007ooOol000]o
o`03001oogoo009oo`03001oogoo08ioo`00Ngoo00@007ooOol000Qoo`04001oogoo0004Ool00`00
Oomoo`2>Ool007aoo`8000Yoo`8000Eoo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool0
0`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>Ool008mo
o`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo
08ioo`00Sgoo00<007ooOol0SWoo002?Ool2002?Ool008moo`03001oogoo08ioo`00Sgoo00<007oo
Ool0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?
Ool00`00Oomoo`2>Ool008moo`8008moo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool0
08moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001o
ogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<0
07ooOol0SWoo002?Ool00`00Oomoo`2>Ool007aoo`8000Aoo`8000=oo`<000Eoo`03001oogoo08io
o`00Ngoo00@007ooOol000=oo`8000Aoo`03001oogoo00Aoo`03001oogoo08ioo`00MGoo1@0000Eo
o`00Oomoo`0000Uoo`03001oogoo00Aoo`<008ioo`00Ngoo00@007ooOol000Uoo`03001oogoo00Ao
o`03001oogoo08ioo`00Ngoo00@007ooOol000Uoo`03001oogoo00Aoo`03001oogoo08ioo`00O7oo
0P002Goo0P001Woo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00
Sgoo0P00Sgoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo
002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Cgoo1`00>Goo00<007ooOol0=goo1`00
D7oo001<Ool40005Ool3000gOol2000fOol40004Ool5001<Ool004Yoo`<000Yoo`8003Ioo`03001o
ogoo03Aoo`8000Yoo`@004Yoo`00BGoo0P003Goo0P00=Goo00<007ooOol0<goo0P003Goo0`00BGoo
0018Ool00`00Oomoo`0?Ool00`00Oomoo`0bOol00`00Oomoo`0bOol00`00Oomoo`0?Ool20018Ool0
04Ioo`8001=oo`03001oogoo035oo`03001oogoo035oo`03001oogoo015oo`<004Ioo`00A7oo0P00
5Goo0P00<Woo00<007ooOol0<7oo00<007ooOol057oo0P00AGoo0012Ool3000GOol2000aOol00`00
Oomoo`0_Ool2000HOol00`00Oomoo`12Ool0045oo`8001Yoo`03001oogoo02moo`80031oo`03001o
ogoo01Qoo`80049oo`00@7oo0P0077oo00<007ooOol0;Woo00<007ooOol0;Woo00<007ooOol06Woo
0P00@Goo000oOol2000MOol2000_Ool00`00Oomoo`0]Ool2000MOol20010Ool003eoo`<001moo`03
001oogoo02eoo`03001oogoo02eoo`03001oogoo01eoo`<003ioo`008Goo0`0067oo0P006Woo1000
0goo0P00;Woo00<007ooOol0;7oo00<007ooOol017oo100067oo0P006goo0`007goo000ROol00`00
Oomoo`0FOol2000LOol00`00Oomoo`04Ool00`00Oomoo`0/Ool00`00Oomoo`0/Ool00`00Oomoo`05
Ool00`00Oomoo`0JOol2000JOol00`00Oomoo`0NOol001Yoo`D00003Ool00000008001Eoo`8001Mo
o`D000=oo`03001oogoo00=oo`8002eoo`03001oogoo02]oo`8000Qoo`03001oogoo01Yoo`<001Io
o`@001moo`0087oo00<007oo00004goo0`008Woo00<007ooOol00goo00<007ooOol0:goo0P00;7oo
00<007ooOol027oo00<007ooOol06goo0`0057oo00<007oo000087oo000POol00`00Ool0000AOol3
000QOol01000Oomoo`001Goo0P00;7oo00<007ooOol0:Woo0P001goo00@007ooOol0021oo`80019o
o`03001oo`00021oo`008Goo0P003goo0`0097oo0P001goo00<007ooOol0:Woo00<007ooOol0:Woo
00<007ooOol01goo0P008Woo0`004Goo0P0087oo000_Ool4000_Ool2000[Ool00`00Oomoo`0YOol2
000_Ool4000`Ool002]oo`H0039oo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo039oo`D0
02]oo`009Woo2000=Goo00<007ooOol0:Goo00<007ooOol0:7oo0P00=goo1P009goo000QOol8000k
Ool00`00Oomoo`0XOol00`00Oomoo`0XOol00`00Oomoo`0iOol:000POol000=oool001X000Aoo`00
4Goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol0
2goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol0
2goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol0
2goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol047oo000OOol00`00
Oomoo`0eOol00`00Oomoo`0;Ool00`00Oomoo`0WOol00`00Oomoo`0VOol2000=Ool00`00Oomoo`0e
Ool00`00Oomoo`0NOol006Eoo`8002Qoo`03001oogoo02Ioo`03001oogoo06Eoo`00IWoo00<007oo
Ool09Woo00<007ooOol09Goo0P00Igoo001VOol2000WOol00`00Oomoo`0UOol2001WOol006Moo`03
001oogoo02Eoo`03001oogoo02Aoo`8006Qoo`00Igoo0P009Woo0P009Goo0P00J7oo001WOol2000V
Ool00`00Oomoo`0TOol00`00Oomoo`1WOol006Qoo`03001oogoo02Aoo`03001oogoo02=oo`8006Uo
o`00J7oo0P009Goo00<007ooOol08goo0P00JGoo001YOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`1XOol006Uoo`8002Aoo`03001oogoo029oo`8006Yoo`00JGoo0P0097oo00<007ooOol0
8Woo00<007ooOol0JGoo001ZOol00`00Oomoo`0ROol2000ROol2001[Ool006Yoo`8002=oo`03001o
ogoo025oo`03001oogoo06Yoo`00JWoo0P008goo00<007ooOol08Goo00<007ooOol0JWoo001[Ool0
0`00Oomoo`0QOol00`00Oomoo`0POol2001/Ool006]oo`80029oo`03001oogoo021oo`03001oogoo
06]oo`00K7oo00<007ooOol087oo00<007ooOol087oo00<007ooOol0Jgoo001/Ool2000QOol00`00
Oomoo`0OOol2001]Ool006aoo`80025oo`80021oo`03001oogoo06aoo`00KGoo0P0087oo00<007oo
Ool07Woo0P00KWoo001]Ool2000POol00`00Oomoo`0NOol2001^Ool006ioo`03001oogoo01ioo`03
001oogoo01ioo`03001oogoo06eoo`00KWoo0P007goo00<007ooOol07Goo0P00Kgoo001^Ool2000O
Ool00`00Oomoo`0MOol2001_Ool006moo`03001oogoo01eoo`03001oogoo01eoo`03001oogoo06io
o`00Kgoo0P007Woo0P007Goo0P00L7oo001_Ool2000NOol00`00Oomoo`0LOol2001`Ool0071oo`03
001oogoo01aoo`03001oogoo01aoo`03001oogoo06moo`00L7oo0P007Goo00<007ooOol06goo0P00
LGoo001aOol00`00Oomoo`0KOol00`00Oomoo`0KOol00`00Oomoo`1`Ool0075oo`03001oogoo00Qo
o`8000Aoo`8000=oo`<000Eoo`03001oogoo01]oo`03001oogoo071oo`00LGoo0P0027oo00@007oo
Ool000=oo`8000Aoo`03001oogoo00Aoo`03001oogoo01Yoo`03001oogoo075oo`00LWoo00<007oo
Ool01Woo00@007ooOol000Uoo`03001oogoo00Aoo`<001Yoo`03001oogoo075oo`00LWoo00<007oo
Ool01Woo00@007ooOol000Uoo`03001oogoo00Aoo`03001oogoo01Yoo`03001oogoo075oo`00LWoo
0P001goo00@007ooOol000Uoo`03001oogoo00Aoo`03001oogoo01Uoo`03001oogoo079oo`00Lgoo
00<007ooOol01Woo0P002Goo0P001Woo00<007ooOol06Goo00<007ooOol0LWoo001cOol2000JOol0
0`00Oomoo`0HOol2001dOol007Aoo`03001oogoo01Qoo`03001oogoo01Qoo`03001oogoo07=oo`00
M7oo00<007ooOol067oo0P006Goo00<007ooOol0Lgoo001dOol2000IOol00`00Oomoo`0GOol00`00
Oomoo`1dOol007Eoo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo07Aoo`00MGoo00<007oo
Ool05goo00<007ooOol05goo00<007ooOol0M7oo001eOol2000HOol00`00Oomoo`0FOol00`00Oomo
o`1eOol007Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo07Eoo`00MWoo00<007ooOol0
5Woo00<007ooOol05Woo00<007ooOol0MGoo001gOol00`00Oomoo`0EOol2000FOol00`00Oomoo`1f
Ool007Moo`03001oogoo01Eoo`03001oogoo01Eoo`03001oogoo07Ioo`00Mgoo00<007ooOol05Goo
00<007ooOol057oo0P00N7oo001hOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`1gOol0
07Qoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo07Moo`00N7oo00<007ooOol057oo00<0
07ooOol04goo0P00NGoo001iOol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`1hOol007Uo
o`03001oogoo01=oo`8001Aoo`03001oogoo07Qoo`00NGoo0P0057oo00<007ooOol04Woo0P00NWoo
001jOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`1iOol007Yoo`03001oogoo019oo`03
001oogoo015oo`8007]oo`00NWoo0P004goo00<007ooOol04Goo0P00Ngoo001kOol00`00Oomoo`0A
Ool00`00Oomoo`0@Ool2001lOol007]oo`80019oo`03001oogoo011oo`8007aoo`00O7oo00<007oo
Ool047oo0P004Goo00<007ooOol0Ngoo001lOol2000AOol00`00Oomoo`0?Ool2001mOol007aoo`80
015oo`03001oogoo00moo`03001oogoo07aoo`00OGoo0P0047oo00<007ooOol03Woo0P00OWoo001m
Ool2000@Ool00`00Oomoo`0>Ool2001nOol007aoo`@0009oo`8000=oo`@000Aoo`03001oogoo00eo
o`8007moo`00Ngoo00<007ooOol00P000Woo0P0017oo00<007ooOol017oo00<007ooOol03Goo0P00
Ogoo001kOol00`00Oomoo`030008Ool00`00Oomoo`03Ool3000<Ool20020Ool007]oo`06001oogoo
001oo`002Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol0Ogoo001kOol01000Oomoo`00
0Woo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo00]oo`80085oo`00O7oo0P000goo00<0
07ooOol017oo0P001Goo00<007ooOol02goo00<007ooOol0P7oo0022Ool00`00Oomoo`0:Ool00`00
Oomoo`0:Ool20022Ool0089oo`8000]oo`03001oogoo00Uoo`8008=oo`00Pgoo0P002Woo00<007oo
Ool02Goo00<007ooOol0PWoo0023Ool2000:Ool20009Ool20024Ool008Aoo`8000Uoo`03001oogoo
00Moo`8008Eoo`00QGoo00<007ooOol01goo00<007ooOol01Woo0P00QWoo0026Ool20007Ool00`00
Oomoo`05Ool20027Ool008Moo`<000Eoo`03001oogoo00Aoo`8008Qoo`00R7oo0`0017oo00<007oo
Ool00Woo0`00RGoo002:Ool30002Ool00`00Oomoo`03002;Ool008aoo`L008eoo`00Sgoo00<007oo
Ool0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?
Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>Ool0
08moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001o
ogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool2002?Ool008moo`03001oogoo08ioo`00Sgoo00<0
07ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo
002?Ool00`00Oomoo`2>Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.14321, -0.213051, 
  0.0358412, 0.00289961}}]
}, Open  ]],

Cell["This is the inverse of the function:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(iftl = InverseFourierNormalisedTable[ftl, \[Omega]max]; \n
    DisplayTogether[Plot[f[x] // Re, {x, \(-xm\), xm}], 
      ListPlot[Transpose[{xl, iftl // Re}], PlotJoined \[Rule] True], 
      PlotRange \[Rule] {{\(-5\), 5}, {\(-0.2\), 0.5}}]; \)], "Input",
  CellLabel->"In[18]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.176581 0.882906 [
[.1 .16408 -6 -9 ]
[.1 .16408 6 0 ]
[.3 .16408 -6 -9 ]
[.3 .16408 6 0 ]
[.7 .16408 -3 -9 ]
[.7 .16408 3 0 ]
[.9 .16408 -3 -9 ]
[.9 .16408 3 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .08829 -24 -4.5 ]
[.4875 .08829 0 4.5 ]
[.4875 .26487 -18 -4.5 ]
[.4875 .26487 0 4.5 ]
[.4875 .35316 -18 -4.5 ]
[.4875 .35316 0 4.5 ]
[.4875 .44145 -18 -4.5 ]
[.4875 .44145 0 4.5 ]
[.4875 .52974 -18 -4.5 ]
[.4875 .52974 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 .17658 m
.1 .18283 L
s
[(-4)] .1 .16408 0 1 Mshowa
.3 .17658 m
.3 .18283 L
s
[(-2)] .3 .16408 0 1 Mshowa
.7 .17658 m
.7 .18283 L
s
[(2)] .7 .16408 0 1 Mshowa
.9 .17658 m
.9 .18283 L
s
[(4)] .9 .16408 0 1 Mshowa
.125 Mabswid
.15 .17658 m
.15 .18033 L
s
.2 .17658 m
.2 .18033 L
s
.25 .17658 m
.25 .18033 L
s
.35 .17658 m
.35 .18033 L
s
.4 .17658 m
.4 .18033 L
s
.45 .17658 m
.45 .18033 L
s
.55 .17658 m
.55 .18033 L
s
.6 .17658 m
.6 .18033 L
s
.65 .17658 m
.65 .18033 L
s
.75 .17658 m
.75 .18033 L
s
.8 .17658 m
.8 .18033 L
s
.85 .17658 m
.85 .18033 L
s
.05 .17658 m
.05 .18033 L
s
.95 .17658 m
.95 .18033 L
s
.25 Mabswid
0 .17658 m
1 .17658 L
s
.5 0 m
.50625 0 L
s
[(-0.2)] .4875 0 1 0 Mshowa
.5 .08829 m
.50625 .08829 L
s
[(-0.1)] .4875 .08829 1 0 Mshowa
.5 .26487 m
.50625 .26487 L
s
[(0.1)] .4875 .26487 1 0 Mshowa
.5 .35316 m
.50625 .35316 L
s
[(0.2)] .4875 .35316 1 0 Mshowa
.5 .44145 m
.50625 .44145 L
s
[(0.3)] .4875 .44145 1 0 Mshowa
.5 .52974 m
.50625 .52974 L
s
[(0.4)] .4875 .52974 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(0.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01766 m
.50375 .01766 L
s
.5 .03532 m
.50375 .03532 L
s
.5 .05297 m
.50375 .05297 L
s
.5 .07063 m
.50375 .07063 L
s
.5 .10595 m
.50375 .10595 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14126 m
.50375 .14126 L
s
.5 .15892 m
.50375 .15892 L
s
.5 .19424 m
.50375 .19424 L
s
.5 .2119 m
.50375 .2119 L
s
.5 .22956 m
.50375 .22956 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .28253 m
.50375 .28253 L
s
.5 .30019 m
.50375 .30019 L
s
.5 .31785 m
.50375 .31785 L
s
.5 .3355 m
.50375 .3355 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .38848 m
.50375 .38848 L
s
.5 .40614 m
.50375 .40614 L
s
.5 .42379 m
.50375 .42379 L
s
.5 .45911 m
.50375 .45911 L
s
.5 .47677 m
.50375 .47677 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .51209 m
.50375 .51209 L
s
.5 .5474 m
.50375 .5474 L
s
.5 .56506 m
.50375 .56506 L
s
.5 .58272 m
.50375 .58272 L
s
.5 .60038 m
.50375 .60038 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .17658 m
.00331 .17658 L
.00879 .17658 L
.01396 .17658 L
.01876 .17658 L
.02782 .17658 L
.03289 .17658 L
.03748 .17658 L
.043 .17658 L
.04882 .17658 L
.05925 .17658 L
.06506 .17658 L
.07048 .17658 L
.08279 .17658 L
.09337 .17658 L
.10338 .17658 L
.10891 .17658 L
.11204 .17658 L
.11493 .17658 L
.12003 .17658 L
.12544 .17658 L
.13023 .17658 L
.13547 .17658 L
.14093 .17658 L
.14601 .17658 L
.15079 .17658 L
.15512 .17658 L
.16013 .17658 L
.16485 .17657 L
.17001 .17657 L
.17546 .17656 L
.18012 .17656 L
.18523 .17655 L
.19073 .17654 L
.19664 .17652 L
.20222 .1765 L
.20731 .17648 L
.21205 .17645 L
.2171 .17641 L
.22617 .17633 L
.23173 .17625 L
.23696 .17617 L
.24672 .17597 L
.25609 .17569 L
.2647 .17536 L
.27415 .17487 L
.28411 .17419 L
.29487 .17323 L
.30504 .17207 L
.32408 .16913 L
Mistroke
.34459 .16485 L
.36684 .1594 L
.37689 .15706 L
.3863 .15523 L
.39103 .15452 L
.39611 .15397 L
.39901 .15377 L
.40176 .15368 L
.40692 .15377 L
.41136 .15418 L
.4161 .15499 L
.42056 .15615 L
.42461 .15758 L
.42939 .15976 L
.43456 .1628 L
.44393 .17026 L
.45389 .18129 L
.46457 .19702 L
.48384 .23614 L
.50676 .29918 L
.52766 .3666 L
.54941 .43639 L
.56089 .46868 L
.57308 .49684 L
.5782 .50629 L
.58371 .51472 L
.58686 .51867 L
.58976 .52172 L
.5927 .52425 L
.59544 .52606 L
.60025 .52799 L
.60551 .52823 L
.61064 .5266 L
.61612 .52284 L
.6213 .51744 L
.62699 .5095 L
.6385 .48764 L
.65913 .43315 L
.68161 .36212 L
.70576 .2876 L
.71748 .25609 L
.7286 .23021 L
.73944 .20919 L
.74948 .19344 L
.75896 .18175 L
.76905 .17245 L
.77482 .16845 L
.78025 .16546 L
.78513 .16337 L
.79039 .16167 L
Mistroke
.79563 .16049 L
.80039 .15982 L
.80589 .15944 L
.8111 .15942 L
.81591 .15964 L
.82036 .16002 L
.82523 .16059 L
.83041 .16134 L
.85305 .16545 L
.87428 .16928 L
.89456 .17214 L
.90595 .17335 L
.91639 .17422 L
.9272 .17492 L
.93901 .17547 L
.94498 .17569 L
.95135 .17588 L
.95681 .17601 L
.96281 .17613 L
.97372 .1763 L
.97968 .17636 L
.98525 .17641 L
.99523 .17648 L
Mfstroke
.99523 .17648 m
1 .1765 L
s
0 .17658 m
.00588 .17658 L
.02157 .17658 L
.03725 .17658 L
.05294 .17658 L
.06863 .17658 L
.08431 .17658 L
.1 .17658 L
.11569 .17658 L
.13137 .17658 L
.14706 .17658 L
.16275 .17657 L
.17843 .17656 L
.19412 .17653 L
.2098 .17646 L
.22549 .17633 L
.24118 .17609 L
.25686 .17567 L
.27255 .17496 L
.28824 .17385 L
.30392 .17221 L
.31961 .16991 L
.33529 .16692 L
.35098 .16332 L
.36667 .15944 L
.38235 .15594 L
.39804 .15383 L
.41373 .15453 L
.42941 .15978 L
.4451 .17138 L
.46078 .19097 L
.47647 .21955 L
.49216 .25716 L
.50784 .30252 L
.52353 .35296 L
.53922 .40452 L
.5549 .45241 L
.57059 .49169 L
.58627 .51798 L
.60196 .52828 L
.61765 .52143 L
.63333 .49836 L
.64902 .46186 L
.66471 .41614 L
.68039 .36604 L
.69608 .31632 L
.71176 .27095 L
.72745 .23269 L
.74314 .20297 L
.75882 .1819 L
Mistroke
.77451 .16864 L
.7902 .16172 L
.80588 .15944 L
.82157 .16015 L
.83725 .16249 L
.85294 .16543 L
.86863 .16833 L
.88431 .17081 L
.9 .17276 L
.91569 .17417 L
.93137 .17514 L
.94706 .17576 L
.96275 .17613 L
.97843 .17635 L
.99412 .17647 L
Mfstroke
.99412 .17647 m
1 .17649 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[18]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool007aoo`8000Aoo`8000=oo`@009Eoo`00Ngoo00@007ooOol000=oo`8000Aoo`03001oogoo09Eo
o`00MGoo1@0000Eoo`00Oomoo`0000Yoo`03001oogoo00=oo`<008ioo`00Ngoo00@007ooOol000]o
o`03001oogoo009oo`03001oogoo08ioo`00Ngoo00@007ooOol000Qoo`04001oogoo0004Ool00`00
Oomoo`2>Ool007aoo`8000Yoo`8000Eoo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool2
002?Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008mo
o`03001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00
Sgoo00<007ooOol0SWoo002?Ool2002?Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo
002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>
Ool008moo`03001oogoo08ioo`00O7oo0P0017oo0P000goo0`001Goo00<007ooOol0SWoo001kOol0
1000Oomoo`000goo0P0017oo00<007ooOol017oo00<007ooOol0SWoo001eOol500001Goo001oogoo
00002Goo00<007ooOol017oo0`00SWoo001kOol01000Oomoo`002Goo00<007ooOol017oo00<007oo
Ool0SWoo001kOol01000Oomoo`002Goo00<007ooOol017oo00<007ooOol0SWoo001lOol20009Ool2
0006Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>
Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`80
08moo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`0097oo
0`00<goo1000<Goo0P00<Woo1000=7oo0`008Woo000UOol00`00Oomoo`0cOol00`00Oomoo`0aOol0
0`00Oomoo`0bOol00`00Oomoo`0eOol00`00Oomoo`0QOol001eoo`D00003Ool00000008002eoo`D0
00=oo`03001oogoo031oo`03001oogoo03=oo`03001oogoo039oo`@0029oo`008goo00<007oo0000
=goo00<007ooOol0;goo00<007ooOol0=7oo00<007ooOol0<Goo00<007oo00008goo000SOol00`00
Ool0000dOol01000Oomoo`003goo3P0057oo00<007ooOol0<Goo00@007ooOol003=oo`03001oo`00
02=oo`0097oo0P00=Goo0P0037oo1P0037oo0P004Woo0P00<goo0P006Woo1P005Goo0P008goo001U
Ool5000COol2000@Ool00`00Oomoo`1:Ool40005Ool9000bOol0061oo`L001Moo`8000moo`03001o
ogoo04Uoo`80011oo`H002eoo`00G7oo1P007Goo0P003Woo00<007ooOol0Agoo0P005goo2@009Goo
001COol:000SOol00`00Oomoo`0<Ool00`00Oomoo`15Ool2000POol:000MOol000Moool0018000Qo
o`005Goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007oo
Ool02goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Woo0P0037oo00<007ooOol02goo
00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007oo00002goo
00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol057oo000ROol00`00Oomo
o`0dOol00`00Oomoo`0VOol00`00Oomoo`0:Ool00`00Oomoo`0cOol00`00Oomoo`0=Ool00`00Oomo
o`0TOol00`00Oomoo`0QOol008=oo`03001oogoo00Uoo`03001oogoo049oo`03001oogoo04Uoo`00
Q7oo00<007ooOol027oo00<007ooOol0@Goo0P00Bgoo0024Ool00`00Oomoo`08Ool20012Ool00`00
Oomoo`1:Ool008Eoo`03001oogoo00Moo`03001oogoo041oo`8004aoo`00QGoo0P0027oo00<007oo
Ool0?goo0P00CGoo0026Ool00`00Oomoo`06Ool00`00Oomoo`0oOol00`00Oomoo`1<Ool008Moo`03
001oogoo00Eoo`03001oogoo03ioo`03001oogoo04eoo`00Qgoo00<007ooOol01Goo0P00?goo00<0
07ooOol0CGoo0028Ool00`00Oomoo`04Ool00`00Oomoo`0mOol00`00Oomoo`1>Ool008Qoo`8000Eo
o`03001oogoo03eoo`03001oogoo04ioo`00RGoo00<007ooOol00goo00<007ooOol0?7oo00<007oo
Ool0Cgoo002:Ool00`00Oomoo`02Ool2000mOol00`00Oomoo`1?Ool008Yoo`03001oogoo009oo`03
001oogoo03]oo`03001oogoo051oo`00RWoo0P000goo00<007ooOol0>goo00<007ooOol0D7oo002;
Ool01@00Oomoogoo0000?7oo00<007ooOol0DGoo002;Ool20002Ool00`00Oomoo`0jOol00`00Oomo
o`1AOol008aoo`03001oogoo008003Yoo`8005=oo`00S7oo00@007ooOol003]oo`03001oogoo059o
o`00S7oo0P0000=oo`00Ool0>Woo00<007ooOol0DWoo001lOol20004Ool20003Ool30003Ool00`00
Ool0000jOol2001DOol007]oo`04001oogoo0003Ool20004Ool00`00Oomoo`02Ool00`00Ool0000j
Ool00`00Oomoo`1COol007]oo`04001oogoo0009Ool00`00Oomoo`03Ool4000gOol2001EOol007]o
o`04001oogoo0009Ool00`00Oomoo`03Ool2000iOol2001EOol007]oo`04001oogoo0009Ool00`00
Oomoo`03Ool2000iOol00`00Oomoo`1DOol007aoo`8000Uoo`8000Ioo`03001oogoo03Ioo`8005Io
o`00Sgoo00<007ooOol0=Woo00<007ooOol0EGoo002?Ool2000gOol00`00Oomoo`1EOol008moo`80
03Ioo`8005Moo`00Sgoo0P00=Woo00<007ooOol0EWoo002?Ool2000eOol2001HOol008moo`03001o
o`0003Aoo`03001oogoo05Moo`00Sgoo0`00=7oo00<007ooOol0Egoo002?Ool00`00Ool0000cOol0
0`00Oomoo`1HOol008moo`04001oo`00000bOol00`00Oomoo`1HOol008moo`04001oogoo000bOol0
0`00Oomoo`1HOol008moo`800003Ool007oo031oo`03001oogoo05Uoo`00Sgoo00<007ooOol00P00
<7oo00<007ooOol0FGoo002?Ool01@00Oomoogoo0000<7oo00<007ooOol0FGoo002?Ool01@00Oomo
ogoo0000;goo00<007ooOol0FWoo002?Ool01000Oomoogoo0P00;Woo00<007ooOol0FWoo002?Ool2
0002Ool2000^Ool00`00Oomoo`1JOol008moo`03001oogoo009oo`03001oogoo02]oo`03001oogoo
05]oo`00Sgoo00<007ooOol00Woo0P00;7oo00<007ooOol0Fgoo001lOol20004Ool20003Ool40004
Ool00`00Oomoo`02Ool2000/Ool00`00Oomoo`1KOol007]oo`04001oogoo0003Ool20004Ool00`00
Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0YOol2001MOol007]oo`04001oogoo000:Ool00`00
Oomoo`03Ool30003Ool2000ZOol00`00Oomoo`1LOol007]oo`04001oogoo000;Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool2000ZOol00`00Oomoo`1LOol007]oo`04001oogoo0008Ool01000Oomoo`00
17oo00<007ooOol017oo00<007ooOol09goo0P00GWoo001lOol2000:Ool20005Ool00`00Oomoo`04
Ool2000XOol00`00Oomoo`1MOol008moo`03001oogoo00Aoo`8002Qoo`03001oogoo05eoo`00Sgoo
0P001Woo00<007ooOol09Goo0P00Ggoo002?Ool00`00Oomoo`05Ool00`00Oomoo`0UOol2001OOol0
08moo`03001oogoo00Eoo`8002Ioo`03001oogoo05ioo`00Sgoo00<007ooOol01Woo00<007ooOol0
8goo0P00H7oo002?Ool00`00Oomoo`06Ool00`00Oomoo`0SOol2001POol008moo`8000Moo`03001o
ogoo02=oo`03001oogoo05moo`00Sgoo00<007ooOol01goo00<007ooOol08Goo0P00HGoo002?Ool0
0`00Oomoo`07Ool00`00Oomoo`0QOol2001QOol008moo`03001oogoo00Moo`03001oogoo025oo`03
001oogoo061oo`00Sgoo0P002Goo00<007ooOol087oo00<007ooOol0H7oo002?Ool00`00Oomoo`08
Ool00`00Oomoo`0OOol2001ROol008moo`03001oogoo00Qoo`03001oogoo01moo`03001oogoo065o
o`00Sgoo00<007ooOol027oo0P0087oo00<007ooOol0HGoo002?Ool00`00Oomoo`09Ool00`00Oomo
o`0MOol2001SOol008moo`8000Yoo`03001oogoo01eoo`03001oogoo069oo`00Sgoo00<007ooOol0
2Goo0P007Woo00<007ooOol0HWoo002?Ool00`00Oomoo`09Ool2000MOol2001TOol007aoo`8000Ao
o`8000=oo`<000Eoo`03001oogoo00Yoo`03001oogoo01]oo`03001oogoo06=oo`00Ngoo00@007oo
Ool000=oo`8000Ioo`03001oogoo009oo`03001oogoo00Yoo`8001aoo`03001oogoo06=oo`00Ngoo
00@007ooOol000]oo`03001oogoo009oo`<000Yoo`8001]oo`03001oogoo06Aoo`00Ngoo00@007oo
Ool000Uoo`8000Eoo`03001oogoo00]oo`03001oogoo01Uoo`03001oogoo06Aoo`00Ngoo00@007oo
Ool000]oo`03001oogoo009oo`03001oogoo00]oo`8001Yoo`03001oogoo06Aoo`00O7oo0P002Goo
0`001Goo00<007ooOol037oo00<007ooOol05goo00<007ooOol0IGoo002?Ool00`00Oomoo`0<Ool0
0`00Oomoo`0GOol00`00Oomoo`1UOol008moo`8000ioo`03001oogoo01Ioo`03001oogoo06Eoo`00
Sgoo00<007ooOol03Goo00<007ooOol05Goo00<007ooOol0IWoo002?Ool00`00Oomoo`0=Ool2000F
Ool00`00Oomoo`1VOol008moo`03001oogoo00ioo`03001oogoo01=oo`8006Qoo`00Sgoo00<007oo
Ool03Woo0P0057oo00<007ooOol0Igoo002?Ool2000?Ool2000COol2001YOol008moo`03001oogoo
00moo`03001oogoo015oo`8006Uoo`00Sgoo00<007ooOol03goo0P004Woo00<007ooOol0J7oo002?
Ool00`00Oomoo`0?Ool2000AOol2001ZOol008moo`80015oo`03001oogoo00moo`8006Yoo`00Sgoo
00<007ooOol047oo0P003goo0P00Jgoo002?Ool00`00Oomoo`0AOol00`00Oomoo`0=Ool2001[Ool0
08moo`03001oogoo015oo`8000eoo`8006aoo`00Sgoo00<007ooOol04Woo00<007ooOol02goo0P00
K7oo002?Ool2000DOol00`00Oomoo`09Ool2001]Ool008moo`03001oogoo01=oo`8000Uoo`8006io
o`00Sgoo00<007ooOol057oo0P0027oo00<007ooOol0KGoo001lOol20004Ool20004Ool30004Ool0
0`00Oomoo`0EOol30004Ool2001`Ool007]oo`04001oogoo0003Ool20005Ool00`00Oomoo`03Ool0
0`00Oomoo`0FOol300000goo0000001bOol007]oo`04001oogoo0008Ool40004Ool3000HOol3001c
Ool007]oo`04001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`2>Ool007]oo`04001oogoo0008
Ool00`00Ool00005Ool00`00Oomoo`2>Ool007aoo`8000Yoo`8000Eoo`03001oogoo08ioo`00Sgoo
00<007ooOol0SWoo002?Ool2002?Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?
Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>Ool0
08moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool2002?Ool008moo`03001oogoo08io
o`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00
Sgoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00O7oo0P0017oo0P000goo0`001Goo
00<007ooOol0SWoo001kOol01000Oomoo`000goo0P001Woo00<007ooOol00Woo00<007ooOol0SWoo
001kOol01000Oomoo`002goo00<007ooOol00Woo0`00SWoo001kOol01000Oomoo`0027oo0`00UWoo
001kOol01000Oomoo`0027oo00<007ooOol0UWoo001lOol20009Ool4002EOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.28102, -0.21876, 
  0.0368016, 0.00416823}}]
}, Open  ]],

Cell["\<\
FourierNormalised[] just constructs an interpolation function from \
FourierNormalisedTable[].\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{850, 705},
WindowMargins->{{4, Automatic}, {Automatic, -2}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
02P0001804P000000aP2@OogooL3@09:8085N`?P0000005X0FP000003gP;A@5/
038;ADLH05000@4100000BL?00400@000000000000000000000000000040I000
00000000000@XP404@002000000eDflP\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "FourierNormalised"->{
    Cell[2514, 72, 1114, 23, 142, "DefinitionBox",
      CellTags->{
      "FourierNormalised", "InverseFourierNormalised", "TransformedRange"}]},
  "InverseFourierNormalised"->{
    Cell[2514, 72, 1114, 23, 142, "DefinitionBox",
      CellTags->{
      "FourierNormalised", "InverseFourierNormalised", "TransformedRange"}]},
  "TransformedRange"->{
    Cell[2514, 72, 1114, 23, 142, "DefinitionBox",
      CellTags->{
      "FourierNormalised", "InverseFourierNormalised", "TransformedRange"}]},
  "FourierNormalisedTable"->{
    Cell[49304, 1921, 746, 12, 82, "DefinitionBox",
      CellTags->{
      "FourierNormalisedTable", "InverseFourierNormalisedTable"}]},
  "InverseFourierNormalisedTable"->{
    Cell[49304, 1921, 746, 12, 82, "DefinitionBox",
      CellTags->{"FourierNormalisedTable", "InverseFourierNormalisedTable"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"FourierNormalised", 81974, 3159},
  {"InverseFourierNormalised", 82153, 3163},
  {"TransformedRange", 82324, 3167},
  {"FourierNormalisedTable", 82501, 3171},
  {"InverseFourierNormalisedTable", 82676, 3175}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 44, 0, 36, "SubsectionIcon"],
Cell[1786, 53, 725, 17, 55, "Text"],
Cell[2514, 72, 1114, 23, 142, "DefinitionBox",
  CellTags->{
  "FourierNormalised", "InverseFourierNormalised", "TransformedRange"}],
Cell[3631, 97, 74, 0, 28, "MathCaption"],
Cell[3708, 99, 95, 2, 27, "Input"],
Cell[3806, 103, 251, 8, 24, "Text"],
Cell[4060, 113, 158, 5, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4243, 122, 201, 5, 52, "Input"],
Cell[4447, 129, 203, 6, 20, "Output"]
}, Open  ]],
Cell[4665, 138, 301, 8, 47, "MathCaption"],

Cell[CellGroupData[{
Cell[4991, 150, 98, 2, 27, "Input"],
Cell[5092, 154, 78, 2, 20, "Output"]
}, Open  ]],
Cell[5185, 159, 78, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5288, 163, 255, 7, 52, "Input"],
Cell[5546, 172, 396, 9, 46, "Output"]
}, Open  ]],
Cell[5957, 184, 108, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6090, 191, 256, 5, 27, "Input"],
Cell[6349, 198, 24177, 975, 184, 12101, 821, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[30541, 1176, 53, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[30619, 1180, 110, 2, 27, "Input"],
Cell[30732, 1184, 151, 4, 20, "Output"]
}, Open  ]],
Cell[30898, 1191, 60, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[30983, 1195, 197, 4, 27, "Input"],
Cell[31183, 1201, 18106, 717, 184, 8574, 594, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[49304, 1921, 746, 12, 82, "DefinitionBox",
  CellTags->{"FourierNormalisedTable", "InverseFourierNormalisedTable"}],
Cell[50053, 1935, 110, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[50188, 1942, 396, 7, 87, "Input"],
Cell[50587, 1951, 15603, 616, 184, 7201, 507, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[66205, 2570, 59, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[66289, 2574, 302, 5, 42, "Input"],
Cell[66594, 2581, 14391, 548, 184, 6104, 441, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[81000, 3132, 118, 3, 22, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

