(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    160871,       4472]*)
(*NotebookOutlinePosition[    161753,       4500]*)
(*  CellTagsIndexPosition[    161709,       4496]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Gaussian likelihoods", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(GaussianLogLikelihood[{\(x\_1\) \[Ellipsis]}, {\[Mu], \
\[Sigma]\^2}]\), \(gives\ the\ log\ likelihood\ for\ the\ sample, \ 
            assuming\ a\ Gaussian\ distribution\ with\ mean\ \[Mu]\ and\ \
variance\ \[Sigma]\^2, \ and\ ignoring\ \(\(constants\)\(.\)\(\ \ \)\)\)},
          {\(GaussianLogLikelihood[{\(x\_1\) \[Ellipsis]}, {\[Mu], \
\[Sigma]\^2}, 
              Compiled \[Rule] 
                True]\), \(is\ a\ compiled\ \(\(version\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->"GaussianLogLikelihood"]], "DefinitionBox"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`RandomNumbers`;\)\)], "Input",
  CellLabel->"In[305]:="],

Cell["\<\
This package automatically loads Statistics`DiscreteDistributions`, \
Statistics`ContinuousDistributions` as well.\
\>", "Text"],

Cell["This is an array of 100 numbers drawn from N[0,1]:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rr = RandomArray[NormalDistribution[0, 1], {100}]; {Mean[rr], 
      Variance[rr]}\)], "Input",
  CellLabel->"In[454]:="],

Cell[BoxData[
    \({0.11461748632355764`, 1.1663342300512647`}\)], "Output",
  CellLabel->"Out[454]="]
}, Open  ]],

Cell["\<\
This plots the log likelihood; contours are spaced at unit \
intervals:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ml = GaussianLogLikelihood[rr, {Mean[rr], Variance[rr]}];\)\), "\n", 
    \(\(ContourPlot[
        GaussianLogLikelihood[rr, {\[Mu], v}], {\[Mu], \(-1\), 1}, {v, 0.5, 
          2}, Contours \[Rule] Range[ml - 10, ml]];\)\)}], "Input",
  CellLabel->"In[459]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 -0.301282 0.641026 [
[.01923 -0.0125 -11.5312 -18 ]
[.01923 -0.0125 11.5312 0 ]
[.25962 -0.0125 -17.5312 -18 ]
[.25962 -0.0125 17.5312 0 ]
[.5 -0.0125 -6 -18 ]
[.5 -0.0125 6 0 ]
[.74038 -0.0125 -12 -18 ]
[.74038 -0.0125 12 0 ]
[.98077 -0.0125 -6 -18 ]
[.98077 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08333 -24 -9 ]
[-0.0125 .08333 0 9 ]
[-0.0125 .21154 -24 -9 ]
[-0.0125 .21154 0 9 ]
[-0.0125 .33974 -12 -9 ]
[-0.0125 .33974 0 9 ]
[-0.0125 .46795 -24 -9 ]
[-0.0125 .46795 0 9 ]
[-0.0125 .59615 -24 -9 ]
[-0.0125 .59615 0 9 ]
[-0.0125 .72436 -24 -9 ]
[-0.0125 .72436 0 9 ]
[-0.0125 .85256 -24 -9 ]
[-0.0125 .85256 0 9 ]
[-0.0125 .98077 -12 -9 ]
[-0.0125 .98077 0 9 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -72.5312 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.25962 0 m
.25962 .00625 L
s
gsave
.25962 -0.0125 -78.5312 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -67 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.74038 0 m
.74038 .00625 L
s
gsave
.74038 -0.0125 -73 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -67 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
gsave
-0.0125 .08333 -85 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .21154 m
.00625 .21154 L
s
gsave
-0.0125 .21154 -85 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .33974 m
.00625 .33974 L
s
gsave
-0.0125 .33974 -73 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .46795 m
.00625 .46795 L
s
gsave
-0.0125 .46795 -85 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .59615 m
.00625 .59615 L
s
gsave
-0.0125 .59615 -85 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
0 .72436 m
.00625 .72436 L
s
gsave
-0.0125 .72436 -85 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
0 .85256 m
.00625 .85256 L
s
gsave
-0.0125 .85256 -85 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
1.000 setlinewidth
grestore
0 .98077 m
.00625 .98077 L
s
gsave
-0.0125 .98077 -73 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .17949 m
.00375 .17949 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .5 m
.00375 .5 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .62821 m
.00375 .62821 L
s
0 .66026 m
.00375 .66026 L
s
0 .69231 m
.00375 .69231 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .82051 m
.00375 .82051 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
0 .05128 m
.00375 .05128 L
s
0 .01923 m
.00375 .01923 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .46795 m
1 .46795 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .72436 m
1 .72436 L
s
.99375 .85256 m
1 .85256 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .17949 m
1 .17949 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .5 m
1 .5 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .66026 m
1 .66026 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .82051 m
1 .82051 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.99625 .05128 m
1 .05128 L
s
.99625 .01923 m
1 .01923 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.796 g
.74589 .98077 m
.76465 .91209 L
.77473 .86323 L
.77858 .84341 L
.78938 .77473 L
.79635 .70604 L
.79962 .63736 L
.7991 .56868 L
.79447 .5 L
.78507 .43132 L
.77473 .37913 L
.77025 .36264 L
.74862 .29396 L
.71305 .22527 L
.70604 .21472 L
.65724 .15659 L
.63736 .14528 L
.56868 .11973 L
.5 .13046 L
.4577 .15659 L
.43132 .17954 L
.39509 .22527 L
.36296 .29396 L
.36264 .29476 L
.33972 .36264 L
.32463 .43132 L
.31547 .5 L
.31098 .56868 L
.31049 .63736 L
.31365 .70604 L
.32042 .77473 L
.33099 .84341 L
.34585 .91209 L
.36264 .97082 L
.36532 .98077 L
F
0 g
.74589 .98077 m
.76465 .91209 L
.77473 .86323 L
.77858 .84341 L
.78938 .77473 L
.79635 .70604 L
.79962 .63736 L
.7991 .56868 L
.79447 .5 L
.78507 .43132 L
.77473 .37913 L
.77025 .36264 L
.74862 .29396 L
.71305 .22527 L
.70604 .21472 L
.65724 .15659 L
.63736 .14528 L
.56868 .11973 L
.5 .13046 L
.4577 .15659 L
.43132 .17954 L
.39509 .22527 L
.36296 .29396 L
.36264 .29476 L
.33972 .36264 L
.32463 .43132 L
.31547 .5 L
.31098 .56868 L
.31049 .63736 L
.31365 .70604 L
.32042 .77473 L
.33099 .84341 L
.34585 .91209 L
.36264 .97082 L
.36532 .98077 L
s
.815 g
.71896 .98077 m
.74318 .91209 L
.76022 .84341 L
.77208 .77473 L
.77473 .75599 L
.78047 .70604 L
.7851 .63736 L
.78565 .56868 L
.78183 .5 L
.77473 .44187 L
.77317 .43132 L
.75949 .36264 L
.73708 .29396 L
.70604 .23371 L
.70277 .22527 L
.63736 .15873 L
.63376 .15659 L
.56868 .13148 L
.5 .14314 L
.47645 .15659 L
.43132 .19565 L
.40814 .22527 L
.37305 .29396 L
.36264 .3241 L
.35145 .36264 L
.3365 .43132 L
.3278 .5 L
.32406 .56868 L
.32459 .63736 L
.32913 .70604 L
.3377 .77473 L
.35066 .84341 L
.36264 .89136 L
.36768 .91209 L
.38951 .98077 L
F
0 g
.71896 .98077 m
.74318 .91209 L
.76022 .84341 L
.77208 .77473 L
.77473 .75599 L
.78047 .70604 L
.7851 .63736 L
.78565 .56868 L
.78183 .5 L
.77473 .44187 L
.77317 .43132 L
.75949 .36264 L
.73708 .29396 L
.70604 .23371 L
.70277 .22527 L
.63736 .15873 L
.63376 .15659 L
.56868 .13148 L
.5 .14314 L
.47645 .15659 L
.43132 .19565 L
.40814 .22527 L
.37305 .29396 L
.36264 .3241 L
.35145 .36264 L
.3365 .43132 L
.3278 .5 L
.32406 .56868 L
.32459 .63736 L
.32913 .70604 L
.3377 .77473 L
.35066 .84341 L
.36264 .89136 L
.36768 .91209 L
.38951 .98077 L
s
.835 g
.69361 .98077 m
.70604 .93926 L
.71725 .91209 L
.73927 .84341 L
.75443 .77473 L
.7644 .70604 L
.77003 .63736 L
.77163 .56868 L
.76901 .5 L
.76153 .43132 L
.7477 .36264 L
.72438 .29396 L
.70604 .25558 L
.69319 .22527 L
.63736 .17222 L
.60881 .15659 L
.56868 .14466 L
.5014 .15659 L
.5 .15716 L
.43132 .21461 L
.42308 .22527 L
.38449 .29396 L
.36375 .36264 L
.36264 .36602 L
.34924 .43132 L
.34108 .5 L
.3382 .56868 L
.33996 .63736 L
.34613 .70604 L
.35688 .77473 L
.36264 .80274 L
.37111 .84341 L
.39112 .91209 L
.42249 .98077 L
F
0 g
.69361 .98077 m
.70604 .93926 L
.71725 .91209 L
.73927 .84341 L
.75443 .77473 L
.7644 .70604 L
.77003 .63736 L
.77163 .56868 L
.76901 .5 L
.76153 .43132 L
.7477 .36264 L
.72438 .29396 L
.70604 .25558 L
.69319 .22527 L
.63736 .17222 L
.60881 .15659 L
.56868 .14466 L
.5014 .15659 L
.5 .15716 L
.43132 .21461 L
.42308 .22527 L
.38449 .29396 L
.36375 .36264 L
.36264 .36602 L
.34924 .43132 L
.34108 .5 L
.3382 .56868 L
.33996 .63736 L
.34613 .70604 L
.35688 .77473 L
.36264 .80274 L
.37111 .84341 L
.39112 .91209 L
.42249 .98077 L
s
.854 g
.64775 .98077 m
.69351 .91209 L
.70604 .86554 L
.71414 .84341 L
.7338 .77473 L
.74681 .70604 L
.75451 .63736 L
.7575 .56868 L
.75577 .5 L
.74869 .43132 L
.73466 .36264 L
.71036 .29396 L
.70604 .28418 L
.67884 .22527 L
.63736 .18841 L
.56868 .15891 L
.5 .17076 L
.43925 .22527 L
.43132 .23494 L
.39767 .29396 L
.37519 .36264 L
.3629 .43132 L
.36264 .43333 L
.35544 .5 L
.35359 .56868 L
.35679 .63736 L
.36264 .69361 L
.36452 .70604 L
.37595 .77473 L
.39406 .84341 L
.42263 .91209 L
.43132 .9279 L
.46503 .98077 L
F
0 g
.64775 .98077 m
.69351 .91209 L
.70604 .86554 L
.71414 .84341 L
.7338 .77473 L
.74681 .70604 L
.75451 .63736 L
.7575 .56868 L
.75577 .5 L
.74869 .43132 L
.73466 .36264 L
.71036 .29396 L
.70604 .28418 L
.67884 .22527 L
.63736 .18841 L
.56868 .15891 L
.5 .17076 L
.43925 .22527 L
.43132 .23494 L
.39767 .29396 L
.37519 .36264 L
.3629 .43132 L
.36264 .43333 L
.35544 .5 L
.35359 .56868 L
.35679 .63736 L
.36264 .69361 L
.36452 .70604 L
.37595 .77473 L
.39406 .84341 L
.42263 .91209 L
.43132 .9279 L
.46503 .98077 L
s
.873 g
.5 .18731 m
.56868 .17324 L
.63736 .20796 L
.65812 .22527 L
.69995 .29396 L
.70604 .31649 L
.72014 .36264 L
.73434 .43132 L
.74092 .5 L
.74153 .56868 L
.73673 .63736 L
.7263 .70604 L
.70925 .77473 L
.70604 .785 L
.69213 .84341 L
.65107 .91209 L
.63736 .92564 L
.56868 .97197 L
.5 .95241 L
.4625 .91209 L
.43132 .85728 L
.4245 .84341 L
.39874 .77473 L
.38273 .70604 L
.37335 .63736 L
.36912 .56868 L
.36966 .5 L
.37548 .43132 L
.38841 .36264 L
.41298 .29396 L
.43132 .25935 L
.457 .22527 L
F
0 g
.5 .18731 m
.56868 .17324 L
.63736 .20796 L
.65812 .22527 L
.69995 .29396 L
.70604 .31649 L
.72014 .36264 L
.73434 .43132 L
.74092 .5 L
.74153 .56868 L
.73673 .63736 L
.7263 .70604 L
.70925 .77473 L
.70604 .785 L
.69213 .84341 L
.65107 .91209 L
.63736 .92564 L
.56868 .97197 L
.5 .95241 L
.4625 .91209 L
.43132 .85728 L
.4245 .84341 L
.39874 .77473 L
.38273 .70604 L
.37335 .63736 L
.36912 .56868 L
.36966 .5 L
.37548 .43132 L
.38841 .36264 L
.41298 .29396 L
.43132 .25935 L
.457 .22527 L
.5 .18731 L
s
.892 g
.5 .20757 m
.56868 .19092 L
.63144 .22527 L
.63736 .23013 L
.68714 .29396 L
.705 .36264 L
.70604 .3704 L
.71817 .43132 L
.72407 .5 L
.72322 .56868 L
.71606 .63736 L
.70604 .69077 L
.70405 .70604 L
.68897 .77473 L
.65142 .84341 L
.63736 .85893 L
.56868 .9095 L
.5 .88832 L
.46223 .84341 L
.43132 .78116 L
.42857 .77473 L
.40576 .70604 L
.39224 .63736 L
.38555 .56868 L
.38477 .5 L
.39025 .43132 L
.40395 .36264 L
.43081 .29396 L
.43132 .29292 L
.47877 .22527 L
F
0 g
.5 .20757 m
.56868 .19092 L
.63144 .22527 L
.63736 .23013 L
.68714 .29396 L
.705 .36264 L
.70604 .3704 L
.71817 .43132 L
.72407 .5 L
.72322 .56868 L
.71606 .63736 L
.70604 .69077 L
.70405 .70604 L
.68897 .77473 L
.65142 .84341 L
.63736 .85893 L
.56868 .9095 L
.5 .88832 L
.46223 .84341 L
.43132 .78116 L
.42857 .77473 L
.40576 .70604 L
.39224 .63736 L
.38555 .56868 L
.38477 .5 L
.39025 .43132 L
.40395 .36264 L
.43081 .29396 L
.43132 .29292 L
.47877 .22527 L
.5 .20757 L
s
.912 g
.56868 .21284 m
.60016 .22527 L
.63736 .25535 L
.66728 .29396 L
.69372 .36264 L
.70289 .43132 L
.70545 .5 L
.70405 .56868 L
.69804 .63736 L
.68311 .70604 L
.64824 .77473 L
.63736 .78827 L
.57438 .84341 L
.56868 .84491 L
.53583 .84341 L
.5 .82147 L
.46466 .77473 L
.43507 .70604 L
.43132 .69452 L
.41604 .63736 L
.40577 .56868 L
.40306 .5 L
.40792 .43132 L
.42234 .36264 L
.43132 .33228 L
.44954 .29396 L
.5 .23059 L
.51005 .22527 L
F
0 g
.56868 .21284 m
.60016 .22527 L
.63736 .25535 L
.66728 .29396 L
.69372 .36264 L
.70289 .43132 L
.70545 .5 L
.70405 .56868 L
.69804 .63736 L
.68311 .70604 L
.64824 .77473 L
.63736 .78827 L
.57438 .84341 L
.56868 .84491 L
.53583 .84341 L
.5 .82147 L
.46466 .77473 L
.43507 .70604 L
.43132 .69452 L
.41604 .63736 L
.40577 .56868 L
.40306 .5 L
.40792 .43132 L
.42234 .36264 L
.43132 .33228 L
.44954 .29396 L
.5 .23059 L
.51005 .22527 L
.56868 .21284 L
s
.931 g
.5 .25748 m
.56868 .23639 L
.63736 .29305 L
.63805 .29396 L
.67498 .36264 L
.68845 .43132 L
.6914 .5 L
.68699 .56868 L
.67282 .63736 L
.64039 .70604 L
.63736 .71043 L
.57562 .77473 L
.56868 .77688 L
.53459 .77473 L
.5 .75004 L
.47058 .70604 L
.44476 .63736 L
.43132 .57148 L
.43099 .56868 L
.42546 .5 L
.42922 .43132 L
.43132 .41662 L
.44283 .36264 L
.47233 .29396 L
F
0 g
.5 .25748 m
.56868 .23639 L
.63736 .29305 L
.63805 .29396 L
.67498 .36264 L
.68845 .43132 L
.6914 .5 L
.68699 .56868 L
.67282 .63736 L
.64039 .70604 L
.63736 .71043 L
.57562 .77473 L
.56868 .77688 L
.53459 .77473 L
.5 .75004 L
.47058 .70604 L
.44476 .63736 L
.43132 .57148 L
.43099 .56868 L
.42546 .5 L
.42922 .43132 L
.43132 .41662 L
.44283 .36264 L
.47233 .29396 L
.5 .25748 L
s
.95 g
.56868 .26834 m
.60569 .29396 L
.63736 .34106 L
.64557 .36264 L
.66361 .43132 L
.66577 .5 L
.65482 .56868 L
.63736 .61811 L
.62864 .63736 L
.56868 .7028 L
.5 .66991 L
.48157 .63736 L
.4596 .56868 L
.4508 .5 L
.45258 .43132 L
.46668 .36264 L
.5 .29893 L
.50452 .29396 L
F
0 g
.56868 .26834 m
.60569 .29396 L
.63736 .34106 L
.64557 .36264 L
.66361 .43132 L
.66577 .5 L
.65482 .56868 L
.63736 .61811 L
.62864 .63736 L
.56868 .7028 L
.5 .66991 L
.48157 .63736 L
.4596 .56868 L
.4508 .5 L
.45258 .43132 L
.46668 .36264 L
.5 .29893 L
.50452 .29396 L
.56868 .26834 L
s
.969 g
.56868 .31701 m
.61015 .36264 L
.62741 .43132 L
.62653 .5 L
.60847 .56868 L
.56868 .61673 L
.50174 .56868 L
.5 .56466 L
.48368 .5 L
.4828 .43132 L
.5 .36276 L
.50006 .36264 L
F
0 g
.56868 .31701 m
.61015 .36264 L
.62741 .43132 L
.62653 .5 L
.60847 .56868 L
.56868 .61673 L
.50174 .56868 L
.5 .56466 L
.48368 .5 L
.4828 .43132 L
.5 .36276 L
.50006 .36264 L
.56868 .31701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[461]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0029oo`D003Ao
o`<000Aoo`03001oo`0000@0035oo`<003Eoo`<000Aoo`03001oo`0000@003Ioo`D000Eoo`0097oo
00<007ooOol0<goo00D007ooOomoo`0000Yoo`03001oogoo02eoo`05001oogooOol0000cOol01@00
Oomoogoo00002Woo00<007ooOol0=Goo00<007ooOol01Goo000TOol00`00Oomoo`0bOol00`00Oomo
o`03Ool00`00Oomoo`08Ool00`00Oomoo`0[Ool00`00Oomoo`03Ool00`00Oomoo`0_Ool00`00Oomo
o`03Ool00`00Oomoo`08Ool00`00Oomoo`0dOol00`00Oomoo`05Ool002Aoo`03001oogoo039oo`03
001oogoo00=oo`03001oogoo00Qoo`03001oogoo02]oo`03001oogoo00=oo`03001oogoo02moo`03
001oogoo00=oo`03001oogoo00Qoo`03001oogoo03Aoo`03001oogoo00Eoo`005goo20001Goo00<0
07ooOol0:7oo20000Woo00<007ooOol00goo00<007ooOol027oo00<007ooOol0:goo00<007ooOol0
0goo00<007ooOol0;goo00<007ooOol00goo00<007ooOol027oo00<007ooOol0=7oo00<007ooOol0
1Goo000TOol00`00Oomoo`0bOol00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`0[Ool00`00
Oomoo`03Ool00`00Oomoo`0_Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`0dOol00`00
Oomoo`05Ool002Aoo`03001oogoo039oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo02ao
o`03001oogoo00=oo`03001oogoo02moo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo03Eo
o`03001oogoo00Eoo`0097oo00<007ooOol0<Woo00<007ooOol00goo00<007ooOol00goo1000;goo
00<007ooOol00goo00<007ooOol0;goo00<007ooOol00goo00<007ooOol00goo1000>7oo00<007oo
Ool01Goo000TOol00`00Oomoo`0bOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0`Ool0
0`00Oomoo`03Ool00`00Oomoo`0_Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0iOol0
0`00Oomoo`05Ool0029oo`<003Eoo`05001oogooOol00007Ool00`00Oomoo`0`Ool01@00Oomoogoo
0000<goo00D007ooOomoo`0000Moo`03001oogoo03Ioo`<000Moo`0097oo00<007ooOol0=7oo0`00
27oo1@00;goo0`00=Goo0`0027oo1@00=Woo00<007ooOol01Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol001]oool000@0009oo`006goo00<007ooOol00Woo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007oo
Ool02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00D007ooOomoo`00009oo`00
6goo00<007ooOol00Woo00<007ooOol0>goo00<007ooOol0>goo00<007ooOol0>goo00<007ooOol0
?7oo00D007ooOomoo`00009oo`006goo00<007ooOol0ogoo0@000Goo0Goo000KOol00`00Oomoo`3o
Ool10001Ool1Ool001]oo`800?moo`5oo`40005oo`5oo`006goo00<007ooOol00Woon@0017oo0@00
0Goo0Goo000KOol00`00Oomoo`02Oooi0004Ool10001Ool1Ool001]oo`03001oogoo009oooT000Ao
o`40005oo`5oo`006goo00<007ooOol00Woon@0017oo0@000Goo0Goo000KOol00`00Oomoo`02Oooi
0004Ool10001Ool1Ool001]oo`03001oogoo009oooT000Aoo`40005oo`5oo`006goo00<007ooOol0
0Woon@0017oo0@000Goo0Goo000KOol00`00Oomoo`02Oooi0004Ool10001Ool1Ool001]oo`8000=o
ooT000Aoo`40005oo`5oo`006goo00<007ooOol00Woon@0017oo0@000Goo0Goo000KOol00`00Oomo
o`02Oooi0004Ool10001Ool1Ool001]oo`03001oogoo009oooT000Aoo`40005oo`5oo`006goo00<0
07ooOol00Woon@0017oo0@000Goo0Goo0004Ool30004Ool01000Oomoogoo0`002Goo00<007ooOol0
0Woon@0017oo0@000Goo0Goo0003Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Qoo`03001o
ogoo009oooT000Aoo`40005oo`5oo`000Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol01Goo00<007ooOol00Woon@0017oo0@000Goo0Goo0002Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`05Ool20003Oooi0003Ool20002Ool0009oo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo009oooT0
00Aoo`40005oo`5oo`000Woo00<007ooOol00goo00<007ooOol00Woo0P000goo00<007ooOol01Woo
00<007ooOol00Woon@0017oo0@000Goo0Goo0002Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Ool000020009Ool00`00Oomoo`02Oooi0004Ool10001Ool1Ool0009oo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo00Yoo`03001oogoo009oooT000Aoo`40005oo`5oo`000Woo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol02Woo00<007ooOol00Woon@0017oo0@000Goo0Goo0003Ool0
1@00Oomoogoo00001goo0P002Woo00<007ooOol00Woon@0017oo0@000Goo0Goo0004Ool3000:Ool3
0007Ool00`00Oomoo`02Oooi0004Ool10001Ool1Ool001]oo`8000=oooT000Aoo`40005oo`5oo`00
6goo00<007ooOol00Woon@0017oo0@000Goo0Goo000KOol00`00Oomoo`02Oon;0005IcUY0004Ool1
0001Ool1Ool001]oo`03001oogoo009oohD000iW>FH000Aoo`40005oo`5oo`006goo00<007ooOol0
0WooO`0036Li1@001FLiI00017oo0@000Goo0Goo000KOol00`00Oomoo`02Oomk000:IcT60005JeX3
0005IcUQ0004Ool10001Ool1Ool001]oo`03001oogoo009oogX000EW>@H000i[FP8000IW>Eh000Ao
o`40005oo`5oo`006goo00<007ooOol00WooN0000fLi10005V]J0`001FLiG00017oo0@000Goo0Goo
000KOol20003Oomf0004IcT00`00JeY[FP0>JeX60007JeX20006IcUI0004Ool10001Ool1Ool001]o
o`03001oogoo009oogD000=W>@8000][FPH000I[FP<000I[FP8000IW>EL000Aoo`40005oo`5oo`00
6goo00<007ooOol00WooL`0016Li00<006]JJeX01F]J1P003f]J0`001F]J0`001FLiE@0017oo0@00
0Goo0Goo000KOol00`00Oomoo`02Oomb0003IcT20004JeX4000<JeX50007JeX30005JeX20004IcUD
0004Ool10001Ool1Ool001]oo`03001oogoo009oog0000AW>@03001[FV]J00=[FP03001[FV]J00Q[
FPH000E_N`8000Q[FP8000A[FP03001W>FLi009W>E@000Aoo`40005oo`5oo`006goo00<007ooOol0
0WooK`0016Li00<006]JJeX00f]J00<006]JJeX00f]J1P003Fmk0`001f]J0P000f]J00<006LiIcT0
0VLiD`0017oo0@000Goo0Goo000KOol00`00Oomoo`02Oom^0004IcT00`00JeY[FP03JeX00`00JeY[
FP04000FKg/20007JeX20002JeX00`00IcUW>@02IcUB0004Ool10001Ool1Ool001]oo`03001oogoo
009oofd000AW>@03001[FV]J00=[FP04001[FV]J000AKg/40007Kg/20007JeX01000JeY[FP0016Li
D@0017oo0@000Goo0Goo000KOol00`00Oomoo`02Oom/0003IcT20004JeX20002JeX00`00Kg]_N`0;
Kg/50004Kg/20007Kg/20006JeX01000JeY[FP0016LiD00017oo0@000Goo0Goo000KOol20003Oom[
0003IcT00`00JeY[FP03JeX01@00JeY[FV]J00002Vmk10002fmk0P001fmk0`0016]J00@006]JJeX0
00=W>E0000Aoo`40005oo`5oo`006goo00<007ooOol00WooJ`000VLi00<006]JJeX00f]J00D006]J
JeY[FP0000I_N`D0015_N`8000Q_N`8000=[FP04001[FV]J0003IcU?0004Ool10001Ool1Ool001]o
o`03001oogoo009oofX0009W>@03001[FV]J00=[FP05001[FV]JJeX00004Kg/3000HKg/20008Kg/0
1@00JeY[FV]J00000V]J00@006LiIcUW>Dh000Aoo`40005oo`5oo`006goo00<007ooOol00WooJ@00
0VLi00<006]JJeX00f]J00D006]JJeY[FP0000A_N`03001_Nfmk00m_N`@000Q_N`8000M_N`05001[
FV]JJeX00002JeX01000IcUW>FLiC@0017oo0@000Goo0Goo000KOol00`00Oomoo`02OomX0002IcT0
0`00JeY[FP02JeX20003JeX00`00Kg]_N`02Kg/00`00Kg]_N`0;Kg/50004Li`20008Kg/20006Kg/0
1@00JeY[FV]J00000V]J00@006LiIcUW>D`000Aoo`40005oo`5oo`0017oo0`0017oo00@007ooOomo
o`<000Uoo`03001oogoo009oofP0009W>@05001[FV]JJeX00004JeX00`00Kg]_N`02Kg/00`00Kg]_
N`08Kg/4000;Li`00`00Kg]_N`07Kg/20005Kg/01@00JeY[FV]J00000V]J00<006LiIcT0C00017oo
0@000Goo0Goo0003Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Qoo`03001oogoo009oofL0
009W>@05001[FV]JJeX00004JeX00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/5000@Li`20009Kg/20004
Kg/01@00JeY[FV]J00000V]J00<006LiIcT0B`0017oo0@000Goo0Goo0002Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`02OomV0002IcT01@00JeY[
FV]J000016]J00<006mkKg/00Vmk00<006mkKg/00fmk0P005g>L0P002Fmk00<006mkKg/00Vmk00D0
06]JJeY[FP00009[FP03001W>FLi04X000Aoo`40005oo`5oo`000Woo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol01Goo0P000gooI@000VLi00D006]JJeY[FP0000A[FP03
001_Nfmk009_N`03001_Nfmk00=_N`03001cW7>L00icW0@000McW08000Q_N`03001_Nfmk009_N`05
001[FV]JJeX00002JeX00`00IcUW>@190003Ool20002Ool0009oo`03001oogoo00=oo`03001oogoo
00=oo`05001oogooOol00008Ool00`00Oomoo`02OomU0002IcT01000JeY[FP0016]J00<006mkKg/0
0Vmk00<006mkKg/00fmk00<007>LLi`02g>L100017Nm0P001g>L0P001fmk00<006mkKg/00Vmk00D0
06]JJeY[FP00009[FP03001W>FLi04P000Aoo`40005oo`5oo`000Woo00<007ooOol00goo00<007oo
Ool017oo0`002Goo00<007ooOol00WooI0000VLi00D006]JJeY[FP0000=[FP03001_Nfmk009_N`03
001_Nfmk00=_N`03001cW7>L00UcW0<000Yg_@8000McW003001_Nfmk00E_N`03001_Nfmk009_N`05
001[FV]JJeX00002JeX00`00IcT000170004Ool10001Ool1Ool0009oo`03001oogoo00=oo`03001o
ogoo00=oo`05001oogooOol00008Ool00`00Oomoo`02OomS0002IcT01@00JeY[FV]J00000f]J00<0
06mkKg/00Vmk00<006mkKg/00fmk00<007>LLi`01W>L10003gNm0P001W>L0P001Vmk00<006mkKg/0
0Vmk00D006]JJeY[FP00009[FP03001W>@0004H000Aoo`40005oo`5oo`000Woo00<007ooOol00goo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00WooHP000VLi00D006]J
JeY[FP0000=[FP03001_Nfmk009_N`03001_Nfmk00=_N`03001cW7>L00AcW0<001Eg_@8000IcW080
00E_N`03001_Nfmk009_N`05001[FV]JJeX00002JeX00`00IcT000150004Ool10001Ool1Ool0009o
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo009o
of80009W>@05001[FV]JJeX00002JeX00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00LiacW002Li`2
000JMkd00`00LiacW005Li`00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/01@00JeY[FV]J00000V]J00<0
06Li0000A@0017oo0@000Goo0Goo0003Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Qoo`03
001oogoo009oof40009W>@05001[FV]JJeX00002JeX00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00
LiacW003Li`00`00Mkeg_@0>Mkd30009Mkd20005Li`00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/01`00
JeY[FV]J001[FP00009W>DD000Aoo`40005oo`5oo`0017oo0`0027oo0`002Goo00<007ooOol00Woo
H@000VLi00D006]JJeY[FP00009[FP03001_Nfmk009_N`03001_Nfmk00=_N`03001cW7>L00=cW003
001g_GNm00ag_@<000=g_@03001g_GNm00Qg_@03001cW7>L00=cW003001_Nfmk00=_N`05001_Nfmk
Kg/00003JeX00`00JeX00002IcU50004Ool10001Ool1Ool001]oo`8000=oof00009W>@05001[FV]J
JeX00002JeX00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00LiacW003Li`00`00Mkeg_@0:Mkd30007
Mkd00`00Mkeg_@08Mkd00`00LiacW003Li`00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/01`00JeY[FV]J
001[FP00009W>D@000Aoo`40005oo`5oo`006goo00<007ooOol00WooH0000VLi00@006]JJeX000=[
FP05001_NfmkKg/00006Kg/00`00LiacW002Li`00`00Mkeg_@08Mkd3000;Mkd00`00Mkeg_@08Mkd2
0004Li`00`00Kg]_N`02Kg/01@00Kg]_Nfmk00000f]J00<006]J00000VLiA00017oo0@000Goo0Goo
000KOol00`00Oomoo`02OomO0002IcT01@00JeY[FV]J00000V]J00D006mkKg]_N`0000I_N`03001c
W7>L009cW003001g_GNm00Ig_@<000mg_@03001g_GNm00Ug_@03001cW7>L009cW003001_Nfmk009_
N`05001_NfmkKg/00002JeX01000JeY[FP000VLi@`0017oo0@000Goo0Goo000KOol00`00Oomoo`02
OomO0002IcT01000JeY[FP000f]J00@006mkKg/000I_N`03001cW7>L00=cW003001g_GNm00=g_@<0
01=g_@8000Yg_@05001cW7>LLi`00004Kg/01@00Kg]_Nfmk00000f]J00<006]J00000VLi@`0017oo
0@000Goo0Goo000KOol00`00Oomoo`02OomN0002IcT01@00JeY[FV]J00000V]J00@006mkKg/000I_
N`03001cW7>L00=cW003001g_GNm009g_@8001Qg_@03001g_GNm00Mg_@03001cW7>L009cW003001_
Nfmk009_N`05001_NfmkKg/00002JeX01000JeY[FP000VLi@P0017oo0@000Goo0Goo000KOol00`00
Oomoo`02OomN00000fLi001[FP02JeX01@00JeY[FV]J00000Vmk00<006mkKg/00fmk00<007>LLi`0
0g>L00<007NmMkd00gNm00<007NmMkd067Nm00<007NmMkd01gNm00<007>LLi`00W>L00<006mkKg/0
0Vmk00@006mkKg/000=[FP03001[FP0000=W>D4000Aoo`40005oo`5oo`006goo00<007ooOol00Woo
GP0000EW>@00JeY[FP0000=[FP04001_Nfmk0006Kg/00`00LiacW002Li`00`00Mkeg_@03Mkd00`00
Mkeg_@0JMkd00`00Mkeg_@07Mkd00`00LiacW002Li`01@00Kg]_Nfmk00000Vmk00D006]JJeY[FP00
009[FP03001W>FLi044000Aoo`40005oo`5oo`006goo00<007ooOol00WooG@0000=W>@00JeX00V]J
00@006]JJeX000=_N`03001_Nfmk00=_N`03001cW7>L009cW003001g_GNm00=g_@03001g_GNm011g
_@<000Ug_@03001g_GNm00Ig_@03001cW7>L00=cW005001_NfmkKg/00002Kg/01@00JeY[FV]J0000
0V]J00<006LiIcT0@00017oo0@000Goo0Goo000KOol00`00Oomoo`02OomM00001FLi001[FV]J0000
0f]J00@006mkKg/000E_N`03001cW7>L009cW003001g_GNm00=g_@03001g_GNm00ig_@<000=kgP03
001g_GNm00Mg_@8000Mg_@03001cW7>L00=cW004001_Nfmk0002Kg/01@00JeY[FV]J00000V]J00<0
06LiIcT0@00017oo0@000Goo0Goo000KOol20003OomL00000fLi001[FP02JeX01000JeY[FP000fmk
00<006mkKg/00Vmk00<007>LLi`00g>L00<007NmMkd00WNm00<007NmMkd037Nm0`001g_N0P002GNm
00<007NmMkd01GNm00<007>LLi`00W>L00D006mkKg]_N`00009_N`05001[FV]JJeX00002JeX00`00
IcUW>@0o0004Ool10001Ool1Ool001]oo`03001oogoo009ooe`00005IcT006]JJeX00003JeX01@00
Kg]_Nfmk000016mk00<007>LLi`00W>L00<007NmMkd00gNm00<007NmMkd02GNm0`0037_N00<007Nm
Mkd01gNm00<007NmMkd01GNm00<007>LLi`00W>L00L006mkKg]_N`00Kg/00003JeX01000JeY[FP00
0VLi?`0017oo0@000Goo0Goo000KOol00`00Oomoo`02OomK00001FLi001[FV]J00000f]J00D006mk
Kg]_N`0000A_N`03001cW7>L009cW003001g_GNm00=g_@03001g_GNm00Mg_@<0011kgP8000Qg_@03
001g_GNm00Ag_@03001cW7>L00=cW004001_Nfmk0002Kg/01@00JeY[FV]J00000V]J00<006LiIcT0
?P0017oo0@000Goo0Goo000KOol00`00Oomoo`02OomK00001FLi001[FV]J00000f]J00D006mkKg]_
N`0000=_N`03001cW7>L009cW003001g_GNm00=g_@03001g_GNm00Eg_@<001EkgP03001g_GNm00Ig
_@03001g_GNm00Ag_@03001cW7>L00=cW004001_Nfmk0002Kg/01000JeY[FP000V]J00<006LiIcT0
?P0017oo0@000Goo0Goo000KOol00`00Oomoo`02OomJ00001FLi001[FV]J00000f]J00D006mkKg]_
N`0000=_N`03001cW7>L009cW003001g_GNm00=g_@03001g_GNm00Eg_@03001kgW_N01MkgP03001g
_GNm00Ig_@03001g_GNm00Ag_@03001cW7>L00=cW004001_Nfmk0002Kg/01000JeY[FP000V]J00<0
06LiIcT0?@0017oo0@000Goo0Goo000KOol00`00Oomoo`02OomJ00001FLi001[FV]J00000f]J00D0
06mkKg]_N`0000=_N`03001cW7>L009cW003001g_GNm00=g_@03001g_GNm00Eg_@03001kgW_N01Mk
gP03001g_GNm00Ig_@03001g_GNm00Ag_@03001cW7>L00=cW004001_Nfmk0002Kg/01000JeY[FP00
0V]J00<006LiIcT0?@0017oo0@000Goo0Goo000KOol00`00Oomoo`02OomI0002IcT01000JeY[FP00
0V]J00D006mkKg]_N`0000=_N`03001cW7>L009cW003001g_GNm00=g_@03001g_GNm00Eg_@03001k
gW_N01UkgP03001g_GNm00Ig_@03001g_GNm00Ag_@03001cW7>L009cW004001_Nfmk0003Kg/01000
JeY[FP000V]J00<006LiIcT0?00017oo0@000Goo0Goo000KOol00`00Oomoo`02OomI00001FLi001[
FV]J00000f]J00D006mkKg]_N`0000=_N`03001cW7>L009cW003001g_GNm00=g_@03001g_GNm00Eg
_@03001kgW_N01YkgP03001g_GNm00Eg_@03001g_GNm00Ag_@03001cW7>L00=cW003001_N`0000=_
N`04001[FV]J0002JeX00`00IcUW>@0l0004Ool10001Ool1Ool001]oo`8000=ooeT00005IcT006]J
JeX00003JeX01@00Kg]_Nfmk00000fmk00D007>LLiacW00000Eg_@03001g_GNm00Eg_@03001kgW_N
01akgP03001g_GNm00Eg_@03001g_GNm00=g_@03001cW7>L00=cW004001_Nfmk0002Kg/01000JeY[
FP000V]J00<006LiIcT0?00017oo0@000Goo0Goo000KOol00`00Oomoo`02OomH0002IcT01000JeY[
FP000V]J00D006mkKg]_N`0000=_N`03001cW7>L009cW003001g_GNm00=g_@03001g_GNm00Eg_@03
001kgW_N01akgP03001g_GNm00Eg_@03001g_GNm00Ag_@03001cW7>L009cW004001_Nfmk0003Kg/0
1000JeY[FP000V]J00<006LiIcT0>`0017oo0@000Goo0Goo000KOol00`00Oomoo`02OomH0002IcT0
0`00JeX00003JeX01@00Kg]_Nfmk00000fmk00D007>LLiacW00000Ig_@03001g_GNm00Ag_@03001k
gW_N011kgP8000akgP03001g_GNm00Eg_@03001g_GNm00=g_@03001cW7>L009cW004001_Nfmk0003
Kg/01000JeY[FP000V]J00<006LiIcT0>`0017oo0@000Goo0Goo000KOol00`00Oomoo`02OomH0000
1FLi001[FV]J00000f]J00@006mkKg/000=_N`03001cW7>L009cW003001g_GNm00=g_@03001g_GNm
00Ag_@03001kgW_N011kgP03001oo`0000ekgP03001g_GNm00Ag_@03001g_GNm00Ag_@05001cW7>L
Li`00002Kg/01@00Kg]_Nfmk00000V]J00@006]JJeX0009W>C/000Aoo`40005oo`5oo`006goo00<0
07ooOol00WooE`000VLi00@006]JJeX0009[FP05001_NfmkKg/00003Kg/01@00LiacW7>L00001WNm
00<007NmMkd017Nm00<007_NNmh03W_N0P000goo00<007_NNmh02g_N00<007NmMkd017Nm00<007Nm
Mkd00gNm00<007>LLi`00W>L00@006mkKg/000=_N`04001[FV]J0002JeX00`00IcUW>@0j0004Ool1
0001Ool1Ool000moo`D000Moo`03001oogoo009ooeL0009W>@04001[FV]J0002JeX01@00Kg]_Nfmk
00000fmk00D007>LLiacW00000Eg_@03001g_GNm00Ag_@03001kgW_N00ikgP03001oogoo00Aoo`03
001kgW_N00YkgP03001g_GNm00Ag_@03001g_GNm00=g_@03001cW7>L009cW004001_Nfmk0003Kg/0
1000JeY[FP000V]J00<006LiIcT0>P0017oo0@000Goo0Goo000AOol00`00Oomoo`07Ool00`00Oomo
o`02OomG0002IcT00`00JeX00003JeX01000Kg]_N`000fmk00D007>LLiacW00000Ig_@03001g_GNm
00Ag_@03001kgW_N00akgP8000Qoo`03001kgW_N00YkgP03001g_GNm00Ag_@03001g_GNm00=g_@05
001cW7>LLi`00002Kg/01@00Kg]_Nfmk00000V]J00@006]JJeX0009W>CX000Aoo`40005oo`5oo`00
4Goo00<007ooOol01goo00<007ooOol00WooEP000VLi00@006]JJeX0009[FP05001_NfmkKg/00003
Kg/01@00LiacW7>L00001GNm00<007NmMkd017Nm00<007_NNmh037_N00<007ooOol02Goo00<007_N
Nmh02W_N00<007NmMkd00gNm00<007NmMkd00gNm00D007>LLiacW00000=_N`05001_NfmkKg/00002
JeX01000JeY[FP000VLi>@0017oo0@000Goo0Goo000AOol00`00Oomoo`07Ool20003OomF0002IcT0
1000JeY[FP000V]J00D006mkKg]_N`0000=_N`05001cW7>LLi`00005Mkd00`00Mkeg_@04Mkd00`00
NmikgP0:Nmh2000=Ool00`00NmikgP0:Nmh00`00Mkeg_@03Mkd00`00Mkeg_@02Mkd00`00LiacW002
Li`01000Kg]_N`000fmk00@006]JJeX0009[FP03001W>FLi03T000=oo`80009oo`004Goo00<007oo
Ool01goo00<007ooOol00WooEP000VLi00@006]JJeX0009[FP04001_Nfmk0003Kg/01@00LiacW7>L
00001GNm00<007NmMkd017Nm00<007_NNmh02W_N00<007ooOol03Woo00<007_NNmh02G_N00<007Nm
Mkd00gNm00<007NmMkd00gNm00D007>LLiacW000009_N`05001_NfmkKg/00002JeX01000JeY[FP00
0VLi>@0017oo0@000Goo0Goo000AOol00`00Oomoo`07Ool00`00Oomoo`02OomE0002IcT01000JeY[
FP000V]J00D006mkKg]_N`0000=_N`05001cW7>LLi`00005Mkd00`00Mkeg_@04Mkd00`00NmikgP08
Nmh2000BOol00`00NmikgP09Nmh00`00Mkeg_@03Mkd00`00Mkeg_@02Mkd01@00LiacW7>L00000fmk
00D006mkKg]_N`00009[FP04001[FV]J0002IcTh0004Ool10001Ool1Ool0015oo`03001oogoo00Mo
o`03001oogoo009ooeD0009W>@04001[FV]J0002JeX01000Kg]_N`000fmk00<007>LLi`00W>L00<0
07NmMkd00gNm00<007NmMkd00gNm00<007_NNmh027_N00<007ooOol04goo00<007_NNmh027_N00<0
07NmMkd00gNm00<007NmMkd00gNm00@007>LLi`000=_N`05001_NfmkKg/00002JeX01000JeY[FP00
0VLi>00017oo0@000Goo0Goo000AOol00`00Oomoo`07Ool00`00Oomoo`02OomE0002IcT01000JeY[
FP000V]J00@006mkKg/000=_N`03001cW7>L009cW003001g_GNm009g_@03001g_GNm00=g_@03001k
gW_N00MkgP8001Moo`03001kgW_N00MkgP03001g_GNm00Ag_@03001g_GNm009g_@04001cW7>L0003
Kg/01@00Kg]_Nfmk00000V]J00@006]JJeX0009W>CP000Aoo`40005oo`5oo`004Goo00<007ooOol0
1goo00<007ooOol00WooE0000VLi00@006]JJeX0009[FP05001_NfmkKg/00003Kg/01@00LiacW7>L
00001GNm00<007NmMkd00gNm00<007_NNmh01W_N00<007ooOol067oo00<007_NNmh01g_N00<007Nm
Mkd00gNm00<007NmMkd00WNm00D007>LLiacW00000=_N`05001_NfmkKg/00002JeX01000JeY[FP00
0VLi=`0017oo0@000Goo0Goo000?Ool30009Ool00`00Oomoo`02OomD0002IcT01000JeY[FP000V]J
00@006mkKg/000=_N`03001cW7>L009cW003001g_GNm009g_@03001g_GNm00=g_@03001kgW_N00Ik
gP03001oogoo01Yoo`03001kgW_N00IkgP03001g_GNm00Ag_@03001g_GNm009g_@04001cW7>L0003
Kg/01@00Kg]_Nfmk00000V]J00@006]JJeX0009W>CL000Aoo`40005oo`5oo`004Goo00<007ooOol0
1goo00<007ooOol00WooE0000VLi00@006]JJeX0009[FP04001_Nfmk0003Kg/00`00LiacW002Li`0
0`00Mkeg_@02Mkd00`00Mkeg_@03Mkd00`00NmikgP06Nmh00`00Oomoo`0JOol00`00NmikgP06Nmh0
0`00Mkeg_@04Mkd00`00Mkeg_@02Mkd01000LiacW0000fmk00D006mkKg]_N`00009[FP04001[FV]J
0002IcTg0004Ool10001Ool1Ool001]oo`8000=ooe@0009W>@04001[FV]J0002JeX01000Kg]_N`00
0fmk00<007>LLi`00W>L00<007NmMkd00WNm00<007NmMkd00gNm00<007_NNmh01W_N00<007ooOol0
6Woo00<007_NNmh01W_N00<007NmMkd017Nm00<007NmMkd00WNm00@007>LLi`000=_N`05001_Nfmk
Kg/00002JeX01000JeY[FP000VLi=`0017oo0@000Goo0Goo000KOol00`00Oomoo`02OomC0002IcT0
1@00JeY[FV]J00000V]J00@006mkKg/000=_N`05001cW7>LLi`00004Mkd00`00Mkeg_@04Mkd00`00
NmikgP05Nmh00`00Oomoo`0LOol00`00NmikgP06Nmh00`00Mkeg_@04Mkd01@00Mkeg_GNm00000W>L
00<006mkKg/00Vmk00@006mkKg/000=[FP04001[FV]J0002IcTf0004Ool10001Ool1Ool001]oo`03
001oogoo009ooe<0009W>@04001[FV]J0002JeX01000Kg]_N`000fmk00<007>LLi`00W>L00<007Nm
Mkd00WNm00<007NmMkd00gNm00<007_NNmh01W_N00<007ooOol077oo00<007_NNmh01W_N00<007Nm
Mkd017Nm00<007NmMkd00WNm00<007>L000016mk00D006mkKg]_N`00009[FP04001[FV]J0002IcTf
0004Ool10001Ool1Ool001]oo`03001oogoo009ooe<0009W>@04001[FV]J0002JeX01000Kg]_N`00
0fmk00<007>LLi`00W>L00<007NmMkd00WNm00<007NmMkd00gNm00<007_NNmh01W_N00<007ooOol0
77oo00<007_NNmh01W_N00<007NmMkd017Nm00<007NmMkd00WNm00@007>LLi`000=_N`05001_Nfmk
Kg/00002JeX01000JeY[FP000VLi=P0017oo0@000Goo0Goo000KOol00`00Oomoo`02OomC0002IcT0
1000JeY[FP000V]J00@006mkKg/000=_N`03001cW7>L009cW003001g_GNm009g_@03001g_GNm00=g
_@03001kgW_N00IkgP03001oogoo01aoo`03001kgW_N00IkgP03001g_GNm00Ag_@03001g_GNm009g
_@04001cW7>L0003Kg/01@00Kg]_Nfmk00000V]J00@006]JJeX0009W>CH000Aoo`40005oo`5oo`00
6goo00<007ooOol00WooD`000VLi00@006]JJeX0009[FP04001_Nfmk0003Kg/00`00LiacW002Li`0
0`00Mkeg_@02Mkd00`00Mkeg_@03Mkd00`00NmikgP06Nmh00`00Oomoo`0LOol00`00NmikgP06Nmh0
0`00Mkeg_@04Mkd00`00Mkeg_@02Mkd01000LiacW0000fmk00D006mkKg]_N`00009[FP04001[FV]J
0003IcTe0004Ool10001Ool1Ool001]oo`03001oogoo009ooe80009W>@04001[FV]J0003JeX01000
Kg]_N`000fmk00D007>LLiacW00000Ag_@03001g_GNm00Ag_@03001kgW_N00EkgP03001oogoo01io
o`03001kgW_N00IkgP03001g_GNm00Ag_@05001g_GNmMkd00002Li`00`00Kg]_N`02Kg/01000Kg]_
N`000f]J00@006]JJeX0009W>CD000Aoo`40005oo`5oo`006goo00<007ooOol00WooDP000VLi00@0
06]JJeX000=[FP04001_Nfmk0003Kg/01@00LiacW7>L000017Nm00<007NmMkd017Nm00<007_NNmh0
1G_N00<007ooOol07Woo00<007_NNmh01W_N00<007NmMkd017Nm00D007NmMkeg_@0000=cW005001_
NfmkKg/00002Kg/01@00JeY[FV]J00000V]J00<006LiIcT0=@0017oo0@000Goo0Goo000KOol00`00
Oomoo`02OomB0002IcT01000JeY[FP000V]J00@006mkKg/000=_N`03001cW7>L009cW003001g_GNm
009g_@03001g_GNm00=g_@03001kgW_N00IkgP03001oogoo01ioo`03001kgW_N00IkgP03001g_GNm
00Ag_@03001g_GNm009g_@04001cW7>L0003Kg/01@00Kg]_Nfmk00000V]J00@006]JJeX0009W>CD0
00Aoo`40005oo`5oo`006goo0P000gooDP000VLi00@006]JJeX0009[FP04001_Nfmk0003Kg/00`00
LiacW002Li`00`00Mkeg_@02Mkd00`00Mkeg_@03Mkd00`00NmikgP06Nmh00`00Oomoo`0NOol00`00
NmikgP06Nmh00`00Mkeg_@04Mkd00`00Mkeg_@02Mkd01000LiacW0000fmk00D006mkKg]_N`00009[
FP04001[FV]J0002IcTe0004Ool10001Ool1Ool001]oo`03001oogoo009ooe40009W>@05001[FV]J
JeX00002JeX01000Kg]_N`000fmk00D007>LLiacW00000Eg_@03001g_GNm00=g_@03001kgW_N00Ek
gP03001oogoo021oo`03001kgW_N00IkgP03001g_GNm00Ag_@05001g_GNmMkd00002Li`00`00Kg]_
N`02Kg/01000Kg]_N`000f]J00@006]JJeX0009W>C@000Aoo`40005oo`5oo`006goo00<007ooOol0
0WooD@000VLi00@006]JJeX000=[FP04001_Nfmk0003Kg/01@00LiacW7>L000017Nm00<007NmMkd0
17Nm00<007_NNmh01G_N00<007ooOol087oo00<007_NNmh01W_N00<007NmMkd017Nm00D007NmMkeg
_@0000=cW005001_NfmkKg/00002Kg/01@00JeY[FV]J00000V]J00<006LiIcT0=00017oo0@000Goo
0Goo000KOol00`00Oomoo`02OomA0002IcT01000JeY[FP000f]J00@006mkKg/000=_N`05001cW7>L
Li`00004Mkd00`00Mkeg_@04Mkd00`00NmikgP05Nmh00`00Oomoo`0POol00`00NmikgP06Nmh00`00
Mkeg_@04Mkd01@00Mkeg_GNm00000g>L00D006mkKg]_N`00009_N`05001[FV]JJeX00002JeX00`00
IcUW>@0d0004Ool10001Ool1Ool001]oo`03001oogoo009ooe40009W>@04001[FV]J0003JeX01000
Kg]_N`000fmk00D007>LLiacW00000Ag_@03001g_GNm00Ag_@03001kgW_N00EkgP03001oogoo021o
o`03001kgW_N00IkgP03001g_GNm00Ag_@05001g_GNmMkd00003Li`01@00Kg]_Nfmk00000Vmk00D0
06]JJeY[FP00009[FP03001W>FLi03@000Aoo`40005oo`5oo`006goo00<007ooOol00WooD@000VLi
00@006]JJeX0009[FP04001_Nfmk0003Kg/00`00LiacW002Li`00`00Mkeg_@02Mkd00`00Mkeg_@03
Mkd00`00NmikgP06Nmh00`00Oomoo`0POol00`00NmikgP06Nmh00`00Mkeg_@04Mkd00`00Mkeg_@02
Mkd01000LiacW0000fmk00D006mkKg]_N`00009[FP04001[FV]J0002IcTd0004Ool10001Ool1Ool0
01]oo`03001oogoo009ooe00009W>@04001[FV]J0003JeX01000Kg]_N`000fmk00D007>LLiacW000
00Eg_@03001g_GNm00=g_@03001kgW_N00EkgP03001oogoo029oo`03001kgW_N00IkgP03001g_GNm
00Ag_@05001g_GNmMkd00003Li`01@00Kg]_Nfmk00000Vmk00D006]JJeY[FP00009[FP03001W>FLi
03<000Aoo`40005oo`5oo`006goo00<007ooOol00WooD0000VLi00@006]JJeX000=[FP04001_Nfmk
0003Kg/01@00LiacW7>L00001GNm00<007NmMkd00gNm00<007_NNmh01G_N00<007ooOol08Woo00<0
07_NNmh01W_N00<007NmMkd017Nm00D007NmMkeg_@0000=cW005001_NfmkKg/00002Kg/01@00JeY[
FV]J00000V]J00<006LiIcT0<`0017oo0@000Goo0Goo000KOol20003Oom@0002IcT01000JeY[FP00
0f]J00@006mkKg/000=_N`05001cW7>LLi`00005Mkd00`00Mkeg_@03Mkd00`00NmikgP05Nmh00`00
Oomoo`0ROol00`00NmikgP06Nmh00`00Mkeg_@04Mkd01@00Mkeg_GNm00000g>L00D006mkKg]_N`00
009_N`05001[FV]JJeX00002JeX00`00IcUW>@0c0004Ool10001Ool1Ool001]oo`03001oogoo009o
oe00009W>@04001[FV]J0003JeX01000Kg]_N`000fmk00D007>LLiacW00000Eg_@03001g_GNm00=g
_@03001kgW_N00EkgP03001oogoo029oo`03001kgW_N00IkgP03001g_GNm00Ag_@05001g_GNmMkd0
0003Li`01@00Kg]_Nfmk00000Vmk00D006]JJeY[FP00009[FP03001W>FLi03<000Aoo`40005oo`5o
o`006goo00<007ooOol00WooD0000VLi00@006]JJeX000=[FP04001_Nfmk0003Kg/01@00LiacW7>L
00001GNm00<007NmMkd00gNm00<007_NNmh01G_N00<007ooOol08Woo00<007_NNmh01W_N00<007Nm
Mkd017Nm00D007NmMkeg_@0000=cW005001_NfmkKg/00002Kg/01@00JeY[FV]J00000V]J00<006Li
IcT0<`0017oo0@000Goo0Goo000KOol00`00Oomoo`02Oom?0003IcT01000JeY[FP000f]J00@006mk
Kg/000=_N`05001cW7>LLi`00005Mkd00`00Mkeg_@03Mkd00`00NmikgP05Nmh00`00Oomoo`0ROol0
0`00NmikgP06Nmh00`00Mkeg_@04Mkd01@00Mkeg_GNm00000g>L00D006mkKg]_N`00009_N`05001[
FV]JJeX00002JeX00`00IcUW>@0c0004Ool10001Ool1Ool001]oo`03001oogoo009oodl0009W>@04
001[FV]J0003JeX01000Kg]_N`000fmk00<007>LLi`00W>L00<007NmMkd00gNm00<007NmMkd00gNm
00<007_NNmh01G_N00<007ooOol08Woo00<007_NNmh01W_N00<007NmMkd017Nm00D007NmMkeg_@00
00=cW005001_NfmkKg/00003Kg/01`00JeY[FV]J001[FP0000=W>C8000Aoo`40005oo`5oo`000goo
1@000goo00<007oo00001@0027oo00<007ooOol00WooC`000VLi00@006]JJeX000=[FP04001_Nfmk
0003Kg/00`00LiacW002Li`00`00Mkeg_@03Mkd00`00Mkeg_@03Mkd00`00NmikgP05Nmh00`00Oomo
o`0ROol00`00NmikgP06Nmh00`00Mkeg_@04Mkd01@00Mkeg_GNm00000g>L00D006mkKg]_N`0000=_
N`07001[FV]JJeX006]J00000fLi<P0017oo0@000Goo0Goo0005Ool00`00Oomoo`05Ool00`00Oomo
o`03Ool00`00Oomoo`05Ool00`00Oomoo`02Oom?0002IcT01000JeY[FP000f]J00@006mkKg/000=_
N`03001cW7>L009cW003001g_GNm00=g_@03001g_GNm00=g_@03001kgW_N00EkgP03001oogoo029o
o`03001kgW_N00IkgP03001g_GNm00Ag_@05001g_GNmMkd00003Li`01@00Kg]_Nfmk00000fmk00L0
06]JJeY[FP00JeX00003IcTb0004Ool10001Ool1Ool000Eoo`03001oogoo00Ioo`03001oogoo00Yo
o`03001oogoo009oodl0009W>@04001[FV]J0003JeX01000Kg]_N`000fmk00<007>LLi`00W>L00<0
07NmMkd00gNm00<007NmMkd00gNm00<007_NNmh01G_N00<007ooOol08Woo00<007_NNmh01W_N00<0
07NmMkd017Nm00D007NmMkeg_@0000=cW005001_NfmkKg/00003Kg/01@00JeY[FV]J00000V]J00<0
06LiIcT0<P0017oo0@000Goo0Goo0005Ool00`00Oomoo`07Ool00`00Oomoo`09Ool20003Oom?0002
IcT01000JeY[FP000f]J00@006mkKg/000=_N`03001cW7>L009cW003001g_GNm00=g_@03001g_GNm
00=g_@03001kgW_N00EkgP03001oogoo029oo`03001kgW_N00IkgP03001g_GNm00Ag_@05001g_GNm
Mkd00003Li`01@00Kg]_Nfmk00000fmk00D006]JJeY[FP00009[FP03001W>FLi038000=oo`80009o
o`001Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol00WooCP000fLi00@006]JJeX000=[
FP04001_Nfmk0003Kg/01@00LiacW7>L00001GNm00<007NmMkd00gNm00<007_NNmh01W_N00<007oo
Ool08Woo00<007_NNmh01g_N00<007NmMkd017Nm00@007NmMkd000AcW005001_NfmkKg/00002Kg/0
1@00JeY[FV]J00000V]J00<006LiIcT0<P0017oo0@000Goo0Goo0005Ool00`00Oomoo`09Ool00`00
Oomoo`07Ool00`00Oomoo`02Oom>0003IcT01000JeY[FP000f]J00@006mkKg/000=_N`05001cW7>L
Li`00005Mkd00`00Mkeg_@03Mkd00`00NmikgP06Nmh00`00Oomoo`0ROol00`00NmikgP07Nmh00`00
Mkeg_@04Mkd01000Mkeg_@0017>L00D006mkKg]_N`00009_N`05001[FV]JJeX00002JeX00`00IcUW
>@0b0004Ool10001Ool1Ool000Eoo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo009oodh0
00=W>@04001[FV]J0003JeX01000Kg]_N`000fmk00D007>LLiacW00000Eg_@03001g_GNm00=g_@03
001kgW_N00IkgP03001oogoo029oo`03001kgW_N00MkgP03001g_GNm00Ag_@04001g_GNm0004Li`0
1@00Kg]_Nfmk00000Vmk00D006]JJeY[FP00009[FP03001W>FLi038000Aoo`40005oo`5oo`001Goo
00<007ooOol02Woo00<007ooOol01Woo00<007ooOol00WooCP000fLi00@006]JJeX000=[FP04001_
Nfmk0003Kg/01@00LiacW7>L00001GNm00<007NmMkd00gNm00<007_NNmh01W_N00<007ooOol08Woo
00<007_NNmh01g_N00<007NmMkd017Nm00@007NmMkd000AcW005001_NfmkKg/00002Kg/01@00JeY[
FV]J00000V]J00<006LiIcT0<P0017oo0@000Goo0Goo0005Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`02Oom>0002IcT01000JeY[FP000f]J00@006mkKg/000=_N`03
001cW7>L009cW003001g_GNm00=g_@03001g_GNm00=g_@03001kgW_N00IkgP03001oogoo029oo`03
001kgW_N00MkgP03001g_GNm00Ag_@04001g_GNm0004Li`01@00Kg]_Nfmk00000fmk00L006]JJeY[
FP00JeX00003IcTa0004Ool10001Ool1Ool000=oo`<000Qoo`04001oogoo0009Ool00`00Oomoo`02
Oom>0002IcT01000JeY[FP000f]J00@006mkKg/000=_N`03001cW7>L009cW003001g_GNm00=g_@03
001g_GNm00=g_@03001kgW_N00IkgP03001oogoo029oo`03001kgW_N00MkgP03001g_GNm00Ag_@04
001g_GNm0004Li`01@00Kg]_Nfmk00000fmk00D006]JJeY[FP00009[FP03001W>FLi034000Aoo`40
005oo`5oo`001Goo00<007ooOol01goo0P002Woo00<007ooOol00WooC@000fLi00@006]JJeX000=[
FP04001_Nfmk0003Kg/00`00LiacW002Li`00`00Mkeg_@03Mkd00`00Mkeg_@03Mkd00`00NmikgP06
Nmh00`00Oomoo`0ROol00`00NmikgP07Nmh00`00Mkeg_@04Mkd01000Mkeg_@0017>L00D006mkKg]_
N`0000=_N`05001[FV]JJeX00002JeX00`00IcUW>@0a0004Ool10001Ool1Ool001]oo`03001oogoo
009oodd000=W>@04001[FV]J0003JeX01000Kg]_N`000fmk00<007>LLi`00W>L00<007NmMkd00gNm
00<007NmMkd00gNm00<007_NNmh01W_N00<007ooOol08Woo00<007_NNmh01g_N00<007NmMkd017Nm
00@007NmMkd000AcW005001_NfmkKg/00003Kg/01@00JeY[FV]J00000V]J00<006LiIcT0<@0017oo
0@000Goo0Goo000KOol20003Oom=0003IcT01000JeY[FP000f]J00@006mkKg/000=_N`03001cW7>L
009cW003001g_GNm00=g_@03001g_GNm00=g_@03001kgW_N00IkgP03001oogoo029oo`03001kgW_N
00MkgP03001g_GNm00Ag_@04001g_GNm0004Li`01@00Kg]_Nfmk00000fmk00D006]JJeY[FP00009[
FP03001W>FLi034000Aoo`40005oo`5oo`006goo00<007ooOol00WooC@000fLi00@006]JJeX000=[
FP04001_Nfmk0003Kg/00`00LiacW002Li`00`00Mkeg_@03Mkd00`00Mkeg_@03Mkd00`00NmikgP06
Nmh00`00Oomoo`0ROol00`00NmikgP07Nmh00`00Mkeg_@04Mkd01000Mkeg_@0017>L00D006mkKg]_
N`0000=_N`05001[FV]JJeX00002JeX00`00IcUW>@0a0004Ool10001Ool1Ool001]oo`03001oogoo
009oodd000=W>@04001[FV]J0003JeX01000Kg]_N`000fmk00<007>LLi`00W>L00<007NmMkd00gNm
00<007NmMkd00gNm00<007_NNmh01W_N00<007ooOol08Woo00<007_NNmh01g_N00<007NmMkd017Nm
00@007NmMkd000AcW005001_NfmkKg/00003Kg/01@00JeY[FV]J00000V]J00<006LiIcT0<@0017oo
0@000Goo0Goo000KOol00`00Oomoo`02Oom=0003IcT01000JeY[FP000f]J00@006mkKg/000=_N`03
001cW7>L009cW003001g_GNm00=g_@03001g_GNm00=g_@03001kgW_N00MkgP03001oogoo021oo`03
001kgW_N00QkgP03001g_GNm00Ag_@04001g_GNm0004Li`01@00Kg]_Nfmk00000fmk00D006]JJeY[
FP00009[FP03001W>FLi034000Aoo`40005oo`5oo`006goo00<007ooOol00WooC@000fLi00@006]J
JeX000=[FP04001_Nfmk0003Kg/00`00LiacW002Li`00`00Mkeg_@03Mkd00`00Mkeg_@04Mkd00`00
NmikgP06Nmh00`00Oomoo`0POol00`00NmikgP07Nmh00`00Mkeg_@05Mkd01000Mkeg_@0017>L00D0
06mkKg]_N`0000=_N`05001[FV]JJeX00002JeX00`00IcUW>@0a0004Ool10001Ool1Ool001]oo`03
001oogoo009oodd000=W>@04001[FV]J0003JeX01000Kg]_N`000fmk00<007>LLi`00W>L00<007Nm
Mkd00gNm00<007NmMkd017Nm00<007_NNmh01W_N00<007ooOol087oo00<007_NNmh01g_N00<007Nm
Mkd017Nm00D007NmMkeg_@0000AcW005001_NfmkKg/00003Kg/01@00JeY[FV]J00000V]J00<006Li
IcT0<@0017oo0@000Goo0Goo000KOol00`00Oomoo`02Oom=0003IcT01000JeY[FP000f]J00@006mk
Kg/000=_N`03001cW7>L009cW003001g_GNm00=g_@03001g_GNm00Ag_@03001kgW_N00IkgP03001o
ogoo01moo`03001kgW_N00QkgP03001g_GNm00Ag_@05001g_GNmMkd00004Li`01@00Kg]_Nfmk0000
0fmk00D006]JJeY[FP00009[FP03001W>FLi034000Aoo`40005oo`5oo`006goo00<007ooOol00Woo
C@000fLi00@006]JJeX000=[FP04001_Nfmk0003Kg/00`00LiacW002Li`00`00Mkeg_@03Mkd00`00
Mkeg_@04Mkd00`00NmikgP07Nmh00`00Oomoo`0NOol00`00NmikgP08Nmh00`00Mkeg_@04Mkd01@00
Mkeg_GNm000017>L00D006mkKg]_N`0000=_N`05001[FV]JJeX00002JeX00`00IcUW>@0a0004Ool1
0001Ool1Ool001]oo`8000=oodd000=W>@04001[FV]J0003JeX01000Kg]_N`000fmk00<007>LLi`0
0W>L00<007NmMkd00gNm00<007NmMkd017Nm00<007_NNmh01g_N00<007ooOol07Woo00<007_NNmh0
27_N00<007NmMkd017Nm00D007NmMkeg_@0000AcW005001_NfmkKg/00003Kg/01@00JeY[FV]J0000
0V]J00<006LiIcT0<@0017oo0@000Goo0Goo000KOol00`00Oomoo`02Oom<0003IcT01000JeY[FP00
0f]J00D006mkKg]_N`0000=_N`03001cW7>L00=cW003001g_GNm00=g_@03001g_GNm00Ag_@03001k
gW_N00IkgP03001oogoo01eoo`03001kgW_N00QkgP03001g_GNm00Eg_@05001g_GNmMkd00004Li`0
0`00Kg]_N`02Kg/01@00Kg]_Nfmk00000V]J00D006]JJeY[FP00009W>C0000Aoo`40005oo`5oo`00
6goo00<007ooOol00WooC0000fLi00@006]JJeX000=[FP05001_NfmkKg/00003Kg/00`00LiacW003
Li`00`00Mkeg_@03Mkd00`00Mkeg_@04Mkd00`00NmikgP06Nmh00`00Oomoo`0MOol00`00NmikgP08
Nmh00`00Mkeg_@05Mkd01@00Mkeg_GNm000017>L00<006mkKg/00Vmk00D006mkKg]_N`00009[FP05
001[FV]JJeX00002IcT`0004Ool10001Ool1Ool001]oo`03001oogoo009ood`000=W>@04001[FV]J
0003JeX01@00Kg]_Nfmk00000fmk00<007>LLi`00g>L00<007NmMkd00gNm00<007NmMkd017Nm00<0
07_NNmh01g_N00<007ooOol077oo00<007_NNmh027_N00<007NmMkd01GNm00D007NmMkeg_@0000Ac
W003001_Nfmk009_N`05001_NfmkKg/00002JeX01@00JeY[FV]J00000VLi<00017oo0@000Goo0Goo
000KOol00`00Oomoo`02Oom<0003IcT01000JeY[FP000f]J00D006mkKg]_N`0000=_N`03001cW7>L
00=cW003001g_GNm00=g_@03001g_GNm00Ag_@03001kgW_N00MkgP03001oogoo01aoo`03001kgW_N
00QkgP03001g_GNm00Eg_@05001g_GNmMkd00004Li`00`00Kg]_N`02Kg/01@00Kg]_Nfmk00000V]J
00D006]JJeY[FP00009W>C0000Aoo`40005oo`5oo`006goo00<007ooOol00WooC0000fLi00@006]J
JeX000=[FP05001_NfmkKg/00003Kg/00`00LiacW003Li`00`00Mkeg_@03Mkd00`00Mkeg_@04Mkd0
0`00NmikgP07Nmh00`00Oomoo`0KOol00`00NmikgP09Nmh00`00Mkeg_@05Mkd01@00Mkeg_GNm0000
17>L00<006mkKg/00Vmk00D006mkKg]_N`00009[FP05001[FV]JJeX00002IcT`0004Ool10001Ool1
Ool001]oo`03001oogoo009ood`000=W>@04001[FV]J0003JeX01@00Kg]_Nfmk00000fmk00<007>L
Li`00g>L00<007NmMkd00gNm00<007NmMkd017Nm00<007_NNmh01g_N00<007ooOol06goo00<007_N
Nmh02G_N00<007NmMkd017Nm00<007NmMkd00WNm00<007>LLi`00W>L00<006mkKg/00Vmk00D006mk
Kg]_N`00009[FP05001[FV]JJeX00002IcT`0004Ool10001Ool1Ool001]oo`03001oogoo009ood`0
00=W>@04001[FV]J0003JeX01@00Kg]_Nfmk00000fmk00<007>LLi`00g>L00<007NmMkd00gNm00<0
07NmMkd01GNm00<007_NNmh01g_N00<007ooOol06Woo00<007_NNmh027_N00<007NmMkd01GNm00<0
07NmMkd00WNm00<007>LLi`00W>L00<006mkKg/00Vmk00D006mkKg]_N`00009[FP05001[FV]JJeX0
0002IcT`0004Ool10001Ool1Ool001]oo`8000=ood`000=W>@04001[FV]J0003JeX01@00Kg]_Nfmk
00000fmk00<007>LLi`00g>L00<007NmMkd00gNm00<007NmMkd01GNm00<007_NNmh01g_N00<007oo
Ool06Goo00<007_NNmh02G_N00<007NmMkd01GNm00<007NmMkd00WNm00<007>LLi`00W>L00<006mk
Kg/00Vmk00D006mkKg]_N`00009[FP05001[FV]JJeX00002IcT`0004Ool10001Ool1Ool001]oo`03
001oogoo009ood`000=W>@04001[FV]J0003JeX01@00Kg]_Nfmk00000fmk00<007>LLi`00g>L00<0
07NmMkd00gNm00<007NmMkd01GNm00<007_NNmh027_N0P006Goo00<007_NNmh02G_N00<007NmMkd0
1GNm00<007NmMkd00WNm00<007>LLi`00W>L00<006mkKg/00Vmk00D006mkKg]_N`00009[FP05001[
FV]JJeX00002IcT`0004Ool10001Ool1Ool001]oo`03001oogoo009ood`000=W>@04001[FV]J0003
JeX01@00Kg]_Nfmk00000fmk00<007>LLi`00g>L00<007NmMkd00gNm00<007NmMkd01GNm00<007_N
Nmh02W_N00<007ooOol05Woo00<007_NNmh02G_N00<007NmMkd01GNm00<007NmMkd00WNm00<007>L
Li`00W>L00<006mkKg/00Vmk00D006mkKg]_N`00009[FP05001[FV]JJeX00002IcT`0004Ool10001
Ool1Ool001]oo`03001oogoo009ood`000=W>@04001[FV]J0003JeX01@00Kg]_Nfmk00000fmk00<0
07>LLi`00g>L00<007NmMkd00gNm00<007NmMkd01GNm00<007_NNmh02g_N00<007ooOol057oo00<0
07_NNmh02W_N00<007NmMkd01GNm00<007NmMkd00WNm00<007>LLi`00W>L00<006mkKg/00Vmk00D0
06mkKg]_N`00009[FP05001[FV]JJeX00002IcT`0004Ool10001Ool1Ool001]oo`03001oogoo009o
od`000=W>@04001[FV]J0003JeX01@00Kg]_Nfmk00000fmk00<007>LLi`00g>L00<007NmMkd00gNm
00<007NmMkd01WNm00<007_NNmh02g_N0P004goo00<007_NNmh02W_N00<007NmMkd01WNm00<007Nm
Mkd00WNm00<007>LLi`00W>L00<006mkKg/00Vmk00D006mkKg]_N`00009[FP05001[FV]JJeX00002
IcT`0004Ool10001Ool1Ool000=oo`D000=oo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo
009ood`000=W>@04001[FV]J0003JeX01@00Kg]_Nfmk00000fmk00<007>LLi`00g>L00<007NmMkd0
17Nm00<007NmMkd01GNm00<007_NNmh03G_N00<007ooOol03goo00<007_NNmh02g_N00<007NmMkd0
1GNm00<007NmMkd00gNm00<007>LLi`00W>L00<006mkKg/00Vmk00D006mkKg]_N`00009[FP05001[
FV]JJeX00002IcT`0004Ool10001Ool1Ool000Eoo`03001oogoo00Yoo`03001oogoo00Ioo`03001o
ogoo009ood`000=W>@04001[FV]J0003JeX01@00Kg]_Nfmk000016mk00<007>LLi`00g>L00<007Nm
Mkd00gNm00<007NmMkd01GNm00<007_NNmh03W_N00<007ooOol03Woo00<007_NNmh02g_N00<007Nm
Mkd01GNm00<007NmMkd00WNm00<007>LLi`00W>L00<006mkKg/00Vmk00<006mkKg/00Vmk00@006]J
JeX000=[FP03001W>FLi030000Aoo`40005oo`5oo`001Goo00<007ooOol02Woo00<007ooOol01Woo
00<007ooOol00WooC0000fLi00@006]JJeX000=[FP05001_NfmkKg/00004Kg/00`00LiacW003Li`0
0`00Mkeg_@03Mkd00`00Mkeg_@06Mkd00`00NmikgP0>Nmh2000=Ool00`00NmikgP0;Nmh00`00Mkeg
_@06Mkd00`00Mkeg_@02Mkd00`00LiacW002Li`00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/01000JeY[
FP000f]J00<006LiIcT0<00017oo0@000Goo0Goo0005Ool00`00Oomoo`05Ool80006Ool20003Oom<
0003IcT01000JeY[FP000f]J00D006mkKg]_N`0000A_N`03001cW7>L00=cW003001g_GNm00=g_@03
001g_GNm00Ig_@03001kgW_N011kgP03001oogoo00Uoo`03001kgW_N00akgP03001g_GNm00Ig_@03
001g_GNm009g_@03001cW7>L009cW003001_Nfmk009_N`03001_Nfmk009_N`04001[FV]J0003JeX0
0`00IcUW>@0`0003Ool20002Ool000Eoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo009ood`000=W>@04001[FV]J0003JeX01@00Kg]_Nfmk000016mk00<007>LLi`00g>L
00<007NmMkd017Nm00<007NmMkd01GNm00<007_NNmh04G_N00<007ooOol01goo00<007_NNmh03G_N
00<007NmMkd01WNm00<007NmMkd00WNm00<007>LLi`00W>L00<006mkKg/00Vmk00<006mkKg/00Vmk
00@006]JJeX000=[FP03001W>FLi030000Aoo`40005oo`5oo`001Goo00<007ooOol01Woo00D007oo
Oomoo`0000Qoo`03001oogoo009ood`000=W>@04001[FV]J0003JeX01@00Kg]_Nfmk000016mk00<0
07>LLi`00g>L00<007NmMkd017Nm00<007NmMkd01GNm00<007_NNmh04W_N00<007ooOol01Goo00<0
07_NNmh03G_N00<007NmMkd01gNm00<007NmMkd00WNm00<007>LLi`00W>L00<006mkKg/00Vmk00<0
06mkKg/00Vmk00@006]JJeX000=[FP03001W>FLi030000Aoo`40005oo`5oo`001Goo00<007ooOol0
1goo00@007ooOol000Qoo`03001oogoo009ood`000=W>@05001[FV]JJeX00003JeX01@00Kg]_Nfmk
00000fmk00<007>LLi`00g>L00<007NmMkd017Nm00<007NmMkd01WNm00<007_NNmh04W_N0P001Goo
00<007_NNmh03G_N00<007NmMkd01WNm00<007NmMkd00gNm00<007>LLi`00W>L00<006mkKg/00Vmk
00D006mkKg]_N`0000=[FP05001[FV]JJeX00003IcT_0004Ool10001Ool1Ool000Eoo`03001oogoo
00Qoo`03001oo`0000Qoo`03001oogoo009ood`000=W>@05001[FV]JJeX00003JeX01@00Kg]_Nfmk
00000fmk00<007>LLi`00g>L00<007NmMkd017Nm00<007NmMkd01WNm00<007_NNmh057_N00D007oo
Oomoo`00011kgP03001g_GNm00Ig_@03001g_GNm00=g_@03001cW7>L009cW003001_Nfmk009_N`05
001_NfmkKg/00003JeX01@00JeY[FV]J00000fLi;`0017oo0@000Goo0Goo0005Ool00`00Oomoo`09
Ool20008Ool00`00Oomoo`02Oom<0003IcT01@00JeY[FV]J00000f]J00D006mkKg]_N`0000=_N`03
001cW7>L00=cW003001g_GNm00Ag_@03001g_GNm00Ig_@03001kgW_N01EkgP03001oo`00011kgP03
001g_GNm00Mg_@03001g_GNm00=g_@03001cW7>L009cW003001_Nfmk009_N`05001_NfmkKg/00003
JeX01@00JeY[FV]J00000fLi;`0017oo0@000Goo0Goo0003Ool3000;Ool20008Ool00`00Oomoo`02
Oom<0003IcT01@00JeY[FV]J00000f]J00D006mkKg]_N`0000=_N`03001cW7>L00=cW003001g_GNm
00Eg_@03001g_GNm00Eg_@03001kgW_N01IkgP03001kgW_N00mkgP03001g_GNm00Mg_@03001g_GNm
00=g_@03001cW7>L009cW003001_Nfmk009_N`05001_NfmkKg/00003JeX01@00JeY[FV]J00000fLi
;`0017oo0@000Goo0Goo0005Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`02Oom<0003
IcT01@00JeY[FV]J00000f]J00D006mkKg]_N`0000A_N`03001cW7>L00=cW003001g_GNm00Ag_@03
001g_GNm00Ig_@03001kgW_N02MkgP03001g_GNm00Mg_@03001g_GNm009g_@03001cW7>L009cW003
001_Nfmk009_N`03001_Nfmk009_N`05001[FV]JJeX00003JeX01000IcUW>FLi;`0017oo0@000Goo
0Goo000KOol00`00Oomoo`02Oom<0003IcT01@00JeY[FV]J00000f]J00D006mkKg]_N`0000A_N`03
001cW7>L00=cW003001g_GNm00Ag_@03001g_GNm00Ig_@03001kgW_N02IkgP03001g_GNm00Qg_@03
001g_GNm009g_@03001cW7>L009cW003001_Nfmk009_N`03001_Nfmk009_N`05001[FV]JJeX00003
JeX01000IcUW>FLi;`0017oo0@000Goo0Goo000KOol20003Oom<0003IcT01@00JeY[FV]J00000f]J
00D006mkKg]_N`0000A_N`03001cW7>L00=cW003001g_GNm00Ag_@03001g_GNm00Ig_@03001kgW_N
02EkgP03001g_GNm00Qg_@03001g_GNm00=g_@03001cW7>L009cW003001_Nfmk009_N`03001_Nfmk
009_N`05001[FV]JJeX00003JeX01000IcUW>FLi;`0017oo0@000Goo0Goo000KOol00`00Oomoo`02
Oom<0003IcT01@00JeY[FV]J00000f]J00D006mkKg]_N`0000A_N`03001cW7>L00=cW003001g_GNm
00Eg_@03001g_GNm00Ig_@03001kgW_N02AkgP03001g_GNm00Qg_@03001g_GNm00=g_@03001cW7>L
009cW003001_Nfmk009_N`03001_Nfmk009_N`05001[FV]JJeX00003JeX01000IcUW>FLi;`0017oo
0@000Goo0Goo000KOol00`00Oomoo`02Oom<0003IcT01@00JeY[FV]J00000f]J00D006mkKg]_N`00
00A_N`03001cW7>L00=cW003001g_GNm00Eg_@03001g_GNm00Ig_@03001kgW_N02=kgP03001g_GNm
00Ug_@03001g_GNm00=g_@03001cW7>L009cW003001_Nfmk009_N`03001_Nfmk009_N`05001[FV]J
JeX00003JeX01000IcUW>FLi;`0017oo0@000Goo0Goo000KOol00`00Oomoo`02Oom<0003IcT01@00
JeY[FV]J00000f]J00D006mkKg]_N`0000A_N`03001cW7>L00=cW003001g_GNm00Eg_@03001g_GNm
00Ig_@03001kgW_N02=kgP03001g_GNm00Ug_@03001g_GNm00=g_@03001cW7>L009cW003001_Nfmk
009_N`03001_Nfmk009_N`05001[FV]JJeX00003JeX01000IcUW>FLi;`0017oo0@000Goo0Goo000K
Ool00`00Oomoo`02Oom<0003IcT01@00JeY[FV]J00000f]J00D006mkKg]_N`0000A_N`03001cW7>L
00=cW003001g_GNm00Ig_@03001g_GNm00Ig_@03001kgW_N025kgP03001g_GNm00Ug_@03001g_GNm
00Ag_@03001cW7>L009cW003001_Nfmk009_N`03001_Nfmk009_N`05001[FV]JJeX00003JeX01000
IcUW>FLi;`0017oo0@000Goo0Goo000KOol00`00Oomoo`02Oom<0003IcT01@00JeY[FV]J00000f]J
00D006mkKg]_N`0000E_N`03001cW7>L00=cW003001g_GNm00Eg_@03001g_GNm00Ig_@03001kgW_N
021kgP03001g_GNm00Yg_@03001g_GNm00=g_@03001cW7>L009cW003001_Nfmk00=_N`03001_Nfmk
009_N`05001[FV]JJeX00003JeX01000IcUW>FLi;`0017oo0@000Goo0Goo000KOol00`00Oomoo`02
Oom<0003IcT01@00JeY[FV]J00000f]J00<006mkKg/00Vmk00<006mkKg/00Vmk00<007>LLi`00g>L
00<007NmMkd01GNm00<007NmMkd01gNm00<007_NNmh07W_N00<007NmMkd02WNm00<007NmMkd017Nm
00<007>LLi`00W>L00<006mkKg/00fmk00<006mkKg/00Vmk00D006]JJeY[FP0000=[FP04001W>FLi
IcT_0004Ool10001Ool1Ool001]oo`03001oogoo009ood`000=W>@05001[FV]JJeX00004JeX01@00
Kg]_Nfmk000016mk00<007>LLi`00g>L00<007NmMkd01WNm00<007NmMkd01gNm00<007_NNmh077_N
00<007NmMkd02gNm00<007NmMkd017Nm00<007>LLi`00W>L00<006mkKg/00Vmk00<006mkKg/00Vmk
00<006]JJeX00V]J00D006]JJeY[FP0000=W>Bl000Aoo`40005oo`5oo`006goo0P000gooC0000fLi
00D006]JJeY[FP0000A[FP05001_NfmkKg/00004Kg/00`00LiacW003Li`00`00Mkeg_@06Mkd00`00
Mkeg_@07Mkd00`00NmikgP0KNmh00`00Mkeg_@0;Mkd00`00Mkeg_@05Mkd00`00LiacW002Li`00`00
Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00JeY[FP02JeX01@00JeY[FV]J00000fLi;`0017oo0@000Goo
0Goo000KOol00`00Oomoo`02Oom<0003IcT01@00JeY[FV]J000016]J00D006mkKg]_N`0000A_N`03
001cW7>L00AcW003001g_GNm00Eg_@03001g_GNm00Qg_@03001kgW_N01UkgP03001g_GNm00ag_@03
001g_GNm00Eg_@03001cW7>L009cW003001_Nfmk009_N`03001_Nfmk009_N`03001[FV]J009[FP05
001[FV]JJeX00003IcT_0004Ool10001Ool1Ool001]oo`03001oogoo009ood`000=W>@05001[FV]J
JeX00004JeX01@00Kg]_Nfmk00001Fmk00<007>LLi`00g>L00<007NmMkd01WNm00<007NmMkd01gNm
00<007_NNmh067_N00<007NmMkd037Nm00<007NmMkd01GNm00<007>LLi`00W>L00<006mkKg/00fmk
00<006mkKg/00Vmk00<006]JJeX00V]J00D006]JJeY[FP0000=W>Bl000Aoo`40005oo`5oo`006goo
00<007ooOol00WooC0000fLi00D006]JJeY[FP0000A[FP05001_NfmkKg/00005Kg/00`00LiacW003
Li`00`00Mkeg_@06Mkd00`00Mkeg_@08Mkd2000GNmh00`00Mkeg_@0=Mkd00`00Mkeg_@05Mkd00`00
LiacW002Li`00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00JeY[FP02JeX01@00JeY[FV]J00000fLi
;`0017oo0@000Goo0Goo000KOol00`00Oomoo`02Oom=0003IcT01@00JeY[FV]J00000f]J00<006mk
Kg/00Vmk00<006mkKg/00Vmk00<007>LLi`017>L00<007NmMkd01GNm00<007NmMkd02WNm0P005G_N
00<007NmMkd037Nm00<007NmMkd01WNm00<007>LLi`00W>L00<006mkKg/00fmk00<006mkKg/00Vmk
00D006]JJeY[FP0000=[FP04001W>FLiIcT`0004Ool10001Ool1Ool001]oo`03001oogoo009oodd0
00=W>@05001[FV]JJeX00003JeX00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00LiacW004Li`00`00
Mkeg_@06Mkd00`00Mkeg_@0;Mkd3000ANmh00`00Mkeg_@0=Mkd00`00Mkeg_@06Mkd00`00LiacW002
Li`00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/01@00JeY[FV]J00000f]J00@006LiIcUW>C0000Aoo`40
005oo`5oo`006goo00<007ooOol00WooC@000fLi00D006]JJeY[FP0000A[FP05001_NfmkKg/00005
Kg/00`00LiacW003Li`00`00Mkeg_@06Mkd00`00Mkeg_@0>Mkd2000>Nmh00`00Mkeg_@0=Mkd00`00
Mkeg_@06Mkd00`00LiacW003Li`00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/01@00JeY[FV]J00000f]J
00@006LiIcUW>C0000Aoo`40005oo`5oo`006goo00<007ooOol00WooC@000fLi00D006]JJeY[FP00
00A[FP05001_NfmkKg/00005Kg/00`00LiacW003Li`00`00Mkeg_@06Mkd00`00Mkeg_@0@Mkd2000;
Nmh00`00Mkeg_@0>Mkd00`00Mkeg_@06Mkd00`00LiacW002Li`00`00Kg]_N`04Kg/00`00Kg]_N`02
Kg/01@00JeY[FV]J00000f]J00@006LiIcUW>C0000Aoo`40005oo`5oo`006goo0P000gooC@000fLi
00D006]JJeY[FP0000A[FP05001_NfmkKg/00005Kg/00`00LiacW004Li`00`00Mkeg_@06Mkd00`00
Mkeg_@0AMkd20008Nmh00`00Mkeg_@0>Mkd00`00Mkeg_@07Mkd00`00LiacW002Li`00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00JeY[FP02JeX01@00JeY[FV]J00000fLi<00017oo0@000Goo0Goo000K
Ool00`00Oomoo`02Oom=0003IcT01@00JeY[FV]J000016]J00D006mkKg]_N`0000E_N`03001cW7>L
00AcW003001g_GNm00Ig_@03001g_GNm01=g_@<000AkgP03001g_GNm00mg_@03001g_GNm00Mg_@03
001cW7>L009cW003001_Nfmk00=_N`03001_Nfmk009_N`03001[FV]J009[FP05001[FV]JJeX00003
IcT`0004Ool10001Ool1Ool001]oo`03001oogoo009oodd000=W>@05001[FV]JJeX00004JeX00`00
Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00LiacW004Li`00`00Mkeg_@06Mkd00`00Mkeg_@0FMkd20000
0g_N001g_@0@Mkd00`00Mkeg_@08Mkd00`00LiacW002Li`00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/0
0`00JeY[FP02JeX01@00JeY[FV]J00000fLi<00017oo0@000Goo0Goo000KOol00`00Oomoo`02Oom=
0003IcT01@00JeY[FV]J000016]J00<006mkKg/00Vmk00<006mkKg/00fmk00<007>LLi`017>L00<0
07NmMkd01WNm00<007NmMkd05gNm00<007NmMkd047Nm00<007NmMkd01gNm00<007>LLi`00g>L00<0
06mkKg/00fmk00<006mkKg/00Vmk00<006]JJeX00V]J00D006]JJeY[FP0000=W>C0000Aoo`40005o
o`5oo`006goo00<007ooOol00WooC@000fLi00D006]JJeY[FP0000A[FP03001_Nfmk009_N`03001_
Nfmk00=_N`03001cW7>L00AcW003001g_GNm00Ig_@03001g_GNm02Ug_@03001g_GNm00Qg_@03001c
W7>L00=cW003001_Nfmk00=_N`03001_Nfmk009_N`03001[FV]J009[FP05001[FV]JJeX00003IcT`
0004Ool10001Ool1Ool001]oo`03001oogoo009oodd000=W>@05001[FV]JJeX00004JeX00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/00`00LiacW004Li`00`00Mkeg_@06Mkd00`00Mkeg_@0YMkd00`00Mkeg
_@08Mkd00`00LiacW003Li`00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00JeY[FP02JeX01@00JeY[
FV]J00000fLi<00017oo0@000Goo0Goo0003Ool50003Ool01000Oomoogoo0`002Goo00<007ooOol0
0WooC@000fLi00D006]JJeY[FP0000A[FP03001_Nfmk009_N`03001_Nfmk00A_N`03001cW7>L00Ac
W003001g_GNm00Ig_@03001g_GNm02Qg_@03001g_GNm00Mg_@03001cW7>L00AcW003001_Nfmk00=_
N`03001_Nfmk009_N`03001[FV]J009[FP05001[FV]JJeX00003IcT`0004Ool10001Ool1Ool000Eo
o`03001oogoo00Ioo`05001oogooOol00008Ool00`00Oomoo`02Oom=0003IcT01@00JeY[FV]J0000
16]J00<006mkKg/00fmk00<006mkKg/00fmk00<007>LLi`017>L00<007NmMkd01gNm00<007NmMkd0
9WNm00<007NmMkd027Nm00<007>LLi`00g>L00<006mkKg/00fmk00<006mkKg/00fmk00<006]JJeX0
0V]J00D006]JJeY[FP0000=W>C0000Aoo`40005oo`5oo`001Goo00<007ooOol01Goo00<007ooOol0
0goo00<007ooOol01Goo00<007ooOol00WooC@000fLi00<006]JJeX00V]J00<006]JJeX00V]J00<0
06mkKg/00Vmk00<006mkKg/00fmk00<007>LLi`01G>L00<007NmMkd01gNm00<007NmMkd097Nm00<0
07NmMkd027Nm00<007>LLi`017>L00<006mkKg/00fmk00<006mkKg/00Vmk00<006]JJeX00V]J00D0
06]JJeY[FP0000AW>C0000Aoo`40005oo`5oo`001Goo00<007ooOol01Goo00<007ooOol00goo00<0
07ooOol01Goo0P000gooCP000fLi00D006]JJeY[FP0000A[FP03001_Nfmk009_N`03001_Nfmk00A_
N`03001cW7>L00AcW003001g_GNm00Mg_@03001g_GNm02=g_@03001g_GNm00Ug_@03001cW7>L00Ac
W003001_Nfmk00=_N`03001_Nfmk009_N`03001[FV]J009[FP05001[FV]JJeX00003IcTa0003Ool2
0002Ool000Eoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo009oodh0
00=W>@05001[FV]JJeX00004JeX00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/00`00LiacW004Li`00`00
Mkeg_@08Mkd00`00Mkeg_@0QMkd00`00Mkeg_@09Mkd00`00LiacW005Li`00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/00`00JeY[FP02JeX01@00JeY[FV]J00000fLi<@0017oo0@000Goo0Goo0005Ool00`00
Oomoo`05Ool20003Ool00`00Oomoo`06Ool00`00Oomoo`02Oom>0003IcT01@00JeY[FV]J000016]J
00<006mkKg/00Vmk00<006mkKg/016mk00<007>LLi`01G>L00<007NmMkd027Nm00<007NmMkd07gNm
00<007NmMkd02WNm00<007>LLi`01G>L00<006mkKg/00Vmk00<006mkKg/00fmk00<006]JJeX00V]J
00D006]JJeY[FP0000=W>C4000Aoo`40005oo`5oo`001Goo00<007ooOol01Goo00<007oo00000P00
2Goo00<007ooOol00WooCP000fLi00D006]JJeY[FP0000A[FP03001_Nfmk00=_N`03001_Nfmk00A_
N`03001cW7>L00AcW003001g_GNm00Qg_@03001g_GNm01ig_@03001g_GNm00Yg_@03001cW7>L00Ec
W003001_Nfmk00=_N`03001_Nfmk00=_N`03001[FV]J009[FP05001[FV]JJeX00003IcTa0004Ool1
0001Ool1Ool000Eoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo009oodh000=W>@05001[
FV]JJeX00004JeX00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00LiacW005Li`00`00Mkeg_@08Mkd0
0`00Mkeg_@0LMkd00`00Mkeg_@0;Mkd00`00LiacW005Li`00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/0
0`00JeY[FP02JeX01@00JeY[FV]J00000fLi<@0017oo0@000Goo0Goo0005Ool00`00Oomoo`06Ool0
0`00Oomoo`0:Ool00`00Oomoo`02Oom>0003IcT00`00JeY[FP02JeX00`00JeY[FP02JeX00`00Kg]_
N`02Kg/00`00Kg]_N`04Kg/00`00LiacW005Li`00`00Mkeg_@09Mkd00`00Mkeg_@0JMkd00`00Mkeg
_@0;Mkd00`00LiacW006Li`00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00JeY[FP02JeX00`00JeY[
FP02JeX01000IcUW>FLi<@0017oo0@000Goo0Goo0003Ool30009Ool2000:Ool00`00Oomoo`02Oom>
0003IcT00`00JeY[FP02JeX00`00JeY[FP02JeX00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Liac
W005Li`00`00Mkeg_@09Mkd2000IMkd00`00Mkeg_@0<Mkd00`00LiacW006Li`00`00Kg]_N`02Kg/0
0`00Kg]_N`03Kg/00`00JeY[FP02JeX01@00JeY[FV]J000016Li<@0017oo0@000Goo0Goo0005Ool0
0`00Oomoo`09Ool30007Ool00`00Oomoo`02Oom>0003IcT00`00JeY[FP02JeX00`00JeY[FP02JeX0
0`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00LiacW005Li`00`00Mkeg_@0;Mkd00`00Mkeg_@0EMkd0
0`00Mkeg_@0<Mkd00`00LiacW006Li`00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00JeY[FP02JeX0
1@00JeY[FV]J000016Li<@0017oo0@000Goo0Goo000KOol20003Oom>0003IcT00`00JeY[FP02JeX0
0`00JeY[FP02JeX00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00LiacW006Li`00`00Mkeg_@0;Mkd0
0`00Mkeg_@0CMkd00`00Mkeg_@0=Mkd00`00LiacW006Li`00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/0
0`00JeY[FP02JeX01@00JeY[FV]J000016Li<@0017oo0@000Goo0Goo000KOol00`00Oomoo`02Oom?
0003IcT01@00JeY[FV]J000016]J00<006mkKg/00fmk00<006mkKg/01Fmk00<007>LLi`01G>L00<0
07NmMkd037Nm0P004WNm00<007NmMkd03GNm00<007>LLi`01g>L00<006mkKg/00Vmk00<006mkKg/0
16mk00<006]JJeX00V]J00D006]JJeY[FP0000=W>C8000Aoo`40005oo`5oo`006goo00<007ooOol0
0WooC`000fLi00D006]JJeY[FP0000A[FP03001_Nfmk00=_N`03001_Nfmk00E_N`03001cW7>L00Ec
W003001g_GNm00ig_@03001g_GNm00ig_@03001g_GNm00ig_@03001cW7>L00McW003001_Nfmk009_
N`03001_Nfmk00A_N`03001[FV]J009[FP05001[FV]JJeX00003IcTb0004Ool10001Ool1Ool001]o
o`03001oogoo009oodl000=W>@03001[FV]J009[FP03001[FV]J009[FP03001_Nfmk009_N`03001_
Nfmk00E_N`03001cW7>L00IcW003001g_GNm00ig_@03001g_GNm00ag_@03001g_GNm00ig_@03001c
W7>L00QcW003001_Nfmk009_N`03001_Nfmk00=_N`03001[FV]J009[FP03001[FV]J009[FP04001W
>FLiIcTb0004Ool10001Ool1Ool001]oo`03001oogoo009oodl000=W>@03001[FV]J009[FP03001[
FV]J009[FP03001_Nfmk00=_N`03001_Nfmk00E_N`03001cW7>L00EcW003001g_GNm00mg_@03001g
_GNm00Yg_@03001g_GNm00mg_@03001cW7>L00McW003001_Nfmk009_N`03001_Nfmk00A_N`03001[
FV]J009[FP03001[FV]J009[FP04001W>FLiIcTb0004Ool10001Ool1Ool001]oo`03001oogoo009o
odl000=W>@03001[FV]J009[FP03001[FV]J009[FP03001_Nfmk00=_N`03001_Nfmk00E_N`03001c
W7>L00IcW003001g_GNm00mg_@`0015g_@03001cW7>L00QcW003001_Nfmk009_N`03001_Nfmk00A_
N`03001[FV]J009[FP03001[FV]J009[FP04001W>FLiIcTb0004Ool10001Ool1Ool001]oo`03001o
ogoo009oodl000=W>@03001[FV]J009[FP03001[FV]J009[FP03001_Nfmk00=_N`03001_Nfmk00E_
N`03001cW7>L00IcW003001g_GNm02ag_@03001cW7>L00QcW003001_Nfmk009_N`03001_Nfmk00A_
N`03001[FV]J009[FP03001[FV]J009[FP04001W>FLiIcTb0004Ool10001Ool1Ool001]oo`03001o
ogoo009oodl000=W>@03001[FV]J009[FP03001[FV]J009[FP03001_Nfmk00A_N`03001_Nfmk00A_
N`03001cW7>L00McW003001g_GNm02Yg_@03001cW7>L00QcW003001_Nfmk009_N`03001_Nfmk00E_
N`03001[FV]J009[FP03001[FV]J009[FP04001W>FLiIcTb0004Ool10001Ool1Ool001]oo`8000=o
odl000=W>@03001[FV]J00=[FP03001[FV]J009[FP03001_Nfmk00=_N`03001_Nfmk00E_N`03001c
W7>L00McW003001g_GNm02Mg_@8000]cW003001_Nfmk009_N`03001_Nfmk00A_N`03001[FV]J009[
FP03001[FV]J009[FP03001W>FLi009W>C8000Aoo`40005oo`5oo`006goo00<007ooOol00WooC`00
16Li00<006]JJeX00V]J00<006]JJeX00V]J00<006mkKg/00fmk00<006mkKg/01Fmk00<007>LLi`0
27>L00<007NmMkd09GNm00<007>LLi`02W>L00<006mkKg/00fmk00<006mkKg/016mk00<006]JJeX0
0V]J00<006]JJeX00V]J00@006LiIcUW>C<000Aoo`40005oo`5oo`006goo00<007ooOol00WooD000
0fLi00<006]JJeX00V]J00<006]JJeX00V]J00<006mkKg/016mk00<006mkKg/01Fmk00<007>LLi`0
1g>L00<007NmMkd097Nm00<007>LLi`02W>L00<006mkKg/00fmk00<006mkKg/01Fmk00<006]JJeX0
0V]J00<006]JJeX00V]J00@006LiIcUW>C<000Aoo`40005oo`5oo`006goo00<007ooOol00WooD000
0fLi00<006]JJeX00f]J00<006]JJeX00V]J00<006mkKg/00fmk00<006mkKg/01Fmk00<007>LLi`0
27>L00<007NmMkd08WNm00<007>LLi`02g>L00<006mkKg/00fmk00<006mkKg/016mk00<006]JJeX0
0f]J00<006]JJeX00V]J00@006LiIcUW>C<000Aoo`40005oo`5oo`006goo00<007ooOol00WooD000
0fLi00<006]JJeX00f]J00<006]JJeX00V]J00<006mkKg/016mk00<006mkKg/01Fmk00<007>LLi`0
27>L00<007NmMkd087Nm00<007>LLi`02g>L00<006mkKg/016mk00<006mkKg/016mk00<006]JJeX0
0V]J00<006]JJeX00V]J00<006LiIcT00VLi<`0017oo0@000Goo0Goo000KOol00`00Oomoo`02Oom@
0003IcT00`00JeY[FP03JeX00`00JeY[FP02JeX00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/00`00Liac
W009Li`00`00Mkeg_@0MMkd2000>Li`00`00Kg]_N`04Kg/00`00Kg]_N`04Kg/00`00JeY[FP02JeX0
0`00JeY[FP02JeX00`00IcUW>@02IcTc0004Ool10001Ool1Ool001]oo`03001oogoo009ooe0000AW
>@03001[FV]J009[FP03001[FV]J00=[FP03001_Nfmk00A_N`03001_Nfmk00E_N`03001cW7>L00Qc
W003001g_GNm01ag_@03001cW7>L00ecW003001_Nfmk00E_N`03001_Nfmk00=_N`03001[FV]J00=[
FP03001[FV]J009[FP04001W>FLiIcTd0004Ool10001Ool1Ool001]oo`03001oogoo009ooe0000AW
>@03001[FV]J00=[FP03001[FV]J009[FP03001_Nfmk00A_N`03001_Nfmk00E_N`03001cW7>L00Uc
W003001g_GNm01Yg_@03001cW7>L00ecW003001_Nfmk00E_N`03001_Nfmk00A_N`03001[FV]J00=[
FP03001[FV]J009[FP04001W>FLiIcTd0004Ool10001Ool1Ool001]oo`03001oogoo009ooe0000AW
>@03001[FV]J00=[FP03001[FV]J009[FP03001_Nfmk00A_N`03001_Nfmk00I_N`03001cW7>L00Uc
W003001g_GNm01Qg_@03001cW7>L00icW003001_Nfmk00E_N`03001_Nfmk00A_N`03001[FV]J00=[
FP03001[FV]J009[FP04001W>FLiIcTd0004Ool10001Ool1Ool001]oo`8000=ooe0000AW>@03001[
FV]J00=[FP03001[FV]J009[FP03001_Nfmk00E_N`03001_Nfmk00E_N`03001cW7>L00YcW08001Ig
_@80011cW003001_Nfmk00I_N`03001_Nfmk00A_N`03001[FV]J009[FP03001[FV]J009[FP03001W
>FLi009W>C@000Aoo`40005oo`5oo`006goo00<007ooOol00WooD00016Li00<006]JJeX00f]J00<0
06]JJeX00f]J00<006mkKg/016mk00<006mkKg/01Vmk00<007>LLi`02g>L0P004gNm00<007>LLi`0
47>L00<006mkKg/01Vmk00<006mkKg/00fmk00<006]JJeX00f]J00<006]JJeX00V]J00<006LiIcT0
0VLi=00017oo0@000Goo0Goo000KOol00`00Oomoo`02OomA0003IcT00`00JeY[FP03JeX00`00JeY[
FP03JeX00`00Kg]_N`05Kg/00`00Kg]_N`05Kg/00`00LiacW00=Li`2000@Mkd00`00LiacW00@Li`0
0`00Kg]_N`07Kg/00`00Kg]_N`03Kg/00`00JeY[FP03JeX00`00JeY[FP02JeX00`00IcUW>@02IcTd
0004Ool10001Ool1Ool001]oo`03001oogoo009ooe4000AW>@03001[FV]J00=[FP03001[FV]J009[
FP03001_Nfmk00E_N`03001_Nfmk00I_N`03001cW7>L00icW003001g_GNm00ag_@03001cW7>L011c
W003001_Nfmk00M_N`03001_Nfmk00A_N`03001[FV]J00=[FP03001[FV]J009[FP04001W>FLiIcTe
0004Ool10001Ool1Ool001]oo`03001oogoo009ooe4000AW>@03001[FV]J00=[FP03001[FV]J00=[
FP03001_Nfmk00A_N`03001_Nfmk00I_N`03001cW7>L00mcW08000]g_@03001cW7>L015cW003001_
Nfmk00M_N`03001_Nfmk00=_N`03001[FV]J00=[FP03001[FV]J009[FP03001W>FLi009W>CD000Ao
o`40005oo`5oo`000goo1@000goo00@007ooOomoo`<000Uoo`03001oogoo009ooe4000AW>@03001[
FV]J00=[FP03001[FV]J00=[FP03001_Nfmk00E_N`03001_Nfmk00I_N`03001cW7>L011cW0H000Ag
_@03001cW7>L015cW003001_Nfmk00Q_N`03001_Nfmk00=_N`03001[FV]J00=[FP03001[FV]J009[
FP03001W>FLi009W>CD000Aoo`40005oo`5oo`001Goo00<007ooOol01Woo00D007ooOomoo`0000Qo
o`03001oogoo009ooe4000AW>@03001[FV]J00=[FP03001[FV]J00=[FP03001_Nfmk00E_N`03001_
Nfmk00I_N`03001cW7>L01IcW0@001AcW003001_Nfmk00Q_N`03001_Nfmk00=_N`03001[FV]J00=[
FP03001[FV]J009[FP03001W>FLi009W>CD000Aoo`40005oo`5oo`001Goo00<007ooOol01Goo00<0
07ooOol00goo00<007ooOol01Goo00<007ooOol00WooD@0016Li00<006]JJeX00f]J00<006]JJeX0
16]J00<006mkKg/016mk00<006mkKg/01fmk00<007>LLi`0;7>L00<006mkKg/026mk00<006mkKg/0
0fmk00<006]JJeX00f]J00<006]JJeX00f]J00<006LiIcT00VLi=@0017oo0@000Goo0Goo0005Ool0
0`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`05Ool20003OomB0004IcT00`00JeY[FP03JeX0
0`00JeY[FP03JeX00`00Kg]_N`05Kg/00`00Kg]_N`07Kg/00`00LiacW00ZLi`00`00Kg]_N`08Kg/0
0`00Kg]_N`04Kg/00`00JeY[FP03JeX00`00JeY[FP02JeX00`00IcUW>@03IcTe0003Ool20002Ool0
00Eoo`03001oogoo00Ioo`05001oogooOol00008Ool00`00Oomoo`02OomB0004IcT00`00JeY[FP03
JeX00`00JeY[FP03JeX00`00Kg]_N`05Kg/00`00Kg]_N`08Kg/00`00LiacW00WLi`2000;Kg/00`00
Kg]_N`03Kg/00`00JeY[FP04JeX00`00JeY[FP02JeX00`00IcUW>@02IcTf0004Ool10001Ool1Ool0
00Eoo`03001oogoo00Moo`<000Uoo`03001oogoo009ooe8000AW>@03001[FV]J00=[FP03001[FV]J
00A[FP03001_Nfmk00A_N`03001_Nfmk00U_N`03001cW7>L02EcW003001_Nfmk00Y_N`03001_Nfmk
00A_N`03001[FV]J00=[FP03001[FV]J00=[FP03001W>FLi009W>CH000Aoo`40005oo`5oo`001Goo
00<007ooOol01Woo00D007ooOomoo`0000Qoo`03001oogoo009ooe8000EW>@03001[FV]J00=[FP03
001[FV]J00=[FP03001_Nfmk00E_N`03001_Nfmk00U_N`03001cW7>L02=cW003001_Nfmk00]_N`03
001_Nfmk00=_N`03001[FV]J00A[FP03001[FV]J00=[FP03001W>FLi009W>CH000Aoo`40005oo`5o
o`001Goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00WooDP001FLi
00<006]JJeX00f]J00<006]JJeX016]J00<006mkKg/016mk00<006mkKg/02Fmk00<007>LLi`08G>L
0P003Fmk00<006mkKg/016mk00<006]JJeX016]J00<006]JJeX00f]J00<006LiIcT00VLi=P0017oo
0@000Goo0Goo0005Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`02
OomC0004IcT00`00JeY[FP03JeX00`00JeY[FP04JeX00`00Kg]_N`05Kg/00`00Kg]_N`09Kg/00`00
LiacW00OLi`00`00Kg]_N`0<Kg/00`00Kg]_N`05Kg/00`00JeY[FP03JeX00`00JeY[FP03JeX00`00
IcUW>@03IcTf0004Ool10001Ool1Ool000=oo`<000Qoo`05001oogooOol00008Ool00`00Oomoo`02
OomC0005IcT00`00JeY[FP02JeX00`00JeY[FP04JeX00`00Kg]_N`06Kg/00`00Kg]_N`09Kg/00`00
LiacW00MLi`00`00Kg]_N`0=Kg/00`00Kg]_N`04Kg/00`00JeY[FP04JeX00`00JeY[FP03JeX00`00
IcUW>@03IcTf0004Ool10001Ool1Ool000Eoo`03001oogoo00Moo`<000Uoo`03001oogoo009ooe<0
00EW>@03001[FV]J00=[FP03001[FV]J00A[FP03001_Nfmk00E_N`03001_Nfmk00Y_N`03001cW7>L
01]cW003001_Nfmk00e_N`03001_Nfmk00E_N`03001[FV]J00A[FP03001[FV]J00=[FP03001W>FLi
009W>CL000Aoo`40005oo`5oo`006goo0P000gooD`001FLi00<006]JJeX00f]J00<006]JJeX016]J
00<006mkKg/01Vmk00<006mkKg/02Vmk00<007>LLi`067>L0P0046mk00<006mkKg/01Fmk00<006]J
JeX00f]J00<006]JJeX016]J00<006LiIcT00VLi=`0017oo0@000Goo0Goo000KOol00`00Oomoo`02
OomD0005IcT00`00JeY[FP02JeX00`00JeY[FP04JeX00`00Kg]_N`06Kg/00`00Kg]_N`0;Kg/3000F
Li`00`00Kg]_N`0?Kg/00`00Kg]_N`06Kg/00`00JeY[FP03JeX00`00JeY[FP03JeX00`00IcUW>@03
IcTg0004Ool10001Ool1Ool001]oo`03001oogoo009ooe@000EW>@03001[FV]J009[FP03001[FV]J
00E[FP03001_Nfmk00I_N`03001_Nfmk00e_N`<0019cW003001_Nfmk00m_N`03001_Nfmk00I_N`03
001[FV]J00A[FP03001[FV]J00=[FP03001W>FLi00=W>CL000Aoo`40005oo`5oo`006goo00<007oo
Ool00WooE0001FLi00<006]JJeX00f]J00<006]JJeX016]J00<006mkKg/01Vmk00<006mkKg/046mk
0`003G>L0P004Vmk00<006mkKg/01Vmk00<006]JJeX00f]J00<006]JJeX016]J00<006LiIcT00fLi
=`0017oo0@000Goo0Goo000KOol00`00Oomoo`02OomD0005IcT00`00JeY[FP03JeX00`00JeY[FP05
JeX00`00Kg]_N`06Kg/00`00Kg]_N`0BKg/30009Li`00`00Kg]_N`0AKg/00`00Kg]_N`07Kg/00`00
JeY[FP03JeX00`00JeY[FP04JeX00`00IcUW>@03IcTg0004Ool10001Ool1Ool001]oo`03001oogoo
009ooe@000IW>@03001[FV]J009[FP03001[FV]J00E[FP03001_Nfmk00M_N`03001_Nfmk01A_N`<0
00EcW003001_Nfmk019_N`03001_Nfmk00M_N`03001[FV]J00=[FP03001[FV]J00A[FP03001W>FLi
009W>CP000Aoo`40005oo`5oo`006goo00<007ooOol00WooE@001FLi00<006]JJeX00f]J00<006]J
JeX016]J00<006mkKg/01fmk00<006mkKg/05fmk0`0000=cW000Kg/04fmk00<006mkKg/01fmk00<0
06]JJeX00f]J00<006]JJeX016]J00<006LiIcT00fLi>00017oo0@000Goo0Goo000KOol00`00Oomo
o`02OomE0005IcT00`00JeY[FP03JeX00`00JeY[FP05JeX00`00Kg]_N`07Kg/00`00Kg]_N`0IKg/0
0`00Kg]_N`0BKg/00`00Kg]_N`08Kg/00`00JeY[FP03JeX00`00JeY[FP04JeX00`00IcUW>@03IcTh
0004Ool10001Ool1Ool001]oo`8000=ooeD000EW>@03001[FV]J00=[FP03001[FV]J00E[FP03001_
Nfmk00M_N`03001_Nfmk02i_N`03001_Nfmk00Q_N`03001[FV]J00=[FP03001[FV]J00A[FP03001W
>FLi00=W>CP000Aoo`40005oo`5oo`006goo00<007ooOol00WooEP001FLi00<006]JJeX00f]J00<0
06]JJeX01F]J00<006mkKg/01fmk00<006mkKg/0;6mk00<006mkKg/026mk00<006]JJeX00f]J00<0
06]JJeX016]J00<006LiIcT016Li>00017oo0@000Goo0Goo000KOol00`00Oomoo`02OomF0005IcT0
0`00JeY[FP03JeX00`00JeY[FP05JeX00`00Kg]_N`08Kg/00`00Kg]_N`0ZKg/00`00Kg]_N`08Kg/0
0`00JeY[FP04JeX00`00JeY[FP04JeX00`00IcUW>@03IcTi0004Ool10001Ool1Ool001]oo`03001o
ogoo009ooeH000EW>@03001[FV]J00A[FP03001[FV]J00E[FP03001_Nfmk00Q_N`03001_Nfmk02M_
N`8000]_N`03001[FV]J00=[FP03001[FV]J00E[FP03001W>FLi00=W>CT000Aoo`40005oo`5oo`00
6goo00<007ooOol00WooE`001FLi00<006]JJeX00f]J00<006]JJeX01F]J00<006mkKg/02Fmk00<0
06mkKg/09Fmk00<006mkKg/02Vmk00<006]JJeX016]J00<006]JJeX016]J00<006LiIcT016Li>@00
17oo0@000Goo0Goo000KOol00`00Oomoo`02OomG0005IcT00`00JeY[FP03JeX00`00JeY[FP06JeX0
0`00Kg]_N`09Kg/00`00Kg]_N`0RKg/2000<Kg/00`00JeY[FP05JeX00`00JeY[FP04JeX00`00IcUW
>@03IcTj0004Ool10001Ool1Ool001]oo`03001oogoo009ooeL000EW>@03001[FV]J00A[FP03001[
FV]J00I[FP03001_Nfmk00U_N`03001_Nfmk021_N`03001_Nfmk00a_N`03001[FV]J00A[FP03001[
FV]J00E[FP03001W>FLi00=W>CX000Aoo`40005oo`5oo`006goo00<007ooOol00WooF0001FLi00<0
06]JJeX00f]J00<006]JJeX01V]J00<006mkKg/02Vmk00<006mkKg/07Fmk0P003Vmk00<006]JJeX0
1F]J00<006]JJeX016]J00<006LiIcT016Li>P0017oo0@000Goo0Goo000KOol00`00Oomoo`02OomH
0005IcT00`00JeY[FP04JeX00`00JeY[FP06JeX00`00Kg]_N`0:Kg/00`00Kg]_N`0KKg/00`00Kg]_
N`0=Kg/00`00JeY[FP06JeX00`00JeY[FP04JeX00`00IcUW>@04IcTj0004Ool10001Ool1Ool001]o
o`8000=ooeP000EW>@03001[FV]J00A[FP03001[FV]J00M[FP03001_Nfmk00Y_N`03001_Nfmk01Q_
N`80011_N`03001[FV]J00E[FP03001[FV]J00E[FP03001W>FLi00=W>C/000Aoo`40005oo`5oo`00
6goo00<007ooOol00WooF@001FLi00<006]JJeX016]J00<006]JJeX01V]J00<006mkKg/02fmk0`00
5Vmk00<006mkKg/03fmk00<006]JJeX01V]J00<006]JJeX016]J00<006LiIcT016Li>`0017oo0@00
0Goo0Goo000KOol00`00Oomoo`02OomI0005IcT00`00JeY[FP04JeX00`00JeY[FP07JeX00`00Kg]_
N`0=Kg/3000AKg/2000AKg/00`00JeY[FP07JeX00`00JeY[FP04JeX00`00IcUW>@04IcTk0004Ool1
0001Ool1Ool001]oo`03001oogoo009ooeT000EW>@03001[FV]J00E[FP03001[FV]J00I[FP03001_
Nfmk011_N`@000a_N`03001_Nfmk015_N`03001[FV]J00I[FP03001[FV]J00E[FP03001W>FLi00AW
>C/000Aoo`40005oo`5oo`006goo00<007ooOol00WooFP001FLi00<006]JJeX016]J00<006]JJeX0
1f]J00<006mkKg/04fmk10001Vmk0P004fmk00<006]JJeX01f]J00<006]JJeX016]J00<006LiIcT0
16Li?00017oo0@000Goo0Goo000>Ool60007Ool00`00Oomoo`02OomJ0005IcT00`00JeY[FP04JeX0
0`00JeY[FP08JeX00`00Kg]_N`0FKg/30002Kg/00`00Kg]_N`0BKg/00`00JeY[FP08JeX00`00JeY[
FP04JeX00`00IcUW>@04IcTl0004Ool10001Ool1Ool000ioo`03001oogoo00=oo`03001oogoo00Ao
o`03001oogoo009ooeX000EW>@03001[FV]J00E[FP03001[FV]J00M[FP03001_Nfmk01U_N`8001E_
N`03001[FV]J00Q[FP03001[FV]J00A[FP03001W>FLi00AW>C`000Aoo`40005oo`5oo`003goo00<0
07ooOol02Goo00<007ooOol00WooFP001VLi00<006]JJeX016]J00<006]JJeX026]J00<006mkKg/0
;Vmk00<006]JJeX026]J00<006]JJeX016]J00<006LiIcT016Li?@0017oo0@000Goo0Goo000@Ool0
0`00Oomoo`08Ool20003OomJ0006IcT00`00JeY[FP05JeX00`00JeY[FP08JeX00`00Kg]_N`0/Kg/0
0`00JeY[FP09JeX00`00JeY[FP04JeX00`00IcUW>@04IcTm0003Ool20002Ool0015oo`03001oogoo
00Moo`03001oogoo0?moo`40005oo`5oo`004Woo00<007ooOol01Woo00<007ooOol0ogoo0@000Goo
0Goo000COol00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0kOol00`00Oomoo`0kOol00`00
Oomoo`0kOol00`00Oomoo`0lOol01@00Oomoogoo00000Woo000COol00`00Oomoo`05Ool00`00Oomo
o`02Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`0:Ool01@00Oomoogoo00000Woo000>Ool00`00Oomoo`02Ool00`00Oomoo`05Oooo00040002Ool0
00moo`04001oogoo003oOol>Ool0011oo`800?moo`moo`00ogoo8Goo003oOolQOol00?moob5oo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.25895, 0.332922, 0.008039, \
0.00602924}}]
}, Open  ]],

Cell["The compiled version is about twice as fast:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[\(Do[GaussianLogLikelihood[rr, {0, 1}], {1000}];\)], 
      Timing[\(Do[
            GaussianLogLikelihood[rr, {0, 1}, 
              Compiled \[Rule] True], {1000}];\)]}\)], "Input",
  CellLabel->"In[467]:="],

Cell[BoxData[
    \({{2.25`\ Second, Null}, {1.0166666666627862`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[467]="]
}, Open  ]],

Cell[TextData[{
  "The log likelihood for a sample of size ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is calculated as:"
}], "Text"],

Cell[BoxData[
    \(TextForm\`\(-\ \(n\/2\)\) \((Log[\[Sigma]\^2] + \(\((x\&_ - \[Mu])\)\^2 \
+ s\^2\)\/\[Sigma]\^2)\)\ \ where\ s\^2 = \[Sum]\+\(j = 1\)\%n\((x\_j - x\&_)\
\)\^2\/\(n - 1\)\)], "NumberedEquation"],

Cell[TextData[{
  "This is not quite equal to the MLE: the denominator in the sample variance \
is ",
  Cell[BoxData[
      \(TraditionalForm\`n - 1\)]],
  ", not ",
  Cell[BoxData[
      \(TraditionalForm\`n\ , \ 
      giving\ the\ conventional\ unbiased\ \(\(estimate\)\(.\)\)\)]]
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(GaussianLogLikelihood[{{x\_1, \[Ellipsis]}, \[Ellipsis]}, {{\
\[Alpha]\_1, \[Beta]\_1}, \[Ellipsis]}, {\[Mu], \[Sigma]\^2}]\), \(gives\ the\
\ log\ likelihood\ for\ several\ samples, \ 
            where\ the\ mean\ and\ variance\ in\ sample\ k\ is\ \[Mu] + \
\[Alpha]\_k, \ \(\[Sigma]\^2\) \[Beta]\_k\)},
          {\(GaussianLogLikelihood[{{x\_1, \[Ellipsis]}, \[Ellipsis]}, {{\
\[Alpha]\_1, \[Beta]\_1}, \[Ellipsis]}, {\[Mu], \[Sigma]\^2}, 
              Compiled \[Rule] 
                True]\), \(is\ a\ compiled\ \(\(version\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->"additive models"]], "DefinitionBox"],

Cell[TextData[{
  "This gives three samples, drawn from distributions with  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{"\[Mu]", ",", 
            RowBox[{
              FormBox[\(\(\[Sigma]\^2\)\(}\)\),
                "TraditionalForm"], "=", \({\(-1\), 1\/2}\)}], 
            ",", \({0, 1}\), ",", \({1, 2}\), " "}]}], TraditionalForm]]],
  ".  Note that the sample variance is not close to the true value:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(rr2 = 
        Table[RandomArray[
            NormalDistribution[j, 2\^\(j/2\)], {100}], {j, \(-1\), 
            1}];\)\), "\[IndentingNewLine]", 
    \({Mean /@ rr2, Variance /@ rr2} // TableForm\)}], "Input",
  CellLabel->"In[91]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\(-0.9698152114845767`\), "0.03055955701030018`", 
            "0.9640092441577549`"},
          {"0.39338428282559634`", "0.8738686060748704`", 
            "1.8278296951208102`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[92]//TableForm="]
}, Open  ]],

Cell["This is the log likelihood of the true values:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GaussianLogLikelihood[
      rr2, {{\(-1\), 1\/2}, {0, 1}, {1, 2}}, {0, 1}]\)], "Input",
  CellLabel->"In[483]:="],

Cell[BoxData[
    \(\(-131.9566333684574`\)\)], "Output",
  CellLabel->"Out[483]="]
}, Open  ]],

Cell["\<\
This is a crude estimate of the mean and variance, given the sample \
effects {\[Alpha],\[Beta]}:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mv = {Mean[Mean /@ rr2], Mean[{2, 1, 1\/2}*Variance /@ rr2]}\)], "Input",\

  CellLabel->"In[484]:="],

Cell[BoxData[
    \({\(-0.031621393795222295`\), 0.8736449668430845`}\)], "Output",
  CellLabel->"Out[484]="]
}, Open  ]],

Cell["This is its log likelihood:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GaussianLogLikelihood[
      rr2, {{\(-1\), 1\/2}, {0, 1}, {1, 2}}, {Mean[Mean /@ rr2], 
        Mean[{2, 1, 1\/2}*Variance /@ rr2]}]\)], "Input",
  CellLabel->"In[485]:="],

Cell[BoxData[
    \(\(-130.53212670912671`\)\)], "Output",
  CellLabel->"Out[485]="]
}, Open  ]],

Cell[TextData[{
  "This shows the likelihood surface, assuming effects {\[Alpha],\[Beta]}=",
  Cell[BoxData[
      \({{\(-1\), 1\/2}, {0, 1}, {1, 2}}\)]],
  ", which here are the true effects."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ml = 
        GaussianLogLikelihood[
          rr2, {{\(-1\), 1\/2}, {0, 1}, {1, 2}}, {Mean[Mean /@ rr2], 
            Mean[{2, 1, 1\/2}*
                Variance /@ rr2]}];\)\), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        GaussianLogLikelihood[
          rr2, {{\(-1\), 1\/2}, {0, 1}, {1, 2}}, {\[Mu], 
            v}], {\[Mu], \(-0.5\), 0.5}, {v, 0.5, 1.5}, 
        Contours \[Rule] Range[ml - 10, ml]];\)\)}], "Input",
  CellLabel->"In[481]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.961538 -0.461538 0.961538 [
[.11538 -0.0125 -17.5312 -18 ]
[.11538 -0.0125 17.5312 0 ]
[.30769 -0.0125 -17.5312 -18 ]
[.30769 -0.0125 17.5312 0 ]
[.5 -0.0125 -6 -18 ]
[.5 -0.0125 6 0 ]
[.69231 -0.0125 -12 -18 ]
[.69231 -0.0125 12 0 ]
[.88462 -0.0125 -12 -18 ]
[.88462 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11538 -24 -9 ]
[-0.0125 .11538 0 9 ]
[-0.0125 .30769 -24 -9 ]
[-0.0125 .30769 0 9 ]
[-0.0125 .5 -12 -9 ]
[-0.0125 .5 0 9 ]
[-0.0125 .69231 -24 -9 ]
[-0.0125 .69231 0 9 ]
[-0.0125 .88462 -24 -9 ]
[-0.0125 .88462 0 9 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
gsave
.11538 -0.0125 -78.5312 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.30769 0 m
.30769 .00625 L
s
gsave
.30769 -0.0125 -78.5312 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -67 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.69231 0 m
.69231 .00625 L
s
gsave
.69231 -0.0125 -73 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.88462 0 m
.88462 .00625 L
s
gsave
.88462 -0.0125 -73 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.06731 0 m
.06731 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11538 m
.00625 .11538 L
s
gsave
-0.0125 .11538 -85 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .30769 m
.00625 .30769 L
s
gsave
-0.0125 .30769 -85 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -73 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .69231 m
.00625 .69231 L
s
gsave
-0.0125 .69231 -85 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .88462 m
.00625 .88462 L
s
gsave
-0.0125 .88462 -85 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .25962 m
.00375 .25962 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .74038 m
.00375 .74038 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .06731 m
.00375 .06731 L
s
0 .01923 m
.00375 .01923 L
s
0 .93269 m
.00375 .93269 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.25962 .99625 m
.25962 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.74038 .99625 m
.74038 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.06731 .99625 m
.06731 1 L
s
.01923 .99625 m
.01923 1 L
s
.93269 .99625 m
.93269 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11538 m
1 .11538 L
s
.99375 .30769 m
1 .30769 L
s
.99375 .5 m
1 .5 L
s
.99375 .69231 m
1 .69231 L
s
.99375 .88462 m
1 .88462 L
s
.125 Mabswid
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .06731 m
1 .06731 L
s
.99625 .01923 m
1 .01923 L
s
.99625 .93269 m
1 .93269 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.849 g
.43132 .13961 m
.5 .13945 L
.54596 .15659 L
.56868 .16852 L
.62634 .22527 L
.63736 .24255 L
.66061 .29396 L
.67941 .36264 L
.68593 .43132 L
.68254 .5 L
.66931 .56868 L
.64406 .63736 L
.63736 .65088 L
.60706 .70604 L
.56868 .74253 L
.51629 .77473 L
.5 .77999 L
.43132 .7798 L
.41578 .77473 L
.36264 .74188 L
.32511 .70604 L
.29396 .64935 L
.28805 .63736 L
.26278 .56868 L
.24953 .5 L
.24614 .43132 L
.25266 .36264 L
.2715 .29396 L
.29396 .24377 L
.30569 .22527 L
.36264 .16901 L
.38611 .15659 L
F
0 g
.43132 .13961 m
.5 .13945 L
.54596 .15659 L
.56868 .16852 L
.62634 .22527 L
.63736 .24255 L
.66061 .29396 L
.67941 .36264 L
.68593 .43132 L
.68254 .5 L
.66931 .56868 L
.64406 .63736 L
.63736 .65088 L
.60706 .70604 L
.56868 .74253 L
.51629 .77473 L
.5 .77999 L
.43132 .7798 L
.41578 .77473 L
.36264 .74188 L
.32511 .70604 L
.29396 .64935 L
.28805 .63736 L
.26278 .56868 L
.24953 .5 L
.24614 .43132 L
.25266 .36264 L
.2715 .29396 L
.29396 .24377 L
.30569 .22527 L
.36264 .16901 L
.38611 .15659 L
.43132 .13961 L
s
.863 g
.43132 .15049 m
.5 .15031 L
.52073 .15659 L
.56868 .18022 L
.6151 .22527 L
.63736 .26422 L
.64922 .29396 L
.66847 .36264 L
.67456 .43132 L
.66997 .5 L
.65447 .56868 L
.63736 .6141 L
.62834 .63736 L
.57845 .70604 L
.56868 .71411 L
.5 .75373 L
.43132 .75352 L
.36264 .71341 L
.35377 .70604 L
.30366 .63736 L
.29396 .61239 L
.27763 .56868 L
.26212 .5 L
.25752 .43132 L
.26363 .36264 L
.28289 .29396 L
.29396 .26592 L
.31702 .22527 L
.36264 .18078 L
.41134 .15659 L
F
0 g
.43132 .15049 m
.5 .15031 L
.52073 .15659 L
.56868 .18022 L
.6151 .22527 L
.63736 .26422 L
.64922 .29396 L
.66847 .36264 L
.67456 .43132 L
.66997 .5 L
.65447 .56868 L
.63736 .6141 L
.62834 .63736 L
.57845 .70604 L
.56868 .71411 L
.5 .75373 L
.43132 .75352 L
.36264 .71341 L
.35377 .70604 L
.30366 .63736 L
.29396 .61239 L
.27763 .56868 L
.26212 .5 L
.25752 .43132 L
.26363 .36264 L
.28289 .29396 L
.29396 .26592 L
.31702 .22527 L
.36264 .18078 L
.41134 .15659 L
.43132 .15049 L
s
.877 g
.36264 .19472 m
.43132 .16106 L
.5 .16091 L
.56868 .19407 L
.60132 .22527 L
.63708 .29396 L
.63736 .29492 L
.65665 .36264 L
.66225 .43132 L
.65623 .5 L
.63809 .56868 L
.63736 .57073 L
.60994 .63736 L
.56868 .68462 L
.54279 .70604 L
.5 .72667 L
.43132 .72645 L
.38928 .70604 L
.36264 .68387 L
.32222 .63736 L
.294 .56868 L
.29396 .56856 L
.27587 .5 L
.26985 .43132 L
.27545 .36264 L
.29396 .29684 L
.29482 .29396 L
.33088 .22527 L
F
0 g
.36264 .19472 m
.43132 .16106 L
.5 .16091 L
.56868 .19407 L
.60132 .22527 L
.63708 .29396 L
.63736 .29492 L
.65665 .36264 L
.66225 .43132 L
.65623 .5 L
.63809 .56868 L
.63736 .57073 L
.60994 .63736 L
.56868 .68462 L
.54279 .70604 L
.5 .72667 L
.43132 .72645 L
.38928 .70604 L
.36264 .68387 L
.32222 .63736 L
.294 .56868 L
.29396 .56856 L
.27587 .5 L
.26985 .43132 L
.27545 .36264 L
.29396 .29684 L
.29482 .29396 L
.33088 .22527 L
.36264 .19472 L
s
.89 g
.36264 .21124 m
.43132 .17184 L
.5 .17166 L
.56868 .21049 L
.58439 .22527 L
.62708 .29396 L
.63736 .33296 L
.64386 .36264 L
.64885 .43132 L
.64116 .5 L
.63736 .5206 L
.62397 .56868 L
.58441 .63736 L
.56868 .65339 L
.5 .69867 L
.43132 .69844 L
.36264 .65257 L
.34782 .63736 L
.30808 .56868 L
.29396 .51682 L
.29095 .5 L
.28326 .43132 L
.28825 .36264 L
.29396 .33593 L
.30493 .29396 L
.34784 .22527 L
F
0 g
.36264 .21124 m
.43132 .17184 L
.5 .17166 L
.56868 .21049 L
.58439 .22527 L
.62708 .29396 L
.63736 .33296 L
.64386 .36264 L
.64885 .43132 L
.64116 .5 L
.63736 .5206 L
.62397 .56868 L
.58441 .63736 L
.56868 .65339 L
.5 .69867 L
.43132 .69844 L
.36264 .65257 L
.34782 .63736 L
.30808 .56868 L
.29396 .51682 L
.29095 .5 L
.28326 .43132 L
.28825 .36264 L
.29396 .33593 L
.30493 .29396 L
.34784 .22527 L
.36264 .21124 L
s
.904 g
.43132 .18489 m
.5 .18468 L
.5645 .22527 L
.56868 .22753 L
.61478 .29396 L
.63194 .36264 L
.6351 .43132 L
.62776 .5 L
.60535 .56868 L
.56868 .62026 L
.55226 .63736 L
.5 .66955 L
.43132 .6693 L
.37981 .63736 L
.36264 .61937 L
.32683 .56868 L
.30425 .5 L
.29681 .43132 L
.30001 .36264 L
.31735 .29396 L
.36264 .22799 L
.36757 .22527 L
F
0 g
.43132 .18489 m
.5 .18468 L
.5645 .22527 L
.56868 .22753 L
.61478 .29396 L
.63194 .36264 L
.6351 .43132 L
.62776 .5 L
.60535 .56868 L
.56868 .62026 L
.55226 .63736 L
.5 .66955 L
.43132 .6693 L
.37981 .63736 L
.36264 .61937 L
.32683 .56868 L
.30425 .5 L
.29681 .43132 L
.30001 .36264 L
.31735 .29396 L
.36264 .22799 L
.36757 .22527 L
.43132 .18489 L
s
.918 g
.43132 .20074 m
.5 .20049 L
.54299 .22527 L
.56868 .24343 L
.59938 .29396 L
.61967 .36264 L
.62255 .43132 L
.61182 .5 L
.58003 .56868 L
.56868 .58358 L
.50342 .63736 L
.5 .63865 L
.43132 .63838 L
.42866 .63736 L
.36264 .58251 L
.3522 .56868 L
.32033 .5 L
.30951 .43132 L
.31242 .36264 L
.33283 .29396 L
.36264 .24433 L
.38908 .22527 L
F
0 g
.43132 .20074 m
.5 .20049 L
.54299 .22527 L
.56868 .24343 L
.59938 .29396 L
.61967 .36264 L
.62255 .43132 L
.61182 .5 L
.58003 .56868 L
.56868 .58358 L
.50342 .63736 L
.5 .63865 L
.43132 .63838 L
.42866 .63736 L
.36264 .58251 L
.3522 .56868 L
.32033 .5 L
.30951 .43132 L
.31242 .36264 L
.33283 .29396 L
.36264 .24433 L
.38908 .22527 L
.43132 .20074 L
s
.932 g
.43132 .2199 m
.5 .21961 L
.51239 .22527 L
.56868 .27265 L
.58007 .29396 L
.60406 .36264 L
.60633 .43132 L
.59057 .5 L
.56868 .54374 L
.54939 .56868 L
.5 .60611 L
.43132 .60581 L
.38268 .56868 L
.36264 .54249 L
.34165 .5 L
.32585 .43132 L
.32813 .36264 L
.35215 .29396 L
.36264 .27412 L
.41968 .22527 L
F
0 g
.43132 .2199 m
.5 .21961 L
.51239 .22527 L
.56868 .27265 L
.58007 .29396 L
.60406 .36264 L
.60633 .43132 L
.59057 .5 L
.56868 .54374 L
.54939 .56868 L
.5 .60611 L
.43132 .60581 L
.38268 .56868 L
.36264 .54249 L
.34165 .5 L
.32585 .43132 L
.32813 .36264 L
.35215 .29396 L
.36264 .27412 L
.41968 .22527 L
.43132 .2199 L
s
.945 g
.43132 .23357 m
.5 .23334 L
.55805 .29396 L
.56868 .31518 L
.58407 .36264 L
.58514 .43132 L
.56868 .48762 L
.56339 .5 L
.50192 .56868 L
.5 .56961 L
.43132 .56925 L
.43015 .56868 L
.36869 .5 L
.36264 .48567 L
.34709 .43132 L
.34816 .36264 L
.36264 .31701 L
.37402 .29396 L
F
0 g
.43132 .23357 m
.5 .23334 L
.55805 .29396 L
.56868 .31518 L
.58407 .36264 L
.58514 .43132 L
.56868 .48762 L
.56339 .5 L
.50192 .56868 L
.5 .56961 L
.43132 .56925 L
.43015 .56868 L
.36869 .5 L
.36264 .48567 L
.34709 .43132 L
.34816 .36264 L
.36264 .31701 L
.37402 .29396 L
.43132 .23357 L
s
.959 g
.43132 .25924 m
.5 .25875 L
.53173 .29396 L
.56025 .36264 L
.55939 .43132 L
.5308 .5 L
.5 .52994 L
.43132 .5295 L
.40128 .5 L
.37269 .43132 L
.37182 .36264 L
.40035 .29396 L
F
0 g
.43132 .25924 m
.5 .25875 L
.53173 .29396 L
.56025 .36264 L
.55939 .43132 L
.5308 .5 L
.5 .52994 L
.43132 .5295 L
.40128 .5 L
.37269 .43132 L
.37182 .36264 L
.40035 .29396 L
.43132 .25924 L
s
.973 g
.43132 .30528 m
.5 .30468 L
.53197 .36264 L
.52775 .43132 L
.5 .4754 L
.43132 .47475 L
.40432 .43132 L
.4001 .36264 L
F
0 g
.43132 .30528 m
.5 .30468 L
.53197 .36264 L
.52775 .43132 L
.5 .4754 L
.43132 .47475 L
.40432 .43132 L
.4001 .36264 L
.43132 .30528 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[481]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo000fOol30004Ool00`00Oomoo`04Ool00`00Oomoo`0QOol30004Ool00`00Ool00005000T
Ool3000XOol30004Ool00`00Ool00005000SOol30004Ool00`00Oomoo`04Ool00`00Oomoo`0GOol0
03Eoo`05001oogooOol0000:Ool00`00Oomoo`0POol01@00Oomoogoo00001Goo00<007ooOol00goo
00<007ooOol087oo00D007ooOomoo`0002Ioo`05001oogooOol00005Ool00`00Oomoo`03Ool00`00
Oomoo`0OOol01@00Oomoogoo00002Woo00<007ooOol05goo000dOol00`00Oomoo`03Ool00`00Oomo
o`07Ool00`00Oomoo`0OOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0TOol00`00Oomo
o`03Ool00`00Oomoo`0ROol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0SOol00`00Oomo
o`03Ool00`00Oomoo`07Ool00`00Oomoo`0GOol003Aoo`03001oogoo00=oo`03001oogoo009oo`P0
01moo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo02=oo`03001oogoo00=oo`03001oogoo
029oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo029oo`03001oogoo00=oo`03001oogoo
009oo`P001Moo`00:Woo20000Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol05Goo20000Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol08Woo00<007ooOol0
0goo00<007ooOol08Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol08Goo00<007ooOol0
0goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol05goo000dOol00`00Oomoo`03Ool00`00
Oomoo`03Ool01@00Oomoogoo00008Goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol08Goo
00<007ooOol00goo00<007ooOol08Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol087oo
00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0001Uoo`00=7oo00<007ooOol00goo00<0
07ooOol017oo00@007ooOol0025oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo021oo`03
001oogoo00=oo`03001oogoo029oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo01moo`03
001oogoo00=oo`03001oogoo00Aoo`04001oogoo000IOol003Aoo`03001oogoo00=oo`03001oogoo
00Eoo`03001oo`00025oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo021oo`03001oogoo
00=oo`03001oogoo029oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo01moo`03001oogoo
00=oo`03001oogoo00Eoo`03001oo`0001Uoo`00=7oo00<007ooOol00goo00<007ooOol01Woo0P00
8Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol087oo00<007ooOol0
0goo00<007ooOol08Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
7goo00<007ooOol00goo00<007ooOol01Woo0P006Goo000eOol01@00Oomoogoo00002Goo0P008Woo
00D007ooOomoo`0000Ioo`04001oogoo000TOol01@00Oomoogoo00009Woo00D007ooOomoo`0000Io
o`04001oogoo000SOol01@00Oomoogoo00002Goo0P006Goo000fOol3000;Ool00`00Oomoo`0QOol3
0008Ool2000VOol3000XOol30008Ool2000UOol3000;Ool00`00Oomoo`0GOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`006gooo`001@000Goo000KOol00`00Oomoo`02Ool00`00Oomoo`09
Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:
Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`02
Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0
0Woon@001Goo0@000Goo000KOol00`00Oomoo`02Oooi0005Ool10001Ool001]oo`03001oogoo009o
ooT000Eoo`40005oo`006goo00<007ooOol00Woon@001Goo0@000Goo000KOol00`00Oomoo`02Oooi
0005Ool10001Ool001]oo`03001oogoo009oooT000Eoo`40005oo`006goo00<007ooOol00Woon@00
1Goo0@000Goo000KOol00`00Oomoo`02Oooi0005Ool10001Ool001]oo`03001oogoo009oooT000Eo
o`40005oo`006goo00<007ooOol00Woon@001Goo0@000Goo000KOol00`00Oomoo`02Oooi0005Ool1
0001Ool001]oo`8000=oooT000Aoo`80005oo`006goo00<007ooOol00Woon@001Goo0@000Goo000K
Ool00`00Oomoo`02Oooi0005Ool10001Ool001]oo`03001oogoo009oooT000Eoo`40005oo`006goo
00<007ooOol00Woon@001Goo0@000Goo000KOol00`00Oomoo`02Oooi0005Ool10001Ool001]oo`03
001oogoo009oooT000Eoo`40005oo`006goo00<007ooOol00Woon@001Goo0@000Goo000KOol00`00
Oomoo`02Oooi0005Ool10001Ool001]oo`03001oogoo009oooT000Eoo`40005oo`0017oo0`0017oo
00@007ooOomoo`<000Uoo`03001oogoo009oooT000Eoo`40005oo`000goo00D007ooOomoo`0000Io
o`05001oogooOol00008Ool00`00Oomoo`02Oooi0005Ool10001Ool0009oo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo009oooT000Eoo`40005oo`00
0Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo0P000goon@00
17oo0P000Goo0002Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`05
Ool00`00Oomoo`02Oooi0005Ool10001Ool0009oo`03001oogoo00=oo`03001oogoo009oo`8000=o
o`03001oogoo00Ioo`03001oogoo009oooT000Eoo`40005oo`000Woo00<007ooOol00goo00<007oo
Ool00Woo00<007oo00000P002Goo00<007ooOol00Woon@001Goo0@000Goo0002Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Oooi0005Ool10001Ool0009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo009oooT000Eoo`40005oo`000goo
00D007ooOomoo`0000Moo`8000Yoo`03001oogoo009oooT000Eoo`40005oo`0017oo0`002Woo0`00
1goo00<007ooOol00WooJP005FmkNP001Goo0@000Goo000KOol00`00Oomoo`02OomW000KKg]g0005
Ool10001Ool001]oo`03001oogoo009oof@000E_NaP000A_Ng@000Eoo`40005oo`006goo00<007oo
Ool00WooH@0016mk100066mk0`0016mkL@001Goo0@000Goo000KOol00`00Oomoo`02OomN0005Kg/2
000OKg/20004Kg]_0005Ool10001Ool001]oo`8000=ooed000A_N`8000M_NaD000M_N`03001_Nfmk
009_Nfh000Aoo`80005oo`006goo00<007ooOol00WooF`0016mk0P001fmk0P005G>L0P001Vmk0P00
16mkK0001Goo0@000Goo000KOol00`00Oomoo`02OomJ0004Kg/00`00Kg]_N`04Kg/30002Li`E0002
Li`20006Kg/20003Kg][0005Ool10001Ool001]oo`03001oogoo009ooeP000A_N`8000E_N`8000Ac
W003001cW7>L01=cW080009cW08000I_N`03001_Nfmk009_NfT000Eoo`40005oo`006goo00<007oo
Ool00WooE`000fmk0P001Fmk0P0017>L0P0067>L00@007>LLiacW0<000A_N`8000=_NfP000Eoo`40
005oo`006goo00<007ooOol00WooEP000Vmk0P001Fmk0P0017>L0P006g>L0P0017>L0P0016mk0P00
0VmkI`001Goo0@000Goo000KOol00`00Oomoo`02OomE0002Kg/00`00Kg]_N`02Kg/30005Li`00`00
LiacW003Li`E0005Li`20004Li`20004Kg/00`00Kg]_N`1V0005Ool10001Ool001]oo`03001oogoo
009ooe@0009_N`04001_NfmkKg/20006Li`20004Li`2000ELi`00`00LiacW004Li`00`00LiacW003
Li`20003Kg/00`00Kg]_N`1U0005Ool10001Ool001]oo`03001oogoo009ooe<0009_N`05001_Nfmk
Kg/00006Li`20005Li`00`00LiacW00FLi`20005Li`20005Li`20002Kg/00`00Kg]_N`1T0005Ool1
0001Ool001]oo`03001oogoo009ooe80009_N`05001_NfmkKg/00006Li`00`00LiacW003Li`2000K
Li`20005Li`20005Li`01000Kg]_N`000VmkH`001Goo0@000Goo000KOol00`00Oomoo`02OomA0002
Kg/01@00Kg]_Nfmk00001G>L0P0017>L0P001G>L5@001G>L00<007>LLi`017>L00<007>LLi`00g>L
00@006mkKg/0009_Nf8000Eoo`40005oo`006goo00<007ooOol00WooD0000Vmk00D006mkKg]_N`00
00AcW08000EcW003001cW7>L00=cW08001Eg_@8000AcW08000EcW08000AcW004001_Nfmk0002Kg]Q
0005Ool10001Ool001]oo`03001oogoo009oodl0009_N`05001_NfmkKg/00004Li`00`00LiacW003
Li`20004Li`2000IMkd20004Li`00`00LiacW004Li`00`00LiacW002Li`01000Kg]_N`000VmkH000
1Goo0@000Goo000KOol20003Oom>0002Kg/01@00Kg]_Nfmk00000g>L0P0017>L0P001G>L00<007Nm
Mkd06gNm00<007>LLi`00W>L0P001G>L00<007>LLi`00W>L00@006mkKg/0009_Nel000Aoo`80005o
o`006goo00<007ooOol00WooC@000Vmk00D006mkKg]_N`0000=cW003001cW7>L00=cW003001cW7>L
00=cW08001mg_@8000AcW08000AcW003001cW7>L009cW004001_Nfmk0002Kg]N0005Ool10001Ool0
01]oo`03001oogoo009ood`0009_N`05001_NfmkKg/00003Li`00`00LiacW002Li`20004Li`20007
MkdF0006Mkd20004Li`00`00LiacW002Li`00`00LiacW002Li`01000Kg]_N`000VmkG@001Goo0@00
0Goo000KOol00`00Oomoo`02Oom;0002Kg/01@00Kg]_Nfmk00000g>L00<007>LLi`00W>L00<007>L
Li`00W>L0P001WNm0`005WNm0P001WNm0P000g>L00<007>LLi`00W>L00<007>LLi`00W>L00@006mk
Kg/0009_Ne`000Eoo`40005oo`006goo00<007ooOol00WooB`000Vmk00D006mkKg]_N`0000=cW005
001cW7>LLi`00004Li`00`00Mkeg_@05Mkd00`00Mkeg_@0IMkd00`00Mkeg_@05Mkd01@00LiacW7>L
00000g>L00<007>LLi`00W>L00@006mkKg/0009_Ne`000Eoo`40005oo`006goo00<007ooOol00Woo
BP000Vmk00D006mkKg]_N`0000=cW003001cW7>L009cW003001cW7>L008000Mg_@03001g_GNm00=g
_A<000Eg_@03001g_GNm00Eg_@04001cW7>L0004Li`00`00LiacW002Li`01000Kg]_N`000VmkF`00
1Goo0@000Goo000KOol00`00Oomoo`02Oom90003Kg/01@00Kg]_Nfmk00000W>L00<007>LLi`00W>L
00@007>LLi`000Qg_@03001g_GNm00Ag_@03001kgW_N00mkgP03001g_GNm00Ag_@03001g_GNm00Eg
_@04001cW7>L0004Li`01@00LiacW7>L00000fmk00<006mkKg/0FP001Goo0@000Goo000KOol00`00
Oomoo`02Oom90002Kg/01@00Kg]_Nfmk00000g>L00D007>LLiacW000009cW003001g_GNm00Ig_@03
001g_GNm00Ag_@03001kgW_N015kgP03001g_GNm00Ag_@03001g_GNm00Eg_@04001cW7>L0003Li`0
0`00LiacW002Li`01000Kg]_N`000VmkFP001Goo0@000Goo000KOol00`00Oomoo`02Oom80003Kg/0
1000Kg]_N`000g>L00<007>LLi`00W>L00<007>L000027Nm00<007NmMkd017Nm00<007_NNmh04g_N
00<007NmMkd017Nm00<007NmMkd01GNm00<007>L000017>L00D007>LLiacW00000=_N`03001_Nfmk
05T000Eoo`40005oo`006goo00<007ooOol00WooB0000Vmk00D006mkKg]_N`0000=cW005001cW7>L
Li`00002Li`00`00Mkeg_@04Mkd20006Mkd00`00NmikgP0ENmh00`00Mkeg_@04Mkd00`00Mkeg_@04
Mkd01000LiacW00017>L00D007>LLiacW000009_N`03001_Nfmk05T000Eoo`40005oo`006goo00<0
07ooOol00WooA`000Vmk00D006mkKg]_N`0000=cW005001cW7>LLi`00002Li`00`00Mkeg_@04Mkd0
0`00Mkeg_@05Mkd00`00NmikgP0GNmh00`00Mkeg_@04Mkd00`00Mkeg_@04Mkd01000LiacW0000g>L
00D007>LLiacW00000=_N`03001_Nfmk05P000Eoo`40005oo`006goo00<007ooOol00WooA`000Vmk
00D006mkKg]_N`00009cW005001cW7>LLi`00002Li`00`00Mkeg_@04Mkd00`00Mkeg_@05Mkd00`00
NmikgP0INmh00`00Mkeg_@04Mkd00`00Mkeg_@04Mkd01000LiacW0000g>L00D007>LLiacW00000=_
N`03001_N`0005L000Eoo`40005oo`006goo0P000gooAP000Vmk00D006mkKg]_N`0000=cW005001c
W7>LLi`00002Li`00`00Mkeg_@03Mkd00`00Mkeg_@05Mkd00`00NmikgP03NmhC0005Nmh00`00Mkeg
_@04Mkd00`00Mkeg_@03Mkd01000LiacW00017>L00@007>LLi`000=_N`03001_Nfmk05L000Aoo`80
005oo`006goo00<007ooOol00WooAP000Vmk00D006mkKg]_N`00009cW005001cW7>LLi`00002Li`0
0`00Mkeg_@03Mkd00`00Mkeg_@05Mkd00`00NmikgP04Nmh00`00NmikgP0?Nmh00`00NmikgP04Nmh0
0`00Mkeg_@04Mkd00`00Mkeg_@03Mkd01000LiacW0000g>L00D007>LLiacW00000=_N`03001_N`00
05H000Eoo`40005oo`006goo00<007ooOol00WooA@000Vmk00D006mkKg]_N`0000=cW004001cW7>L
0003Li`00`00Mkeg_@02Mkd00`00Mkeg_@05Mkd00`00NmikgP04Nmh00`00NmikgP0ANmh00`00Nmik
gP04Nmh00`00Mkeg_@04Mkd00`00Mkeg_@02Mkd01@00LiacW7>L00000g>L00@007>LLi`000=_N`03
001_Nfmk05H000Eoo`40005oo`006goo00<007ooOol00WooA@000Vmk00D006mkKg]_N`00009cW005
001cW7>LLi`00002Li`00`00Mkeg_@02Mkd00`00Mkeg_@05Mkd00`00NmikgP04Nmh00`00NmikgP0C
Nmh00`00NmikgP04Nmh00`00Mkeg_@04Mkd00`00Mkeg_@02Mkd01000LiacW00017>L00@007>LLi`0
00=_N`03001_N`0005D000Eoo`40005oo`006goo00<007ooOol00WooA@0000=_N`00Kg/00Vmk00@0
07>LLi`000=cW004001cW7>L0004Mkd00`00Mkeg_@05Mkd00`00NmikgP04Nmh00`00NmikgP0ENmh0
0`00NmikgP04Nmh00`00Mkeg_@04Mkd00`00Mkeg_@02Mkd01000LiacW0000g>L00@007>LLi`000=_
N`03001_N`0005D000Eoo`40005oo`006goo00<007ooOol00WooA0000Vmk00@006mkKg/000=cW004
001cW7>L0003Li`00`00Mkeg_@02Mkd00`00Mkeg_@04Mkd00`00NmikgP04Nmh00`00NmikgP0GNmh0
0`00NmikgP04Nmh00`00Mkeg_@03Mkd00`00Mkeg_@02Mkd01@00LiacW7>L00000g>L00@007>LLi`0
009_N`03001_Nfmk05D000Eoo`40005oo`006goo00<007ooOol00WooA00000=_N`00Kg/00Vmk00@0
07>LLi`0009cW005001cW7>LLi`00004Mkd00`00Mkeg_@04Mkd00`00NmikgP04Nmh00`00NmikgP0I
Nmh00`00NmikgP04Nmh00`00Mkeg_@03Mkd00`00Mkeg_@02Mkd01@00LiacW7>L00000g>L00<007>L
00000fmk00<006mk0000E0001Goo0@000Goo000KOol00`00Oomoo`02Oom30002Kg/01000Kg]_N`00
0g>L00@007>LLi`000=cW005001g_GNmMkd00006Mkd00`00NmikgP04Nmh00`00NmikgP0KNmh00`00
NmikgP04Nmh00`00Mkeg_@03Mkd01@00Mkeg_GNm00000g>L00D007>LLiacW000009cW004001_Nfmk
0002Kg]D0005Ool10001Ool001]oo`03001oogoo009ood<0009_N`04001_Nfmk0002Li`01000Liac
W0000g>L00<007NmMkd00WNm00<007NmMkd00gNm00<007_NNmh017_N00<007_NNmh07G_N00<007_N
Nmh017_N00<007NmMkd00WNm00<007NmMkd00WNm00D007>LLiacW00000=cW003001cW000009_N`03
001_Nfmk05@000Eoo`40005oo`006goo00<007ooOol00Woo@P000Vmk00@006mkKg/0009cW004001c
W7>L0003Li`00`00Mkeg_@02Mkd00`00Mkeg_@03Mkd00`00NmikgP04Nmh00`00NmikgP0ONmh00`00
NmikgP04Nmh00`00Mkeg_@02Mkd00`00Mkeg_@02Mkd01@00LiacW7>L00000g>L00<007>L00000Vmk
00<006mkKg/0D`001Goo0@000Goo0004Ool30004Ool01000Oomoogoo0`002Goo00<007ooOol00Woo
@P000Vmk00@006mkKg/0009cW004001cW7>L0003Li`00`00Mkeg_@02Mkd00`00Mkeg_@03Mkd00`00
NmikgP04Nmh00`00NmikgP0ONmh00`00NmikgP04Nmh00`00Mkeg_@02Mkd00`00Mkeg_@02Mkd01@00
LiacW7>L00000g>L00<007>L00000Vmk00<006mkKg/0D`001Goo0@000Goo0003Ool01@00Oomoogoo
00001Woo00D007ooOomoo`0000Qoo`03001oogoo009ood80009_N`04001_Nfmk0002Li`01000Liac
W0000g>L00D007NmMkeg_@0000Eg_@03001kgW_N00AkgP03001kgW_N025kgP03001kgW_N00AkgP03
001g_GNm009g_@03001g_GNm009g_@04001cW7>L0003Li`00`00Li`00002Kg/00`00Kg]_N`1C0005
Ool10001Ool0009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eo
o`03001oogoo009ood40009_N`07001_NfmkKg/007>L00000W>L00D007>LLiacW00000Ag_@03001g
_GNm00=g_@03001kgW_N00AkgP03001kgW_N00IkgQ<000QkgP03001kgW_N00AkgP03001g_GNm009g
_@03001g_GNm009g_@05001cW7>LLi`00003Li`00`00Li`00002Kg/00`00Kg]_N`1B0005Ool10001
Ool0009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`8000=o
od40009_N`04001_Nfmk0002Li`01000LiacW0000g>L00<007NmMkd00WNm00<007NmMkd00WNm00<0
07_NNmh017_N00<007_NNmh01g_N00<007ooOol03goo00<007_NNmh01W_N00<007_NNmh017_N00<0
07NmMkd00WNm00<007NmMkd00WNm00D007>LLiacW00000=cW003001cW000009_N`03001_Nfmk0580
00Aoo`80005oo`000Woo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000Qoo`03001o
ogoo009ood40009_N`04001_Nfmk0002Li`01000LiacW0000g>L00D007NmMkeg_@0000Eg_@03001k
gW_N00AkgP03001kgW_N00IkgP03001oogoo015oo`03001kgW_N00IkgP03001kgW_N00AkgP03001g
_GNm009g_@03001g_GNm009g_@04001cW7>L0003Li`00`00Li`00002Kg/00`00Kg]_N`1B0005Ool1
0001Ool0009oo`03001oogoo00=oo`03001oogoo00Aoo`<000Uoo`03001oogoo009ood00009_N`07
001_NfmkKg/007>L00000g>L00@007>LLi`000Ag_@03001g_GNm009g_@03001kgW_N00EkgP03001k
gW_N00IkgP03001oogoo015oo`03001kgW_N00IkgP03001kgW_N00AkgP03001g_GNm009g_@03001g
_GNm009g_@05001cW7>LLi`00002Li`01000LiacW0000Vmk00<006mkKg/0D@001Goo0@000Goo0002
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo000027oo00<007ooOol00Woo@0000Vmk
00@006mkKg/0009cW005001cW7>LLi`00002Li`00`00Mkeg_@02Mkd00`00Mkeg_@02Mkd00`00Nmik
gP04Nmh00`00NmikgP06Nmh00`00Oomoo`0COol00`00NmikgP06Nmh00`00NmikgP03Nmh00`00Mkeg
_@03Mkd01@00Mkeg_GNm00000g>L00@007>LLi`0009cW004001_Nfmk0002Kg]A0005Ool10001Ool0
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo
009ood00009_N`04001_Nfmk0002Li`01000LiacW0000g>L00D007NmMkeg_@0000Ag_@03001kgW_N
00EkgP03001kgW_N00IkgP03001oogoo01=oo`03001kgW_N00IkgP03001kgW_N00AkgP03001g_GNm
009g_@03001g_GNm009g_@04001cW7>L0003Li`00`00Li`00002Kg/00`00Kg]_N`1A0005Ool10001
Ool0009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001o
ogoo009ood00009_N`04001_Nfmk0002Li`01000LiacW0000g>L00D007NmMkeg_@0000Ag_@03001k
gW_N00AkgP03001kgW_N00IkgP03001oogoo01Eoo`03001kgW_N00EkgP03001kgW_N00AkgP03001g
_GNm009g_@03001g_GNm009g_@04001cW7>L0003Li`00`00Li`00002Kg/00`00Kg]_N`1A0005Ool1
0001Ool000=oo`05001oogooOol00006Ool01@00Oomoogoo000027oo00<007ooOol00Woo?`000Vmk
00@006mkKg/0009cW005001cW7>LLi`00002Li`00`00Mkeg_@02Mkd00`00Mkeg_@02Mkd00`00Nmik
gP04Nmh00`00NmikgP06Nmh00`00Oomoo`0EOol00`00NmikgP06Nmh00`00NmikgP03Nmh00`00Mkeg
_@03Mkd01@00Mkeg_GNm00000g>L00@007>LLi`0009cW004001_Nfmk0002Kg]@0005Ool10001Ool0
00Aoo`<000Qoo`<000Uoo`03001oogoo009oocl0009_N`04001_Nfmk0002Li`01@00LiacW7>L0000
0W>L00D007NmMkeg_@0000Ag_@03001kgW_N00AkgP03001kgW_N00IkgP03001oogoo01Moo`03001k
gW_N00EkgP03001kgW_N00AkgP03001g_GNm009g_@03001g_GNm009g_@04001cW7>L0002Li`01000
LiacW0000Vmk00<006mkKg/0D0001Goo0@000Goo000KOol00`00Oomoo`02Oolo0002Kg/01000Kg]_
N`000W>L00@007>LLi`000=cW005001g_GNmMkd00004Mkd00`00NmikgP04Nmh00`00NmikgP05Nmh0
0`00Oomoo`0IOol00`00NmikgP04Nmh00`00NmikgP04Nmh00`00Mkeg_@02Mkd00`00Mkeg_@02Mkd0
1000LiacW0000W>L00@007>LLi`0009_N`03001_Nfmk050000Eoo`40005oo`006goo00<007ooOol0
0Woo?`000Vmk00@006mkKg/0009cW004001cW7>L0003Li`01@00Mkeg_GNm000017Nm00<007_NNmh0
0g_N00<007_NNmh01W_N00<007ooOol06Goo00<007_NNmh01G_N00<007_NNmh00g_N00<007NmMkd0
0gNm00D007NmMkeg_@00009cW007001cW7>LLi`007>L00000Vmk00<006mkKg/0D0001Goo0@000Goo
000KOol00`00Oomoo`02Ooln0002Kg/01000Kg]_N`000g>L00@007>LLi`0009cW005001g_GNmMkd0
0004Mkd00`00NmikgP04Nmh00`00NmikgP05Nmh00`00Oomoo`0KOol00`00NmikgP04Nmh00`00Nmik
gP04Nmh00`00Mkeg_@02Mkd00`00Mkeg_@02Mkd01000LiacW0000W>L00@007>LLi`0009_N`03001_
Nfmk04l000Eoo`40005oo`006goo00<007ooOol00Woo?P000Vmk00@006mkKg/0009cW005001cW7>L
Li`00002Li`01@00Mkeg_GNm000017Nm00<007_NNmh017_N00<007_NNmh01G_N00<007ooOol06goo
00<007_NNmh01G_N00<007_NNmh00g_N00<007NmMkd00gNm00D007NmMkeg_@00009cW004001cW7>L
0002Li`01000Kg]_N`000VmkC`001Goo0@000Goo000KOol20003Ooln0002Kg/01000Kg]_N`000W>L
00D007>LLiacW000009cW005001g_GNmMkd00004Mkd00`00NmikgP03Nmh00`00NmikgP05Nmh00`00
Oomoo`0MOol00`00NmikgP04Nmh00`00NmikgP03Nmh00`00Mkeg_@03Mkd01@00Mkeg_GNm00000W>L
00@007>LLi`0009cW004001_Nfmk0002Kg]?0004Ool20001Ool001]oo`03001oogoo009oocd0009_
N`04001_Nfmk0003Li`01000LiacW0000W>L00D007NmMkeg_@0000Ag_@03001kgW_N00AkgP03001k
gW_N00EkgP03001oogoo01eoo`03001kgW_N00AkgP03001kgW_N00AkgP03001g_GNm009g_@03001g
_GNm009g_@04001cW7>L0002Li`01000LiacW0000Vmk00<006mkKg/0CP001Goo0@000Goo000KOol0
0`00Oomoo`02Oolm0002Kg/01000Kg]_N`000g>L00@007>LLi`0009cW005001g_GNmMkd00004Mkd0
0`00NmikgP03Nmh00`00NmikgP05Nmh00`00Oomoo`0OOol00`00NmikgP04Nmh00`00NmikgP03Nmh0
0`00Mkeg_@03Mkd01@00Mkeg_GNm00000W>L00@007>LLi`0009cW004001_Nfmk0002Kg]>0005Ool1
0001Ool001]oo`03001oogoo009oocd0009_N`04001_Nfmk0003Li`01000LiacW0000W>L00D007Nm
Mkeg_@0000Ag_@03001kgW_N00=kgP03001kgW_N00EkgP03001oogoo01moo`03001kgW_N00AkgP03
001kgW_N00=kgP03001g_GNm00=g_@05001g_GNmMkd00002Li`01000LiacW0000W>L00@006mkKg/0
009_Ndh000Eoo`40005oo`006goo00<007ooOol00Woo?@000Vmk00@006mkKg/000=cW004001cW7>L
0002Li`01@00Mkeg_GNm000017Nm00<007_NNmh00g_N00<007_NNmh01G_N00<007ooOol07goo00<0
07_NNmh017_N00<007_NNmh00g_N00<007NmMkd00gNm00D007NmMkeg_@00009cW004001cW7>L0002
Li`01000Kg]_N`000VmkCP001Goo0@000Goo000KOol00`00Oomoo`02Oolm0002Kg/01000Kg]_N`00
0g>L00@007>LLi`0009cW005001g_GNmMkd00004Mkd00`00NmikgP03Nmh00`00NmikgP05Nmh00`00
Oomoo`0OOol00`00NmikgP04Nmh00`00NmikgP03Nmh00`00Mkeg_@03Mkd01@00Mkeg_GNm00000W>L
00@007>LLi`0009cW004001_Nfmk0002Kg]>0005Ool10001Ool001]oo`03001oogoo009oocd0009_
N`04001_Nfmk0003Li`01000LiacW0000W>L00D007NmMkeg_@0000Ag_@03001kgW_N00=kgP03001k
gW_N00EkgP03001oogoo01moo`03001kgW_N00AkgP03001kgW_N00=kgP03001g_GNm00=g_@05001g
_GNmMkd00002Li`01000LiacW0000W>L00@006mkKg/0009_Ndh000Eoo`40005oo`006goo00<007oo
Ool00Woo?@000Vmk00@006mkKg/0009cW005001cW7>LLi`00002Li`01@00Mkeg_GNm000017Nm00<0
07_NNmh00g_N00<007_NNmh01G_N00<007ooOol07goo00<007_NNmh017_N00<007_NNmh00g_N00<0
07NmMkd00gNm00D007NmMkeg_@00009cW004001cW7>L0003Li`01000Kg]_N`000VmkC@001Goo0@00
0Goo000KOol00`00Oomoo`02Oolm0002Kg/01000Kg]_N`000W>L00D007>LLiacW000009cW005001g
_GNmMkd00004Mkd00`00NmikgP03Nmh00`00NmikgP05Nmh00`00Oomoo`0OOol00`00NmikgP04Nmh0
0`00NmikgP03Nmh00`00Mkeg_@03Mkd01@00Mkeg_GNm00000W>L00@007>LLi`000=cW004001_Nfmk
0002Kg]=0005Ool10001Ool001]oo`03001oogoo009oocd0009_N`04001_Nfmk0002Li`01@00Liac
W7>L00000W>L00D007NmMkeg_@0000Ag_@03001kgW_N00=kgP03001kgW_N00EkgP03001oogoo01mo
o`03001kgW_N00AkgP03001kgW_N00=kgP03001g_GNm00=g_@05001g_GNmMkd00002Li`01000Liac
W0000g>L00@006mkKg/0009_Ndd000Eoo`40005oo`006goo00<007ooOol00Woo?@000Vmk00@006mk
Kg/0009cW005001cW7>LLi`00002Li`01@00Mkeg_GNm000017Nm00<007_NNmh00g_N00<007_NNmh0
1G_N00<007ooOol07goo00<007_NNmh017_N00<007_NNmh00g_N00<007NmMkd00gNm00D007NmMkeg
_@00009cW004001cW7>L0003Li`01000Kg]_N`000VmkC@001Goo0@000Goo000KOol00`00Oomoo`02
Oolm0002Kg/01000Kg]_N`000W>L00D007>LLiacW000009cW005001g_GNmMkd00004Mkd00`00Nmik
gP03Nmh00`00NmikgP05Nmh00`00Oomoo`0OOol00`00NmikgP04Nmh00`00NmikgP03Nmh00`00Mkeg
_@03Mkd01@00Mkeg_GNm00000W>L00@007>LLi`000=cW004001_Nfmk0002Kg]=0005Ool10001Ool0
01]oo`03001oogoo009ooc`0009_N`04001_Nfmk0003Li`01000LiacW0000W>L00D007NmMkeg_@00
00Eg_@03001kgW_N00AkgP03001kgW_N00EkgP03001oogoo01eoo`03001kgW_N00EkgP03001kgW_N
00AkgP03001g_GNm009g_@05001g_GNmMkd00003Li`01000LiacW0000W>L00@006mkKg/0009_Ndd0
00Eoo`40005oo`006goo0P000goo?0000Vmk00@006mkKg/000=cW004001cW7>L0002Li`01@00Mkeg
_GNm00001GNm00<007_NNmh017_N00<007_NNmh01G_N00<007ooOol07Goo00<007_NNmh01G_N00<0
07_NNmh017_N00<007NmMkd00WNm00D007NmMkeg_@0000=cW004001cW7>L0002Li`01000Kg]_N`00
0VmkC@0017oo0P000Goo000KOol00`00Oomoo`02Ooll0002Kg/01000Kg]_N`000g>L00@007>LLi`0
009cW005001g_GNmMkd00005Mkd00`00NmikgP04Nmh00`00NmikgP05Nmh00`00Oomoo`0MOol00`00
NmikgP05Nmh00`00NmikgP04Nmh00`00Mkeg_@02Mkd01@00Mkeg_GNm00000g>L00@007>LLi`0009c
W004001_Nfmk0002Kg]=0005Ool10001Ool001]oo`03001oogoo009ooc`0009_N`04001_Nfmk0003
Li`01000LiacW0000W>L00D007NmMkeg_@0000Eg_@03001kgW_N00AkgP03001kgW_N00EkgP03001o
ogoo01eoo`03001kgW_N00EkgP03001kgW_N00AkgP03001g_GNm009g_@05001g_GNmMkd00003Li`0
1000LiacW0000W>L00@006mkKg/0009_Ndd000Eoo`40005oo`006goo00<007ooOol00Woo?0000Vmk
00@006mkKg/0009cW005001cW7>LLi`00002Li`01@00Mkeg_GNm00001GNm00<007_NNmh017_N00<0
07_NNmh01G_N00<007ooOol07Goo00<007_NNmh01G_N00<007_NNmh017_N00<007NmMkd00WNm00D0
07NmMkeg_@0000=cW004001cW7>L0003Li`01000Kg]_N`000VmkC0001Goo0@000Goo000KOol00`00
Oomoo`02Ooll0002Kg/01000Kg]_N`000W>L00D007>LLiacW000009cW005001g_GNmMkd00005Mkd0
0`00NmikgP04Nmh00`00NmikgP05Nmh00`00Oomoo`0MOol00`00NmikgP05Nmh00`00NmikgP04Nmh0
0`00Mkeg_@02Mkd01@00Mkeg_GNm00000g>L00@007>LLi`000=cW004001_Nfmk0002Kg]<0005Ool1
0001Ool001]oo`03001oogoo009ooc`0009_N`04001_Nfmk0002Li`01@00LiacW7>L00000W>L00D0
07NmMkeg_@0000Eg_@03001kgW_N00AkgP03001kgW_N00EkgP03001oogoo01eoo`03001kgW_N00Ek
gP03001kgW_N00AkgP03001g_GNm009g_@05001g_GNmMkd00003Li`01000LiacW0000g>L00@006mk
Kg/0009_Nd`000Eoo`40005oo`006goo00<007ooOol00Woo?0000Vmk00@006mkKg/0009cW005001c
W7>LLi`00002Li`01@00Mkeg_GNm00001GNm00<007_NNmh017_N00<007_NNmh01G_N00<007ooOol0
7Goo00<007_NNmh01G_N00<007_NNmh017_N00<007NmMkd00WNm00D007NmMkeg_@0000=cW004001c
W7>L0003Li`01000Kg]_N`000VmkC0001Goo0@000Goo000KOol00`00Oomoo`02Ooll0002Kg/01000
Kg]_N`000W>L00D007>LLiacW000009cW005001g_GNmMkd00005Mkd00`00NmikgP04Nmh00`00Nmik
gP05Nmh00`00Oomoo`0MOol00`00NmikgP05Nmh00`00NmikgP04Nmh00`00Mkeg_@02Mkd01@00Mkeg
_GNm00000g>L00@007>LLi`000=cW004001_Nfmk0002Kg]<0005Ool10001Ool001]oo`03001oogoo
009ooc`0009_N`04001_Nfmk0002Li`01@00LiacW7>L00000W>L00D007NmMkeg_@0000Eg_@03001k
gW_N00AkgP03001kgW_N00EkgP03001oogoo01eoo`03001kgW_N00EkgP03001kgW_N00AkgP03001g
_GNm009g_@05001g_GNmMkd00003Li`01000LiacW0000g>L00@006mkKg/0009_Nd`000Eoo`40005o
o`006goo00<007ooOol00Woo?0000Vmk00@006mkKg/0009cW005001cW7>LLi`00002Li`01@00Mkeg
_GNm00001GNm00<007_NNmh01G_N00<007_NNmh01G_N00<007ooOol06goo00<007_NNmh01G_N00<0
07_NNmh017_N00<007NmMkd00gNm00D007NmMkeg_@0000=cW004001cW7>L0003Li`01000Kg]_N`00
0VmkC0001Goo0@000Goo000KOol00`00Oomoo`02Ooll0002Kg/01000Kg]_N`000W>L00D007>LLiac
W000009cW003001g_GNm009g_@03001g_GNm00=g_@03001kgW_N00AkgP03001kgW_N00IkgP03001o
ogoo01Uoo`03001kgW_N00IkgP03001kgW_N00AkgP03001g_GNm009g_@03001g_GNm009g_@05001c
W7>LLi`00002Li`01@00LiacW7>L00000Vmk00<006mkKg/0C0001Goo0@000Goo000KOol00`00Oomo
o`02Ooll0002Kg/01000Kg]_N`000W>L00D007>LLiacW00000=cW005001g_GNmMkd00005Mkd00`00
NmikgP04Nmh00`00NmikgP06Nmh00`00Oomoo`0IOol00`00NmikgP06Nmh00`00NmikgP04Nmh00`00
Mkeg_@02Mkd00`00Mkeg_@02Mkd01@00LiacW7>L00000W>L00D007>LLiacW000009_N`03001_Nfmk
04`000Eoo`40005oo`006goo0P000goo?0000Vmk00@006mkKg/000=cW005001cW7>LLi`00002Li`0
1@00Mkeg_GNm00001GNm00<007_NNmh01G_N00<007_NNmh01W_N00<007ooOol05goo00<007_NNmh0
1W_N00<007_NNmh017_N00<007NmMkd00gNm00D007NmMkeg_@0000=cW004001cW7>L0003Li`01@00
Kg]_Nfmk00000VmkC00017oo0P000Goo000KOol00`00Oomoo`02Ooll0002Kg/01000Kg]_N`000g>L
00D007>LLiacW000009cW005001g_GNmMkd00006Mkd00`00NmikgP04Nmh00`00NmikgP07Nmh00`00
Oomoo`0EOol00`00NmikgP07Nmh00`00NmikgP04Nmh00`00Mkeg_@03Mkd01@00Mkeg_GNm00000g>L
00@007>LLi`000=cW005001_NfmkKg/00002Kg]<0005Ool10001Ool001]oo`03001oogoo009ooc`0
009_N`04001_Nfmk0003Li`01@00LiacW7>L00000W>L00D007NmMkeg_@0000Ig_@03001kgW_N00Ek
gP03001kgW_N00IkgP03001oogoo01Eoo`03001kgW_N00IkgP03001kgW_N00EkgP03001g_GNm00=g
_@05001g_GNmMkd00003Li`01000LiacW0000g>L00D006mkKg]_N`00009_Nd`000Eoo`40005oo`00
6goo00<007ooOol00Woo?0000Vmk00@006mkKg/000=cW005001cW7>LLi`00002Li`00`00Mkeg_@02
Mkd00`00Mkeg_@03Mkd00`00NmikgP05Nmh00`00NmikgP07Nmh00`00Oomoo`0COol00`00NmikgP07
Nmh00`00NmikgP04Nmh00`00Mkeg_@03Mkd00`00Mkeg_@02Mkd01@00LiacW7>L00000W>L00D007>L
LiacW00000=_N`03001_Nfmk04`000Eoo`40005oo`006goo00<007ooOol00Woo?0000Vmk00@006mk
Kg/000=cW005001cW7>LLi`00002Li`00`00Mkeg_@02Mkd00`00Mkeg_@03Mkd00`00NmikgP05Nmh0
0`00NmikgP07Nmh00`00Oomoo`0COol00`00NmikgP07Nmh00`00NmikgP04Nmh00`00Mkeg_@03Mkd0
0`00Mkeg_@02Mkd01@00LiacW7>L00000W>L00D007>LLiacW00000=_N`03001_Nfmk04`000Eoo`40
005oo`006goo00<007ooOol00Woo?@000Vmk00@006mkKg/0009cW005001cW7>LLi`00003Li`01@00
Mkeg_GNm00001WNm00<007_NNmh01G_N00<007_NNmh01g_N00<007ooOol04Goo00<007_NNmh01g_N
00<007_NNmh01G_N00<007NmMkd00gNm00<007NmMkd00WNm00D007>LLiacW000009cW005001cW7>L
Li`00002Kg/00`00Kg]_N`1=0005Ool10001Ool001]oo`03001oogoo009oocd0009_N`04001_Nfmk
0002Li`01@00LiacW7>L00000g>L00D007NmMkeg_@0000Ig_@03001kgW_N00EkgP03001kgW_N00Qk
gQ<000YkgP03001kgW_N00AkgP03001g_GNm00Ag_@03001g_GNm009g_@05001cW7>LLi`00002Li`0
1@00LiacW7>L00000Vmk00<006mkKg/0C@001Goo0@000Goo000KOol00`00Oomoo`02Oolm0002Kg/0
1000Kg]_N`000W>L00D007>LLiacW00000=cW003001g_GNm009g_@03001g_GNm00=g_@03001kgW_N
00EkgP03001kgW_N02EkgP03001kgW_N00AkgP03001g_GNm00=g_@03001g_GNm00=g_@05001cW7>L
Li`00002Li`01@00LiacW7>L00000Vmk00<006mkKg/0C@001Goo0@000Goo000KOol00`00Oomoo`02
Oolm0002Kg/01000Kg]_N`000W>L00D007>LLiacW00000=cW003001g_GNm009g_@03001g_GNm00Ag
_@03001kgW_N00EkgP03001kgW_N02=kgP03001kgW_N00EkgP03001g_GNm00=g_@03001g_GNm00=g
_@05001cW7>LLi`00002Li`01@00LiacW7>L00000Vmk00<006mkKg/0C@001Goo0@000Goo000KOol0
0`00Oomoo`02Oolm0002Kg/01000Kg]_N`000g>L00D007>LLiacW000009cW003001g_GNm009g_@03
001g_GNm00Ag_@03001kgW_N00EkgP03001kgW_N02=kgP03001kgW_N00AkgP03001g_GNm00Ag_@03
001g_GNm009g_@05001cW7>LLi`00002Li`01@00LiacW7>L00000fmk00<006mkKg/0C@001Goo0@00
0Goo000?Ool50007Ool00`00Oomoo`02Oolm0002Kg/01000Kg]_N`000g>L00D007>LLiacW000009c
W003001g_GNm009g_@03001g_GNm00Ag_@03001kgW_N00IkgP03001kgW_N025kgP03001kgW_N00Ek
gP03001g_GNm00Ag_@03001g_GNm009g_@05001cW7>LLi`00002Li`01@00LiacW7>L00000fmk00<0
06mkKg/0C@001Goo0@000Goo000AOol00`00Oomoo`07Ool00`00Oomoo`02Oolm0002Kg/01000Kg]_
N`000g>L00D007>LLiacW00000=cW005001g_GNmMkd00006Mkd00`00NmikgP06Nmh00`00NmikgP0Q
Nmh00`00NmikgP05Nmh00`00Mkeg_@04Mkd00`00Mkeg_@02Mkd01@00LiacW7>L00000W>L00D007>L
LiacW00000=_N`03001_Nfmk04d000Eoo`40005oo`004Goo00<007ooOol01goo00<007ooOol00Woo
?@000Vmk00@006mkKg/000=cW005001cW7>LLi`00003Li`00`00Mkeg_@02Mkd00`00Mkeg_@04Mkd0
0`00NmikgP05Nmh00`00NmikgP0QNmh00`00NmikgP04Nmh00`00Mkeg_@04Mkd00`00Mkeg_@03Mkd0
1@00LiacW7>L00000W>L00D007>LLiacW00000=_N`03001_Nfmk04d000Eoo`40005oo`004Goo00<0
07ooOol01goo0P000goo?@000Vmk00@006mkKg/000=cW005001cW7>LLi`00003Li`00`00Mkeg_@02
Mkd00`00Mkeg_@04Mkd00`00NmikgP06Nmh2000ONmh20007Nmh00`00Mkeg_@04Mkd00`00Mkeg_@03
Mkd01@00LiacW7>L00000W>L00D007>LLiacW00000=_N`03001_Nfmk04d000Aoo`80005oo`004Goo
00<007ooOol01goo00<007ooOol00Woo?@000Vmk00@006mkKg/000=cW005001cW7>LLi`00003Li`0
0`00Mkeg_@02Mkd00`00Mkeg_@04Mkd00`00NmikgP08Nmh00`00NmikgP0KNmh00`00NmikgP07Nmh0
0`00Mkeg_@04Mkd00`00Mkeg_@03Mkd01@00LiacW7>L00000W>L00D007>LLiacW00000=_N`03001_
Nfmk04d000Eoo`40005oo`004Goo00<007ooOol01goo00<007ooOol00Woo?@000Vmk00@006mkKg/0
00=cW003001cW7>L009cW005001cW7>LLi`00004Mkd00`00Mkeg_@04Mkd00`00NmikgP08Nmh00`00
NmikgP0INmh00`00NmikgP07Nmh00`00Mkeg_@04Mkd00`00Mkeg_@03Mkd01@00LiacW7>L00000g>L
00D007>LLiacW00000=_N`03001_Nfmk04d000Eoo`40005oo`004Goo00<007ooOol01goo00<007oo
Ool00Woo?@000fmk00@006mkKg/000=cW005001cW7>LLi`00003Li`00`00Mkeg_@02Mkd00`00Mkeg
_@05Mkd00`00NmikgP08Nmh00`00NmikgP0GNmh00`00NmikgP07Nmh00`00Mkeg_@05Mkd00`00Mkeg
_@03Mkd01@00LiacW7>L00000W>L00D007>LLiacW00000=_N`04001_NfmkKg]=0005Ool10001Ool0
015oo`03001oogoo00Moo`03001oogoo009ooch0009_N`04001_Nfmk0003Li`01@00LiacW7>L0000
17>L00<007NmMkd00WNm00<007NmMkd01GNm00<007_NNmh027_N00<007_NNmh05G_N00<007_NNmh0
1g_N00<007NmMkd01GNm00<007NmMkd00gNm00<007>LLi`00W>L00@007>LLi`000=cW005001_Nfmk
Kg/00002Kg]>0005Ool10001Ool0015oo`03001oogoo00Moo`03001oogoo009ooch0009_N`04001_
Nfmk0003Li`00`00LiacW002Li`01@00LiacW7>L000017Nm00<007NmMkd01WNm00<007_NNmh027_N
00<007_NNmh04g_N00<007_NNmh01g_N00<007NmMkd01WNm00<007NmMkd00gNm00D007>LLiacW000
00=cW005001cW7>LLi`00003Kg/00`00Kg]_N`1>0005Ool10001Ool000moo`<000Uoo`03001oogoo
009ooch0009_N`05001_NfmkKg/00002Li`00`00LiacW002Li`00`00LiacW002Li`00`00Mkeg_@02
Mkd00`00Mkeg_@06Mkd00`00NmikgP08Nmh00`00NmikgP0ANmh00`00NmikgP07Nmh00`00Mkeg_@06
Mkd00`00Mkeg_@03Mkd00`00LiacW002Li`01@00LiacW7>L00000W>L00<006mkKg/00Vmk00<006mk
Kg/0CP001Goo0@000Goo000AOol00`00Oomoo`07Ool00`00Oomoo`02Ooln0003Kg/01000Kg]_N`00
0g>L00D007>LLiacW00000AcW003001g_GNm00=g_@03001g_GNm00Ig_@03001kgW_N00QkgQ<000Uk
gP03001g_GNm00Ig_@03001g_GNm00Ag_@03001cW7>L009cW005001cW7>LLi`00002Li`01@00Kg]_
Nfmk00000fmkCP001Goo0@000Goo000KOol00`00Oomoo`02Ooln0003Kg/01000Kg]_N`000g>L00<0
07>LLi`00W>L00<007>LLi`00W>L00<007NmMkd00WNm00<007NmMkd01gNm00<007_NNmh08W_N00<0
07NmMkd01gNm00<007NmMkd00gNm00<007>LLi`00W>L00D007>LLiacW00000=cW005001_NfmkKg/0
0003Kg]>0005Ool10001Ool001]oo`03001oogoo009oocl0009_N`05001_NfmkKg/00002Li`00`00
LiacW002Li`00`00LiacW002Li`00`00Mkeg_@03Mkd00`00Mkeg_@07Mkd00`00NmikgP0PNmh00`00
Mkeg_@07Mkd00`00Mkeg_@03Mkd00`00LiacW003Li`01@00LiacW7>L00000W>L00<006mkKg/00Vmk
00<006mkKg/0C`001Goo0@000Goo000KOol00`00Oomoo`02Oolo0002Kg/01@00Kg]_Nfmk00000g>L
00D007>LLiacW00000AcW003001g_GNm00=g_@03001g_GNm00Qg_@03001kgW_N01ikgP03001g_GNm
00Qg_@03001g_GNm00=g_@03001cW7>L00=cW005001cW7>LLi`00002Li`00`00Kg]_N`02Kg/00`00
Kg]_N`1?0005Ool10001Ool001]oo`03001oogoo009oocl0009_N`05001_NfmkKg/00003Li`00`00
LiacW002Li`00`00LiacW002Li`00`00Mkeg_@03Mkd00`00Mkeg_@08Mkd00`00NmikgP0LNmh00`00
Mkeg_@08Mkd00`00Mkeg_@03Mkd00`00LiacW003Li`00`00LiacW002Li`01000LiacW00016mk00<0
06mkKg/0C`001Goo0@000Goo000KOol20003Oolo0003Kg/01000Kg]_N`000g>L00<007>LLi`00W>L
00<007>LLi`00W>L00<007NmMkd00gNm00<007NmMkd02GNm00<007_NNmh06W_N00<007NmMkd02GNm
00<007NmMkd00gNm00<007>LLi`00g>L00D007>LLiacW00000=cW005001_NfmkKg/00003Kg]?0004
Ool20001Ool001]oo`03001oogoo009oocl000=_N`05001_NfmkKg/00003Li`01@00LiacW7>L0000
1G>L00<007NmMkd00gNm00<007NmMkd02GNm00<007_NNmh067_N00<007NmMkd02GNm00<007NmMkd0
0gNm00<007>LLi`017>L00D007>LLiacW000009cW003001_Nfmk009_N`04001_NfmkKg]?0005Ool1
0001Ool001]oo`03001oogoo009oocl000=_N`05001_NfmkKg/00003Li`00`00LiacW002Li`00`00
LiacW002Li`00`00Mkeg_@04Mkd00`00Mkeg_@09Mkd00`00NmikgP0FNmh00`00Mkeg_@09Mkd00`00
Mkeg_@04Mkd00`00LiacW003Li`00`00LiacW002Li`01000LiacW00016mk00@006mkKg]_Ndl000Eo
o`40005oo`006goo00<007ooOol00Woo@0000Vmk00D006mkKg]_N`0000=cW003001cW7>L009cW003
001cW7>L00=cW003001g_GNm00Ag_@03001g_GNm00Ug_@03001kgW_N01AkgP03001g_GNm00Ug_@03
001g_GNm00Ag_@03001cW7>L00AcW003001cW7>L009cW004001cW7>L0004Kg/00`00Kg]_N`1@0005
Ool10001Ool001]oo`03001oogoo009ood0000=_N`05001_NfmkKg/00003Li`01@00LiacW7>L0000
1G>L00<007NmMkd01GNm00<007NmMkd02GNm00<007_NNmh04W_N00<007NmMkd02GNm00<007NmMkd0
1GNm00<007>LLi`017>L00D007>LLiacW000009cW003001_Nfmk009_N`04001_NfmkKg]@0005Ool1
0001Ool001]oo`03001oogoo009ood0000=_N`05001_NfmkKg/00003Li`00`00LiacW002Li`00`00
LiacW003Li`00`00Mkeg_@05Mkd2000:Mkd00`00NmikgP0@Nmh00`00Mkeg_@08Mkd20007Mkd00`00
LiacW004Li`00`00LiacW002Li`01000LiacW00016mk00@006mkKg]_Ne0000Eoo`40005oo`006goo
00<007ooOol00Woo@0000fmk00D006mkKg]_N`0000=cW003001cW7>L009cW003001cW7>L00=cW003
001g_GNm00Mg_@03001g_GNm00Qg_A<000Ug_@03001g_GNm00Mg_@03001cW7>L00AcW003001cW7>L
009cW004001cW7>L0004Kg/01000Kg]_NfmkD0001Goo0@000Goo000KOol00`00Oomoo`02Oom10003
Kg/01@00Kg]_Nfmk00000g>L00<007>LLi`00W>L00<007>LLi`00g>L00<007NmMkd01gNm00<007Nm
Mkd08WNm00<007NmMkd01gNm00<007>LLi`017>L00<007>LLi`00W>L00D007>LLiacW00000=_N`04
001_NfmkKg]A0005Ool10001Ool001]oo`03001oogoo009ood4000=_N`05001_NfmkKg/00003Li`0
0`00LiacW003Li`00`00LiacW003Li`00`00Mkeg_@07Mkd2000QMkd00`00Mkeg_@07Mkd00`00Liac
W004Li`00`00LiacW002Li`01@00LiacW7>L000016mk00@006mkKg]_Ne4000Eoo`40005oo`006goo
00<007ooOol00Woo@@000fmk00D006mkKg]_N`0000AcW003001cW7>L009cW003001cW7>L00AcW080
00Ug_@03001g_GNm01eg_@03001g_GNm00Ig_@8000IcW003001cW7>L00=cW005001cW7>LLi`00004
Kg/01000Kg]_NfmkD@001Goo0@000Goo000KOol00`00Oomoo`02Oom20003Kg/01@00Kg]_Nfmk0000
17>L00<007>LLi`00W>L00<007>LLi`01G>L00<007NmMkd01gNm00<007NmMkd06WNm0P0027Nm00<0
07>LLi`01W>L00<007>LLi`00W>L00<007>LLi`00W>L00D006mkKg]_N`0000=_Ne8000Eoo`40005o
o`006goo00<007ooOol00Woo@P000fmk00D006mkKg]_N`0000AcW003001cW7>L00=cW003001cW7>L
00EcW003001g_GNm00Mg_@03001g_GNm01Qg_@03001g_GNm00Mg_@03001cW7>L00IcW003001cW7>L
00=cW005001cW7>LLi`00004Kg/01000Kg]_NfmkDP001Goo0@000Goo000KOol00`00Oomoo`02Oom3
0002Kg/00`00Kg]_N`02Kg/00`00LiacW002Li`00`00LiacW002Li`00`00LiacW006Li`00`00Mkeg
_@07Mkd2000GMkd00`00Mkeg_@07Mkd00`00LiacW006Li`00`00LiacW003Li`00`00LiacW002Li`0
1@00Kg]_Nfmk00000fmkD`001Goo0@000Goo000KOol20003Oom30003Kg/01@00Kg]_Nfmk000017>L
00<007>LLi`00g>L00<007>LLi`01W>L00<007NmMkd027Nm00<007NmMkd04gNm00<007NmMkd01gNm
00<007>LLi`01g>L00<007>LLi`00W>L00<007>LLi`00W>L00<006mkKg/00Vmk00@006mkKg]_Ne<0
00Aoo`80005oo`006goo00<007ooOol00Woo@`000fmk00D006mkKg]_N`0000EcW003001cW7>L009c
W003001cW7>L00McW08000Ug_@03001g_GNm015g_@03001g_GNm00Ig_@8000UcW003001cW7>L00=c
W003001cW7>L009cW005001_NfmkKg/00004Kg]C0005Ool10001Ool001]oo`03001oogoo009ood@0
009_N`03001_Nfmk009_N`03001cW7>L009cW003001cW7>L00=cW003001cW7>L00QcW003001g_GNm
00Mg_A<000Qg_@03001cW7>L00QcW003001cW7>L00=cW003001cW7>L009cW003001_Nfmk009_N`04
001_NfmkKg]D0005Ool10001Ool001]oo`03001oogoo009ood@000=_N`05001_NfmkKg/00005Li`0
0`00LiacW003Li`00`00LiacW008Li`00`00Mkeg_@0PMkd00`00LiacW008Li`00`00LiacW004Li`0
0`00LiacW002Li`00`00Kg]_N`02Kg/01000Kg]_NfmkE0001Goo0@000Goo000KOol00`00Oomoo`02
Oom40003Kg/01@00Kg]_Nfmk00001G>L00<007>LLi`00g>L00<007>LLi`02G>L00<007NmMkd07WNm
00<007>LLi`02G>L00<007>LLi`00g>L00<007>LLi`00g>L00D006mkKg]_N`0000A_Ne@000Eoo`40
005oo`006goo00<007ooOol00WooA@000Vmk00<006mkKg/00Vmk00<007>LLi`00g>L00<007>LLi`0
0g>L00<007>LLi`02G>L0P0077Nm0P002g>L00<007>LLi`00g>L00<007>LLi`00g>L00<006mkKg/0
0Vmk00@006mkKg]_NeD000Eoo`40005oo`006goo00<007ooOol00WooA@000fmk00D006mkKg]_N`00
00IcW003001cW7>L00=cW003001cW7>L00YcW003001g_GNm01Qg_@03001cW7>L00YcW003001cW7>L
00AcW003001cW7>L00=cW005001_NfmkKg/00004Kg]E0005Ool10001Ool001]oo`03001oogoo009o
odH0009_N`03001_Nfmk009_N`03001cW7>L00=cW003001cW7>L00AcW003001cW7>L00YcW003001g
_GNm01Ig_@03001cW7>L00YcW003001cW7>L00AcW003001cW7>L00=cW003001_Nfmk009_N`04001_
NfmkKg]F0005Ool10001Ool001]oo`03001oogoo009oodH000=_N`05001_NfmkKg/00006Li`00`00
LiacW004Li`00`00LiacW00:Li`00`00Mkeg_@0DMkd00`00LiacW00:Li`00`00LiacW005Li`00`00
LiacW003Li`00`00Kg]_N`02Kg/01000Kg]_NfmkEP001Goo0@000Goo000KOol00`00Oomoo`02Oom6
0003Kg/01@00Kg]_Nfmk00001W>L00<007>LLi`01G>L00<007>LLi`02W>L00<007NmMkd04WNm00<0
07>LLi`02W>L00<007>LLi`01G>L00<007>LLi`017>L00D006mkKg]_N`0000A_NeH000Eoo`40005o
o`006goo00<007ooOol00WooA`000fmk00D006mkKg]_N`0000IcW003001cW7>L00EcW08000]cW003
001g_GNm011g_@03001cW7>L00UcW08000McW003001cW7>L00AcW003001_Nfmk009_N`04001_Nfmk
Kg]G0005Ool10001Ool001]oo`03001oogoo009oodL000=_N`05001_NfmkKg/00007Li`00`00Liac
W006Li`00`00LiacW009Li`C000:Li`00`00LiacW006Li`00`00LiacW005Li`00`00Kg]_N`02Kg/0
1000Kg]_NfmkE`001Goo0@000Goo000KOol20003Oom80003Kg/01@00Kg]_Nfmk00001g>L00<007>L
Li`01W>L0P0097>L0P0027>L00<007>LLi`01G>L00<006mkKg/00Vmk00@006mkKg]_NeP000Aoo`80
005oo`006goo00<007ooOol00WooB00016mk00D006mkKg]_N`0000McW003001cW7>L00McW003001c
W7>L021cW003001cW7>L00McW003001cW7>L00EcW003001_Nfmk009_N`03001_Nfmk009_NeP000Eo
o`40005oo`006goo00<007ooOol00WooB0001Fmk00D006mkKg]_N`0000McW08000QcW08001icW080
00QcW08000McW003001_Nfmk009_N`03001_Nfmk009_NeT000Eoo`40005oo`006goo00<007ooOol0
0WooB@0016mk00<006mkKg/00Vmk00<007>LLi`01W>L00<007>LLi`01g>L0P006g>L00<007>LLi`0
1g>L00<007>LLi`01W>L00<006mkKg/00fmk00<006mkKg/00VmkF@001Goo0@000Goo000KOol00`00
Oomoo`02Oom90005Kg/00`00Kg]_N`02Kg/00`00LiacW006Li`20009Li`00`00LiacW00GLi`00`00
LiacW006Li`20008Li`00`00Kg]_N`03Kg/00`00Kg]_N`02Kg]J0005Ool10001Ool001]oo`03001o
ogoo009oodX000E_N`03001_Nfmk009_N`03001cW7>L00McW003001cW7>L00McW08001EcW08000Qc
W003001cW7>L00McW003001_Nfmk00=_N`03001_Nfmk00=_NeX000Eoo`40005oo`006goo00<007oo
Ool00WooBP001Fmk00<006mkKg/00fmk00<007>LLi`01g>L0P002G>L00<007>LLi`04G>L00<007>L
Li`01g>L00<007>LLi`027>L00<006mkKg/00fmk00<006mkKg/00VmkF`001Goo0@000Goo000KOol0
0`00Oomoo`02Oom;0005Kg/00`00Kg]_N`03Kg/00`00LiacW008Li`00`00LiacW007Li`C0008Li`2
000:Li`00`00Kg]_N`03Kg/00`00Kg]_N`02Kg]L0005Ool10001Ool001]oo`03001oogoo009ood/0
00I_N`03001_Nfmk00=_N`03001cW7>L00QcW080025cW003001cW7>L00UcW003001_Nfmk00=_N`03
001_Nfmk00=_Ne`000Eoo`40005oo`006goo00<007ooOol00WooC0001Vmk00<006mkKg/00fmk00<0
07>LLi`02G>L00<007>LLi`077>L0P002g>L00<006mkKg/00fmk00<006mkKg/00fmkG@001Goo0@00
0Goo0003Ool50003Ool00`00Ool000050008Ool00`00Oomoo`02Oom=0005Kg/00`00Kg]_N`04Kg/2
000:Li`2000KLi`00`00LiacW00:Li`00`00Kg]_N`04Kg/00`00Kg]_N`03Kg]M0005Ool10001Ool0
00Eoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo009oodd000I_N`03
001_Nfmk00E_N`03001cW7>L00UcW003001cW7>L01McW003001cW7>L00UcW08000I_N`03001_Nfmk
00=_Neh000Eoo`40005oo`001Goo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol00WooCP00
1Vmk00<006mkKg/01Fmk00<007>LLi`02G>L0P005G>L0P002g>L00<006mkKg/01Fmk00<006mkKg/0
16mkGP001Goo0@000Goo0005Ool00`00Oomoo`07Ool00`00Oomoo`09Ool20003Oom>0006Kg/00`00
Kg]_N`06Kg/00`00LiacW00:Li`00`00LiacW00ALi`00`00LiacW00:Li`00`00Kg]_N`06Kg/00`00
Kg]_N`03Kg]O0004Ool20001Ool000Eoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo009o
odl000I_N`03001_Nfmk00I_N`03001cW7>L00YcW1<000acW003001_Nfmk00I_N`03001_Nfmk00=_
Nf0000Eoo`40005oo`001Goo00<007ooOol02Goo00<007ooOol01goo00<007ooOol00WooC`001fmk
00<006mkKg/01Vmk00<007>LLi`09g>L00<006mkKg/01Vmk00<006mkKg/016mkH0001Goo0@000Goo
0005Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`02OomA0006Kg/00`00Kg]_N`06Kg/2
000ULi`20007Kg/20006Kg]Q0005Ool10001Ool000Eoo`03001oogoo00Yoo`03001oogoo00Ioo`03
001oogoo009ooe8000I_N`03001_Nfmk00M_N`80025cW08000Q_N`03001_Nfmk00E_Nf8000Eoo`40
005oo`001Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00WooD`00
1Vmk0P002Fmk0`006g>L0`0026mk0P001fmkH`001Goo0@000Goo0003Ool30008Ool01000Oomoo`00
2Goo00<007ooOol00WooE0001fmk0P002Vmk0P005g>L0P002Fmk0P0026mkI0001Goo0@000Goo0005
Ool00`00Oomoo`07Ool2000:Ool00`00Oomoo`02OomE0008Kg/2000:Kg/2000CLi`2000:Kg/00`00
Kg]_N`07Kg]U0005Ool10001Ool001]oo`03001oogoo009ooeH000U_N`03001_Nfmk00U_Na<000Y_
N`8000U_NfH000Eoo`40005oo`006goo00<007ooOol00WooE`002Fmk0P0096mk0P002VmkI`001Goo
0@000Goo000KOol00`00Oomoo`02OomH000:Kg/2000QKg/00`00Kg]_N`09Kg]X0005Ool10001Ool0
01]oo`03001oogoo009ooeT000]_N`8001e_N`8000]_NfT000Eoo`40005oo`006goo0P000gooF`00
2fmk0P006Fmk0P0036mkJP0017oo0P000Goo000KOol00`00Oomoo`02OomL000<Kg/00`00Kg]_N`0E
Kg/00`00Kg]_N`0:Kg]/0005Ool10001Ool001]oo`03001oogoo009ooeh000]_N`8001=_N`8000a_
Nfd000Eoo`40005oo`006goo00<007ooOol00WooG`0036mk4`0036mkK`001Goo0@000Goo000KOol0
0`00Oomoo`02OomQ000WKg]a0005Ool10001Ool001]oo`03001oogoo009oof<002A_Ng8000Eoo`40
005oo`006goo00<007ooOol00WooI0008FmkM0001Goo0@000Goo000KOol00`00Oomoo`02OomV000M
Kg]f0005Ool10001Ool001]oo`03001oogoo009oofL001]_NgL000Eoo`40005oo`006goo00<007oo
Ool00WooJP005FmkNP001Goo0@000Goo000KOol00`00Oomoo`02Oooi0005Ool10001Ool001]oo`03
001oogoo009oooT000Eoo`40005oo`006goo00<007ooOol00Woon@001Goo0@000Goo000KOol20003
Oooi0004Ool20001Ool001]oo`03001oogoo009oooT000Eoo`40005oo`006goo00<007ooOol00Woo
n@001Goo0@000Goo000KOol00`00Oomoo`02Oooi0005Ool10001Ool001]oo`03001oogoo009oooT0
00Eoo`40005oo`006goo00<007ooOol00Woon@001Goo0@000Goo000KOol00`00Oomoo`02Oooi0005
Ool10001Ool001]oo`03001oogoo009oooT000Eoo`40005oo`006goo00<007ooOol00Woon@001Goo
0@000Goo000KOol00`00Oomoo`02Oooi0005Ool10001Ool001]oo`03001oogoo009oooT000Eoo`40
005oo`006goo00<007ooOol00Woon@001Goo0@000Goo000KOol20003Oooi0004Ool20001Ool001]o
o`03001oogoo009oooT000Eoo`40005oo`006goo00<007ooOol00Woon@001Goo0@000Goo000KOol0
0`00Oomoo`02Oooi0005Ool10001Ool001]oo`03001oogoo009oooT000Eoo`40005oo`006goo00<0
07ooOol00Woon@001Goo0@000Goo000KOol00`00Oomoo`02Oooi0005Ool10001Ool001]oo`03001o
ogoo009oooT000Eoo`40005oo`006goo00<007ooOol00Woon@001Goo0@000Goo0003Ool50003Ool0
0`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`02Oooi0005Ool10001Ool000Eoo`03001oogoo
00Yoo`03001oogoo00Ioo`03001oogoo009oooT000Eoo`40005oo`001Goo00<007ooOol02Woo00<0
07ooOol01Woo00<007ooOol00Woon@001Goo0@000Goo0005Ool00`00Oomoo`05Ool80006Ool20003
Oooi0004Ool20001Ool000Eoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo009oooT000Eoo`40005oo`001Goo00<007ooOol01Woo00D007ooOomoo`0000Qoo`03001oogoo
009oooT000Eoo`40005oo`001Goo00<007ooOol01goo00@007ooOol000Qoo`03001oogoo009oooT0
00Eoo`40005oo`001Goo00<007ooOol027oo00<007oo000027oo00<007ooOol00Woon@001Goo0@00
0Goo0005Ool00`00Oomoo`09Ool20008Ool00`00Oomoo`02Oooi0005Ool10001Ool000=oo`<000]o
o`8000Qoo`03001oogoo009oooT000Eoo`40005oo`001Goo00<007ooOol02Woo00<007ooOol01Woo
00<007ooOol00Woon@001Goo0@000Goo000KOol00`00Oomoo`02Oooi0005Ool10001Ool001]oo`03
001oogoo009oooT000Eoo`40005oo`006goo00<007ooOol00Woon@001Goo0@000Goo000KOol00`00
Oomoo`02Oooi0005Ool10001Ool001]oo`03001oogoo009oooT000Eoo`40005oo`006goo0P000goo
n@0017oo0P000Goo000KOol00`00Oomoo`02Oooi0005Ool10001Ool001]oo`03001oogoo009oooT0
00Eoo`40005oo`006goo00<007ooOol00Woon@001Goo0@000Goo000KOol00`00Oomoo`02Oooi0005
Ool10001Ool001]oo`03001oogoo009oooT000Eoo`40005oo`006goo00<007ooOol00Woon@001Goo
0@000Goo000KOol00`00Oomoo`02Oooi0005Ool10001Ool001]oo`03001oogoo009oooT000Eoo`40
005oo`006goo00<007ooOol00Woon@001Goo0@000Goo000KOol00`00Oomoo`02Oooi0005Ool10001
Ool001]oo`03001oogoo009oooT000Eoo`40005oo`006goo0P000goon@0017oo0P000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0
ogoo0Goo0@000Goo000KOol00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`02Ool10001Ool001]oool000D0005o
o`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.629143, 0.382623, 0.00400575, \
0.00400575}}]
}, Open  ]],

Cell[TextData[{
  "The reason for adding ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Alpha]\_k\)\(\ \)\)\)]],
  "to the mean, but multiplying the variance by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Beta]\_k\)\(\ \)\)\)]],
  ", is that this prevents negative variances being generated (provided \
\[Beta]>0).  "
}], "Text"],

Cell[TextData[{
  "The log likelihood for samples of size ",
  Cell[BoxData[
      \(TraditionalForm\`n\_k\)]],
  " is calculated as:"
}], "Text"],

Cell[BoxData[
    \(TextForm\`\(-\ \(1\/2\)\) \(\[Sum]\+k\( 
                n\_k\) \((Log[\(\[Sigma]\^2\) \[Beta]\_k] + \(\(\((x\&_\_k - \
\[Mu] - \[Alpha]\_k)\)\^2\) \(+s\_k\%2\)\)\/\(\(\[Sigma]\^2\) \
\[Beta]\_k\))\)\ \ where\ s\_k\^2\) = \[Sum]\+\(j = 1\)\%n\_k\((x\_\(k, j\) - \
x\&_\_k)\)\^2\/\(n\_k - 1\)\)], "NumberedEquation"],

Cell[TextData[{
  "This is not quite equal to the MLE: the denominator in the sample variance \
is ",
  Cell[BoxData[
      \(TraditionalForm\`n\_k - 1\)]],
  ", not ",
  Cell[BoxData[
      \(TraditionalForm\`n\_k\ , \ 
      giving\ the\ conventional\ unbiased\ \(\(estimate\)\(.\)\)\)]]
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(GaussianMLE[{x\_1, \[Ellipsis]}]\), \(gives\ estimates\ of\ the\ \
mean\ and\ variance, \ 
            in\ the\ form\ \(\({L, \ {\[Mu]\&^, \[Sigma]\&^\^2}}\)\(.\)\(\ \)\
\)\)},
          {\(GaussianMLE[{x\_1, \[Ellipsis]}, 
              Compiled \[Rule] 
                True]\), \(is\ a\ compiled\ \(\(version\)\(.\)\)\)},
          {\(GaussianMLE[{x\_1, \[Ellipsis]}, 
              FullOutput \[Rule] 
                False]\), \(gives\ estimates\ in\ the\ form\ \(\({\[Mu]\&^, \
\[Sigma]\&^\^2}\)\(.\)\(\ \)\)\)}
          }], TraditionalForm]],
  CellTags->"GaussianMLE"]], "DefinitionBox"],

Cell["This is a sample of 100 values from N[0,1]:", "MathCaption"],

Cell[BoxData[
    \(\(rr = RandomArray[NormalDistribution[0, 1], {100}];\)\)], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
This gives the log likelihood, followed by estimates of the mean \
and variance:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GaussianMLE[rr]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \({\(-53.18454086928192`\), {0.21420176790889353`, 
        1.065762832477213`}}\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell[TextData[{
  "Note that the variance is estimated using the conventional unbiased \
estimator ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(j = 1\)\%n\((x\_j - x\&_)\)\^2\/\(n - \
1\)\)]],
  ", rather than by strict maximum likelihood.  However, the estimate does \
maximise GaussianLogLikelihood[], because that calculates the sample variance \
using the unbiased estimator: it is a simple version of REML. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMinimum[\(-GaussianLogLikelihood[rr, {m, v}]\), {m, {\(-0.1\), 
          0.1}}, {v, {0.5, 1.5}}]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \({53.1845408692819`, {m \[Rule] 0.2142017591303518`, 
        v \[Rule] 1.0657628319564374`}}\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell["\<\
This suppresses calculation of the likelihood, and is  \
faster:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GaussianMLE[rr, FullOutput \[Rule] False]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \({0.21420176790889353`, 1.065762832477213`}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(GaussianMLE[{x\_1, \[Ellipsis]}, {None, \[Sigma]\^2}]\), \(gives\
\ the\ estimated\ mean, \ 
            for\ given\ variance\ \(\(\[Sigma]\^2\)\(.\)\(\ \)\)\)},
          {\(GaussianMLE[{x\_1, \[Ellipsis]}, {\[Mu], 
                None}]\), \(gives\ the\ estimated\ variance, \ 
            for\ given\ mean\ \(\(\[Mu]\)\(.\)\)\)},
          {\(GaussianMLE[{x\_1, \[Ellipsis]}, {\[Mu], \[Sigma]\^2}]\), \(just\
\ returns\ {L, {\[Mu], \[Sigma]\^2}}\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[TextData[{
  "This estimates the variance, given ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2\)]],
  "=1",
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({GaussianMLE[rr, {None, 1}], 
        GaussianMLE[rr, {None, 1}, Compiled \[Rule] True], 
        FindMinimum[\(-GaussianLogLikelihood[rr, {m, 1}]\), {m, {\(-0.1\), 
              0.1}}]} // TableForm\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(-53.28814162386065`\), GridBox[{
                {"0.21420176790889353`"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(-53.28814162386065`\), GridBox[{
                {"0.21420176790889353`"},
                {"1.`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"53.28814162386065`", GridBox[{
                {\(m \[Rule] 0.21420176899531396`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{-53.288141623860653, {0.21420176790889353, 
        1}}, {-53.288141623860653, {0.21420176790889353, 1.0}}, {
        53.288141623860653, {m -> 0.21420176899531396}}}]]], "Output",
  CellLabel->"Out[15]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "This estimates the variance, given ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\)]],
  "=0:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({GaussianMLE[rr, {0, None}], 
        GaussianMLE[rr, {0, None}, Compiled \[Rule] True], 
        FindMinimum[\(-GaussianLogLikelihood[rr, {0, v}]\), {v, {0.5, 1}}]} // 
      TableForm\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(-55.294382932471244`\), GridBox[{
                {"0"},
                {"1.100987601527737`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(-55.294382932471244`\), GridBox[{
                {"0.`"},
                {"1.100987601527737`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"55.29205535113303`", GridBox[{
                {\(v \[Rule] 1.1116457487432456`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{-55.294382932471244, {0, 
        1.1009876015277369}}, {-55.294382932471244, {0.0, 
        1.1009876015277369}}, {55.29205535113303, {v -> 
        1.1116457487432456}}}]]], "Output",
  CellLabel->"Out[16]//TableForm="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(GaussianMLE[{{x\_\(1, 1\), \[Ellipsis]}, \[Ellipsis]}, \
{{\[Alpha]\_1, \[Beta]\_1}, \[Ellipsis]}]\), \(gives\ estimates\ of\ {\[Mu], \
\[Sigma]\^2}, \ 
            where\ the\ mean\ and\ variance\ in\ sample\ k\ are\ {\[Mu] + \
\[Alpha]\_k, \ \(\[Sigma]\^2\) \[Beta]\_k} . \ \ results\ are\ given\ as\ {L, \
{\[Mu]\&^, \[Sigma]\&^\^2}}\)},
          {\(GaussianMLE[{{x\_\(1, 1\), \[Ellipsis]}, \[Ellipsis]}, \
{{\[Alpha]\_1, \[Beta]\_1}, \[Ellipsis]}, 
              Compiled \[Rule] 
                True]\), \(is\ a\ compiled\ \(\(version\)\(.\)\)\)},
          {\(GaussianMLE[{{x\_\(1, 1\), \[Ellipsis]}, \[Ellipsis]}, \
{{\[Alpha]\_1, \[Beta]\_1}, \[Ellipsis]}, 
              FullOutput \[Rule] 
                False]\), \(gives\ estimates\ in\ the\ form\ \(\({\[Mu]\&^, \
\[Sigma]\&^\^2}\)\(.\)\(\ \)\)\)}
          }], TraditionalForm]],
  CellTags->{"additive models", "FullOutput"}]], "DefinitionBox"],

Cell[TextData[{
  "This gives three samples, drawn from distributions with  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{"\[Mu]", ",", 
            RowBox[{
              FormBox[\(\(\[Sigma]\^2\)\(}\)\),
                "TraditionalForm"], "=", \({\(-1\), 1\/2}\)}], 
            ",", \({0, 1}\), ",", \({1, 2}\), " "}]}], TraditionalForm]]],
  ".  Note that the sample variance is not close to the true value:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(rr2 = 
        Table[RandomArray[
            NormalDistribution[j, 2\^\(j/2\)], {100}], {j, \(-1\), 
            1}];\)\), "\[IndentingNewLine]", 
    \({Mean /@ rr2, Variance /@ rr2} // TableForm\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\(-0.992702332095941`\), "0.13190347811067604`", 
            "0.9776264714668308`"},
          {"0.502023817765109`", "0.9268356000780358`", 
            "2.0622971748645633`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[3]//TableForm="]
}, Open  ]],

Cell["\<\
This is the log likelihood of the best estimates, and the estimates \
themselves, assuming the true {\[Alpha],\[Beta]}:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GaussianMLE[rr2, {{\(-1\), 1\/2}, {0, 1}, {1, 2}}]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \({\(-148.72236962430304`\), {0.038660585614916955`, 
        0.9915186356003693`}}\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell["\<\
The same can be obtained more slowly by maximising \
GaussianLogLikelihood[]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMinimum[\(-GaussianLogLikelihood[
          rr2, {{\(-1\), 1\/2}, {0, 1}, {1, 2}}, {m, v}]\), {m, {0, 
          0.1}}, {v, {1, 1.5}}]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \({148.72236962430304`, {m \[Rule] 0.038660586427526906`, 
        v \[Rule] 0.9915186339259585`}}\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell["The estimates are given by:", "MathCaption"],

Cell[BoxData[
    \(\[Mu]\&^ = \(\[LeftAngleBracket]\((z\&_\_k - \[Alpha]\_k)\)/\[Beta]\_k\
\[RightAngleBracket]\/\[LeftAngleBracket]1/\[Beta]\_k\[RightAngleBracket]\
\ \ \ \ \[Sigma]\&^\^2 = \[LeftAngleBracket]\((\((z\&_\_k - \[Alpha]\_k)\)\^2 \
+ s\_k\%2)\)\/\[Beta]\_k\[RightAngleBracket] - \(\[Mu]\&^\^2\) \
\[LeftAngleBracket]1\/\[Beta]\_k\[RightAngleBracket]\ \ \ \[LeftAngleBracket]\
f\[RightAngleBracket] \[Congruent] \(\[Sum]\+k\( n\_k\) f\)\/\(\[Sum]\+k n\_k\
\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "This model is chosen so that the variance is guaranteed to be positive for \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\_k > 0\)]],
  "."
}], "Text"],

Cell["The compiled version is much faster: ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[\(Do[
            GaussianMLE[rr2, {{\(-1\), 1\/2}, {0, 1}, {1, 2}}], {100}];\)], 
      Timing[\(Do[
            GaussianMLE[rr2, {{\(-1\), 1\/2}, {0, 1}, {1, 2}}, 
              Compiled \[Rule] True], {100}];\)]}\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \({{1.349999999999909`\ Second, Null}, {0.6166666666667879`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(GaussianMLE[{{x\_\(1, 1\), \[Ellipsis]}, \[Ellipsis]}, \
{{\[Alpha]\_1, \[Beta]\_1}, \[Ellipsis]}, {\[Mu], 
                None}]\), \(estimates\ the\ variance, \ for\ given\ mean\)},
          {\(GaussianMLE[{{x\_\(1, 1\), \[Ellipsis]}, \[Ellipsis]}, \
{{\[Alpha]\_1, \[Beta]\_1}, \[Ellipsis]}, {None, \[Sigma]\^2}]\), \(estimates\
\ the\ mean\ for\ given\ variance\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["\<\
This is the estimated variance, for \[Mu]=0:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GaussianMLE[
      rr2, {{\(-1\), 1\/2}, {0, 1}, {1, 2}}, {0, None}]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \({\(-148.9934476832896`\), {0, 0.9833889438836708`}}\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell[TextData[{
  "This is the estimated mean, for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2\)]],
  "=1:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GaussianMLE[
      rr2, {{\(-1\), 1\/2}, {0, 1}, {1, 2}}, {None, 1}]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \({\(-148.72779534005537`\), {0.038660585614916955`, 1}}\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 46, 0, 36, "SubsectionIcon"],
Cell[1788, 53, 610, 11, 76, "DefinitionBox"],
Cell[2401, 66, 46, 0, 28, "MathCaption"],
Cell[2450, 68, 91, 2, 27, "Input"],
Cell[2544, 72, 138, 3, 22, "Text"],
Cell[2685, 77, 73, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2783, 81, 141, 3, 27, "Input"],
Cell[2927, 86, 103, 2, 20, "Output"]
}, Open  ]],
Cell[3045, 91, 102, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3172, 98, 284, 5, 42, "Input"],
Cell[3459, 105, 81060, 2145, 294, 21666, 1406, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[84534, 2253, 67, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[84626, 2257, 237, 5, 27, "Input"],
Cell[84866, 2264, 129, 3, 20, "Output"]
}, Open  ]],
Cell[85010, 2270, 144, 5, 22, "Text"],
Cell[85157, 2277, 213, 3, 63, "NumberedEquation"],
Cell[85373, 2282, 295, 9, 22, "Text"],
Cell[85671, 2293, 689, 12, 74, "DefinitionBox"],
Cell[86363, 2307, 460, 11, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[86848, 2322, 259, 6, 43, "Input"],
Cell[87110, 2330, 430, 12, 35, "Output"]
}, Open  ]],
Cell[87555, 2345, 69, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[87649, 2349, 134, 3, 42, "Input"],
Cell[87786, 2354, 83, 2, 20, "Output"]
}, Open  ]],
Cell[87884, 2359, 128, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[88037, 2366, 121, 3, 42, "Input"],
Cell[88161, 2371, 109, 2, 20, "Output"]
}, Open  ]],
Cell[88285, 2376, 50, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[88360, 2380, 192, 4, 42, "Input"],
Cell[88555, 2386, 84, 2, 20, "Output"]
}, Open  ]],
Cell[88654, 2391, 212, 5, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[88891, 2400, 480, 11, 71, "Input"],
Cell[89374, 2413, 58481, 1646, 294, 17192, 1131, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[147870, 4062, 338, 9, 22, "Text"],
Cell[148211, 4073, 146, 5, 22, "Text"],
Cell[148360, 4080, 335, 5, 65, "NumberedEquation"],
Cell[148698, 4087, 301, 9, 22, "Text"],
Cell[149002, 4098, 659, 14, 88, "DefinitionBox"],
Cell[149664, 4114, 66, 0, 28, "MathCaption"],
Cell[149733, 4116, 111, 2, 27, "Input"],
Cell[149847, 4120, 111, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[149983, 4127, 72, 2, 27, "Input"],
Cell[150058, 4131, 136, 3, 20, "Output"]
}, Open  ]],
Cell[150209, 4137, 434, 9, 69, "Text"],

Cell[CellGroupData[{
Cell[150668, 4150, 159, 3, 27, "Input"],
Cell[150830, 4155, 151, 3, 20, "Output"]
}, Open  ]],
Cell[150996, 4161, 95, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[151116, 4168, 98, 2, 27, "Input"],
Cell[151217, 4172, 100, 2, 20, "Output"]
}, Open  ]],
Cell[151332, 4177, 567, 10, 80, "DefinitionBox"],
Cell[151902, 4189, 147, 6, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[152074, 4199, 258, 5, 42, "Input"],
Cell[152335, 4206, 1228, 33, 75, "Output"]
}, Open  ]],
Cell[153578, 4242, 135, 5, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[153738, 4251, 243, 5, 27, "Input"],
Cell[153984, 4258, 1230, 34, 75, "Output"]
}, Open  ]],
Cell[155229, 4295, 975, 18, 104, "DefinitionBox"],
Cell[156207, 4315, 460, 11, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[156692, 4330, 258, 6, 43, "Input"],
Cell[156953, 4338, 426, 12, 35, "Output"]
}, Open  ]],
Cell[157394, 4353, 150, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[157569, 4360, 108, 2, 42, "Input"],
Cell[157680, 4364, 140, 3, 20, "Output"]
}, Open  ]],
Cell[157835, 4370, 108, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[157968, 4377, 196, 4, 42, "Input"],
Cell[158167, 4383, 155, 3, 20, "Output"]
}, Open  ]],
Cell[158337, 4389, 50, 0, 28, "MathCaption"],
Cell[158390, 4391, 498, 7, 50, "NumberedEquation"],
Cell[158891, 4400, 177, 6, 22, "Text"],
Cell[159071, 4408, 60, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[159156, 4412, 281, 6, 42, "Input"],
Cell[159440, 4420, 141, 3, 20, "Output"]
}, Open  ]],
Cell[159596, 4426, 485, 8, 62, "DefinitionBox"],
Cell[160084, 4436, 75, 2, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[160184, 4442, 126, 3, 42, "Input"],
Cell[160313, 4447, 110, 2, 20, "Output"]
}, Open  ]],
Cell[160438, 4452, 138, 5, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[160601, 4461, 126, 3, 42, "Input"],
Cell[160730, 4466, 113, 2, 20, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

