(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10386,        292]*)
(*NotebookOutlinePosition[     11729,        334]*)
(*  CellTagsIndexPosition[     11569,        326]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Utilities`Hyperlinks`", "SubsectionIcon"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`Hyperlinks`;\)\)], "Input",
  CellLabel->"In[29]:=  (9:36:06 on 2/23/01)",
  AspectRatioFixed->False],

Cell[TextData[{
  "Here is a link to the documentation for ",
  ButtonBox["life cycle stages",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ 
          ParentDirectory[ 
            ParentDirectory[ ]]], "Multilocus", "Documentation", "English"}, 
        "GenesDocumentation.nb", CharacterEncoding -> "MacintoshRoman"], 
      "stages"},
    ButtonStyle->"Hyperlink"],
  ".  Use \[CloverLeaf]E to show its full form."
}], "Text"],

Cell[TextData[{
  "Here is a link to the documentation for ",
  ButtonBox["genes and contexts",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ 
          ParentDirectory[ 
            ParentDirectory[ ]]], "Multilocus", "Documentation", "English"}, 
        "GenesDocumentation.nb", CharacterEncoding -> "MacintoshRoman"], 
      None},
    ButtonStyle->"Hyperlink"],
  " which does not specify a target cell tag."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(ConvertHyperlinkToAddOnsLink[]\), \(finds\ all\ hyperlinks\ \
within\ the\ selected\ notebook, \ 
            and\ changes\ them\ to\ the\ style\ AddOnsLink\)}
          }], TraditionalForm]],
  CellTags->"ConvertHyperlinkToAddOnsLink"]], "DefinitionBox",
  CellTags->"ConvertHyperlinkToAddOnsLink"],

Cell["\<\
This generates a new notebook, in which the four hyperlinks in this \
notebook have been converted into the style AddOnsLink:  \
\>", "MathCaption"],

Cell[BoxData[
    \(\(ConvertHyperlinkToAddOnsLink[];\)\)], "Input",
  CellLabel->"In[30]:=  (9:36:08 on 2/23/01)"],

Cell["\<\
The key difference is that when a hyperlink is clicked, the target \
file is opened in the normal way.  In contrast, when an AddOnsLink is \
clicked, the target file is opened within the Help Browser.\
\>", "Text"],

Cell["\<\
This conversion is useful because it gives an easy way to write new \
documentation notebooks:
\t1)  Write the documentation in a notebook, using style sheet HelpBrowser.
\t2)  Use the Input... menu to Create Hyperlink\[Ellipsis] as necessary; \
point to the required documentation file and (optionally) to a cell tag \
within it.
\t3)  Use ConvertHyperlinkToAddOnsLink[] to generate a new notebook with \
AddOnsLinks.
\t4) Delete the ConvertHyperlinkToAddOnsLink[] line
\t5)  Check that it is in the HelpBrowser style sheet; save as the final \
documentation folder.  \
\>", "Text"],

Cell[TextData[{
  StyleBox["NOTE: ",
    FontWeight->"Bold"],
  " The new links will not work until the new file is saved in the same \
folder as the original (see listed ",
  ButtonBox["bugs",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ 
          ParentDirectory[ 
            ParentDirectory[ ]]], "Using packages", "Documentation", 
        "English"}, "Bugs.nb", CharacterEncoding -> "MacintoshRoman"], 
      "Pasting hyperlinks"},
    ButtonStyle->"Hyperlink"],
  ")"
}], "Text"],

Cell[TextData[{
  StyleBox["NOTE: ",
    FontWeight->"Bold"],
  " ",
  StyleBox["This",
    FontSlant->"Italic"],
  " notebook has not been converted in this way, so that the four hyperlinks \
can be converted as a demonstration exercise."
}], "Text"],

Cell["\<\
ConvertHyperlinkToAddOnsLink[] reads in the entire notebook as an \
expression, and then converts any hyperlinks to AddOnsLinks using \
FindIndexTag[] (below).  The tricky part of the conversion is that hyperlinks \
give the file name, whereas AddOnsLinks refer to files by an IndexTag, which \
is defined in the BrowserCategories.m file that sits next to the \
documentation file.  If the hyperlink is  not to a documentation file, a \
warning message is generated, and the link is left unchanged.\
\>", "Text"],

Cell["\<\
It is essential that the Browsercategories.m file contain a single \
entry of the form Item[\"nameg\", \"filename\", \
IndexTag\[Rule]\"indextag\",CopyTag\[Rule]None]; FindIndexTag[] demands that \
the IndexTag be the third argument.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(FindHyperlinks[]\), \(finds\ all\ hyperlinks\ within\ the\ \
selected\ notebook, \ and\ lists\ their\ \(\(targets\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->"FindHyperlinks"]], "DefinitionBox",
  CellTags->"FindHyperlinks"],

Cell["\<\
The target of the hyperlink is denoted by the file name and the \
cell tag, \"stages\".  This information can be extracted for all the \
hyperlinks in the notebook:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fh = FindHyperlinks[]\)], "Input",
  CellLabel->"In[3]:=  (9:21:08 on 2/23/01)"],

Cell[BoxData[
    \({{"life cycle stages", {FrontEnd`FileName[{ParentDirectory[
                ParentDirectory[ParentDirectory[]]], "Multilocus", 
              "Documentation", "English"}, "GenesDocumentation.nb", 
            CharacterEncoding \[Rule] "MacintoshRoman"], 
          "stages"}}, {"genes and contexts", \
{FrontEnd`FileName[{ParentDirectory[ParentDirectory[ParentDirectory[]]], 
              "Multilocus", "Documentation", "English"}, 
            "GenesDocumentation.nb", 
            CharacterEncoding \[Rule] "MacintoshRoman"], 
          None}}, {"bugs", {FrontEnd`FileName[{ParentDirectory[
                ParentDirectory[ParentDirectory[]]], "Using packages", 
              "Documentation", "English"}, "Bugs.nb", 
            CharacterEncoding \[Rule] "MacintoshRoman"], 
          "Pasting hyperlinks"}}, {"bug", {FrontEnd`FileName[{ParentDirectory[
                ParentDirectory[ParentDirectory[]]], "Using packages", 
              "Documentation", "English"}, "Bugs.nb", 
            CharacterEncoding \[Rule] "MacintoshRoman"], 
          "Manipulating notebooks"}}}\)], "Output",
  CellLabel->"Out[3]=  (9:21:09 on 2/23/01)"]
}, Open  ]],

Cell["\<\
The results are listed in the form {name,{filename,cell tag}}.  If \
no cell tag is specified, the last element is None.  Note that the filename \
is represented in a cumbersome form usable by \
ForntEndExecute`NotebookLocate[filename].\
\>", "Text"],

Cell[TextData[{
  "After executing FindHyperlinks[], all the cells in the notebook are \
selected; this is not a serious ",
  ButtonBox["bug",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ 
          ParentDirectory[ 
            ParentDirectory[ ]]], "Using packages", "Documentation", 
        "English"}, "Bugs.nb", CharacterEncoding -> "MacintoshRoman"], 
      "Manipulating notebooks"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(FindIndexTag[
              filename]\), \(looks\ up\ the\ IndexTag\ for\ a\ documentation\ \
file, \ which\ is\ defined\ in\ the\ appropriate\ BrowserCategories . 
                m\ \(\(file\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->"FindIndexTag"]], "DefinitionBox",
  CellTags->"FindIndexTag"],

Cell["\<\
This allows conversion between standard hyperlinks (which refer to \
files by their names) and Add-ons hyperlinks, which refer to files by their \
index tags.  The file name must be specified in the form FrontEnd`FileName[], \
as produced by FindHyperlinks[].  \
\>", "Text"],

Cell["\<\
This finds the IndexTag which is associated with the second \
hyperlink in this notebook:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindIndexTag[
      fh\[LeftDoubleBracket]2, 2, 1\[RightDoubleBracket]]\)], "Input",
  CellLabel->"In[40]:=  (19:36:33 on 2/21/01)"],

Cell[BoxData[
    \("Genes and contexts"\)], "Output",
  CellLabel->"Out[40]=  (19:36:36 on 2/21/01)"]
}, Open  ]],

Cell["\<\
FindIndexTag[filename] first finds the BrowserCategories.m file in \
the same folder as the named documentation notebook, and then searches within \
it for the IndexTag associated with that notebook.   It is essential that the \
notebook have an entry in BrowserCategories.m of the form Item[\"nameg\", \
\"filename\", IndexTag\[Rule]\"indextag\",CopyTag\[Rule]None]; FindIndexTag[] \
demands that the IndexTag be the third argument.\
\>", "Text"],

Cell["\<\
Error messages are generated if the files are not found, or the \
IndexTag is not found; a blank string \"\" is then returned.\
\>", "Text"],

Cell[TextData[{
  "NOTE: ",
  StyleBox["Links to built-in functions, within RefGuide.nb, are not \
converted properly.  To make these links, paste in from \
Refguide:BrowserIndex.nb",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{908, 686},
WindowMargins->{{0, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000_02@?oaonh32@9BH`85:0?l0@00005X0FP000003[0;@001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
ojH?;@^J00P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "ConvertHyperlinkToAddOnsLink"->{
    Cell[2886, 88, 362, 7, 37, "DefinitionBox",
      CellTags->"ConvertHyperlinkToAddOnsLink"]},
  "FindHyperlinks"->{
    Cell[5907, 170, 300, 6, 37, "DefinitionBox",
      CellTags->"FindHyperlinks"]},
  "FindIndexTag"->{
    Cell[8432, 234, 375, 8, 50, "DefinitionBox",
      CellTags->"FindIndexTag"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"ConvertHyperlinkToAddOnsLink", 11236, 313},
  {"FindHyperlinks", 11356, 316},
  {"FindIndexTag", 11461, 319}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 47, 0, 36, "SubsectionIcon"],
Cell[1789, 53, 46, 0, 28, "MathCaption"],
Cell[1838, 55, 136, 3, 27, "Input"],
Cell[1977, 60, 454, 12, 22, "Text"],
Cell[2434, 74, 449, 12, 22, "Text"],
Cell[2886, 88, 362, 7, 37, "DefinitionBox",
  CellTags->"ConvertHyperlinkToAddOnsLink"],
Cell[3251, 97, 158, 3, 28, "MathCaption"],
Cell[3412, 102, 115, 2, 27, "Input"],
Cell[3530, 106, 224, 4, 36, "Text"],
Cell[3757, 112, 593, 12, 132, "Text"],
Cell[4353, 126, 512, 15, 24, "Text"],
Cell[4868, 143, 251, 8, 24, "Text"],
Cell[5122, 153, 522, 8, 50, "Text"],
Cell[5647, 163, 257, 5, 36, "Text"],
Cell[5907, 170, 300, 6, 37, "DefinitionBox",
  CellTags->"FindHyperlinks"],
Cell[6210, 178, 188, 4, 22, "Text"],

Cell[CellGroupData[{
Cell[6423, 186, 100, 2, 27, "Input"],
Cell[6526, 190, 1160, 19, 111, "Output"]
}, Open  ]],
Cell[7701, 212, 260, 5, 36, "Text"],
Cell[7964, 219, 465, 13, 22, "Text"],
Cell[8432, 234, 375, 8, 50, "DefinitionBox",
  CellTags->"FindIndexTag"],
Cell[8810, 244, 285, 5, 36, "Text"],
Cell[9098, 251, 120, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[9243, 258, 152, 3, 27, "Input"],
Cell[9398, 263, 102, 2, 20, "Output"]
}, Open  ]],
Cell[9515, 268, 457, 7, 50, "Text"],
Cell[9975, 277, 150, 3, 22, "Text"],
Cell[10128, 282, 242, 7, 24, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

