(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     17071,        395]*)
(*NotebookOutlinePosition[     17955,        423]*)
(*  CellTagsIndexPosition[     17911,        419]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Marginal tables", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MarginalTable[
              m, {\[Alpha], \[Beta], \[Ellipsis]}]\), \(gives\ a\ table\ of\ \
marginal\ value, \ 
            averaging\ over\ all\ dimensions\ of\ m\ other\ than\ {\[Alpha], \
\[Beta]\[Ellipsis]}\)}
          }], TraditionalForm]],
  CellTags->"MarginalTable"]], "DefinitionBox"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`Matrices`;\)\)], "Input",
  CellLabel->"In[9]:="],

Cell["This is a four-dimensional array:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tt = Array[g\_## &, {3, 4, 3, 2}]; tt // MatrixForm\)], "Input",
  CellLabel->"In[766]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(g\_\(1, 1, 1, 1\)\), \(g\_\(1, 1, 1, 2\)\)},
                    {\(g\_\(1, 1, 2, 1\)\), \(g\_\(1, 1, 2, 2\)\)},
                    {\(g\_\(1, 1, 3, 1\)\), \(g\_\(1, 1, 3, 2\)\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(g\_\(1, 2, 1, 1\)\), \(g\_\(1, 2, 1, 2\)\)},
                    {\(g\_\(1, 2, 2, 1\)\), \(g\_\(1, 2, 2, 2\)\)},
                    {\(g\_\(1, 2, 3, 1\)\), \(g\_\(1, 2, 3, 2\)\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(g\_\(1, 3, 1, 1\)\), \(g\_\(1, 3, 1, 2\)\)},
                    {\(g\_\(1, 3, 2, 1\)\), \(g\_\(1, 3, 2, 2\)\)},
                    {\(g\_\(1, 3, 3, 1\)\), \(g\_\(1, 3, 3, 2\)\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(g\_\(1, 4, 1, 1\)\), \(g\_\(1, 4, 1, 2\)\)},
                    {\(g\_\(1, 4, 2, 1\)\), \(g\_\(1, 4, 2, 2\)\)},
                    {\(g\_\(1, 4, 3, 1\)\), \(g\_\(1, 4, 3, 2\)\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(g\_\(2, 1, 1, 1\)\), \(g\_\(2, 1, 1, 2\)\)},
                    {\(g\_\(2, 1, 2, 1\)\), \(g\_\(2, 1, 2, 2\)\)},
                    {\(g\_\(2, 1, 3, 1\)\), \(g\_\(2, 1, 3, 2\)\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(g\_\(2, 2, 1, 1\)\), \(g\_\(2, 2, 1, 2\)\)},
                    {\(g\_\(2, 2, 2, 1\)\), \(g\_\(2, 2, 2, 2\)\)},
                    {\(g\_\(2, 2, 3, 1\)\), \(g\_\(2, 2, 3, 2\)\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(g\_\(2, 3, 1, 1\)\), \(g\_\(2, 3, 1, 2\)\)},
                    {\(g\_\(2, 3, 2, 1\)\), \(g\_\(2, 3, 2, 2\)\)},
                    {\(g\_\(2, 3, 3, 1\)\), \(g\_\(2, 3, 3, 2\)\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(g\_\(2, 4, 1, 1\)\), \(g\_\(2, 4, 1, 2\)\)},
                    {\(g\_\(2, 4, 2, 1\)\), \(g\_\(2, 4, 2, 2\)\)},
                    {\(g\_\(2, 4, 3, 1\)\), \(g\_\(2, 4, 3, 2\)\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(g\_\(3, 1, 1, 1\)\), \(g\_\(3, 1, 1, 2\)\)},
                    {\(g\_\(3, 1, 2, 1\)\), \(g\_\(3, 1, 2, 2\)\)},
                    {\(g\_\(3, 1, 3, 1\)\), \(g\_\(3, 1, 3, 2\)\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(g\_\(3, 2, 1, 1\)\), \(g\_\(3, 2, 1, 2\)\)},
                    {\(g\_\(3, 2, 2, 1\)\), \(g\_\(3, 2, 2, 2\)\)},
                    {\(g\_\(3, 2, 3, 1\)\), \(g\_\(3, 2, 3, 2\)\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(g\_\(3, 3, 1, 1\)\), \(g\_\(3, 3, 1, 2\)\)},
                    {\(g\_\(3, 3, 2, 1\)\), \(g\_\(3, 3, 2, 2\)\)},
                    {\(g\_\(3, 3, 3, 1\)\), \(g\_\(3, 3, 3, 2\)\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(g\_\(3, 4, 1, 1\)\), \(g\_\(3, 4, 1, 2\)\)},
                    {\(g\_\(3, 4, 2, 1\)\), \(g\_\(3, 4, 2, 2\)\)},
                    {\(g\_\(3, 4, 3, 1\)\), \(g\_\(3, 4, 3, 2\)\)}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{{
        Subscript[ g, 1, 1, 1, 1], 
        Subscript[ g, 1, 1, 1, 2]}, {
        Subscript[ g, 1, 1, 2, 1], 
        Subscript[ g, 1, 1, 2, 2]}, {
        Subscript[ g, 1, 1, 3, 1], 
        Subscript[ g, 1, 1, 3, 2]}}, {{
        Subscript[ g, 1, 2, 1, 1], 
        Subscript[ g, 1, 2, 1, 2]}, {
        Subscript[ g, 1, 2, 2, 1], 
        Subscript[ g, 1, 2, 2, 2]}, {
        Subscript[ g, 1, 2, 3, 1], 
        Subscript[ g, 1, 2, 3, 2]}}, {{
        Subscript[ g, 1, 3, 1, 1], 
        Subscript[ g, 1, 3, 1, 2]}, {
        Subscript[ g, 1, 3, 2, 1], 
        Subscript[ g, 1, 3, 2, 2]}, {
        Subscript[ g, 1, 3, 3, 1], 
        Subscript[ g, 1, 3, 3, 2]}}, {{
        Subscript[ g, 1, 4, 1, 1], 
        Subscript[ g, 1, 4, 1, 2]}, {
        Subscript[ g, 1, 4, 2, 1], 
        Subscript[ g, 1, 4, 2, 2]}, {
        Subscript[ g, 1, 4, 3, 1], 
        Subscript[ g, 1, 4, 3, 2]}}}, {{{
        Subscript[ g, 2, 1, 1, 1], 
        Subscript[ g, 2, 1, 1, 2]}, {
        Subscript[ g, 2, 1, 2, 1], 
        Subscript[ g, 2, 1, 2, 2]}, {
        Subscript[ g, 2, 1, 3, 1], 
        Subscript[ g, 2, 1, 3, 2]}}, {{
        Subscript[ g, 2, 2, 1, 1], 
        Subscript[ g, 2, 2, 1, 2]}, {
        Subscript[ g, 2, 2, 2, 1], 
        Subscript[ g, 2, 2, 2, 2]}, {
        Subscript[ g, 2, 2, 3, 1], 
        Subscript[ g, 2, 2, 3, 2]}}, {{
        Subscript[ g, 2, 3, 1, 1], 
        Subscript[ g, 2, 3, 1, 2]}, {
        Subscript[ g, 2, 3, 2, 1], 
        Subscript[ g, 2, 3, 2, 2]}, {
        Subscript[ g, 2, 3, 3, 1], 
        Subscript[ g, 2, 3, 3, 2]}}, {{
        Subscript[ g, 2, 4, 1, 1], 
        Subscript[ g, 2, 4, 1, 2]}, {
        Subscript[ g, 2, 4, 2, 1], 
        Subscript[ g, 2, 4, 2, 2]}, {
        Subscript[ g, 2, 4, 3, 1], 
        Subscript[ g, 2, 4, 3, 2]}}}, {{{
        Subscript[ g, 3, 1, 1, 1], 
        Subscript[ g, 3, 1, 1, 2]}, {
        Subscript[ g, 3, 1, 2, 1], 
        Subscript[ g, 3, 1, 2, 2]}, {
        Subscript[ g, 3, 1, 3, 1], 
        Subscript[ g, 3, 1, 3, 2]}}, {{
        Subscript[ g, 3, 2, 1, 1], 
        Subscript[ g, 3, 2, 1, 2]}, {
        Subscript[ g, 3, 2, 2, 1], 
        Subscript[ g, 3, 2, 2, 2]}, {
        Subscript[ g, 3, 2, 3, 1], 
        Subscript[ g, 3, 2, 3, 2]}}, {{
        Subscript[ g, 3, 3, 1, 1], 
        Subscript[ g, 3, 3, 1, 2]}, {
        Subscript[ g, 3, 3, 2, 1], 
        Subscript[ g, 3, 3, 2, 2]}, {
        Subscript[ g, 3, 3, 3, 1], 
        Subscript[ g, 3, 3, 3, 2]}}, {{
        Subscript[ g, 3, 4, 1, 1], 
        Subscript[ g, 3, 4, 1, 2]}, {
        Subscript[ g, 3, 4, 2, 1], 
        Subscript[ g, 3, 4, 2, 2]}, {
        Subscript[ g, 3, 4, 3, 1], 
        Subscript[ g, 3, 4, 3, 2]}}}}]]], "Output",
  CellLabel->"Out[766]//MatrixForm="]
}, Open  ]],

Cell["\<\
This tabulates the mean over dimensions {1,2}, yielding a table of \
marginal values indexed by levels {3,4}:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MarginalTable[tt, {3, 4}] // MatrixForm\)], "Input",
  CellLabel->"In[715]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/12\ \((g\_\(1, 1, 1, 1\) + g\_\(1, 2, 1, 1\) + 
                    g\_\(1, 3, 1, 1\) + g\_\(1, 4, 1, 1\) + 
                    g\_\(2, 1, 1, 1\) + g\_\(2, 2, 1, 1\) + 
                    g\_\(2, 3, 1, 1\) + g\_\(2, 4, 1, 1\) + 
                    g\_\(3, 1, 1, 1\) + g\_\(3, 2, 1, 1\) + 
                    g\_\(3, 3, 1, 1\) + 
                    g\_\(3, 4, 1, 1\))\)\), \(1\/12\ \((g\_\(1, 1, 1, 2\) + 
                    g\_\(1, 2, 1, 2\) + g\_\(1, 3, 1, 2\) + 
                    g\_\(1, 4, 1, 2\) + g\_\(2, 1, 1, 2\) + 
                    g\_\(2, 2, 1, 2\) + g\_\(2, 3, 1, 2\) + 
                    g\_\(2, 4, 1, 2\) + g\_\(3, 1, 1, 2\) + 
                    g\_\(3, 2, 1, 2\) + g\_\(3, 3, 1, 2\) + 
                    g\_\(3, 4, 1, 2\))\)\)},
            {\(1\/12\ \((g\_\(1, 1, 2, 1\) + g\_\(1, 2, 2, 1\) + 
                    g\_\(1, 3, 2, 1\) + g\_\(1, 4, 2, 1\) + 
                    g\_\(2, 1, 2, 1\) + g\_\(2, 2, 2, 1\) + 
                    g\_\(2, 3, 2, 1\) + g\_\(2, 4, 2, 1\) + 
                    g\_\(3, 1, 2, 1\) + g\_\(3, 2, 2, 1\) + 
                    g\_\(3, 3, 2, 1\) + 
                    g\_\(3, 4, 2, 1\))\)\), \(1\/12\ \((g\_\(1, 1, 2, 2\) + 
                    g\_\(1, 2, 2, 2\) + g\_\(1, 3, 2, 2\) + 
                    g\_\(1, 4, 2, 2\) + g\_\(2, 1, 2, 2\) + 
                    g\_\(2, 2, 2, 2\) + g\_\(2, 3, 2, 2\) + 
                    g\_\(2, 4, 2, 2\) + g\_\(3, 1, 2, 2\) + 
                    g\_\(3, 2, 2, 2\) + g\_\(3, 3, 2, 2\) + 
                    g\_\(3, 4, 2, 2\))\)\)},
            {\(1\/12\ \((g\_\(1, 1, 3, 1\) + g\_\(1, 2, 3, 1\) + 
                    g\_\(1, 3, 3, 1\) + g\_\(1, 4, 3, 1\) + 
                    g\_\(2, 1, 3, 1\) + g\_\(2, 2, 3, 1\) + 
                    g\_\(2, 3, 3, 1\) + g\_\(2, 4, 3, 1\) + 
                    g\_\(3, 1, 3, 1\) + g\_\(3, 2, 3, 1\) + 
                    g\_\(3, 3, 3, 1\) + 
                    g\_\(3, 4, 3, 1\))\)\), \(1\/12\ \((g\_\(1, 1, 3, 2\) + 
                    g\_\(1, 2, 3, 2\) + g\_\(1, 3, 3, 2\) + 
                    g\_\(1, 4, 3, 2\) + g\_\(2, 1, 3, 2\) + 
                    g\_\(2, 2, 3, 2\) + g\_\(2, 3, 3, 2\) + 
                    g\_\(2, 4, 3, 2\) + g\_\(3, 1, 3, 2\) + 
                    g\_\(3, 2, 3, 2\) + g\_\(3, 3, 3, 2\) + 
                    g\_\(3, 4, 3, 2\))\)\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[715]//MatrixForm="]
}, Open  ]],

Cell["\<\
When applied to the null set, MarginalTable[] returns the overall \
mean:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MarginalTable[tt, {}]\)], "Input",
  CellLabel->"In[767]:="],

Cell[BoxData[
    \(1\/72\ \((g\_\(1, 1, 1, 1\) + g\_\(1, 1, 1, 2\) + g\_\(1, 1, 2, 1\) + 
          g\_\(1, 1, 2, 2\) + g\_\(1, 1, 3, 1\) + g\_\(1, 1, 3, 2\) + 
          g\_\(1, 2, 1, 1\) + g\_\(1, 2, 1, 2\) + g\_\(1, 2, 2, 1\) + 
          g\_\(1, 2, 2, 2\) + g\_\(1, 2, 3, 1\) + g\_\(1, 2, 3, 2\) + 
          g\_\(1, 3, 1, 1\) + g\_\(1, 3, 1, 2\) + g\_\(1, 3, 2, 1\) + 
          g\_\(1, 3, 2, 2\) + g\_\(1, 3, 3, 1\) + g\_\(1, 3, 3, 2\) + 
          g\_\(1, 4, 1, 1\) + g\_\(1, 4, 1, 2\) + g\_\(1, 4, 2, 1\) + 
          g\_\(1, 4, 2, 2\) + g\_\(1, 4, 3, 1\) + g\_\(1, 4, 3, 2\) + 
          g\_\(2, 1, 1, 1\) + g\_\(2, 1, 1, 2\) + g\_\(2, 1, 2, 1\) + 
          g\_\(2, 1, 2, 2\) + g\_\(2, 1, 3, 1\) + g\_\(2, 1, 3, 2\) + 
          g\_\(2, 2, 1, 1\) + g\_\(2, 2, 1, 2\) + g\_\(2, 2, 2, 1\) + 
          g\_\(2, 2, 2, 2\) + g\_\(2, 2, 3, 1\) + g\_\(2, 2, 3, 2\) + 
          g\_\(2, 3, 1, 1\) + g\_\(2, 3, 1, 2\) + g\_\(2, 3, 2, 1\) + 
          g\_\(2, 3, 2, 2\) + g\_\(2, 3, 3, 1\) + g\_\(2, 3, 3, 2\) + 
          g\_\(2, 4, 1, 1\) + g\_\(2, 4, 1, 2\) + g\_\(2, 4, 2, 1\) + 
          g\_\(2, 4, 2, 2\) + g\_\(2, 4, 3, 1\) + g\_\(2, 4, 3, 2\) + 
          g\_\(3, 1, 1, 1\) + g\_\(3, 1, 1, 2\) + g\_\(3, 1, 2, 1\) + 
          g\_\(3, 1, 2, 2\) + g\_\(3, 1, 3, 1\) + g\_\(3, 1, 3, 2\) + 
          g\_\(3, 2, 1, 1\) + g\_\(3, 2, 1, 2\) + g\_\(3, 2, 2, 1\) + 
          g\_\(3, 2, 2, 2\) + g\_\(3, 2, 3, 1\) + g\_\(3, 2, 3, 2\) + 
          g\_\(3, 3, 1, 1\) + g\_\(3, 3, 1, 2\) + g\_\(3, 3, 2, 1\) + 
          g\_\(3, 3, 2, 2\) + g\_\(3, 3, 3, 1\) + g\_\(3, 3, 3, 2\) + 
          g\_\(3, 4, 1, 1\) + g\_\(3, 4, 1, 2\) + g\_\(3, 4, 2, 1\) + 
          g\_\(3, 4, 2, 2\) + g\_\(3, 4, 3, 1\) + 
          g\_\(3, 4, 3, 2\))\)\)], "Output",
  CellLabel->"Out[767]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MarginalTable[m, {\[Alpha], \[Beta], \[Ellipsis]}, 
              Function \[Rule] f]\), \(uses\ f[]\ instead\ of\ Mean[
                Flatten[]]\ to\ construct\ the\ \(\(table\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->"Function"]], "DefinitionBox"],

Cell["\<\
Instead of taking the average, some other function can be \
used:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MarginalTable[tt, {3, 4}, Function \[Rule] f] // MatrixForm\)], "Input",\

  CellLabel->"In[716]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(f[{{g\_\(1, 1, 1, 1\), g\_\(1, 2, 1, 1\), g\_\(1, 3, 1, 1\), 
                    g\_\(1, 4, 1, 1\)}, {g\_\(2, 1, 1, 1\), 
                    g\_\(2, 2, 1, 1\), g\_\(2, 3, 1, 1\), 
                    g\_\(2, 4, 1, 1\)}, {g\_\(3, 1, 1, 1\), 
                    g\_\(3, 2, 1, 1\), g\_\(3, 3, 1, 1\), 
                    g\_\(3, 4, 1, 1\)}}]\), \(f[{{g\_\(1, 1, 1, 2\), 
                    g\_\(1, 2, 1, 2\), g\_\(1, 3, 1, 2\), 
                    g\_\(1, 4, 1, 2\)}, {g\_\(2, 1, 1, 2\), 
                    g\_\(2, 2, 1, 2\), g\_\(2, 3, 1, 2\), 
                    g\_\(2, 4, 1, 2\)}, {g\_\(3, 1, 1, 2\), 
                    g\_\(3, 2, 1, 2\), g\_\(3, 3, 1, 2\), 
                    g\_\(3, 4, 1, 2\)}}]\)},
            {\(f[{{g\_\(1, 1, 2, 1\), g\_\(1, 2, 2, 1\), g\_\(1, 3, 2, 1\), 
                    g\_\(1, 4, 2, 1\)}, {g\_\(2, 1, 2, 1\), 
                    g\_\(2, 2, 2, 1\), g\_\(2, 3, 2, 1\), 
                    g\_\(2, 4, 2, 1\)}, {g\_\(3, 1, 2, 1\), 
                    g\_\(3, 2, 2, 1\), g\_\(3, 3, 2, 1\), 
                    g\_\(3, 4, 2, 1\)}}]\), \(f[{{g\_\(1, 1, 2, 2\), 
                    g\_\(1, 2, 2, 2\), g\_\(1, 3, 2, 2\), 
                    g\_\(1, 4, 2, 2\)}, {g\_\(2, 1, 2, 2\), 
                    g\_\(2, 2, 2, 2\), g\_\(2, 3, 2, 2\), 
                    g\_\(2, 4, 2, 2\)}, {g\_\(3, 1, 2, 2\), 
                    g\_\(3, 2, 2, 2\), g\_\(3, 3, 2, 2\), 
                    g\_\(3, 4, 2, 2\)}}]\)},
            {\(f[{{g\_\(1, 1, 3, 1\), g\_\(1, 2, 3, 1\), g\_\(1, 3, 3, 1\), 
                    g\_\(1, 4, 3, 1\)}, {g\_\(2, 1, 3, 1\), 
                    g\_\(2, 2, 3, 1\), g\_\(2, 3, 3, 1\), 
                    g\_\(2, 4, 3, 1\)}, {g\_\(3, 1, 3, 1\), 
                    g\_\(3, 2, 3, 1\), g\_\(3, 3, 3, 1\), 
                    g\_\(3, 4, 3, 1\)}}]\), \(f[{{g\_\(1, 1, 3, 2\), 
                    g\_\(1, 2, 3, 2\), g\_\(1, 3, 3, 2\), 
                    g\_\(1, 4, 3, 2\)}, {g\_\(2, 1, 3, 2\), 
                    g\_\(2, 2, 3, 2\), g\_\(2, 3, 3, 2\), 
                    g\_\(2, 4, 3, 2\)}, {g\_\(3, 1, 3, 2\), 
                    g\_\(3, 2, 3, 2\), g\_\(3, 3, 3, 2\), 
                    g\_\(3, 4, 3, 2\)}}]\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[716]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "The default function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is Mean[Flatten[]].  "
}], "Text"],

Cell["\<\
MarginalTable[m,{\[Alpha],\[Beta]}] consructs a table of values \
using ExtractSubMatrix[].  It is called by VarianceComponents[]\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{Automatic, 186}, {32, Automatic}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 41, 0, 36, "SubsectionIcon"],
Cell[1783, 53, 359, 8, 50, "DefinitionBox"],
Cell[2145, 63, 46, 0, 28, "MathCaption"],
Cell[2194, 65, 84, 2, 27, "Input"],
Cell[2281, 69, 56, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2362, 73, 110, 2, 27, "Input"],
Cell[2475, 77, 6522, 140, 165, "Output"]
}, Open  ]],
Cell[9012, 220, 140, 3, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[9177, 227, 98, 2, 27, "Input"],
Cell[9278, 231, 2513, 44, 77, "Output"]
}, Open  ]],
Cell[11806, 278, 104, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11935, 285, 80, 2, 27, "Input"],
Cell[12018, 289, 1774, 26, 162, "Output"]
}, Open  ]],
Cell[13807, 318, 329, 6, 50, "DefinitionBox"],
Cell[14139, 326, 96, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[14260, 333, 120, 3, 27, "Input"],
Cell[14383, 338, 2372, 41, 57, "Output"]
}, Open  ]],
Cell[16770, 382, 129, 5, 22, "Text"],
Cell[16902, 389, 153, 3, 36, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

