(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11702,        364]*)
(*NotebookOutlinePosition[     12585,        392]*)
(*  CellTagsIndexPosition[     12541,        388]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Drawing lists of random numbers", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                
                FormBox[\(\(RandomList\)\([\)\(k, {p\_1, \(p\_2 .. \) 
                        p\_n\)\),
                  "TraditionalForm"], "}"}], "]"}], 
            RowBox[{
              RowBox[{
              "gives", " ", "k", " ", "integers", " ", "in", " ", "the", " ", 
                "range", " ", \({1.  . n}\), " ", "from", " ", "the", " ", 
                "probability", " ", "vector", " ", 
                FormBox[\({p\_1, \(p\_2 .. \) p\_n\),
                  "TraditionalForm"]}], "}"}]},
          {
            RowBox[{
              RowBox[{
                RowBox[{
                  
                  FormBox[\(\(RandomList\)\([\)\(k, {p\_1, \(p\_2 .. \) 
                          p\_n\)\),
                    "TraditionalForm"], "}"}], 
                ",", \({s\_1, \(s\_2 .. \) s\_n}\)}], 
              "]"}], \(gives\ a\ list\ containing\ k\ randomly\ chosen\ \
elements\ from\ the\ set\ {s\_1, \(s\_2 .. \) s\_n}\)}
          }], TraditionalForm]],
  CellTags->"RandomList"]], "DefinitionBox"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`RandomNumbers`;\)\)], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
This package automatically loads Statistics`DiscreteDistributions`, \
Statistics`ContinuousDistributions` as well.\
\>", "Text"],

Cell["\<\
Here is a random sample from the probability distribution, given as \
a list of 10 integers\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RandomList[10, {0.1, 0.4, 0.5}]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \({3, 2, 2, 2, 2, 3, 3, 2, 3, 3}\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell["\<\
The probability vector must sum to 1: it is not normalised \
internally.  If the sum is less than 1, then the remaining probability is \
assigned to the next integer:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RandomList[10, {0.01, 0.04, 0.05}]\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \({2, 4, 4, 4, 4, 4, 4, 4, 3, 2}\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell["\<\
Here is a random sample from the probability distribution, given as \
a list of elements of the set {a,b,c}\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RandomList[10, {0.1, 0.4, 0.5}, {a, b, c}]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \({b, c, b, b, c, b, c, a, b, c}\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(\(RandomList\)\([\)\(k, {p\_1, \(p\_2 .. \) p\_n\)\),
              "TraditionalForm"], "}"}], "]"}], TraditionalForm]]],
  " just makes ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " separate trials; in principle, that is less efficient than using \
RandomMultinomial[] to produce the numbers of each outcome, and then generate \
a set with that number.  However, that requires a random reordering (using \
Muddle[]), and overall, is slower than using RandomList[]"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                RowBox[{
                  
                  FormBox[\(\(RandomList\)\([\)\(k, {p\_1, \(p\_2 .. \) 
                          p\_n\)\),
                    "TraditionalForm"], "}"}], 
                ",", \(Compiled \[Rule] True\)}], "]"}], 
            RowBox[{
              RowBox[{
              "uses", " ", "compiled", " ", "code", " ", "to", " ", "give", 
                " ", "k", " ", "integers", " ", "in", " ", "the", " ", 
                "range", " ", \({1.  . n}\), " ", "from", " ", "the", " ", 
                "probability", " ", "vector", " ", 
                FormBox[\({p\_1, \(p\_2 .. \) p\_n\),
                  "TraditionalForm"]}], "}"}]},
          {
            RowBox[{
              RowBox[{
                RowBox[{
                  
                  FormBox[\(\(RandomList\)\([\)\(k, {p\_1, \(p\_2 .. \) 
                          p\_n\)\),
                    "TraditionalForm"], "}"}], 
                ",", \({s\_1, \(s\_2 .. \) s\_n}\), 
                ",", \(Compiled \[Rule] True\)}], 
              "]"}], \(uses\ compiled\ code\ to\ give\ a\ list\ containing\ k\
\ randomly\ chosen\ elements\ from\ the\ set\ {s\_1, \(s\_2 .. \) s\_n}\)}
          }], TraditionalForm]],
  CellTags->"Compiled"]], "DefinitionBox"],

Cell["Compiling RandomList[] is fivefold faster.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(pp = Table[Random[], {100}]; pp = pp/\((Plus @@ pp)\);\), "\n", 
    \({Timing[\(RandomList[1000, pp];\)], 
      Timing[\(RandomList[1000, pp, Compiled \[Rule] True];\)]}\)}], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \({{1.0666666666667197`\ Second, Null}, {0.1999999999999318`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                RowBox[{
                  
                  FormBox[\(\(RandomList\)\([\)\(k, {p\_1, \(p\_2 .. \) 
                          p\_n\)\),
                    "TraditionalForm"], "}"}], 
                ",", \(Replace \[Rule] False\)}], "]"}], 
            RowBox[{
              RowBox[{"samples", " ", "k", " ", "integers", " ", 
                StyleBox["without",
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                StyleBox["replacement",
                  FontSlant->"Italic"], " ", "in", " ", "the", " ", "range", 
                " ", \({1.  . n}\), " ", "from", " ", "the", " ", 
                "probability", " ", "vector", " ", 
                FormBox[\({p\_1, \(p\_2 .. \) p\_n\),
                  "TraditionalForm"]}], "}"}]},
          {
            RowBox[{
              RowBox[{
                RowBox[{
                  
                  FormBox[\(\(RandomList\)\([\)\(k, {p\_1, \(p\_2 .. \) 
                          p\_n\)\),
                    "TraditionalForm"], "}"}], 
                ",", \({s\_1, \(s\_2 .. \) s\_n}\), 
                ",", \(Replace \[Rule] False\)}], "]"}], 
            RowBox[{
            "samples", " ", "k", " ", "randomly", " ", "chosen", " ", 
              "elements", " ", 
              StyleBox["without",
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["replacement",
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSlant->"Italic"], "from", " ", "the", " ", "set", 
              " ", \({s\_1, \(s\_2 .. \) s\_n}\)}]}
          }], TraditionalForm]],
  CellTags->"Replace"]], "DefinitionBox"],

Cell[TextData[{
  "This samples 8 integers ",
  StyleBox["with replacement:",
    FontSlant->"Italic"]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RandomList[8, {1, 2, 3, 4, 5, 6, 7, 8, 9, 10}/55]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \({7, 8, 8, 8, 5, 10, 3, 10}\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell["\<\
Note that absolute probabilities must be given: probabilities are \
not normalised internally.\
\>", "Text"],

Cell[TextData[{
  "This gives the same, but sampling ",
  StyleBox["without replacement",
    FontSlant->"Italic"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RandomList[8, {1, 2, 3, 4, 5, 6, 7, 8, 9, 10}/55, 
      Replace \[Rule] False]\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \({9, 5, 6, 8, 10, 3, 4, 2}\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["\<\
The values are given in order: so, the more probable values tend to \
be first.\
\>", "Text"],

Cell["The number sampled cannot be greater than the list of items:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RandomList[12, {1, 2, 3, 4, 5, 6, 7, 8, 9, 10}/55, 
      Replace \[Rule] False]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(RandomList::"tooMany" \(\(:\)\(\ \)\) 
      "\!\(12\) cannot be sampled without replacement from the list \
\!\({1\/55, 2\/55, 3\/55, 4\/55, 1\/11, 6\/55, 7\/55, 8\/55, 9\/55, 2\/11}\)"\
\)], "Message",
  CellLabel->"From In[33]:="],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7, 8, 9, 10}\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell["\<\
Sampling without replacement is considerably slower.  However, it \
can still be speeded by compiling:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(pp = Table[Random[], {100}]; pp = pp/\((Plus @@ pp)\);\), "\n", 
    \({{"\<With replacement\>", \(Timing[\(RandomList[100, 
                  pp];\)]\)\[LeftDoubleBracket]1\[RightDoubleBracket], \
\(Timing[\(RandomList[100, pp, 
                  Compiled \[Rule] 
                    True];\)]\)\[LeftDoubleBracket]1\[RightDoubleBracket]}, \
{"\<No replacement\>", \(Timing[\(RandomList[100, pp, 
                  Replace \[Rule] 
                    False];\)]\)\[LeftDoubleBracket]1\[RightDoubleBracket], \
\(Timing[\(RandomList[100, pp, Compiled \[Rule] True, 
                  Replace \[Rule] 
                    False];\)]\)\[LeftDoubleBracket]1\[RightDoubleBracket]}} // 
      TableForm\)}], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"With replacement\"\>", \(0.11666666666667425`\ Second\), \
\(0.01666666666665151`\ Second\)},
          {"\<\"No replacement\"\>", \(0.3166666666666629`\ Second\), \
\(0.15000000000000568`\ Second\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[18]//TableForm="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{832, 645},
WindowMargins->{{41, Automatic}, {Automatic, 13}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 57, 0, 36, "SubsectionIcon"],
Cell[1799, 53, 1152, 28, 54, "DefinitionBox"],
Cell[2954, 83, 46, 0, 28, "MathCaption"],
Cell[3003, 85, 89, 2, 27, "Input"],
Cell[3095, 89, 138, 3, 22, "Text"],
Cell[3236, 94, 122, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3383, 101, 89, 2, 27, "Input"],
Cell[3475, 105, 89, 2, 20, "Output"]
}, Open  ]],
Cell[3579, 110, 197, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3801, 118, 92, 2, 27, "Input"],
Cell[3896, 122, 89, 2, 20, "Output"]
}, Open  ]],
Cell[4000, 127, 138, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4163, 134, 100, 2, 27, "Input"],
Cell[4266, 138, 89, 2, 20, "Output"]
}, Open  ]],
Cell[4370, 143, 591, 14, 36, "Text"],
Cell[4964, 159, 1378, 32, 54, "DefinitionBox"],
Cell[6345, 193, 65, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6435, 197, 231, 4, 42, "Input"],
Cell[6669, 203, 142, 3, 20, "Output"]
}, Open  ]],
Cell[6826, 209, 1873, 46, 70, "DefinitionBox"],
Cell[8702, 257, 121, 4, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[8848, 265, 107, 2, 27, "Input"],
Cell[8958, 269, 85, 2, 20, "Output"]
}, Open  ]],
Cell[9058, 274, 118, 3, 22, "Text"],
Cell[9179, 279, 140, 5, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[9344, 288, 137, 3, 27, "Input"],
Cell[9484, 293, 84, 2, 20, "Output"]
}, Open  ]],
Cell[9583, 298, 103, 3, 22, "Text"],
Cell[9689, 303, 85, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[9799, 308, 138, 3, 27, "Input"],
Cell[9940, 313, 253, 5, 36, "Message"],
Cell[10196, 320, 90, 2, 20, "Output"]
}, Open  ]],
Cell[10301, 325, 133, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[10459, 332, 758, 14, 72, "Input"],
Cell[11220, 348, 454, 12, 47, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

