(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      3548,        121]*)
(*NotebookOutlinePosition[      4609,        156]*)
(*  CellTagsIndexPosition[      4528,        150]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Degrees of freedom", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\("DegreesOfFreedom[data,vars,{\!\(model\_1\),\[Ellipsis]}]"\), \
\(gives\ the\ number\ of\ parameters\ specified\ by\ the\ \(\(models\)\(.\)\)\
\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"DegreesOfFreedom"],

Cell["This loads the package", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`StructuredModels`;\)\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
If a model is fitted with density effects, and {rep,line} effects, \
then the number of degrees of freedom is 1+(4-1)+(10*2-1)=23 - that is, one \
main effect, (4-1) parametrs for variation across the four densities, and \
(10*2-1) parameters for variation across the 2 replicates and 10 lines, and \
their interaction.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DegreesOfFreedom[
      dd, {line, rep, density}, {{density, {rep, line}}}]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \({23}\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell["\<\
The null model fits just one parameter to all entries in the array:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DegreesOfFreedom[dd, {line, rep, density}, {{}}]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \({1}\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell["\<\
The format allows a list of models to be given, and returns a \
corresponding list of the number of parameters to be fitted:\
\>", \
"MathCaption"],

Cell[BoxData[
    \(DegreesOfFreedom[
      dd, {line, rep, 
        density}, {{line, {density, rep}}, {line, density}}]\)], "Input",
  CellLabel->"In[23]:="],

Cell["\<\
This allows different models to be fitted to different \
parameters.\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{572, 668},
WindowMargins->{{45, Automatic}, {-13, Automatic}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "DegreesOfFreedom"->{
    Cell[1786, 53, 293, 6, 50, "DefinitionBox",
      CellTags->"DegreesOfFreedom"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"DegreesOfFreedom", 4417, 143}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 44, 0, 36, "SubsectionIcon"],
Cell[1786, 53, 293, 6, 50, "DefinitionBox",
  CellTags->"DegreesOfFreedom"],
Cell[2082, 61, 45, 0, 28, "MathCaption"],
Cell[2130, 63, 92, 2, 27, "Input"],
Cell[2225, 67, 343, 6, 50, "Text"],

Cell[CellGroupData[{
Cell[2593, 77, 133, 3, 27, "Input"],
Cell[2729, 82, 63, 2, 20, "Output"]
}, Open  ]],
Cell[2807, 87, 100, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2932, 94, 106, 2, 27, "Input"],
Cell[3041, 98, 62, 2, 20, "Output"]
}, Open  ]],
Cell[3118, 103, 157, 4, 42, "MathCaption"],
Cell[3278, 109, 159, 4, 27, "Input"],
Cell[3440, 115, 92, 3, 22, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

