(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     19530,        454]*)
(*NotebookOutlinePosition[     21038,        501]*)
(*  CellTagsIndexPosition[     20861,        492]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Options", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"StructuredMLE", "[", 
              RowBox[{
                StyleBox["data",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["vars",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["{",
                    FontSlant->"Italic"], 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["model",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["pars",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["LogL",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox[\(PrintDetails \[Rule] True\),
                  FontSlant->"Italic"]}], 
              "]"}], \(prints\ details\ of\ intermediate\ \(\(stages\)\(.\)\)\
\)}
          }], TraditionalForm]],
  CellTags->{"StructuredMLE", "PrintDetails"}]], "DefinitionBox",
  CellTags->{"StructuredMLE", "PrintDetails"}],

Cell["This loads the package", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`StructuredModels`;\)\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
The algorithm adjusts each model element, for each parameter.  If \
the change after this cycle of optimisations is greater than \[Epsilon] (by \
default, 0.01), then the cycle is repeated.  Intermediate likelihoods and \
parameter estimates can be printed by setting PrintDetails\[Rule]True.\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StructuredMLE", "[", 
      RowBox[{
      "dd", ",", \({line, rep, density}\), 
        ",", \({{density, {rep, line}}, {density}}\), ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"2.", ",", \({0, 1, 2, 3}\), ",", 
                RowBox[{"(", GridBox[{
                      {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
                      {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"}
                      }], ")"}]}], "}"}], ",", \({2. , {0, 1, 2, 3}}\)}], 
          "}"}], ",", "LogL2", ",", \(PrintDetails \[Rule] True\)}], 
      "]"}]], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \({\(-1339.6486778948474`\), {{4.394681244505241`, {\(-1.051984883819937`\
\), \(-0.32328423342279455`\), 0.1567971428528021`, 
            1.2184719743899297`}, {{0.052949179108802244`, 
              0.05250337433430208`, \(-0.07391481547678311`\), \
\(-0.17856484362501102`\), \(-0.008068480891398916`\), \
\(-0.09835548915334004`\), 0.032519944307405485`, 0.09895005878140288`, 
              0.07909194192271027`, 
              0.0327818364870926`}, {\(-0.017192770325944295`\), 
              0.03743742543609276`, \(-0.04978926877809629`\), \
\(-0.25883410143650554`\), \(-0.04257226670595216`\), \
\(-0.032433821635365435`\), 0.0887057921396411`, 0.13141598583970926`, 
              0.11508912198699847`, 
              0.038281197684239696`}}}, {1.574446129790101`, \
{\(-1.909099902997332`\), \(-0.8079577807159029`\), 0.6480285576459064`, 
            2.0690291260673286`}}}}\)], "Print",
  CellLabel->"From In[47]:="],

Cell[BoxData[
    \({\(-1149.5670109157918`\), {{4.213771628292442`, \
{\(-0.9854362049114456`\), \(-0.2996178574310857`\), 0.08475489136247075`, 
            1.2002991709800608`}, {{0.05894153235504725`, 
              0.04816523457146671`, \(-0.07558596794677773`\), \
\(-0.23492790238526431`\), 0.011820262143038617`, \(-0.10669773655776436`\), 
              0.036756299717831016`, 0.09444368442686105`, 
              0.09771191479165152`, 
              0.023933482808108125`}, {\(-0.0015104809042280935`\), 
              0.04620185392559469`, \(-0.04803889467120432`\), \
\(-0.2972933921260509`\), \(-0.03613361387089482`\), \(-0.014336684436438367`\
\), 0.09610340320459161`, 0.1268718112094337`, 0.11760185024597407`, 
              0.05597334349902448`}}}, {0.4212758635933711`, \
{\(-1.3911787718087072`\), \(-1.0830576706904442`\), \(-0.146980616806498`\), 
            2.6212170593056503`}}}}\)], "Print",
  CellLabel->"From In[47]:="],

Cell[BoxData[
    \({\(-1135.4597240072496`\), {{4.1910297001001435`, \
{\(-0.9594431468344076`\), \(-0.2846596269418406`\), 0.05886255827062534`, 
            1.1852402155056228`}, {{0.023424890290044496`, 
              0.04212895612499246`, \(-0.06456908735181177`\), \
\(-0.2236287352463348`\), \(-0.009129138619934033`\), \(-0.07802394168534706`\
\), 0.03489772409197494`, 0.09637761413672932`, 0.10765522254271741`, 
              0.042729291200163236`}, {\(-0.0497542429280797`\), 
              0.03176628847343616`, \(-0.03855119856959945`\), \
\(-0.2857027640611225`\), \(-0.02958430380600824`\), \(-0.029528489973781345`\
\), 0.09382351504590834`, 0.12357896856255603`, 0.1344781341528098`, 
              0.07761129762068672`}}}, {0.3371341760423827`, \
{\(-1.2327598328013465`\), \(-1.0547952838580212`\), \
\(-0.40330317040537356`\), 2.6908582870647413`}}}}\)], "Print",
  CellLabel->"From In[47]:="],

Cell[BoxData[
    \({\(-1134.7115992018844`\), {{4.190183103085084`, \
{\(-0.9587159001459391`\), \(-0.2840116966091292`\), 0.05918328954084689`, 
            1.1835443072142213`}, {{0.008878704777888411`, 
              0.04182680848419836`, \(-0.06356924153236793`\), \
\(-0.2182646593873146`\), \(-0.016761228709850466`\), \(-0.07205123535790414`\
\), 0.0345559429176284`, 0.10058362198478185`, 0.11084181780390825`, 
              0.049649849620915856`}, {\(-0.06741404520484184`\), 
              0.028216219190912495`, \(-0.04379751400864585`\), \
\(-0.27997803950098715`\), \(-0.02408830000595718`\), \
\(-0.034728676763442844`\), 0.09555615459755014`, 0.12709078039868754`, 
              0.13882711498008538`, 
              0.08462592571475525`}}}, {0.33496494727652504`, \
{\(-1.1890517480889944`\), \(-1.0431862909195015`\), \
\(-0.46926244247537036`\), 2.701500481483866`}}}}\)], "Print",
  CellLabel->"From In[47]:="],

Cell[BoxData[
    \({\(-1134.6479119890628`\), {{4.190019334205747`, \
{\(-0.9586898887204083`\), \(-0.2839848035422412`\), 0.059210941362343054`, 
            1.1834637509003065`}, {{0.004611310326098055`, 
              0.04190155120492963`, \(-0.06335863524605095`\), \
\(-0.2168525212418771`\), \(-0.01889967798340259`\), \
\(-0.07053677624654081`\), 0.03441053869608717`, 0.1019603487458776`, 
              0.11171463730362975`, 
              0.051617130953919475`}, {\(-0.07257183471276205`\), 
              0.027291494998683417`, \(-0.04551720211201405`\), \
\(-0.278360339462704`\), \(-0.0224289700290322`\), \(-0.03613275908665982`\), 
              0.09621242304384253`, 0.12832907712274855`, 0.140041726562822`, 
              0.08656847716240547`}}}, {0.33536616924237594`, \
{\(-1.1765188217365148`\), \(-1.0385416223690878`\), \
\(-0.48891972403658374`\), 2.703980168142187`}}}}\)], "Print",
  CellLabel->"From In[47]:="],

Cell[BoxData[
    \({\(-1134.6420825572734`\), {{4.189977078479839`, \
{\(-0.9586888903099968`\), \(-0.28398238577957635`\), 0.05921388266825948`, 
            1.1834573934213135`}, {{0.0032689111924914228`, 
              0.04192619417926831`, \(-0.06330038612068803`\), \
\(-0.21642583547878122`\), \(-0.019550514555830283`\), \
\(-0.07012001035134705`\), 0.03434917252665527`, 0.1023850427568016`, 
              0.11196264515022981`, 
              0.05219999406507832`}, {\(-0.0740820749412691`\), 
              0.027020917669450185`, \(-0.046046221535282`\), \
\(-0.2778260069353985`\), \(-0.021900094743260965`\), \(-0.03653660843308529`\
\), 0.09641699601240843`, 0.12872002654805229`, 0.14038444006166234`, 
              0.08715341293284445`}}}, {0.3355644325706919`, \
{\(-1.1728431487760547`\), \(-1.036921166265824`\), \(-0.4949362609592864`\), 
            2.704700576001165`}}}}\)], "Print",
  CellLabel->"From In[47]:="],

Cell[BoxData[
    \({\(-1134.6420825572734`\), {{4.189977078479839`, \
{\(-0.9586888903099968`\), \(-0.28398238577957635`\), 0.05921388266825948`, 
            1.1834573934213135`}, {{0.0032689111924914228`, 
              0.04192619417926831`, \(-0.06330038612068803`\), \
\(-0.21642583547878122`\), \(-0.019550514555830283`\), \
\(-0.07012001035134705`\), 0.03434917252665527`, 0.1023850427568016`, 
              0.11196264515022981`, 
              0.05219999406507832`}, {\(-0.0740820749412691`\), 
              0.027020917669450185`, \(-0.046046221535282`\), \
\(-0.2778260069353985`\), \(-0.021900094743260965`\), \(-0.03653660843308529`\
\), 0.09641699601240843`, 0.12872002654805229`, 0.14038444006166234`, 
              0.08715341293284445`}}}, {0.3355644325706919`, \
{\(-1.1728431487760547`\), \(-1.036921166265824`\), \(-0.4949362609592864`\), 
            2.704700576001165`}}}}\)], "Output",
  CellLabel->"Out[47]="]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"StructuredMLE", "[", 
              RowBox[{
                StyleBox["data",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["vars",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["{",
                    FontSlant->"Italic"], 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["model",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["pars",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["LogL",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox[\(ErrorBound \[Rule] \[Epsilon]\),
                  FontSlant->"Italic"]}], 
              "]"}], \(stops\ when\ the\ change\ in\ log\ likelihood\ over\ a\
\ whole\ cycle\ is\ less\ than\ \[Epsilon] . \ 
                  The\ default\ is\ \[Epsilon] = \(\(0.01\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"ErrorBound"],

Cell["\<\
This reduces the threshold change at which the algorithm stops to \
\[Epsilon]=0.001, and hence increases accuracy:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StructuredMLE", "[", 
      RowBox[{
      "dd", ",", \({line, rep, density}\), 
        ",", \({{density, {rep, line}}, {density}}\), ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"2.", ",", \({0, 1, 2, 3}\), ",", 
                RowBox[{"(", GridBox[{
                      {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
                      {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"}
                      }], ")"}]}], "}"}], ",", \({2. , {0, 1, 2, 3}}\)}], 
          "}"}], ",", "LogL2", ",", \(ErrorBound \[Rule] 0.001\)}], 
      "]"}]], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \({81636.20550984523`, {{4.189935719546395`, {\(-0.9586603019874238`\), \
\(-0.2839532641913279`\), 0.0592457475879096`, 
            1.183367818590842`}, {{0.0026935264649110458`, 
              0.04194092439174509`, \(-0.06327873078094622`\), \
\(-0.2162146561816417`\), \(-0.019842774041333923`\), \(-0.06999270210555468`\
\), 0.03431190870355457`, 0.10257224625072191`, 0.11204466940917993`, 
              0.05243898519984763`}, {\(-0.07466445122340541`\), 
              0.026909491665583058`, \(-0.04626895011746945`\), \
\(-0.2775661859233566`\), \(-0.021675102097531502`\), \(-0.03671078676174387`\
\), 0.09650077849837992`, 0.12890417237719956`, 0.1405141077396645`, 
              0.08738352853219626`}}}, {0.3339479681353047`, \
{\(-1.1696528984778514`\), \(-1.0343576215104024`\), \
\(-0.4991443246722257`\), 2.70315484466048`}}}}\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"StructuredMLE", "[", 
              RowBox[{
                StyleBox["data",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["vars",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["{",
                    FontSlant->"Italic"], 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["model",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["pars",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["LogL",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox[\(StartingStepSize \[Rule] g\),
                  FontSlant->"Italic"]}], "]"}], 
            
            RowBox[{\(gives\ FindMinimum[]\ starting\ values\ equal\ to\ g[
                  parameter]\), ";", " ", 
              RowBox[{
                RowBox[{"the", " ", "default", " ", "is", " ", 
                  RowBox[{"g", "[", 
                    RowBox[{
                      StyleBox["par",
                        FontSlant->"Italic"], ",", "j"}], "]"}]}], "=", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["par",
                      FontSlant->"Italic"], "j"], 
                  "+", \(\({\(-0.1\), 0.1}\)\(.\)\)}]}]}]}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"StartingStepSize"],

Cell[TextData[{
  "Unless a formula for component estimates is provided (MLE\[Rule]True), \
maximisation is performed by FindMinimum[].  Some care is needed to ensure \
that appropriate starting values are supplied to this function.  First, the \
likelihood function will not usually have a symbolic derivative; the \
numerical version FindMimimum[f,{x,{x0,x1}}] is therefore used by default, \
rather than the symbolic version FindMinimum[f,{x,x0}].  Second, the \
parameter values must stay within the allowed range.  In this example, that \
is acheived by parameterising the mean and ",
  Cell[BoxData[
      \(TraditionalForm\`variance\/mean\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`{\[ExponentialE]\^z, \[ExponentialE]\^c}\)]],
  ", so that they must remain positive."
}], "Text"],

Cell[TextData[{
  "The option StartingStepSize gives some flexibility, since it allows an \
arbitrary assignment of starting values for each parameter.  ",
  Cell[BoxData[
      \(TraditionalForm\`FindMinimum[f[x], {x, g[par\_j, j]}]\)]],
  "  is called for the ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  "'th parameter; if g[] returns a single value, then symbolic derivatives \
are used.  The default is {#+{0.1,0.1}}&, which subtracts or adds 0.1 to each \
parameter to give a pair of starting values.  This could be changed to give \
more appropriate values for each parameter.  A function such as {#}& would \
lead FindMinimum[] to use symbolic derivatives.  If f[] can be \
differentiated, that might be faster."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StructuredMLE", "[", 
      RowBox[{
      "dd", ",", \({line, rep, density}\), 
        ",", \({{density, {rep, line}}, {density}}\), ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"2.", ",", \({0, 1, 2, 3}\), ",", 
                RowBox[{"(", GridBox[{
                      {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
                      {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"}
                      }], ")"}]}], "}"}], ",", \({2. , {0, 1, 2, 3}}\)}], 
          "}"}], ",", "LogL2", 
        ",", \(StartingStepSize \[Rule] \(({# + {\(-0.1\), 0.1}} &)\)\)}], 
      "]"}]], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \({81636.20511773837`, {{4.18994572990146`, {\(-0.9586582282259238`\), \
\(-0.2839515014480307`\), 0.05924619315573917`, 
            1.1833635365182154`}, {{0.003191399338567512`, 
              0.041937678365276024`, \(-0.06330055034940607`\), \
\(-0.216366195728638`\), \(-0.01961038994433815`\), \
\(-0.07013047277932959`\), 0.03433998145683262`, 0.1024250143024837`, 
              0.11196060690717607`, 
              0.05223748442639849`}, {\(-0.07414967378595133`\), 
              0.027004931876906224`, \(-0.04608060695882188`\), \
\(-0.27778091915290404`\), \(-0.0218765084998804`\), \
\(-0.03657608476840449`\), 0.0964304758265533`, 0.12876783416916868`, 
              0.14040454814016376`, 
              0.08717144715814763`}}}, {0.33395482448663205`, \
{\(-1.1709916433048557`\), \(-1.0350732490367256`\), \
\(-0.4966592642635155`\), 2.702724156605097`}}}}\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{893, 702},
WindowMargins->{{16, Automatic}, {2, Automatic}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "StructuredMLE"->{
    Cell[1775, 53, 1499, 39, 52, "DefinitionBox",
      CellTags->{"StructuredMLE", "PrintDetails"}]},
  "PrintDetails"->{
    Cell[1775, 53, 1499, 39, 52, "DefinitionBox",
      CellTags->{"StructuredMLE", "PrintDetails"}]},
  "ErrorBound"->{
    Cell[11020, 247, 1549, 39, 48, "DefinitionBox",
      CellTags->"ErrorBound"]},
  "StartingStepSize"->{
    Cell[14330, 329, 1961, 50, 52, "DefinitionBox",
      CellTags->"StartingStepSize"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"StructuredMLE", 20394, 476},
  {"PrintDetails", 20517, 479},
  {"ErrorBound", 20638, 482},
  {"StartingStepSize", 20746, 485}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 33, 0, 36, "SubsectionIcon"],
Cell[1775, 53, 1499, 39, 52, "DefinitionBox",
  CellTags->{"StructuredMLE", "PrintDetails"}],
Cell[3277, 94, 45, 0, 28, "MathCaption"],
Cell[3325, 96, 92, 2, 27, "Input"],
Cell[3420, 100, 318, 6, 36, "Text"],

Cell[CellGroupData[{
Cell[3763, 110, 670, 15, 63, "Input"],
Cell[4436, 127, 949, 16, 59, "Print"],
Cell[5388, 145, 949, 15, 59, "Print"],
Cell[6340, 162, 914, 14, 59, "Print"],
Cell[7257, 178, 931, 15, 59, "Print"],
Cell[8191, 195, 938, 15, 59, "Print"],
Cell[9132, 212, 937, 15, 59, "Print"],
Cell[10072, 229, 933, 15, 59, "Output"]
}, Closed]],
Cell[11020, 247, 1549, 39, 48, "DefinitionBox",
  CellTags->"ErrorBound"],
Cell[12572, 288, 146, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[12743, 295, 669, 15, 63, "Input"],
Cell[13415, 312, 900, 14, 59, "Output"]
}, Open  ]],
Cell[14330, 329, 1961, 50, 52, "DefinitionBox",
  CellTags->"StartingStepSize"],
Cell[16294, 381, 800, 15, 78, "Text"],
Cell[17097, 398, 740, 14, 67, "Text"],

Cell[CellGroupData[{
Cell[17862, 416, 708, 16, 63, "Input"],
Cell[18573, 434, 929, 16, 59, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

