(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4454,        134]*)
(*NotebookOutlinePosition[      5524,        169]*)
(*  CellTagsIndexPosition[      5440,        163]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Structured parameters", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(StructuredParameter[{i, j\[Ellipsis]}, vars, model, 
              pars]\), \(constructs\ the\ parameter\ value\ appropriate\ to\ \
the\ element\ {i, j\[Ellipsis]}\ in\ the\ data\ array, 
            assuming\ an\ additive\ \(\(model\)\(.\)\)\)},
          {\(StructuredParameter[{i, j\[Ellipsis]}, 
              vars, {model\_1, \[Ellipsis]}, 
              pars]\), \(specifies\ a\ list\ of\ several\ models; \ 
            parameter\ values\ are\ returned\ as\ lists\ corresponding\ to\ \
the\ list\ of\ \(\(models\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"StructuredParameter"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`StructuredModels`;\)\)], "Input",
  CellLabel->"In[1]:="],

Cell[TextData[{
  "This parameter list specifies a main effect, ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0\)]],
  "; an effect of density, ",
  Cell[BoxData[
      \(TraditionalForm\`z\_d\%1\)]],
  "; and an interaction between replicate and line, ",
  Cell[BoxData[
      \(TraditionalForm\`z\_\(r, l\)\%2\)]],
  ":"
}], "MathCaption"],

Cell[BoxData[
    \(\(pars = {z\_0, {z\_1\%1, z\_2\%1, z\_3\%1, 
            z\_4\%1}, {{z\_\(1, 1\)\%2, z\_\(1, 2\)\%2, z\_\(1, 3\)\%2, 
              z\_\(1, 4\)\%2, z\_\(1, 5\)\%2, z\_\(1, 6\)\%2, z\_\(1, 7\)\%2, 
              z\_\(1, 8\)\%2, z\_\(1, 9\)\%2, 
              z\_\(1, 10\)\%2}, {z\_\(2, 1\)\%2, z\_\(2, 2\)\%2, 
              z\_\(2, 3\)\%2, z\_\(2, 4\)\%2, z\_\(2, 5\)\%2, z\_\(2, 6\)\%2, 
              z\_\(2, 7\)\%2, z\_\(2, 8\)\%2, z\_\(2, 9\)\%2, 
              z\_\(2, 10\)\%2}}};\)\)], "Input",
  CellLabel->"In[3]:="],

Cell["\<\
This constructs the parameter value appropriate for element {8,1,3} \
in the data array: that is, for density # 3, replicate #1, and line #8:\
\>", \
"SmallText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StructuredParameter[{8, 1, 3}, {line, rep, 
        density}, {density, {rep, line}}, pars]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(z\_0 + z\_3 + z\_\(1, 8\)\%2\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell["\<\
A list of models and parameters can be given; then, a list of \
parameters is returned:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StructuredParameter[{8, 1, 3}, {line, rep, 
        density}, {{density}, {density, {rep, line}}}, {{y\_0, {y\_1\%1, 
            y\_2\%1, y\_3\%1, y\_4\%1}}, pars}]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \({y\_0 + y\_3, z\_0 + z\_3 + z\_\(1, 8\)\%2}\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{572, 668},
WindowMargins->{{17, Automatic}, {Automatic, 16}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "StructuredParameter"->{
    Cell[1789, 53, 680, 12, 98, "DefinitionBox",
      CellTags->"StructuredParameter"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"StructuredParameter", 5325, 156}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 47, 0, 36, "SubsectionIcon"],
Cell[1789, 53, 680, 12, 98, "DefinitionBox",
  CellTags->"StructuredParameter"],
Cell[2472, 67, 46, 0, 28, "MathCaption"],
Cell[2521, 69, 92, 2, 27, "Input"],
Cell[2616, 73, 342, 11, 47, "MathCaption"],
Cell[2961, 86, 544, 9, 47, "Input"],
Cell[3508, 97, 172, 4, 22, "SmallText"],

Cell[CellGroupData[{
Cell[3705, 105, 148, 3, 27, "Input"],
Cell[3856, 110, 86, 2, 25, "Output"]
}, Open  ]],
Cell[3957, 115, 118, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4100, 122, 222, 4, 42, "Input"],
Cell[4325, 128, 101, 2, 25, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

