(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     21328,        483]*)
(*NotebookOutlinePosition[     22406,        518]*)
(*  CellTagsIndexPosition[     22319,        512]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Simplifying a structured model", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"StructuredModelReduce", "[", 
              StyleBox[\(data, vars, model, pars\),
                FontSlant->"Italic"], "]"}], 
            
            RowBox[{\(generates\ a\ flattened\ version\ of\ the\ data\ and\ \
parameters\), ",", " ", 
              RowBox[{"of", " ", "the", " ", "form", " ", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox["data",
                            FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                      "}"}], ",", 
                    RowBox[{"{", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox["pars",
                            FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                      "}"}]}], "}"}]}]}]}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"StructuredModelReduce"],

Cell["This loads the package", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`StructuredModels`;\)\)], "Input",
  CellLabel->"In[1]:="],

Cell[TextData[{
  "StructuredModelReduce[",
  StyleBox["data,vars,model,pars",
    FontSlant->"Italic"],
  "] flattens the dataset over irrelevant variables, and generates parallel \
lists of data elements and parameter values.  The model specifies that each \
",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["data",
            FontSlant->"Italic"], "i"], TraditionalForm]]],
  " is drawn from a distribution given by parameters ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["pars",
            FontSlant->"Italic"], "i"], TraditionalForm]]],
  ".  Thus, the overall likelihood is calculated by StructuredLogLikelihood \
as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+i LogL[data\_i, pars\_i]\)]],
  ".  "
}], "Text"],

Cell["\<\
For example, the model {density, line} specifies that every data \
element that has a distinct density and line is drawn from a distribution \
specified by a sum of main effect, density, and line effects for means, and \
density effects only for variances.  \
\>", "Text"],

Cell["\<\
For 4 densities and 10 lines, there are 40 distinct datasets, each \
corresponding to a distinct parameter set:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StructuredModelReduce[
      ldd, {line, rep, 
        density}, {{density, 
          line}, {density}}, {{z\_\(m, 0\), {z\_\(d, 1\), z\_\(d, 2\), 
            z\_\(d, 3\), z\_\(d, 4\)}, {z\_\(l, 1\), z\_\(l, 2\), 
            z\_\(l, 3\), z\_\(l, 4\), z\_\(l, 5\), z\_\(l, 6\), z\_\(l, 7\), 
            z\_\(l, 8\), z\_\(l, 9\), 
            z\_\(l, 10\)}}, {y\_\(m, 0\), {y\_\(d, 1\), y\_\(d, 2\), 
            y\_\(d, 3\), y\_\(d, 4\)}}}]\)], "Input",
  CellLabel->"In[383]:="],

Cell[BoxData[
    \({{{3.295836866004329`, 3.367295829986474`, 3.1780538303479458`, 
          3.295836866004329`, 3.367295829986474`, 3.1780538303479458`, 
          3.367295829986474`, 3.258096538021482`, 3.4965075614664802`, 
          3.258096538021482`}, {3.9889840465642745`, 3.871201010907891`, 
          4.0943445622221`, 4.060443010546419`, 3.8918202981106265`, 
          3.8501476017100584`, 3.828641396489095`, 3.8066624897703196`, 
          3.8501476017100584`, 3.7376696182833684`}, {4.04305126783455`, 
          4.07753744390572`, 4.127134385045092`, 3.970291913552122`, 
          4.07753744390572`, 3.9318256327243257`, 4.02535169073515`, 
          4.007333185232471`, 4.143134726391533`, 
          4.060443010546419`}, {5.817111159963204`, 5.834810737062605`, 
          5.484796933490655`, 5.3981627015177525`}, {3.1780538303479458`, 
          3.1354942159291497`, 3.332204510175204`, 3.367295829986474`, 
          3.295836866004329`, 3.295836866004329`, 3.1354942159291497`, 
          3.295836866004329`, 3.4339872044851463`, 
          3.332204510175204`}, {3.9512437185814275`, 3.8501476017100584`, 
          3.9318256327243257`, 4.02535169073515`, 4.007333185232471`, 
          3.9512437185814275`, 4.0943445622221`, 3.8918202981106265`, 
          3.8066624897703196`, 3.8501476017100584`}, {4.219507705176107`, 
          4.189654742026425`, 4.189654742026425`, 4.48863636973214`, 
          4.290459441148391`, 4.189654742026425`, 4.330733340286331`, 
          4.219507705176107`, 4.30406509320417`, 
          4.219507705176107`}, {5.556828061699537`, 5.6937321388027`, 
          5.476463551931511`, 5.3230099791384085`}, {3.367295829986474`, 
          3.2188758248682006`, 3.1780538303479458`, 2.6390573296152584`, 
          3.1354942159291497`, 3.044522437723423`, 3.091042453358316`, 
          3.4965075614664802`, 3.1354942159291497`, 
          2.8903717578961645`}, {3.871201010907891`, 3.8066624897703196`, 
          4.007333185232471`, 3.713572066704308`, 3.8501476017100584`, 
          3.871201010907891`, 3.912023005428146`, 3.8066624897703196`, 
          3.970291913552122`, 3.970291913552122`}, {4.174387269895637`, 
          4.30406509320417`, 3.828641396489095`, 4.276666119016055`, 
          4.290459441148391`, 3.8501476017100584`, 4.1588830833596715`, 
          4.2626798770413155`, 4.276666119016055`, 
          4.143134726391533`}, {5.424950017481403`, 4.890349128221754`, 
          5.407171771460119`, 5.135798437050262`}, {2.995732273553991`, 
          2.4849066497880004`, 3.1780538303479458`, 3.044522437723423`, 
          2.9444389791664403`, 2.70805020110221`, 2.8903717578961645`, 
          3.2188758248682006`, 2.833213344056216`, 
          3.091042453358316`}, {3.828641396489095`, 3.8501476017100584`, 
          3.4965075614664802`, 3.4657359027997265`, 3.5263605246161616`, 
          3.6375861597263857`, 3.332204510175204`, 3.7612001156935624`, 
          3.1780538303479458`, 3.6888794541139363`}, {4.110873864173311`, 
          4.02535169073515`, 4.110873864173311`, 4.04305126783455`, 
          4.127134385045092`, 4.290459441148391`, 3.828641396489095`, 
          3.9318256327243257`, 3.9889840465642745`, 
          4.127134385045092`}, {5.552959584921617`, 5.545177444479562`, 
          4.962844630259907`, 4.59511985013459`}, {3.367295829986474`, 
          3.295836866004329`, 3.332204510175204`, 3.1354942159291497`, 
          3.295836866004329`, 3.367295829986474`, 2.995732273553991`, 
          3.258096538021482`, 3.258096538021482`, 
          3.2188758248682006`}, {4.04305126783455`, 3.8918202981106265`, 
          3.784189633918261`, 3.8918202981106265`, 3.912023005428146`, 
          3.828641396489095`, 3.9318256327243257`, 3.5263605246161616`, 
          3.912023005428146`, 3.8918202981106265`}, {4.23410650459726`, 
          4.219507705176107`, 4.23410650459726`, 4.0943445622221`, 
          3.9889840465642745`, 4.290459441148391`, 4.330733340286331`, 
          4.219507705176107`, 4.406719247264253`, 
          4.219507705176107`}, {4.875197323201151`, 5.2832037287379885`, 
          4.990432586778736`, 4.836281906951478`}, {2.995732273553991`, 
          3.1354942159291497`, 3.1780538303479458`, 3.091042453358316`, 
          2.995732273553991`, 3.367295829986474`, 3.1354942159291497`, 
          3.091042453358316`, 3.4011973816621555`, 
          3.295836866004329`}, {3.8501476017100584`, 3.784189633918261`, 
          3.8918202981106265`, 3.8501476017100584`, 3.9889840465642745`, 
          3.784189633918261`, 3.8918202981106265`, 3.784189633918261`, 
          3.8501476017100584`, 3.9889840465642745`}, {4.276666119016055`, 
          4.189654742026425`, 4.174387269895637`, 4.290459441148391`, 
          4.127134385045092`, 4.30406509320417`, 4.219507705176107`, 
          4.007333185232471`, 4.248495242049359`, 
          4.110873864173311`}, {4.882801922586371`, 4.672828834461906`, 
          4.736198448394496`, 5.209486152841421`}, {3.1780538303479458`, 
          3.258096538021482`, 3.332204510175204`, 3.295836866004329`, 
          3.295836866004329`, 3.367295829986474`, 3.367295829986474`, 
          3.332204510175204`, 3.2188758248682006`, 
          3.332204510175204`}, {3.912023005428146`, 4.127134385045092`, 
          3.970291913552122`, 3.9889840465642745`, 3.6635616461296463`, 
          4.07753744390572`, 4.007333185232471`, 3.8918202981106265`, 
          3.9889840465642745`, 4.007333185232471`}, {4.204692619390966`, 
          4.290459441148391`, 4.204692619390966`, 4.418840607796598`, 
          4.23410650459726`, 4.454347296253507`, 4.330733340286331`, 
          4.442651256490317`, 4.343805421853684`, 
          4.219507705176107`}, {5.303304908059076`, 5.438079308923196`, 
          5.488937726156687`, 5.476463551931511`}, {3.367295829986474`, 
          3.295836866004329`, 3.295836866004329`, 3.2188758248682006`, 
          3.332204510175204`, 3.367295829986474`, 3.332204510175204`, 
          3.332204510175204`, 3.4011973816621555`, 
          3.258096538021482`}, {4.060443010546419`, 3.9889840465642745`, 
          3.9512437185814275`, 3.9889840465642745`, 3.970291913552122`, 
          3.970291913552122`, 4.04305126783455`, 3.970291913552122`, 
          4.02535169073515`, 4.04305126783455`}, {4.430816798843313`, 
          4.406719247264253`, 4.382026634673881`, 4.3694478524670215`, 
          4.356708826689592`, 4.356708826689592`, 4.394449154672439`, 
          4.477336814478207`, 4.343805421853684`, 
          4.477336814478207`}, {5.777652323222656`, 5.58724865840025`, 
          5.8522024797744745`, 5.84354441703136`}, {3.295836866004329`, 
          3.258096538021482`, 3.332204510175204`, 3.332204510175204`, 
          3.4011973816621555`, 3.332204510175204`, 3.295836866004329`, 
          3.1780538303479458`, 3.367295829986474`, 
          3.295836866004329`}, {3.9512437185814275`, 4.060443010546419`, 
          3.9318256327243257`, 3.970291913552122`, 4.189654742026425`, 
          4.0943445622221`, 4.127134385045092`, 3.9889840465642745`, 
          4.04305126783455`, 4.0943445622221`}, {4.356708826689592`, 
          4.442651256490317`, 4.343805421853684`, 4.23410650459726`, 
          4.51085950651685`, 4.454347296253507`, 4.406719247264253`, 
          4.477336814478207`, 4.382026634673881`, 
          4.330733340286331`}, {4.762173934797756`, 5.616771097666572`, 
          5.53338948872752`, 5.673323267171493`}, {3.1354942159291497`, 
          3.091042453358316`, 3.258096538021482`, 3.332204510175204`, 
          3.2188758248682006`, 3.4657359027997265`, 3.091042453358316`, 
          3.295836866004329`, 3.2188758248682006`, 
          3.295836866004329`}, {3.9512437185814275`, 3.9318256327243257`, 
          3.828641396489095`, 4.02535169073515`, 4.04305126783455`, 
          3.784189633918261`, 4.0943445622221`, 3.9512437185814275`, 
          4.07753744390572`, 3.9512437185814275`}, {4.418840607796598`, 
          4.454347296253507`, 4.290459441148391`, 4.276666119016055`, 
          4.30406509320417`, 4.442651256490317`, 4.499809670330265`, 
          4.343805421853684`, 4.430816798843313`, 
          4.2626798770413155`}, {5.37989735354046`, 5.484796933490655`, 
          5.0689042022202315`, 
          4.919980925828125`}}, {{z\_\(d, 1\) + z\_\(l, 1\) + z\_\(m, 0\), 
          y\_\(d, 1\) + y\_\(m, 0\)}, {z\_\(d, 2\) + z\_\(l, 1\) + 
            z\_\(m, 0\), 
          y\_\(d, 2\) + y\_\(m, 0\)}, {z\_\(d, 3\) + z\_\(l, 1\) + 
            z\_\(m, 0\), 
          y\_\(d, 3\) + y\_\(m, 0\)}, {z\_\(d, 4\) + z\_\(l, 1\) + 
            z\_\(m, 0\), 
          y\_\(d, 4\) + y\_\(m, 0\)}, {z\_\(d, 1\) + z\_\(l, 2\) + 
            z\_\(m, 0\), 
          y\_\(d, 1\) + y\_\(m, 0\)}, {z\_\(d, 2\) + z\_\(l, 2\) + 
            z\_\(m, 0\), 
          y\_\(d, 2\) + y\_\(m, 0\)}, {z\_\(d, 3\) + z\_\(l, 2\) + 
            z\_\(m, 0\), 
          y\_\(d, 3\) + y\_\(m, 0\)}, {z\_\(d, 4\) + z\_\(l, 2\) + 
            z\_\(m, 0\), 
          y\_\(d, 4\) + y\_\(m, 0\)}, {z\_\(d, 1\) + z\_\(l, 3\) + 
            z\_\(m, 0\), 
          y\_\(d, 1\) + y\_\(m, 0\)}, {z\_\(d, 2\) + z\_\(l, 3\) + 
            z\_\(m, 0\), 
          y\_\(d, 2\) + y\_\(m, 0\)}, {z\_\(d, 3\) + z\_\(l, 3\) + 
            z\_\(m, 0\), 
          y\_\(d, 3\) + y\_\(m, 0\)}, {z\_\(d, 4\) + z\_\(l, 3\) + 
            z\_\(m, 0\), 
          y\_\(d, 4\) + y\_\(m, 0\)}, {z\_\(d, 1\) + z\_\(l, 4\) + 
            z\_\(m, 0\), 
          y\_\(d, 1\) + y\_\(m, 0\)}, {z\_\(d, 2\) + z\_\(l, 4\) + 
            z\_\(m, 0\), 
          y\_\(d, 2\) + y\_\(m, 0\)}, {z\_\(d, 3\) + z\_\(l, 4\) + 
            z\_\(m, 0\), 
          y\_\(d, 3\) + y\_\(m, 0\)}, {z\_\(d, 4\) + z\_\(l, 4\) + 
            z\_\(m, 0\), 
          y\_\(d, 4\) + y\_\(m, 0\)}, {z\_\(d, 1\) + z\_\(l, 5\) + 
            z\_\(m, 0\), 
          y\_\(d, 1\) + y\_\(m, 0\)}, {z\_\(d, 2\) + z\_\(l, 5\) + 
            z\_\(m, 0\), 
          y\_\(d, 2\) + y\_\(m, 0\)}, {z\_\(d, 3\) + z\_\(l, 5\) + 
            z\_\(m, 0\), 
          y\_\(d, 3\) + y\_\(m, 0\)}, {z\_\(d, 4\) + z\_\(l, 5\) + 
            z\_\(m, 0\), 
          y\_\(d, 4\) + y\_\(m, 0\)}, {z\_\(d, 1\) + z\_\(l, 6\) + 
            z\_\(m, 0\), 
          y\_\(d, 1\) + y\_\(m, 0\)}, {z\_\(d, 2\) + z\_\(l, 6\) + 
            z\_\(m, 0\), 
          y\_\(d, 2\) + y\_\(m, 0\)}, {z\_\(d, 3\) + z\_\(l, 6\) + 
            z\_\(m, 0\), 
          y\_\(d, 3\) + y\_\(m, 0\)}, {z\_\(d, 4\) + z\_\(l, 6\) + 
            z\_\(m, 0\), 
          y\_\(d, 4\) + y\_\(m, 0\)}, {z\_\(d, 1\) + z\_\(l, 7\) + 
            z\_\(m, 0\), 
          y\_\(d, 1\) + y\_\(m, 0\)}, {z\_\(d, 2\) + z\_\(l, 7\) + 
            z\_\(m, 0\), 
          y\_\(d, 2\) + y\_\(m, 0\)}, {z\_\(d, 3\) + z\_\(l, 7\) + 
            z\_\(m, 0\), 
          y\_\(d, 3\) + y\_\(m, 0\)}, {z\_\(d, 4\) + z\_\(l, 7\) + 
            z\_\(m, 0\), 
          y\_\(d, 4\) + y\_\(m, 0\)}, {z\_\(d, 1\) + z\_\(l, 8\) + 
            z\_\(m, 0\), 
          y\_\(d, 1\) + y\_\(m, 0\)}, {z\_\(d, 2\) + z\_\(l, 8\) + 
            z\_\(m, 0\), 
          y\_\(d, 2\) + y\_\(m, 0\)}, {z\_\(d, 3\) + z\_\(l, 8\) + 
            z\_\(m, 0\), 
          y\_\(d, 3\) + y\_\(m, 0\)}, {z\_\(d, 4\) + z\_\(l, 8\) + 
            z\_\(m, 0\), 
          y\_\(d, 4\) + y\_\(m, 0\)}, {z\_\(d, 1\) + z\_\(l, 9\) + 
            z\_\(m, 0\), 
          y\_\(d, 1\) + y\_\(m, 0\)}, {z\_\(d, 2\) + z\_\(l, 9\) + 
            z\_\(m, 0\), 
          y\_\(d, 2\) + y\_\(m, 0\)}, {z\_\(d, 3\) + z\_\(l, 9\) + 
            z\_\(m, 0\), 
          y\_\(d, 3\) + y\_\(m, 0\)}, {z\_\(d, 4\) + z\_\(l, 9\) + 
            z\_\(m, 0\), 
          y\_\(d, 4\) + y\_\(m, 0\)}, {z\_\(d, 1\) + z\_\(l, 10\) + 
            z\_\(m, 0\), 
          y\_\(d, 1\) + y\_\(m, 0\)}, {z\_\(d, 2\) + z\_\(l, 10\) + 
            z\_\(m, 0\), 
          y\_\(d, 2\) + y\_\(m, 0\)}, {z\_\(d, 3\) + z\_\(l, 10\) + 
            z\_\(m, 0\), 
          y\_\(d, 3\) + y\_\(m, 0\)}, {z\_\(d, 4\) + z\_\(l, 10\) + 
            z\_\(m, 0\), y\_\(d, 4\) + y\_\(m, 0\)}}}\)], "Output",
  CellLabel->"Out[383]="]
}, Closed]],

Cell["\<\
To take a concrete example, choose some definite values for the \
parameters:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sp = 
      StructuredInitialParameters[
        ldd, {line, rep, density}, {{density, line}, {density}}, {Mean[#] &, 
          Log[Variance[#]] &}]\)], "Input",
  CellLabel->"In[87]:="],

Cell[BoxData[
    \({{3.9684402997789467`, {\(-0.7451104230071586`\), \
\(-0.06943969770548808`\), 0.2740023645391263`, 
          1.351369390433832`}, {0.003352446938551523`, 
          0.05667089822017246`, \(-0.07431964606889574`\), \
\(-0.250941585286955`\), \(-0.046045212684851844`\), \
\(-0.09192751756807072`\), 0.07460471724941531`, 0.1571196333656122`, 
          0.12170788220172213`, 
          0.04977838363334275`}}, {\(-0.8174410358244136`\), \
{\(-2.7033124555815333`\), \(-2.7828899702635206`\), \(-2.859279955627502`\), \
\(-1.2377866165537301`\)}}}\)], "Output",
  CellLabel->"Out[87]="]
}, Open  ]],

Cell["Choose a likelihood function:", "MathCaption"],

Cell[BoxData[{
    \(\(<< Utilities`RandomNumbers`;\)\), "\[IndentingNewLine]", 
    \(\(L[d_List, {m_, lv_}] := 
        GaussianLogLikelihood[d, {m, \[ExponentialE]\^lv}, 
          Compiled \[Rule] True];\)\)}], "Input",
  CellLabel->"In[89]:="],

Cell["\<\
The overall log likelihood is the same as is given by \
StructuredLogLikelihood[]: \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(smr = 
        StructuredModelReduce[
          ldd, {line, rep, density}, {{density, line}, {density}}, 
          sp];\)\), "\[IndentingNewLine]", 
    \({Plus @@ MapThread[L, smr], 
      StructuredLogLikelihood[
        ldd, {line, rep, density}, {{density, line}, {density}}, sp, 
        L]}\)}], "Input",
  CellLabel->"In[97]:="],

Cell[BoxData[
    \({467.9558456907913`, 467.9558456907913`}\)], "Output",
  CellLabel->"Out[98]="]
}, Open  ]],

Cell[TextData[{
  "The most likely values of the main effects are calculated by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(GaussianMLE\)\([\)\({data\_1, \[Ellipsis]}, {{\
\[Alpha]\_1, \[Beta]\_1}, \[Ellipsis]}\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GaussianMLE[smr\[LeftDoubleBracket]1\[RightDoubleBracket], 
        smr\[LeftDoubleBracket]2\[RightDoubleBracket] /. {m_, 
              lv_} \[RuleDelayed] {m, \[ExponentialE]\^lv}] // 
      Chop\)], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    \({480.365997533489`, {0, 0.6649351870827145`}}\)], "Output",
  CellLabel->"Out[107]="]
}, Open  ]],

Cell["\<\
(Note that since GaussianMLE works by multiplying the variance by \
\[Beta], whereas StructuredModelReduce[] here works with the log variance, \
the parameters must be transformed).\
\>", "Text"],

Cell["\<\
The same result is found by adding \[Alpha], l\[Beta] to the mean \
and log variance, and maximising the likelihood:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sp2 = 
      sp /. {{m1_, m2__}, {v1_, v2__}} \[RuleDelayed] {{m1 + \[Alpha], 
              m2}, {v1 + \ l\[Beta], v2}}\)], "Input",
  CellLabel->"In[127]:="],

Cell[BoxData[
    \({{\(\(3.9684402997789467`\)\(\[InvisibleSpace]\)\) + \[Alpha], \
{\(-0.7451104230071586`\), \(-0.06943969770548808`\), 0.2740023645391263`, 
          1.351369390433832`}, {0.003352446938551523`, 
          0.05667089822017246`, \(-0.07431964606889574`\), \
\(-0.250941585286955`\), \(-0.046045212684851844`\), \
\(-0.09192751756807072`\), 0.07460471724941531`, 0.1571196333656122`, 
          0.12170788220172213`, 
          0.04977838363334275`}}, {\(-0.8174410358244136`\) + 
          l\[Beta], {\(-2.7033124555815333`\), \(-2.7828899702635206`\), \
\(-2.859279955627502`\), \(-1.2377866165537301`\)}}}\)], "Output",
  CellLabel->"Out[127]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(fm = 
      FindMinimum[\(-StructuredLogLikelihood[
              ldd, {line, rep, density}, {{density, line}, {density}}, sp2, 
              L]\), {\[Alpha], 0, 0.1}, {l\[Beta], \(-2\), 0}] // 
        Chop\)], "Input",
  CellLabel->"In[128]:="],

Cell[BoxData[
    \({\(-480.3659975334891`\), {\[Alpha] \[Rule] 0, 
        l\[Beta] \[Rule] \(-0.40806570566268124`\)}}\)], "Output",
  CellLabel->"Out[128]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ExponentialE]\^l\[Beta] /. 
      fm\[LeftDoubleBracket]2\[RightDoubleBracket]\)], "Input",
  CellLabel->"In[137]:="],

Cell[BoxData[
    \(0.6649351782248826`\)], "Output",
  CellLabel->"Out[137]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{572, 668},
WindowMargins->{{17, Automatic}, {Automatic, 16}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "StructuredModelReduce"->{
    Cell[1798, 53, 1058, 25, 52, "DefinitionBox",
      CellTags->"StructuredModelReduce"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"StructuredModelReduce", 22201, 505}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 56, 0, 36, "SubsectionIcon"],
Cell[1798, 53, 1058, 25, 52, "DefinitionBox",
  CellTags->"StructuredModelReduce"],
Cell[2859, 80, 45, 0, 28, "MathCaption"],
Cell[2907, 82, 92, 2, 27, "Input"],
Cell[3002, 86, 782, 23, 94, "Text"],
Cell[3787, 111, 282, 5, 50, "Text"],
Cell[4072, 118, 142, 3, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[4239, 125, 502, 10, 59, "Input"],
Cell[4744, 137, 12057, 200, 787, "Output"]
}, Closed]],
Cell[16816, 340, 108, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[16949, 347, 207, 5, 42, "Input"],
Cell[17159, 354, 606, 11, 59, "Output"]
}, Open  ]],
Cell[17780, 368, 52, 0, 28, "MathCaption"],
Cell[17835, 370, 248, 5, 42, "Input"],
Cell[18086, 377, 114, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[18225, 384, 359, 9, 57, "Input"],
Cell[18587, 395, 99, 2, 20, "Output"]
}, Open  ]],
Cell[18701, 400, 241, 5, 40, "MathCaption"],

Cell[CellGroupData[{
Cell[18967, 409, 256, 5, 28, "Input"],
Cell[19226, 416, 105, 2, 20, "Output"]
}, Open  ]],
Cell[19346, 421, 205, 4, 36, "Text"],
Cell[19554, 427, 147, 3, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[19726, 434, 179, 4, 27, "Input"],
Cell[19908, 440, 667, 11, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20612, 456, 267, 6, 42, "Input"],
Cell[20882, 464, 160, 3, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21079, 472, 139, 3, 28, "Input"],
Cell[21221, 477, 79, 2, 20, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

