(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13246,        386]*)
(*NotebookOutlinePosition[     14469,        425]*)
(*  CellTagsIndexPosition[     14347,        418]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Examining variance components", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"StructuredVariance", "[", 
              StyleBox["pars",
                FontSlant->"Italic"], "]"}], 
            RowBox[{
            "gives", " ", "the", " ", "variances", " ", "among", " ", "the", 
              " ", "parameter", " ", "lists", " ", "in", " ", 
              StyleBox["pars",
                FontSlant->"Italic"]}]},
          {
            RowBox[{"StructuredVariance", "[", 
              RowBox[{"{", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["pars",
                      FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], "}"}],
               "]"}], \(does\ the\ same\ for\ a\ list\ of\ parameter\ sets\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"StructuredVariance"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`StructuredModels`;\)\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
This is a simple way to find the variance among parameter \
estimates.  The parameter estimates have the standard form, with the first \
element giving the baseline, and the succeeding lists giving estimates for \
different components of the model.  \
\>", "Text"],

Cell[TextData[{
  "The second element of this output from ",
  Cell[BoxData[
      \(TraditionalForm\`lik[]\)]],
  " gives parameter estimates associated with the two models for the two \
variables:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(xx = 
      lik[{{density, {line, rep}}, {density}}, {{density, 
            line}, {density}}]\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \({{5.24188927173509`, 10, 
        0.3991222045404412`}, {{4.189967935434801`, \
{\(-0.9586888020715802`\), \(-0.283981963368828`\), 0.0592144214089593`, 
            1.1834563440314492`}, {{0.0029674762613124323`, \
\(-0.07441452760748905`\)}, {0.04193187335634811`, 
              0.026961317894172474`}, {\(-0.06328777210686656`\), \
\(-0.04616433587087604`\)}, {\(-0.21633064520905165`\), \
\(-0.2777044324260038`\)}, {\(-0.019695627529144853`\), \
\(-0.02178106844516286`\)}, {\(-0.07003011001198899`\), \
\(-0.036625277489968175`\)}, {0.034334463459989806`, 
              0.09646280527923874`}, {0.10248001521028036`, 
              0.1288080641290432`}, {0.11201668311678116`, 
              0.14045915843479145`}, {0.052328840899481116`, 
              0.08728309865511302`}}}, {0.335612936073153`, \
{\(-1.1720330134148715`\), \(-1.0365472598526624`\), \
\(-0.4962773253883712`\), 2.704857598655905`}}}}\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell[TextData[{
  "This gives the variances of ",
  StyleBox["density",
    FontSlant->"Italic"],
  " and {",
  StyleBox["line, rep",
    FontSlant->"Italic"],
  "} components for the first variable:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StructuredVariance[
      xx\[LeftDoubleBracket]2, 1\[RightDoubleBracket]]\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \({0.8012684135557792`, 0.011863443619333438`}\)], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell[TextData[{
  "This gives the variances of the {",
  StyleBox["density,line}",
    FontSlant->"Italic"],
  " effects for the second variable:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StructuredVariance[
      xx\[LeftDoubleBracket]2, 2\[RightDoubleBracket]]\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \({3.3368791397145436`}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell["This gives the two lists together:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StructuredVariance[
      xx\[LeftDoubleBracket]2\[RightDoubleBracket]]\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({{0.8012684135557792`, 
        0.011863443619333438`}, {3.3368791397145436`}}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["\<\
This method does not give covariances among different variables: \
that would be hard to implement, because the models for the variables might \
(as above) have different structures.  \
\>", "Text"],

Cell[TextData[{
  "StructuredVariance[",
  StyleBox["pars",
    FontSlant->"Italic"],
  "] works in a very simple way:"
}], "MathCaption"],

Cell[BoxData[
    \(\(StructuredVariance[
          x : {_?NumberQ, ___List}] := \(Variance[Flatten[#]] &\) /@ 
          Drop[x, 1];\)\)], "Input"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"StructuredVariance", "[", 
              StyleBox[\(pars, VarianceComponents \[Rule] True\),
                FontSlant->"Italic"], "]"}], 
            RowBox[{
            "gives", " ", "the", " ", "variances", " ", "among", " ", "the", 
              " ", "parameter", " ", "lists", " ", "in", " ", 
              StyleBox["pars",
                FontSlant->"Italic"], " ", "in", " ", "the", " ", "form", " ",
               "of", " ", "their", " ", "components"}]},
          {
            RowBox[{"StructuredVariance", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["pars",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}], ",", 
                StyleBox[\(VarianceComponents \[Rule] True\),
                  FontSlant->"Italic"]}], 
              "]"}], \(does\ the\ same\ for\ a\ list\ of\ parameter\ sets\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"VarianceComponents"],

Cell["Here is a more complicated model:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(yy = lik[{{{density, line, rep}}, {density, {line, rep}}}]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \({\(-1023.2551810251255`\), {{4.177907725110015`, \
{{{\(-0.8776153273547116`\), \(-0.8404122280055163`\)}, \
{\(-0.9160765566773746`\), \(-0.8738913373786343`\)}, \
{\(-1.04066026042518`\), \(-1.0171258846404145`\)}, \
{\(-1.2136321407315818`\), \(-1.2132300108781524`\)}, {\(-0.8961585007424907`\
\), \(-0.9502929330674441`\)}, {\(-1.0991583247658518`\), \
\(-0.9113077822647273`\)}, {\(-0.9151493317991445`\), \
\(-0.8614906544538963`\)}, {\(-0.8787879787434774`\), \
\(-0.8423432980833863`\)}, {\(-0.8599158338380524`\), \
\(-0.8840647335998791`\)}, {\(-0.9659205913634462`\), \
\(-0.8928702626809069`\)}}, {{\(-0.18517389768356468`\), \
\(-0.36831576367423713`\)}, {\(-0.22589117772678804`\), \(-0.249788119801108`\
\)}, {\(-0.32190010477575054`\), \(-0.26993180148190227`\)}, \
{\(-0.5273565221291068`\), \(-0.6349486866222122`\)}, {\(-0.2705826352928481`\
\), \(-0.3458462322931375`\)}, {\(-0.30095658684737286`\), \
\(-0.31724708051340395`\)}, {\(-0.22834545400037173`\), \
\(-0.1823954520745769`\)}, {\(-0.18649039763385636`\), \
\(-0.17082378061993736`\)}, {\(-0.15285827362877305`\), \
\(-0.10847732039574834`\)}, {\(-0.21915053719554686`\), \
\(-0.19935255111010838`\)}}, {{\(-0.12027316999002338`\), \
\(-0.14341714910945574`\)}, {0.1076639538320147`, 
                0.07424878048445926`}, {0.011207291916754035`, \
\(-0.028506031807833634`\)}, {\(-0.09445392138924055`\), \
\(-0.13138886250745357`\)}, {\(-0.018817660915351753`\), 
                0.11704354348932787`}, {0.03561925125054686`, 
                0.005613094381528557`}, {0.09564595667369856`, 
                0.1889099976646931`}, {0.20850147586649292`, 
                0.23940473115117866`}, {0.2044888424165881`, 
                0.23447719340764656`}, {0.17458705598139215`, 
                0.2210841283371827`}}, {{1.6487073183231182`, 
                1.266472289953936`}, {1.4517811078622187`, 
                1.2264228110300548`}, {1.0055179770920193`, 
                1.1100395412144977`}, {1.3787788091214972`, 
                0.6338258766441052`}, {0.9143099017222376`, 
                0.7445919995492299`}, {0.6056600470394136`, 
                0.8120812934476889`}, {1.1987793990012872`, 
                1.3056834417024548`}, {1.5099662238806786`, 
                1.6696004411508925`}, {1.040715906026526`, 
                1.427877871763703`}, {1.2572955343685281`, 
                0.8261900549663892`}}}}, {\(-0.5326810067252057`\), \
{\(-0.9107408421527385`\), \(-0.4198743676847921`\), \
\(-0.18884064843910262`\), 
            1.519455858276633`}, {{\(-0.6385582861270006`\), \
\(-0.23451514066158083`\)}, {0.11313772157877326`, \
\(-0.06695075706875603`\)}, {1.1676225122589299`, 
              0.949715810490169`}, {0.604314878035395`, 
              1.1467345257857469`}, {0.061074881145139016`, 
              0.18798746041378775`}, {\(-0.5908836386905034`\), 
              0.3770491964056778`}, {0.19837109286715157`, \
\(-0.6413251273600055`\)}, {\(-1.2395208597648066`\), \
\(-1.2978556638108865`\)}, {0.8669734207971918`, \(-0.961114431787814`\)}, \
{\(-0.30316877169445466`\), 0.3009111771878473`}}}}}\)], "Output",
  CellLabel->"Out[36]="]
}, Closed]],

Cell[TextData[{
  "This gives the overall variance for the first parameter, ",
  StyleBox["density\[Times]line\[Times]rep",
    FontSlant->"Italic"],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StructuredVariance[
      yy\[LeftDoubleBracket]2, 1\[RightDoubleBracket]]\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({0.6190440986310448`}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["\<\
This model yields a three-dimensional matrix of parameter \
estimates.  This breaks down that variance into its components:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StructuredVariance[yy\[LeftDoubleBracket]2, 1\[RightDoubleBracket], 
      VarianceComponents \[Rule] True]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \({{{0.767891305239283`, 0.01655027269312259`, 
          0.00013936223599971958`}, {0.012334380425494154`, 
          0.0007783643913674872`, 
          0.002796456919371485`}, {0.00512295503410447`}}}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell["These components are in the following order:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Subsets[{density, line, rep}]\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \({{}, {density}, {line}, {rep}, {density, line}, {density, rep}, {line, 
        rep}, {density, line, rep}}\)], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell[TextData[{
  "Do the same for the second parameter, for which the model is {",
  StyleBox["density, line\[Times]rep",
    FontSlant->"Italic"],
  "}\""
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StructuredVariance[
      yy\[LeftDoubleBracket]2, 2\[RightDoubleBracket]]\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({1.1167167539859546`, 0.5518551356276614`}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell["\<\
This model yields a vector, followed by a two-dimensional matrix of \
parameter estimates.  \
\>", "Text"],

Cell["\<\
This breaks down each of those arrays into their variance \
components:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StructuredVariance[yy\[LeftDoubleBracket]2, 2\[RightDoubleBracket], 
      VarianceComponents \[Rule] True]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({{{1.1167167539859546`}}, {{0.4184666326749802`, 
          0.0011458924405395284`}, {0.15480996128265948`}}}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{572, 668},
WindowMargins->{{17, Automatic}, {Automatic, 16}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "StructuredVariance"->{
    Cell[1797, 53, 845, 20, 58, "DefinitionBox",
      CellTags->"StructuredVariance"]},
  "VarianceComponents"->{
    Cell[6237, 198, 1137, 25, 86, "DefinitionBox",
      CellTags->"VarianceComponents"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"StructuredVariance", 14116, 408},
  {"VarianceComponents", 14231, 411}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 55, 0, 36, "SubsectionIcon"],
Cell[1797, 53, 845, 20, 58, "DefinitionBox",
  CellTags->"StructuredVariance"],
Cell[2645, 75, 46, 0, 28, "MathCaption"],
Cell[2694, 77, 92, 2, 27, "Input"],
Cell[2789, 81, 274, 5, 50, "Text"],
Cell[3066, 88, 218, 6, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[3309, 98, 153, 4, 27, "Input"],
Cell[3465, 104, 971, 17, 85, "Output"]
}, Open  ]],
Cell[4451, 124, 219, 8, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[4695, 136, 132, 3, 27, "Input"],
Cell[4830, 141, 103, 2, 20, "Output"]
}, Open  ]],
Cell[4948, 146, 165, 5, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[5138, 155, 132, 3, 27, "Input"],
Cell[5273, 160, 80, 2, 20, "Output"]
}, Open  ]],
Cell[5368, 165, 57, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5450, 169, 129, 3, 27, "Input"],
Cell[5582, 174, 137, 3, 20, "Output"]
}, Open  ]],
Cell[5734, 180, 208, 4, 36, "Text"],
Cell[5945, 186, 138, 5, 30, "MathCaption"],
Cell[6086, 193, 148, 3, 27, "Input"],
Cell[6237, 198, 1137, 25, 86, "DefinitionBox",
  CellTags->"VarianceComponents"],
Cell[7377, 225, 56, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7458, 229, 116, 2, 27, "Input"],
Cell[7577, 233, 3178, 53, 200, "Output"]
}, Closed]],
Cell[10770, 289, 174, 5, 20, "MathCaption"],

Cell[CellGroupData[{
Cell[10969, 298, 132, 3, 27, "Input"],
Cell[11104, 303, 80, 2, 20, "Output"]
}, Open  ]],
Cell[11199, 308, 156, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[11380, 316, 165, 3, 27, "Input"],
Cell[11548, 321, 259, 5, 33, "Output"]
}, Open  ]],
Cell[11822, 329, 67, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11914, 333, 87, 2, 27, "Input"],
Cell[12004, 337, 166, 3, 20, "Output"]
}, Open  ]],
Cell[12185, 343, 175, 5, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[12385, 352, 132, 3, 27, "Input"],
Cell[12520, 357, 101, 2, 20, "Output"]
}, Open  ]],
Cell[12636, 362, 116, 3, 22, "Text"],
Cell[12755, 367, 102, 3, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[12882, 374, 165, 3, 27, "Input"],
Cell[13050, 379, 168, 3, 20, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

