(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5217,        202]*)
(*NotebookOutlinePosition[      6513,        245]*)
(*  CellTagsIndexPosition[      6393,        237]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"TakeAway[U,V]\\\\\\\"\\\",\
 \\\"MR\\\"]\\) \"\>", "\<\"gives the set U, minus elements V.  Not the same \
as Complement[U,V] \"\>"},
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"TakeAway[U,V]\\\\\\\"\\\",\
 \\\"MR\\\"]\\) \"\>", "\<\"gives the set U, minus elements V and W.  \"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"SA.8.7", "7.2", "TakeAway"}],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(<< Utilities`SetManipulation`\)], "Input",
  CellLabel->"In[1]:="],

Cell[TextData[{
  "It also automatically loads the package",
  " ",
  ButtonBox["Utilities`Notation`",
    ButtonData:>{"Notation Documentation", None},
    Active->True,
    ButtonStyle->"AddOnsLink"]
}], "Text"],

Cell[TextData[{
  "TakeAway[U,V] removes ",
  StyleBox["exactly",
    FontSlant->"Italic"],
  " the elements in V from U:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TakeAway[{a, b, c, c}, {b, c}]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \({a, c}\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell["This is a more compact notation:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b, c, c}\[Backslash]{b, c}\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \({a, c}\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell["\<\
This MUST be entered as \[AliasIndicator]\\\[AliasIndicator], not \
just \\ - these two characters are subtly different.\
\>", "Text"],

Cell["Note that this is not the same as Complement[]:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Complement[{a, b, c, c}, {b, c}]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({a}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[TextData[{
  "V ",
  StyleBox["must",
    FontWeight->"Bold"],
  " be a subset of U, otherwise the function is not applied:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TakeAway[{a, b, c, c}, {b, d}]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \({a, b, c, c}\[Backslash]{b, d}\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell["Several sets can be subtracted at once:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TakeAway[{a, b, c, d}, {c}, {d}]\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \({a, b}\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell["\<\
The compact notation must be used twice to give the same \
result:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b, c, d}\[Backslash]{c}\[Backslash]{d}\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \({a, b}\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell["The precedence rules make this equivalent to:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(({a, b, c, d}\[Backslash]{c})\)\[Backslash]{d}\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({a, b}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["Not to:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b, c, d}\[Backslash]\(({c}\[Backslash]{d})\)\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \({a, b, c, d}\[Backslash]\(({c}\[Backslash]{d})\)\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "SA.8.7"->{
    Cell[1717, 49, 641, 14, 57, "Text",
      CellTags->{"SA.8.7", "7.2", "TakeAway"}]},
  "7.2"->{
    Cell[1717, 49, 641, 14, 57, "Text",
      CellTags->{"SA.8.7", "7.2", "TakeAway"}]},
  "TakeAway"->{
    Cell[1717, 49, 641, 14, 57, "Text",
      CellTags->{"SA.8.7", "7.2", "TakeAway"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"SA.8.7", 6074, 224},
  {"7.2", 6174, 227},
  {"TakeAway", 6279, 230}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 641, 14, 57, "Text",
  CellTags->{"SA.8.7", "7.2", "TakeAway"}],
Cell[2361, 65, 46, 0, 28, "MathCaption"],
Cell[2410, 67, 86, 2, 27, "Input"],
Cell[2499, 71, 213, 7, 23, "Text"],
Cell[2715, 80, 141, 5, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[2881, 89, 88, 2, 27, "Input"],
Cell[2972, 93, 65, 2, 20, "Output"]
}, Open  ]],
Cell[3052, 98, 55, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3132, 102, 88, 2, 27, "Input"],
Cell[3223, 106, 65, 2, 20, "Output"]
}, Open  ]],
Cell[3303, 111, 144, 3, 22, "Text"],
Cell[3450, 116, 70, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3545, 120, 90, 2, 27, "Input"],
Cell[3638, 124, 62, 2, 20, "Output"]
}, Open  ]],
Cell[3715, 129, 148, 5, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[3888, 138, 88, 2, 27, "Input"],
Cell[3979, 142, 89, 2, 20, "Output"]
}, Open  ]],
Cell[4083, 147, 62, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4170, 151, 90, 2, 27, "Input"],
Cell[4263, 155, 65, 2, 20, "Output"]
}, Open  ]],
Cell[4343, 160, 97, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4465, 167, 100, 2, 27, "Input"],
Cell[4568, 171, 65, 2, 20, "Output"]
}, Open  ]],
Cell[4648, 176, 68, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4741, 180, 106, 2, 27, "Input"],
Cell[4850, 184, 65, 2, 20, "Output"]
}, Open  ]],
Cell[4930, 189, 30, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4985, 193, 106, 2, 27, "Input"],
Cell[5094, 197, 107, 2, 20, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

