(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18279,        491]*)
(*NotebookOutlinePosition[     19156,        519]*)
(*  CellTagsIndexPosition[     19112,        515]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\(BeginPackage["\<Utilities`Matrices`\>", \
{"\<LinearAlgebra`MatrixManipulation`\>", "\<LinearAlgebra`Tridiagonal`\>", "\
\<Utilities`SetManipulation`\>", "\<Statistics`DescriptiveStatistics`\>"}];\)\
\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell["Public parts", "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`UpperOffDiagonal[{a\_1, a\_2, \[Ellipsis]}]\ gives\ a\ matrix\ with\ the
        \ list\ {a\_1, a\_2, \[Ellipsis]}\ in\ the\ upper\ off - 
      \(diagonal . \)\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(UpperOffDiagonal::usage = 
      \*"\"\<UpperOffDiagonal[{\!\(a\_1\),\!\(a\_2\),\[Ellipsis]}] gives a \
matrix with the list {\!\(a\_1\),\!\(a\_2\),\[Ellipsis]} in the upper \
off-diagonal.\>\""; \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`LowerOffDiagonal[{a\_1, a\_2, \[Ellipsis]}]\ gives\ a\ matrix\ with\ the
        \ list\ {a\_1, a\_2, \[Ellipsis]}\ in\ the\ lower\ off - 
      \(diagonal . \)\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(LowerOffDiagonal::usage = 
      \*"\"\<LowerOffDiagonal[{\!\(a\_1\),\!\(a\_2\),\[Ellipsis]}] gives a \
matrix with the list {\!\(a\_1\),\!\(a\_2\),\[Ellipsis]} in the lower \
off-diagonal.\>\""; \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`TridiagonalMatrix[{a\_2, \[Ellipsis], a\_n}, {b\_1, \[Ellipsis], 
            b\_n}, {c\_1, \[Ellipsis], c\_\(n - 1\)}]\ gives\ a\ tridiagonal\ 
        matrix\ with\ {a\_2, \[Ellipsis], a\_n}\ in\ the\ upper\ off - 
      diagonal, {b\_1, \[Ellipsis], b\_n}\ on\ the\ diagonal, \ 
    and\ {c\_1, \[Ellipsis], c\_\(n - 1\)}\ on\ the\ lower\ off - 
      \(diagonal . \)\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(TridiagonalMatrix::usage = 
      \*"\"\<TridiagonalMatrix[{\!\(a\_2\),\[Ellipsis],\!\(a\_n\)},{\!\(b\_1\)\
,\[Ellipsis],\!\(b\_n\)},{\!\(c\_1\),\[Ellipsis],\!\(c\_\(n - 1\)\)}] gives a \
tridiagonal matrix with {\!\(a\_2\),\[Ellipsis],\!\(a\_n\)} in the upper \
off-diagonal,{\!\(b\_1\),\[Ellipsis],\!\(b\_n\)} on the diagonal, and \
{\!\(c\_1\),\[Ellipsis],\!\(c\_\(n - 1\)\)} on the lower off-diagonal.\>\""; 
    \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Flatten[list,{i,j}] flattens out levels i to j", "Subsubsection"],

Cell[BoxData[
    \(\(Unprotect[Flatten];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(Flatten::usage = \((Flatten::usage)\)~
          StringJoin~"\<  Flatten[list,{i,j}] flattens out levels i to \
j\>";\)\(\ \)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Protect[Flatten];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(ExtractSubMatrix[
          M, {i\_\[Alpha], 
            i\_\[Beta], \[Ellipsis]}, {\[Alpha], \[Beta], \[Ellipsis]}]\ \
extracts\ the\ submatrix\ of\ M\ which\ is\ defined\ by\ setting\ levels\ {\
\[Alpha], \[Beta], \[Ellipsis]}\ to\ \(\({i\_\[Alpha], 
            i\_\[Beta], \[Ellipsis]}\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(ExtractSubMatrix::usage = \
\*"\"\<ExtractSubMatrix[M,{\!\(i\_\[Alpha]\),\!\(i\_\[Beta]\),\[Ellipsis]},{\
\[Alpha],\[Beta],\[Ellipsis]}] extracts the submatrix of M which is defined \
by setting levels {\[Alpha],\[Beta],\[Ellipsis]} to \
{\!\(i\_\[Alpha]\),\!\(i\_\[Beta]\),\[Ellipsis]}.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
VarianceComponentsOld[m] gives the variance components associated \
with the matrix m, up to order 3.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(VarianceComponentsOld::usage = "\<VarianceComponentsOld[m] gives the \
variance components associated with the matrix m, up to order 3. \>";\)\)], \
"Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
VarianceComponents[m] gives the variance components associated with \
the matrix m\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(VarianceComponents::usage = "\<VarianceComponents[m] gives the \
variance components associated with the matrix m. \>";\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
MarginalTable[m,{\[Alpha],\[Beta],\[Ellipsis]}] gives a table of \
marginal values {\[Alpha],\[Beta],\[Ellipsis]}, averaging over all dimensions \
other than {\[Alpha],\[Beta],\[Ellipsis]}.  \
MarginalTable[m,{\[Alpha],\[Beta],\[Ellipsis]},Function\[Rule]f] uses the \
function f[] instead of Mean[] to construct the table.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MarginalTable::usage = "\<MarginalTable[m,{\[Alpha],\[Beta],\
\[Ellipsis]}] gives a table of marginal values \
{\[Alpha],\[Beta],\[Ellipsis]}, averaging over all dimensions other than {\
\[Alpha],\[Beta],\[Ellipsis]}.  \
MarginalTable[m,{\[Alpha],\[Beta],\[Ellipsis]},Function\[Rule]f] uses the \
function f[] instead of Mean[Flatten[]] to construct the table.\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Private parts", "Subsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Begin["\<Utilities`Matrices`Private`\>"]; \)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`UpperOffDiagonal[{a\_1, a\_2, \[Ellipsis]}]\ gives\ a\ matrix\ with\ the
        \ list\ {a\_1, a\_2, \[Ellipsis]}\ in\ the\ upper\ off - 
      \(diagonal . \)\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(UpperOffDiagonal[a_List] := 
      Module[{n = Length[a] + 1}, \n\t\t
        AppendRows[ZeroMatrix[n, 1], 
          AppendColumns[DiagonalMatrix[a], ZeroMatrix[1, n - 1]]]]; \)\)], 
  "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`LowerOffDiagonal[{a\_1, a\_2, \[Ellipsis]}]\ gives\ a\ matrix\ with\ the
        \ list\ {a\_1, a\_2, \[Ellipsis]}\ in\ the\ lower\ off - 
      \(diagonal . \)\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(LowerOffDiagonal[a_List] := Transpose[UpperOffDiagonal[a]]; \)\)], 
  "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`TridiagonalMatrix[{a\_2, \[Ellipsis], a\_n}, {b\_1, \[Ellipsis], 
            b\_n}, {c\_1, \[Ellipsis], c\_\(n - 1\)}]\ gives\ a\ tridiagonal\ 
        matrix\ with\ {a\_2, \[Ellipsis], a\_n}\ in\ the\ upper\ off - 
      diagonal, {b\_1, \[Ellipsis], b\_n}\ on\ the\ diagonal, \ 
    and\ {c\_1, \[Ellipsis], c\_\(n - 1\)}\ on\ the\ lower\ off - 
      \(diagonal . \)\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(TridiagonalMatrix[a_List, b_List, c_List] := 
      UpperOffDiagonal[a] + DiagonalMatrix[b] + LowerOffDiagonal[c]; \)\)], 
  "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Flatten[list,{i,j}] flattens out levels i to j", "Subsubsection"],

Cell[BoxData[
    \(\(Unprotect[Flatten];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Flatten[d_List, {i_Integer, j_Integer}] := 
        Map[Flatten[#, j - i] &, d, {i - 1}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Protect[Flatten];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(ExtractSubMatrix[
          M, {i\_\[Alpha], 
            i\_\[Beta], \[Ellipsis]}, {\[Alpha], \[Beta], \[Ellipsis]}]\ \
extracts\ the\ submatrix\ of\ M\ which\ is\ defined\ by\ setting\ levels\ {\
\[Alpha], \[Beta], \[Ellipsis]}\ to\ \(\({i\_\[Alpha], 
            i\_\[Beta], \[Ellipsis]}\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(ExtractSubMatrix[M_List, i_List, \[Alpha]_List] := 
        Module[{zz}, \[IndentingNewLine]If[\[Alpha] === {}, \
\[IndentingNewLine]M, \[IndentingNewLine]zz = 
              Array[All &, {Max[\[Alpha]]}]; \
\[IndentingNewLine]MapIndexed[\((zz = 
                    ReplacePart[zz, 
                      Extract[\ 
                        i, #2], \ #1])\) &, \ \[Alpha]]; \[IndentingNewLine]M\
\[LeftDoubleBracket]Sequence @@ zz\[RightDoubleBracket]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
VarianceComponentsOld[m] gives the variance components associated \
with the matrix m, up to order 3\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(VarianceComponentsOld[m_] := 
        Module[{d = Dimensions[m], i1, i2, i3, v1, v2, v3, v12, v13, v23, 
            v123, mm}, \[IndentingNewLine]Switch[
            TensorRank[
              m], \[IndentingNewLine]0, \((Print["\<Error: rank of \>", 
                m, "\< is 0\>"]; {})\), \[IndentingNewLine]1, {{Variance[
                  m]}}, \[IndentingNewLine]2, \((v1 = Variance[Mean /@ m]; 
              v2 = Variance[
                  Mean /@ Transpose[
                      m]]; \[IndentingNewLine]v12 = \((\((d\
\[LeftDoubleBracket]1\[RightDoubleBracket] 
                              d\[LeftDoubleBracket]2\[RightDoubleBracket] - 
                            1)\) Variance[Flatten[m]] - 
                      d\[LeftDoubleBracket]2\[RightDoubleBracket] \((d\
\[LeftDoubleBracket]1\[RightDoubleBracket] - 1)\) v1 - 
                      d\[LeftDoubleBracket]1\[RightDoubleBracket] \((d\
\[LeftDoubleBracket]2\[RightDoubleBracket] - 1)\) 
                        v2)\)/\((\((d\[LeftDoubleBracket]1\
\[RightDoubleBracket] - 1)\) \((d\[LeftDoubleBracket]2\[RightDoubleBracket] - 
                          1)\))\); {{v1, 
                  v2}, {v12}})\), \[IndentingNewLine]3, \[IndentingNewLine]v1 \
= Table[Sum[m\[LeftDoubleBracket]i1, i2, i3\[RightDoubleBracket], {i2, d\
\[LeftDoubleBracket]2\[RightDoubleBracket]}, {i3, d\[LeftDoubleBracket]3\
\[RightDoubleBracket]}]\/\(d\[LeftDoubleBracket]2\[RightDoubleBracket] d\
\[LeftDoubleBracket]3\[RightDoubleBracket]\), {i1, 
                  d\[LeftDoubleBracket]1\[RightDoubleBracket]}]; \
\[IndentingNewLine]v2 = 
              Table[Sum[m\[LeftDoubleBracket]i1, i2, i3\[RightDoubleBracket], \
{i1, d\[LeftDoubleBracket]1\[RightDoubleBracket]}, {i3, \
d\[LeftDoubleBracket]3\[RightDoubleBracket]}]\/\(d\[LeftDoubleBracket]1\
\[RightDoubleBracket] d\[LeftDoubleBracket]3\[RightDoubleBracket]\), {i2, 
                  d\[LeftDoubleBracket]2\[RightDoubleBracket]}]; \
\[IndentingNewLine]v3 = 
              Table[Sum[m\[LeftDoubleBracket]i1, i2, i3\[RightDoubleBracket], \
{i1, d\[LeftDoubleBracket]1\[RightDoubleBracket]}, {i2, \
d\[LeftDoubleBracket]2\[RightDoubleBracket]}]\/\(d\[LeftDoubleBracket]1\
\[RightDoubleBracket] d\[LeftDoubleBracket]2\[RightDoubleBracket]\), {i3, 
                  d\[LeftDoubleBracket]3\[RightDoubleBracket]}]; \
\[IndentingNewLine]v12 = 
              Table[\((Sum[m\[LeftDoubleBracket]i1, i2, i3\
\[RightDoubleBracket], {i3, d\[LeftDoubleBracket]3\[RightDoubleBracket]}]\/d\
\[LeftDoubleBracket]3\[RightDoubleBracket] - 
                    v1\[LeftDoubleBracket]i1\[RightDoubleBracket] - 
                    v2\[LeftDoubleBracket]i2\[RightDoubleBracket])\), {i1, 
                  d\[LeftDoubleBracket]1\[RightDoubleBracket]}, {i2, 
                  d\[LeftDoubleBracket]2\[RightDoubleBracket]}]; \
\[IndentingNewLine]v23 = 
              Table[\((Sum[m\[LeftDoubleBracket]i1, i2, i3\
\[RightDoubleBracket], {i1, d\[LeftDoubleBracket]1\[RightDoubleBracket]}]\/d\
\[LeftDoubleBracket]1\[RightDoubleBracket] - 
                    v2\[LeftDoubleBracket]i2\[RightDoubleBracket] - 
                    v3\[LeftDoubleBracket]i3\[RightDoubleBracket])\), {i2, 
                  d\[LeftDoubleBracket]2\[RightDoubleBracket]}, {i3, 
                  d\[LeftDoubleBracket]3\[RightDoubleBracket]}]; \
\[IndentingNewLine]v13 = 
              Table[\((Sum[m\[LeftDoubleBracket]i1, i2, i3\
\[RightDoubleBracket], {i2, d\[LeftDoubleBracket]2\[RightDoubleBracket]}]\/d\
\[LeftDoubleBracket]2\[RightDoubleBracket] - 
                    v1\[LeftDoubleBracket]i1\[RightDoubleBracket] - 
                    v3\[LeftDoubleBracket]i3\[RightDoubleBracket])\), {i1, 
                  d\[LeftDoubleBracket]1\[RightDoubleBracket]}, {i3, 
                  d\[LeftDoubleBracket]3\[RightDoubleBracket]}]; \
\[IndentingNewLine]v123 = 
              Table[\((m\[LeftDoubleBracket]i1, i2, i3\[RightDoubleBracket] - 
                    v1\[LeftDoubleBracket]i1\[RightDoubleBracket] - 
                    v2\[LeftDoubleBracket]i2\[RightDoubleBracket] - 
                    v3\[LeftDoubleBracket]i3\[RightDoubleBracket] - 
                    v23\[LeftDoubleBracket]i2, i3\[RightDoubleBracket] - 
                    v13\[LeftDoubleBracket]i1, i3\[RightDoubleBracket] - 
                    v12\[LeftDoubleBracket]i1, 
                      i2\[RightDoubleBracket])\), {i1, 
                  d\[LeftDoubleBracket]1\[RightDoubleBracket]}, {i2, 
                  d\[LeftDoubleBracket]2\[RightDoubleBracket]}, {i3, 
                  d\[LeftDoubleBracket]3\[RightDoubleBracket]}]; \
\[IndentingNewLine]Map[
              Variance[Flatten[#]] &, {{v1, v2, v3}, {v23, v13, 
                  v12}, {v123}}, {2}], \[IndentingNewLine]_, \
\((Print["\<Error: rank of \>", m, "\< is > 3\>"]; {})\)]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
VarianceComponents[m] gives the variance components associated with \
the matrix m\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Options[VarianceComponents] = {Table \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(VarianceComponents[m_, {}, {}] := 
        MarginalTable[m, {}];\)\), "\[IndentingNewLine]", 
    \(\(VarianceComponents[m_, ii_, lev_] := 
        Mean[Flatten[{ExtractSubMatrix[m, ii, lev]}]] - 
          Plus @@ \((\(VarianceComponents[
                    m, \(Transpose[#]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket], \(Transpose[#]\)\[LeftDoubleBracket]2\
\[RightDoubleBracket]] &\) /@ 
                Subsets[Transpose[{ii, lev}], 1, Length[lev] - 1])\) - 
          VarianceComponents[m, {}, {}];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(VarianceComponents[m_, lev_, 
          opts___Rule] := \[IndentingNewLine]Module[{d = Dimensions[m], j, 
            tt}, \[IndentingNewLine]tt = 
            Table[VarianceComponents[m, j /@ lev, lev], 
              Sequence @@ \((lev /. {k_Integer \[RuleDelayed] {j[k], 
                            d\[LeftDoubleBracket]k\[RightDoubleBracket]}})\) // 
                Evaluate]; 
          If[\(Table /. {opts}\) /. 
              Options[VarianceComponents], \[IndentingNewLine]tt, \
\[IndentingNewLine]If[ListQ[tt] && \((Length[tt] > 1)\), 
              Variance[Flatten[tt]], 0]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(VarianceComponents[m_, opts___Rule] := 
        Module[{n = TensorRank[m], 
            j}, \[IndentingNewLine]Table[\(VarianceComponents[m, #, 
                  opts] &\) /@ Subsets[Range[n], j], {j, 0, 
              n}]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
MarginalTable[m,{\[Alpha],\[Beta],\[Ellipsis]}] gives a table of \
marginal values {\[Alpha],\[Beta],\[Ellipsis]}, averaging over all dimensions \
other than {\[Alpha],\[Beta],\[Ellipsis]}.  \
MarginalTable[m,{\[Alpha],\[Beta],\[Ellipsis]},Function\[Rule]f] uses the \
function f[] instead of Mean[] to construct the table.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          MarginalTable] = {Function \[Rule] \((Mean[
                  Flatten[#]] &)\)};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MarginalTable[m_List, lev_List, opts___Rule] := 
        Module[{d = Dimensions[m], j, 
            f = \(Function /. {opts}\) /. 
                Options[MarginalTable]}, \[IndentingNewLine]Table[
            f[ExtractSubMatrix[m, j /@ lev, lev]], 
            Sequence @@ \((lev /. {k_Integer \[RuleDelayed] {j[k], 
                          d\[LeftDoubleBracket]k\[RightDoubleBracket]}})\) // 
              Evaluate]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ending", "Subsection",
  InitializationCell->True],

Cell["\<\
End[];
\
\>", "Input",
  InitializationCell->True],

Cell["EndPackage[];", "Input",
  InitializationCell->True]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->Automatic,
WindowSize->{786, 696},
WindowMargins->{{24, Automatic}, {Automatic, 2}},
MacintoshSystemPageSetup->"\<\
00h0001804P000000_02@?oaonh32@9BH`85:0?l0@00005X0FP000003[0;@001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
ojH?;@^J00P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 290, 6, 59, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2032, 59, 62, 1, 46, "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2119, 64, 244, 5, 42, "Subsubsection",
  InitializationCell->True],
Cell[2366, 71, 261, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[2664, 81, 244, 5, 28, "Subsubsection",
  InitializationCell->True],
Cell[2911, 88, 261, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3209, 98, 454, 8, 43, "Subsubsection",
  InitializationCell->True],
Cell[3666, 108, 482, 8, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4185, 121, 71, 0, 28, "Subsubsection"],
Cell[4259, 123, 84, 2, 27, "Input",
  InitializationCell->True],
Cell[4346, 127, 192, 4, 43, "Input",
  InitializationCell->True],
Cell[4541, 133, 82, 2, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4660, 140, 377, 7, 29, "Subsubsection"],
Cell[5040, 149, 358, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5435, 160, 134, 3, 28, "Subsubsection"],
Cell[5572, 165, 207, 4, 59, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[5816, 174, 115, 3, 42, "Subsubsection"],
Cell[5934, 179, 184, 3, 59, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[6155, 187, 356, 6, 58, "Subsubsection"],
Cell[6514, 195, 431, 8, 91, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6994, 209, 63, 1, 30, "Subsection",
  InitializationCell->True],
Cell[7060, 212, 134, 3, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[7219, 219, 244, 5, 42, "Subsubsection",
  InitializationCell->True],
Cell[7466, 226, 244, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[7747, 237, 244, 5, 28, "Subsubsection",
  InitializationCell->True],
Cell[7994, 244, 128, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8159, 252, 454, 8, 43, "Subsubsection",
  InitializationCell->True],
Cell[8616, 262, 183, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8836, 271, 71, 0, 28, "Subsubsection"],
Cell[8910, 273, 84, 2, 27, "Input",
  InitializationCell->True],
Cell[8997, 277, 154, 3, 43, "Input",
  InitializationCell->True],
Cell[9154, 282, 82, 2, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9273, 289, 377, 7, 29, "Subsubsection"],
Cell[9653, 298, 519, 10, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[10209, 313, 133, 3, 28, "Subsubsection"],
Cell[10345, 318, 4840, 79, 462, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[15222, 402, 115, 3, 28, "Subsubsection"],
Cell[15340, 407, 117, 2, 27, "Input",
  InitializationCell->True],
Cell[15460, 411, 574, 11, 91, "Input",
  InitializationCell->True],
Cell[16037, 424, 654, 12, 123, "Input",
  InitializationCell->True],
Cell[16694, 438, 290, 6, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[17021, 449, 356, 6, 58, "Subsubsection"],
Cell[17380, 457, 164, 4, 27, "Input",
  InitializationCell->True],
Cell[17547, 463, 487, 9, 75, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18083, 478, 56, 1, 46, "Subsection",
  InitializationCell->True],
Cell[18142, 481, 60, 4, 42, "Input",
  InitializationCell->True],
Cell[18205, 487, 58, 1, 27, "Input",
  InitializationCell->True]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

