(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     63579,       1502]*)
(*NotebookOutlinePosition[    102406,       2809]*)
(*  CellTagsIndexPosition[    102362,       2805]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\(BeginPackage["\<Utilities`RandomNumbers`\>", \
{"\<Statistics`DescriptiveStatistics`\>", \n\t\ \ \ \ \ \
"\<Statistics`Common`DistributionsCommon`\>", \
"\<Statistics`DiscreteDistributions`\>", "\<Statistics`DataManipulation`\>", \
"\<Statistics`ContinuousDistributions`\>"}];\)\)], "Input",
  PageWidth->PaperWidth,
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[" Usage statements", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[
"RandomSet[j,k] gives a random (ordered) set of j distinct integers in the \
range {1,k}.  (j\[LessEqual]k).  RandomSet[j,{a,b,..}] gives j randomly \
chosen elements from the set {a,b,..}."], "Subsubsection"],

Cell[BoxData[
    \(\(RandomSet::usage = "\<RandomSet[j,k] gives a random (ordered) set of \
j distinct integers in the range {1,k}.  (j\[LessEqual]k). \
RandomSet[{j1,j2,..},k] splits k into random sets of the specified size. \
RandomSet[j,{a,b,..}] gives j randomly chosen elements from the set {a,b,..}. \
  RandomSet[{j1,j2,..},{a,b,..}] splits {a,b,..} into random sets of the \
specified size; these are NOT sorted.  To sort them, use Sort[Sort/@#]&\>";\)\
\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomSetCompiled::usage = "\<RandomSetCompiled[j,n] chooses j \
distinct integers from the set n.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Muddle[{a,b,c,..}] gives a random reordering of the list", 
  "Subsubsection"],

Cell[BoxData[
    \(\(Muddle::usage = "\<Muddle[{a,b,c,..}] gives a random reordering of \
the list\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Subdivide[{a,b,..},{1,2,3,..}] splits the list into subsets of the \
specified length.  BEWARE: the lengths must match.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Subdivide::usage = "\<Subdivide[{a,b,..},{1,2,3,..}] splits the list \
into subsets of the specified length.  BEWARE: the lengths must \
match.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
RandomCum[CDF[#]&,j0] generates a random number from the \
distribution whose cumulative distribution is given by CDF[j],  defined as \
the probability of going from 0 to j inclusive.  j0 is an initial guess.\
\>",
   "Subsubsection"],

Cell[BoxData[
    \(\(RandomCum::usage = \*"\"\<RandomCum[CDF[#]&,j0] generates a random \
number from the distribution whose cumulative distribution is given by \
CDF[j],  defined as the probability of going from 0 to j inclusive.  j0 is an \
initial guess.  Range is 0 to \[Infinity]. RandomCum[CDF[#]&,j0,x] generates \
the integer appropriate to \
x.RandomCum[{\!\(F\_0\),\!\(F\_1\),\[Ellipsis]},j0] is a faster version which \
uses a precalculated tableof the CDF.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`RandomMultinomial[n, {p\_1, \[Ellipsis]}]\ gives\ a\ list\ of\ random\ 
      integers\ drawn\ from\ the\ \(multinomial . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(RandomMultinomial::usage = \*"\"\<RandomMultinomial[n,{\!\(p\_1\),\
\[Ellipsis]}] gives a list of random integers drawn from the multinomial. \
RandomMultinomial[{J,K,\[Ellipsis]},{\!\(n\_1\),\!\(n\_2\),\[Ellipsis]}] \
gives a list of numbers sampled without replacement from an urn with {J,K,\
\[Ellipsis]} of each kind.  Sampling is assumed to be exhaustive, so that the \
total number in the urn equals the total sample size \
\!\(\[Sum]\+i\)\!\(n\_i\).The probability of each configuration is given by \
MultinomialSamplingProbability[{{\!\(j\_1\),\[Ellipsis]},{\!\(k\_1\),\
\[Ellipsis]},\[Ellipsis]}].  Compiled\[Rule]True is faster.\>\"";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
RandomList[k,{p1,p2,...,pn}] returns k integers with probability \
{p1,p2,...,pn}\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomList::usage = "\<RandomList[k,{p1,p2,...,pn}] returns k \
integers with probability {p1,p2,...,pn}. \
RandomList[k,{p1,p2,...,pn},{s1,s2,..}] returns a list of the elements s1. \
Compiled\[Rule]True uses compiled code.  Replace->False samples without \
replacement.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
RandomListCompiled[k,{p1,p2,...,pn}] returns k integers with \
probability {p1,p2,...,pn}, using compiled code.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(RandomListCompiled::usage = "\<RandomListCompiled[k,{p1,p2,...,pn}] \
returns k integers with probability {p1,p2,...,pn}, using compiled code, and \
sampling without replacement.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
RandomListCompiledReplace[k,{p1,p2,...,pn}] returns k integers with \
probability {p1,p2,...,pn}, using compiled code.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(RandomListCompiledReplace::usage = \
"\<RandomListCompiledReplace[k,{p1,p2,...,pn}] returns k integers with \
probability {p1,p2,...,pn}, using compiled code, and sampling with \
replacement.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
LogLikelihoodTest[obs,exp] gives log(L) for the comparison of \
observed and expected.\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(LogLikelihoodTest::usage = \*"\"\<LogLikelihoodTest[obs,exp] gives \
log(L) for the comparison of observed and expected.  obs and exp can be any \
lists with coresponding structure.  Compiled\[Rule]True is a compiled \
version.  LogLikelihoodTest[{{\!\(obs\_\(1, 1\)\),\[Ellipsis]}\[Ellipsis]}] \
gives a test for associations between rows & columns.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`NegativeHypergeometricDistribution[n, p, \[Alpha]]\ gives\ the\ 
      distribution\ obtained\ by\ binomial\ sampling\ from\ an\ underlying\ 
      Beta\ distribution\ with\ mean\ p\ and\ variance\ 
      \(p\[VeryThinSpace]q\)\/\(\[Alpha] + 1\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(NegativeHypergeometricDistribution::usage = \
\*"\"\<NegativeHypergeometricDistribution[n,p,\[Alpha]] gives the \
distribution obtained by binomial sampling from an underlying Beta \
distribution with mean p and variance \
\!\(\(p\[VeryThinSpace]q\)\/\(\[Alpha]\\\\\\\  + \\\\\\\ 1\)\).\>\"";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(NegativeBinomialLogLikelihood[{n\_1, \[Ellipsis]}, {n\&_, 
              c}]\ gives\ the\ log\ likelihood\ that\ the\ list\ of\ numbers\ \
{n\_1, \[Ellipsis]}\ are\ drawn\ from\ a\ negative\ binomial\ with\ mean\ \
n\&_\ and\ variance/
            mean\ ratio\ c . \ \ \ \ Compiled -> \(True\ is\ a\ compiled\ \
version . \ \ NegativeBinomialLogLikelihood[{n\&_, 
                    c}]\ gives\ the\ normalisation\ constant\ required\ for\ \
c < 1. \ Normalised \[Rule] False\ omits\ normalisation\); \ 
      this\ may\ give\ errors\ for\ c < 
        1\ but\ is\ substantially\ faster . 
            NegativeBinomialLogLikelihood[{{n\_1, \[Ellipsis]} \[Ellipsis]}, \
{{\[Alpha]\_1, \[Beta]\_1} \[Ellipsis]}, {n\&_, c}]\ gives\ the\ log . \ 
            likelihood\ for\ a\ multiplicative\ model, \ 
      in\ which\ the\ parameters\ in\ \ sample\ k\ are\ \(\({\(\[Alpha]\_k\) 
              n\&_, \(\[Beta]\_k\) c}\)\(.\)\(\ \)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(\(\ \)\(NegativeBinomialLogLikelihood::usage = \
\*"\"\<NegativeBinomialLogLikelihood[{\!\(n\_1\),\[Ellipsis]},{\!\(n\&_\),c}] \
gives the log likelihood that the list of numbers {\!\(n\_1\),\[Ellipsis]} \
are drawn from a negative binomial with mean \!\(n\&_\) and variance/mean \
ratio c.    Compiled->True is a compiled version.  \
NegativeBinomialLogLikelihood[{\!\(n\&_\),c}] gives the normalisation \
constant required for c<1. Normalised\[Rule]False omits normalisation; this \
may give errors for c<1 but is substantially \
faster.NegativeBinomialLogLikelihood[{{\!\(n\_1\),\[Ellipsis]}\[Ellipsis]},{{\
\!\(\[Alpha]\_1\),\!\(\[Beta]\_1\)}\[Ellipsis]},{\!\(n\&_\),c}] gives the \
log. likelihood for a multiplicative model, in which the parameters in  \
sample k are {\!\(\[Alpha]\_k\)\!\(n\&_\),\!\(\[Beta]\_k\)c}. \>\"";\)\(\ \
\)\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(\(NegativeBinomialLogLikelihoodCompiled[{\(n\_1\) \
\[Ellipsis]}, n\&_, 
          c]\)\(\ \)\(is\)\(\ \)\(a\)\(\ \)\(compiled\)\(\ \)\(version\)\(\ \
\)\(of\)\(\ \)\(NegativeBinomialLogLikelihood[]\)\(\ \)\),
      FontFamily->"Times"]], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(NegativeBinomialLogLikelihoodCompiled::usage = \
\*"\"\<NegativeBinomialLogLikelihoodCompiled[{\!\(n\_1\)\[Ellipsis]},\!\(n\&_\
\),c] is a compiled version of NegativeBinomialLogLikelihood[]\>\"";\)\(\ \
\)\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(NegativeBinomialMLE[{n\_1, \[Ellipsis]}]\ gives\ the\ MLE\ and\
\ log\ likelihood, \ {L, {n\&_, c}}, \ 
      given\ that\ the\ list\ of\ numbers\ {n\_1, \[Ellipsis]}\ are\ drawn\ \
from\ a\ negative\ binomial\ with\ mean\ n\&_\ and\ variance/
          mean\ ratio\ c . \ 
          NegativeBinomialMLE[{n\_1, \[Ellipsis]}, {None, 
              c}]\ fixes\ c\ at\ some\ definite\ value; \ 
      similarly\ for\ \(\(n\&_\)\(.\)\(\ \ \)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(NegativeBinomialMLE::usage = \*"\"\<NegativeBinomialMLE[{\!\(n\_1\),\
\[Ellipsis]}] gives the MLE and log likelihood, {L,{\!\(n\&_\),c}}, given \
that the list of numbers {\!\(n\_1\),\[Ellipsis]} are drawn from a negative \
binomial with mean \!\(n\&_\) and variance/mean ratio c. \
NegativeBinomialMLE[{\!\(n\_1\),\[Ellipsis]},{None,c}] fixes c at some \
definite value; similarly for \!\(n\&_\). \>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Normalised is an option for NegativeBinomialLogLikelihood which \
determines whether the result is normalised to sum to 1 for c<1.\
\>", \
"Subsubsection"],

Cell[BoxData[
    \(\(Normalised::usage = "\<Normalised is an option for \
NegativeBinomialLogLikelihood which determines whether the result is \
normalised to sum to 1 for c<1.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
FullOutput is an option for NegativeBinomialMLE and GaussianMLE \
which specifies that output should be in the form {L,pars} rather than \
{pars}.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(FullOutput::usage = "\<FullOutput is an option for \
NegativeBinomialMLE and GaussianMLE which specifies that output should be in \
the form {L,pars} rather than {pars}.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(GaussianLogLikelihood[{\(x\_1\) \[Ellipsis]}, {\[Mu], \[Sigma]\
\^2}]\ gives\ the\ log\ likelihood\ for\ the\ sample, \ 
      ignoring\ constants . \ \[Mu], \[Sigma]\^2\ are\ the\ mean\ and\ \
variance\ of\ the\ x\_i . \ 
          GaussianLogLikelihood[{{\(x\_1\) \[Ellipsis]} \[Ellipsis]}, {{\
\[Alpha]\_1, \[Beta]\_1} \[Ellipsis]}, {\[Mu], \[Sigma]\^2}]\ does\ the\ same\
\ for\ an\ additive/multiplicative\ model, \ 
      in\ which\ mean\ and\ variance\ in\ each\ sample\ are\ \[Mu] + \[Alpha]\
\_k, \ \(\[Sigma]\^2\) \[Beta]\_k . \ \ Compiled \[Rule] 
        True\ is\ a\ compiled\ \(\(version\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(GaussianLogLikelihood::usage = \*"\"\<GaussianLogLikelihood[{\!\(x\_1\
\)\[Ellipsis]},{\[Mu],\!\(\[Sigma]\^2\)}] gives the log likelihood for the \
sample, ignoring constants. \[Mu],\!\(\[Sigma]\^2\) are the mean and variance \
of the \!\(x\_i\). \
GaussianLogLikelihood[{{\!\(x\_1\)\[Ellipsis]}\[Ellipsis]},{{\!\(\[Alpha]\_1\)\
,\!\(\[Beta]\_1\)}\[Ellipsis]},{\[Mu],\!\(\[Sigma]\^2\)}] does the same for \
an additive/multiplicative model, in which mean and variance in each sample \
are \[Mu]+\!\(\[Alpha]\_k\), \!\(\[Sigma]\^2\)\!\(\[Beta]\_k\).  Compiled\
\[Rule]True is a compiled version.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(GaussianMLE[{\(x\_1\) \[Ellipsis]}]\ gives\ the\ MLE\ for\ \
\[Mu], \ \[Sigma]\^2, \ 
      the\ mean\ and\ variance\ of\ the\ x\_i . \ 
          GaussianMLE[{{\(x\_1\) \[Ellipsis]} \[Ellipsis]}, {{\[Alpha]\_1, \
\[Beta]\_1} \[Ellipsis]}]\ does\ the\ same\ for\ an\ additive/
          multiplicative\ model, \ 
      in\ which\ mean\ and\ variance\ in\ each\ sample\ are\ \[Mu] + \[Alpha]\
\_k, \ \(\[Sigma]\^2\) \[Beta]\_k . \ \ Compiled \[Rule] 
        True\ is\ a\ compiled\ \(\(version\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(GaussianMLE::usage = \*"\"\<GaussianMLE[{\!\(x\_1\),\[Ellipsis]}] \
gives estimates of the mean and variance of the population from which the \
\!\(x\_i\) were sampled.  GaussianMLE[{{\!\(x\_\(1, 1\)\),\[Ellipsis]},\
\[Ellipsis]},{{\!\(\[Alpha]\_1\),\!\(\[Beta]\_1\)},\[Ellipsis]}] does the \
same for an additive/multiplicative model, in which the mean and variance in \
each sample are \[Mu]+\!\(\[Alpha]\_k\), \!\(\[Sigma]\^2\)\!\(\[Beta]\_k\).  \
Compiled\[Rule]True is a compiled version.  FullOutput\[Rule]False suppresses \
output of the log likelihood, and just returns {\[Mu], \
\!\(\[Sigma]\^2\)}.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      StyleBox[\(MultinomialSamplingProbability[{{j\_1, \(k\_1\) \
\[Ellipsis]}, \[Ellipsis]}]\ gives\ the\ probability\ of\ sampling\ a\ set\ \
of\ numbers\ {{j\_1, \(k\_1\) \[Ellipsis]}, \[Ellipsis]}\ from\ an\ urn\ \
containing\ {\[Sum]\_i j\_i, \[Sum]\_i\( 
                    k\_i\) \[Ellipsis]}\ of\ each\ \(\(kind\)\(.\)\)\),
        FontFamily->"Times"]}]], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(\ \)\(MultinomialSamplingProbability::usage = \
\*"\"\<MultinomialSamplingProbability[{{\!\(j\_1\),\!\(k\_1\)\[Ellipsis]},\
\[Ellipsis]}] gives the probability of sampling without replacement a set of \
numbers {{\!\(j\_1\),\!\(k\_1\)\[Ellipsis]},\[Ellipsis]} from an urn \
containing {\!\(\[Sum]\_i\)\!\(j\_i\),\!\(\[Sum]\_i\)\!\(k\_i\)\[Ellipsis]} \
of each kind.\>\"";\)\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Private parts", "Subsection"],

Cell[BoxData[
    \(\(Begin["\<Utilities`RandomNumbers`Private`\>"];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(<< Statistics`ContinuousDistributions`;\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[TextData[{
  "RandomSet[j,k] gives a random (ordered) set of j distinct integers in the \
range {1,k}.  (j\[LessEqual]k).  ",
  "RandomSet",
  "[j,{a,b,..}] gives j randomly chosen elements from the set {a,b,..}."
}], "Subsubsection"],

Cell[BoxData[{
    \(\(RandomSet[j_Integer, s_List] := 
        Extract[s, List /@ RandomSet[j, Length[s]]];\)\), "\n", 
    \(\(RandomSet[j_Integer, k_Integer] := 
        RandomSetCompiled[j, k];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \( (*RandomSet[0, _Integer] := {}; \n
      RandomSet[j_Integer, k_Integer] := \n\t
        Module[{rs = RandomSet[j - 1, k], 
            jj = Random[Integer, {1, k - j + 1}]}, \n
          Sort[Append[
              rs, \(Complement[Range[k], rs]\)\[LeftDoubleBracket]
                jj\[RightDoubleBracket]]]];*) \)], "Input"],

Cell[BoxData[{
    \(\(RandomSet[{x__Integer}, k_Integer] := 
        RandomSet[{x}, Range[k]];\)\), "\n", 
    \(\(RandomSet[{x__Integer}, s_List] := 
        Subdivide[Muddle[s], {x}];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomSetCompiled = 
        Compile[{{j, _Integer}, {n, _Integer}}, \[IndentingNewLine]Module[{aa \
= Range[n], na = n, ns = {}, k, new}, \[IndentingNewLine]If[
              j > n \[Or] j < 0, 
              Message[RandomSet::tooBig]]; \[IndentingNewLine]If[
              j \[LessEqual] Quotient[n, 2], \[IndentingNewLine]Sort[
                Table[\((k = Random[Integer, {1, na}]; na -= 1; 
                    new = aa\[LeftDoubleBracket]k\[RightDoubleBracket]; 
                    aa = Delete[aa, k]; 
                    new)\), {j}]], \[IndentingNewLine]Sort[
                Complement[
                  Range[n], \[IndentingNewLine]Table[\((k = 
                        Random[Integer, {1, na}]; na -= 1; 
                      new = aa\[LeftDoubleBracket]k\[RightDoubleBracket]; 
                      aa = Delete[aa, k]; 
                      new)\), {n - 
                        j}]]]]], \[IndentingNewLine]{{ns, _Integer, 
              1}, {na, _Integer}, {k, _Integer}, {new, _Integer}, {aa, \
_Integer, 1}}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomSet::tooBig = "\<The number of distinct elements chosen must be \
no greater than the size of the set.\>";\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Muddle[{a,b,c,..}] gives a random reordering of the list", 
  "Subsubsection"],

Cell[BoxData[
    \(\(Muddle[s_List] := Sort[s, \((Random[] < 1/2)\) &];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Subdivide[{a,b,..},{1,2,3,..}] splits the list into subsets of the \
specified length.  BEWARE: the lengths must match.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Subdivide::lengthMismatch = "\<Length of set `1` does not match that \
requested,  `2`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Subdivide[s_List, {j_Integer, k__Integer}] := 
        Join[{Take[s, j]}, Subdivide[Drop[s, j], {k}]];\)\), "\n", 
    \(\(Subdivide[s_List, {k_Integer}] := 
        If[k == Length[s], {s}, Message[Subdivide::lengthMismatch, s, k]; 
          s];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
RandomCum[CDF[#]&,j0] generates a random number from the \
distribution whose cumulative distribution is given by CDF[j],  defined as \
the probability of going from 0 to j inclusive.  j0 is an initial \
guess.\
\>", "Subsubsection"],

Cell[BoxData[{
    \(\(RandomCum[f_, j0_] := RandomCum[f, j0, Random[]];\)\), "\n", 
    \(\(RandomCum[f_?\((\(! ListQ[#]\) &)\), jj0_, 
          x_] := \[IndentingNewLine]Module[{z, j, j0, 
            ff}, \n\ \ \ \ \ \ \ j0 = 
            Round[Max[1, jj0]]; \[IndentingNewLine]\ 
          z = {{\(-1\), 0}, {j0, f[j0]}}; \[IndentingNewLine]While[
            z[\([2, 2]\)] < x, 
            z[\([2]\)] = {2  z[\([2, 1]\)], 
                f[2  z[\([2, 1]\)]]}]; \n\t\tWhile[
            z[\([2, 1]\)] - z[\([1, 1]\)] > 1, \n\t\t\tj = 
              Round[\((z[\([2, 1]\)] + z[\([1, 1]\)])\)/2]; 
            ff = f[j]; \n\t\t\tz[\([If[ff < x, 1, 2]]\)] = {j, ff}]; \n\t
          z[\([2, 1]\)]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomCum[f_List, jj0_Integer, x_] := 
        RandomCumCompiled[f, jj0, x];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomCumCompiled = 
        Compile[{{f, _Real, 
              1}, {jj0, _Integer}, {x, _Real}}, \[IndentingNewLine]Module[{z, 
              j, j0, ff, n = Length[f] - 1}, \n\ \ \ \ \ \ \ j0 = 
              Max[Min[n, jj0], 1]; \[IndentingNewLine]\ 
            z = {{\(-1\), 0}, {j0, 
                  f\[LeftDoubleBracket]j0 + 
                      1\[RightDoubleBracket]}}; \[IndentingNewLine]While[
              z[\([2, 2]\)] < x, 
              z[\([2]\)] = {2  z[\([2, 1]\)], 
                  f\[LeftDoubleBracket]Min[2  Round[z[\([2, 1]\)]], n] + 
                      1\[RightDoubleBracket]}]; \n\t\tWhile[
              z[\([2, 1]\)] - z[\([1, 1]\)] > 1, \n
              j = Min[Round[\((z[\([2, 1]\)] + z[\([1, 1]\)])\)/2], n]; 
              ff = f\[LeftDoubleBracket]j + 
                    1\[RightDoubleBracket]; \n\t\t\tz[\([If[ff < x, 1, 
                      2]]\)] = {j, ff}]; \n\t
            Round[z[\([2, 1]\)]]], \[IndentingNewLine]{{z, _Real, 
              2}, {n, _Integer}, {j, _Integer}, {j0, _Integer}, {ff, \
_Real}}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`RandomMultinomial[
        n, {p\_1, \[Ellipsis]}]\ gives\ a\ list\ of\ random\ integers\ drawn\ \
from\ the\ \(\(multinomial\)\(.\)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[RandomMultinomial] = {Compiled \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(RandomMultinomial[n_Integer, {_}] := {n};\)\), "\n", 
    \(\(RandomMultinomial[n_Integer, {p_, r__}] := \n\t\t\t\tIf[p == 1, 
          Prepend[Table[0, {Length[{r}]}], 
            n], \[IndentingNewLine]Module[{np = 
                If[n < 10000, \[IndentingNewLine]Random[
                    BinomialDistribution[n, 
                      p]], \[IndentingNewLine]RandomCum[\[IndentingNewLine]\
CDF[BinomialDistribution[n, N[p]], #] &, n\ p]]}, \[IndentingNewLine]Prepend[
              RandomMultinomial[n - np, {r}\/\(1 - p\)], np]]];\)\)}], "Input",\

  InitializationCell->True],

Cell[BoxData[{
    \(\(RandomMultinomial[{}, {}, ___Rule] := {};\)\), "\[IndentingNewLine]", \

    \(\(RandomMultinomial[{j_Integer}, n : {__Integer}, ___Rule] := 
        List /@ n;\)\), "\[IndentingNewLine]", 
    \(\(RandomMultinomial[
          jk : {__Integer}, {n1_Integer}, ___Rule] := {jk};\)\), "\
\[IndentingNewLine]", 
    \(\(RandomMultinomial[jk : {__Integer}, {n1_Integer, n2__Integer}, 
          opts___Rule] := \[IndentingNewLine]If[\(Compiled /. {opts}\) /. 
            Options[RandomMultinomial], \
\[IndentingNewLine]RandomMultinomialCompiled[
            jk, {n1, n2}], \[IndentingNewLine]Module[{ss = {}, jj, nr = n1, 
              nt = Plus @@ jk, i = 1, 
              ljk = Length[jk]}, \[IndentingNewLine]While[
              i < ljk, \[IndentingNewLine]jj = 
                If[jk\[LeftDoubleBracket]i\[RightDoubleBracket] \[Equal] 0, 
                  0, Random[
                    HypergeometricDistribution[nr, 
                      jk\[LeftDoubleBracket]i\[RightDoubleBracket], 
                      nt]]]; \[IndentingNewLine]nt -= 
                jk\[LeftDoubleBracket]i\[RightDoubleBracket]; i += 1; 
              nr -= jj; AppendTo[ss, jj]]; \[IndentingNewLine]AppendTo[ss, 
              nr]; \[IndentingNewLine]Prepend[
              RandomMultinomial[jk - ss, {n2}], ss]]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomMultinomialCompiled = 
        Compile[{{jk, _Integer, 1}, {nn, _Integer, 
              1}}, \[IndentingNewLine]Module[{ljk = Length[jk], 
              lnn = Length[nn], ss, n1 = First[nn], nt = Plus @@ nn, i, 
              jj}, \[IndentingNewLine]If[
              lnn \[Equal] 
                1, \[IndentingNewLine]{jk}, \[IndentingNewLine]ss = 
                Table[\[IndentingNewLine]jj = 
                    If[jk\[LeftDoubleBracket]i\[RightDoubleBracket] \[Equal] 
                        0, 0, RandomHyperGeometricDistribution[n1, 
                        jk\[LeftDoubleBracket]i\[RightDoubleBracket], 
                        nt]]; \[IndentingNewLine]nt = 
                    nt - jk\[LeftDoubleBracket]i\[RightDoubleBracket]; 
                  n1 = n1 - jj; \[IndentingNewLine]jj, \[IndentingNewLine]{i, 
                    ljk}]; \[IndentingNewLine]Prepend[
                RandomMultinomialCompiled[jk - ss, Drop[nn, 1]], 
                ss]]], \[IndentingNewLine]{{RandomMultinomialCompiled[_, _], \
_Integer, 
              2}, {RandomHyperGeometricDistribution[_, _, _], _Integer}, {n1, \
_Integer}, {nr, _Integer}, {nt, _Integer}, {jj, _Integer}, {ss, _Integer, 
              1}, {i, _Integer}, {ljk, _Integer}}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomHyperGeometricDistribution[i_, j_, k_] := 
        Random[HypergeometricDistribution[i, j, k]];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
RandomList[k,{p1,p2,...,pn}] returns k integers with probability \
{p1,p2,...,pn}\
\>", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[RandomList] = {Compiled \[Rule] False, 
          Replace -> True};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomList::tooMany = "\<`1` cannot be sampled without replacement \
from the list `2`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomList[k_Integer, p_List, opts___Rule] := \n\t
        If[\(Replace /. {opts}\) /. 
            Options[RandomList], \[IndentingNewLine]If[\(Compiled /. {opts}\) \
/. Options[RandomList], \n\t\tRandomListCompiledReplace[k, 
              p], \[IndentingNewLine]Module[{cp = FoldList[Plus, 0, p], 
                rr}, \nTable[\((rr = 
                    Random[]; \(Position[Sort[Append[cp, \ rr]], rr]\)[\([1, 
                        1]\)] - 1)\), {k}]]], \[IndentingNewLine]If[
            k > Length[p], \[IndentingNewLine]Message[RandomList::tooMany, k, 
              p]; Range[
              Length[p]], \[IndentingNewLine]If[\(Compiled /. {opts}\) /. 
                Options[RandomList], \n\t\tRandomListCompiled[k, 
                p], \[IndentingNewLine]Module[{pr = p, 
                  rk}, \[IndentingNewLine]Table[
                  rk = First[RandomList[1, pr]]; \[IndentingNewLine]pr = 
                    ReplacePart[pr, 0, rk]\/\(1 - pr\[LeftDoubleBracket]rk\
\[RightDoubleBracket]\); rk, {k}]\[IndentingNewLine]]]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomList[k_Integer, p_List, s_List, opts___Rule] := 
        Map[s\[LeftDoubleBracket]#\[RightDoubleBracket] &, 
          RandomList[k, p, opts]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomListCompiledReplace = 
        Compile[{{k, _Integer}, {p, _Real, 1}}, \n\t
          Module[{cp, rr}, \n\ \ \ \ \ \ \ cp = 
              FoldList[Plus, 0, 
                p]; \n\t\t\tTable[\((rr = 
                  Random[]; \(Position[Sort[Append[cp, \ rr]], rr]\)[\([1, 
                      1]\)] - 1)\), {k}]], \n\t\t{{cp, _Real, 
              1}, {rr, _Real}}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomListCompiled = 
        Compile[{{k, _Integer}, {p, _Real, 1}}, \n\t
          Module[{pr = p, 
              rk}, \[IndentingNewLine]Table[\((rk = 
                  First[RandomListCompiledReplace[1, 
                      pr]]; \[IndentingNewLine]pr = 
                  ReplacePart[pr, 0, rk]\/\(1 - pr\[LeftDoubleBracket]rk\
\[RightDoubleBracket]\); rk)\), \[IndentingNewLine]{k}]], \n\t\t{{pr, _Real, 
              1}, {rk, _Integer}, {RandomListCompiledReplace[_, _], _Integer, 
              1}}];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
LogLikelihoodTest[obs,exp] gives log(L) for the comparison of \
observed and expected.\
\>", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[LogLikelihoodTest] = {Compiled \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(LogLikelihoodTest[o_?NumberQ, e_?NumberQ] = 
        If[o \[Equal] 0, 0, o*Log[o/e]];\)\), "\[IndentingNewLine]", 
    \(\(LogLikelihoodTest[obs_List, exp_List, 
          opts___Rule] := \[IndentingNewLine]If[\(Compiled /. {opts}\) /. 
            Options[LogLikelihoodTest], \
\[IndentingNewLine]LogLikelihoodTestCompiled[obs // Flatten, 
            exp // Flatten], \[IndentingNewLine]Plus @@ 
            MapThread[
              LogLikelihoodTest, {obs // Flatten, 
                exp // Flatten}]];\)\), "\[IndentingNewLine]", 
    \(\(LogLikelihoodTest[obs : {{___?NumberQ} ... }, 
          opts___Rule] := \[IndentingNewLine]Module[{m1 = Plus @@ obs, 
            m2 = Plus @@ 
                Transpose[obs]}, \[IndentingNewLine]LogLikelihoodTest[
            Flatten[obs], Flatten[Outer[Times, m2, m1]\/Plus @@ m1], 
            opts]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LogLikelihoodTestCompiled = 
        Compile[{{obs, _Integer, 1}, {exp, _Real, 
              1}}, \[IndentingNewLine]Module[{j}, \[IndentingNewLine]Sum[
              If[obs\[LeftDoubleBracket]j\[RightDoubleBracket] \[Equal] 0, 0, 
                obs\[LeftDoubleBracket]j\[RightDoubleBracket]*
                  Log[obs\[LeftDoubleBracket]j\[RightDoubleBracket]/
                      exp\[LeftDoubleBracket]j\[RightDoubleBracket]]], {j, 
                Length[obs]}]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`NegativeHypergeometricDistribution[n, p, \[Alpha]]\ gives\ the\ 
      distribution\ obtained\ by\ binomial\ sampling\ from\ an\ underlying\ 
      Beta\ distribution\ with\ mean\ p\ and\ variance\ 
      \(p\[VeryThinSpace]q\)\/\(\[Alpha] + 1\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(NegativeHypergeometricDistribution /: 
        Domain[NegativeHypergeometricDistribution[n_, p_, \[Alpha]_]\ ] := 
        Range[0, n];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeHypergeometricDistribution /: 
        PDF[NegativeHypergeometricDistribution[n_, p_, \[Alpha]_]\ , 
          i_] := \(\(Pochhammer[\[Alpha]\ p, \ i] 
                Pochhammer[\[Alpha] \((1 - p)\), \ 
                  n - i]\)\/Pochhammer[\[Alpha], \ n]\) 
          Binomial[n, i];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeHypergeometricDistribution /: 
        CDF[NegativeHypergeometricDistribution[n_, p_, \[Alpha]_]\ , i_] := 
        Module[{j, 
            t = Pochhammer[\[Alpha] \((1 - p)\), \ n]\/Pochhammer[\[Alpha], \ \
n]}, \n\tt + 
            Sum[t = t \(\((\[Alpha]\ p + j - 1)\)\/\((\[Alpha] \((1 - p)\) + 
                          n - j)\)\) \((n - j + 1)\)\/j, {j, 1, 
                i}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeHypergeometricDistribution /: 
        Quantile[
          NegativeHypergeometricDistribution[n_Integer, p_, \[Alpha]_]\ , 
          q_] := Module[{i, s}, \n\t\tIf[q \[LessEqual] 0, 0, 
            If[q \[GreaterEqual] 1, n, 
              If[q < CDF[NegativeHypergeometricDistribution[n, p, \[Alpha]], 
                    Quotient[n, 2]], \n\t\t\t\ti = 0; 
                s = 0; \n\t\t\t\t\tWhile[
                  s += PDF[
                      NegativeHypergeometricDistribution[n, p, \[Alpha]], i]; 
                  s < q, \n\t\t\t\t\t\ti += 1]; i, \n\t\t\t\t\t\ti = n; 
                s = 1; \n\t\t\t\tWhile[
                  s -= PDF[
                      NegativeHypergeometricDistribution[n, p, \[Alpha]], i]; 
                  s \[GreaterEqual] q, \n\t\t\t\t\t\ti -= 1]; 
                i]]\ ]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeHypergeometricDistribution /: 
        Mean[NegativeHypergeometricDistribution[n_, p_, \[Alpha]_]] := 
        n\[VeryThinSpace]p;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeHypergeometricDistribution /: 
        Variance[NegativeHypergeometricDistribution[n_, p_, \[Alpha]_]] := 
        n\ p \((1 - p)\) \((n + \[Alpha])\)\/\((1 + \[Alpha])\);\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeHypergeometricDistribution /: 
        StandardDeviation[
          NegativeHypergeometricDistribution[n_, 
            p_, \[Alpha]_]] := \@\(n\ p \((1 - p)\) \((n + \[Alpha])\)\/\((1 \
+ \[Alpha])\)\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeHypergeometricDistribution /: 
        Skewness[NegativeHypergeometricDistribution[n_, p_, \[Alpha]_]\ ] := 
        n\ p \((1 - p)\) \((1 - 
              2  p)\) \(\(\((n + \[Alpha])\) \((2  
                        n + \[Alpha])\)\)\/\(\((1 + \[Alpha])\) \((2 + \
\[Alpha])\)\)\)/
            StandardDeviation[
                NegativeHypergeometricDistribution[n, 
                  p, \[Alpha]]]^3;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeHypergeometricDistribution /: 
        Kurtosis[NegativeHypergeometricDistribution[n_, p_, \[Alpha]_]] := 
        n\ p \((1 - 
              p)\) \((\(\((n + \[Alpha])\)\/\(\((1 + \[Alpha])\)\ \((2 + \
\[Alpha])\)\ \((3 + \[Alpha])\)\)\) \((\((6 
                           n\^2 + \((6  n - 
                              1\ )\) \[Alpha] + \ \[Alpha]\^2)\) - \((18 
                             n\^2 - 3  n \((n - 6)\)\ \[Alpha]\  - 
                          3 \((n - 2)\)\ \[Alpha]\^2)\)\ p \((1 - p)\))\))\)/
            Variance[
                NegativeHypergeometricDistribution[n, 
                  p, \[Alpha]]]^2;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeHypergeometricDistribution /: 
        KurtosisExcess[
          NegativeHypergeometricDistribution[n_, p_, \[Alpha]_]\ ] := 
        Kurtosis[NegativeHypergeometricDistribution[n, p, \[Alpha]]] - 
          3;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeHypergeometricDistribution /: 
        ExpectedValue[f_, 
          NegativeHypergeometricDistribution[n_, p_, \[Alpha]_]\ ] := 
        Module[{i}, 
          Sum[f[i] 
              PDF[NegativeHypergeometricDistribution[n, p, \[Alpha]], i], {i, 
              0, n}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeHypergeometricDistribution /: 
        ExpectedValue[f_, 
          NegativeHypergeometricDistribution[n_, p_, \[Alpha]_], x_\ ] := 
        Module[{i}, 
          Sum[\((f /. x -> i)\) 
                PDF[NegativeHypergeometricDistribution[n, p, \[Alpha]], 
                  i], {i, 0, n}] // Together];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeHypergeometricDistribution /: 
        CharacteristicFunction[
          NegativeHypergeometricDistribution[n_, p_, \[Alpha]_], 
          t_\ ] := \((Gamma[\[Alpha]]\ Gamma[
                n + \[Alpha] - p\ \[Alpha]]\ HypergeometricPFQ[{\(-n\), 
                  p\ \[Alpha]}, {1 - n - \[Alpha] + p\ \[Alpha]}, 
                Exp[I\ t]])\)/\((Gamma[\((1 - p)\)\ \[Alpha]]\ Gamma[
                n + \[Alpha]])\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeHypergeometricDistribution /: 
        Random[NegativeHypergeometricDistribution[n_, p_, \[Alpha]_]\ ] := 
        Random[BinomialDistribution[n, 
            Random[BetaDistribution[\[Alpha]\ p, \[Alpha] \((1 - 
                      p)\)]]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeHypergeometricDistribution /: 
        RandomArray[NegativeHypergeometricDistribution[n_, p_, \[Alpha]_]\ , 
          dims_List] := 
        Array[Random[NegativeHypergeometricDistribution[n, p, \[Alpha]]] &, 
          dims];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(NegativeBinomialLogLikelihood[{n\_1, \[Ellipsis]}, {n\&_, 
              c}]\ gives\ the\ log\ likelihood\ that\ the\ list\ of\ numbers\ \
{n\_1, \[Ellipsis]}\ are\ drawn\ from\ a\ negative\ binomial\ with\ mean\ \
n\&_\ and\ variance/
            mean\ ratio\ c . \ \ \ \ Compiled -> \(True\ is\ a\ compiled\ \
version . \ \ NegativeBinomialLogLikelihood[{n\&_, 
                    c}]\ gives\ the\ normalisation\ constant\ required\ for\ \
c < 1. \ Normalised \[Rule] False\ omits\ normalisation\); \ 
      this\ may\ give\ errors\ for\ c < 
        1\ but\ is\ substantially\ faster . 
            NegativeBinomialLogLikelihood[{{n\_1, \[Ellipsis]} \[Ellipsis]}, \
{{\[Alpha]\_1, \[Beta]\_1} \[Ellipsis]}, {n\&_, c}]\ gives\ the\ log . \ 
            likelihood\ for\ a\ multiplicative\ model, \ 
      in\ which\ the\ parameters\ in\ \ sample\ k\ are\ \(\({\(\[Alpha]\_k\) 
              n\&_, \(\[Beta]\_k\) c}\)\(.\)\(\ \)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell["\<\
I have tried all sorts of variations on these schemes.  Using a \
Stirling's approximation to Log[Gamma[]] does not give any gain over \
Pochhammer or Log[Gamma[]].  Using the latter seems if anything slower than \
the scheme used below - though timings vary with what kind of array of n's is \
passed.  The scheme below constructs the cumulative distribution of numbers, \
Kl, which seems wasteful relative to Log[Gamma[]], but performs well for the \
few tests I have done.\
\>", "Text"],

Cell[BoxData[
    \(\(Options[NegativeBinomialLogLikelihood] = {Compiled \[Rule] False, 
          Normalised \[Rule] True};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeBinomialLogLikelihood[n : {___Integer}, {nb_, c_}, 
          opts___Rule] := 
        Module[{mx, K, Kl, nbObs, \[IndentingNewLine]bc, rng, 
            nflg = \(Normalised /. {opts}\) /. 
                Options[NegativeBinomialLogLikelihood], 
            cflg = \(Compiled /. {opts}\) /. 
                Options[
                  NegativeBinomialLogLikelihood]}, \[IndentingNewLine]If[
            cflg, \[IndentingNewLine]If[
              nflg, \[IndentingNewLine]\
NegativeBinomialLogLikelihoodNormalisedCompiled[n, nb, c], 
              NegativeBinomialLogLikelihoodCompiled[n, nb, 
                c]], \[IndentingNewLine]mx = Max[n]; K = Length[n]; 
            nbObs = Plus @@ n\/K; \[IndentingNewLine]\[IndentingNewLine]rng = 
              Range[mx]; 
            bc = \(Count[n, #] &\) /@ rng; \[IndentingNewLine]Kl = 
              Drop[Reverse[
                  FoldList[Plus, 0, 
                    Reverse[bc]]], \(-1\)]; \[IndentingNewLine]If[
              nflg, \[IndentingNewLine]If[
                c \[Equal] 
                  1, \[IndentingNewLine]K \((nbObs\ Log[nb] - 
                        nb)\) - \[IndentingNewLine]Kl . 
                    Log[rng], \[IndentingNewLine]If[\((c < 
                        1)\) && \((mx \[GreaterEqual] 
                        1 + nb\/\(1 - c\))\), \[IndentingNewLine]\(-\
\[Infinity]\), \[IndentingNewLine]\(-K\) \((nb\/\(c - 1\) + 
                          nbObs)\)\[VeryThinSpace]Log[c] + 
                    Kl . Log[\((c - 
                              1)\) + \(nb + 1 - c\)\/rng] - \
\[IndentingNewLine]K*NegativeBinomialLogLikelihood[{nb, c}, 
                        opts]]], \[IndentingNewLine]\(-K\) \((nb\/\(c - 1\) + 
                      nbObs)\)\[VeryThinSpace]Log[c] + 
                Kl . Log[\((c - 1)\) + \(nb + 1 - c\)\/rng]]]];\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeBinomialLogLikelihood[{nb_, c_}, opts___Rule] := 
        Module[{k}, \[IndentingNewLine]Chop[
            If[c < 1, \[IndentingNewLine]k = Ceiling[nb\/\(1 - c\)]; 
              Log[1 - \((\((c - 1)\)\^\(k + 1\)\ c\^\(\(-\(nb\/\(c - 1\)\)\) \
- k - 1\)\ \ Pochhammer[nb\/\(c - 1\), k + 1]\ Hypergeometric2F1Regularized[
                        1, 1 + k + nb\/\(c - 1\), 2 + k, \(c - 1\)\/c])\)], 
              0]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeBinomialLogLikelihoodNormalisedCompiled = \
\[IndentingNewLine]Compile[{{n, _Integer, 
              1}, {nb, _Real}, {c, _Real}}, \[IndentingNewLine]Module[{mx = 
                Max[n], rng, K = Length[n], nbObs, bc, 
              Kl}, \[IndentingNewLine]rng = Range[mx]; 
            nbObs = Plus @@ n\/K; \[IndentingNewLine]bc = \(Count[n, #] &\) /@ 
                rng; \[IndentingNewLine]Kl = 
              Drop[Reverse[
                  FoldList[Plus, 0, 
                    Reverse[bc]]], \(-1\)]; \[IndentingNewLine]If[
              c \[Equal] 1, \[IndentingNewLine]K \((nbObs\ Log[nb] - nb)\) - 
                Kl . Log[
                    rng], \[IndentingNewLine]If[\((c < 
                      1)\) && \((mx \[GreaterEqual] 
                      1 + nb\/\(1 - c\))\), \[IndentingNewLine]\(-10\^8. \), \
\[IndentingNewLine]\(-K\) \((nb\/\(c - 1\) + nbObs)\)\[VeryThinSpace]Log[c] + 
                  Kl . Log[\((c - 
                            1)\) + \(nb + 1 - c\)\/rng] - \
\[IndentingNewLine]K*
                    NegativeBinomialLogLikelihood[{nb, 
                        c}]]]], \
\[IndentingNewLine]{{NegativeBinomialLogLikelihood[{_, _}], _Real}}];\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeBinomialLogLikelihoodCompiled = \
\[IndentingNewLine]Compile[{{n, _Integer, 
              1}, {nb, _Real}, {c, _Real}}, \[IndentingNewLine]Module[{mx = 
                Max[n], rng, K = Length[n], nbObs, bc, 
              Kl}, \[IndentingNewLine]rng = Range[mx]; 
            nbObs = Plus @@ n\/K; \[IndentingNewLine]bc = \(Count[n, #] &\) /@ 
                rng; \[IndentingNewLine]Kl = 
              Drop[Reverse[
                  FoldList[Plus, 0, 
                    Reverse[bc]]], \(-1\)]; \[IndentingNewLine]If[
              c \[Equal] 1, \[IndentingNewLine]K \((nbObs\ Log[nb] - nb)\) - 
                Kl . Log[
                    rng], \[IndentingNewLine]If[\((c < 
                      1)\) && \((mx \[GreaterEqual] 
                      1 + nb\/\(1 - c\))\), \[IndentingNewLine]\(-10\^8. \), \
\[IndentingNewLine]\(-K\) \((nb\/\(c - 1\) + nbObs)\)\[VeryThinSpace]Log[c] + 
                  Kl . Log[\((c - 
                            1)\) + \(nb + 1 - c\)\/rng]]]], \
\[IndentingNewLine]{}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeBinomialLogLikelihood[n : {___List}, ab : {{_, _} ... }, 
          nbc : {_, _}, 
          opts___Rule] := \[IndentingNewLine]Module[{nn, nl, 
            mxl}, \[IndentingNewLine]If[\(Compiled /. {opts}\) /. 
              Options[NegativeBinomialLogLikelihood], \[IndentingNewLine]nl = 
              Length /@ n; 
            mxl = Max[nl]; \[IndentingNewLine]nn = 
              If[Min[nl] < mxl, \(PadRight[#, \ mxl, \(-1\)] &\) /@ n, 
                n]; \[IndentingNewLine]If[\(Normalised /. {opts}\) /. 
                Options[NegativeBinomialLogLikelihood], 
              NegativeBinomialLogLikelihoodNMC[nn, ab, 
                nbc], \[IndentingNewLine]NegativeBinomialLogLikelihoodMC[nn, 
                ab, nbc]], \[IndentingNewLine]Plus @@ 
              MapThread[
                NegativeBinomialLogLikelihood[#1, nbc\ #2, opts] &, {n, 
                  ab}]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeBinomialLogLikelihoodMC = \[IndentingNewLine]Compile[{{n, \
_Integer, 2}, {ab, _Real, 2}, {nbc, _Real, 1}}, \[IndentingNewLine]Module[{k, 
              nk = Length[n]}, \[IndentingNewLine]Sum[
              NegativeBinomialLogLikelihoodCompiled[
                DeleteCases[
                  n\[LeftDoubleBracket]k\[RightDoubleBracket], \(-1\)], 
                nbc\[LeftDoubleBracket]1\[RightDoubleBracket]*
                  ab\[LeftDoubleBracket]k, 1\[RightDoubleBracket], 
                nbc\[LeftDoubleBracket]2\[RightDoubleBracket]*
                  ab\[LeftDoubleBracket]k, 2\[RightDoubleBracket]], {k, 
                nk}]], \[IndentingNewLine]{{\
NegativeBinomialLogLikelihoodCompiled[_, _, _], _Real}, {DeleteCases[_, _], \
_Integer, 1}}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeBinomialLogLikelihoodNMC = \[IndentingNewLine]Compile[{{n, \
_Integer, 2}, {ab, _Real, 2}, {nbc, _Real, 1}}, \[IndentingNewLine]Module[{k, 
              nk = Length[n]}, \[IndentingNewLine]Sum[
              NegativeBinomialLogLikelihoodNormalisedCompiled[
                DeleteCases[
                  n\[LeftDoubleBracket]k\[RightDoubleBracket], \(-1\)], 
                nbc\[LeftDoubleBracket]1\[RightDoubleBracket]*
                  ab\[LeftDoubleBracket]k, 1\[RightDoubleBracket], 
                nbc\[LeftDoubleBracket]2\[RightDoubleBracket]*
                  ab\[LeftDoubleBracket]k, 2\[RightDoubleBracket]], {k, 
                nk}]], \[IndentingNewLine]{{\
NegativeBinomialLogLikelihoodNormalisedCompiled[_, _, _], _Real}, \
{DeleteCases[_, _], _Integer, 1}}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(NegativeBinomialMLE[{n\_1, \[Ellipsis]}]\ gives\ the\ MLE\ and\
\ log\ likelihood, \ {L, {n\&_, c}}, \ 
      given\ that\ the\ list\ of\ numbers\ {n\_1, \[Ellipsis]}\ are\ drawn\ \
from\ a\ negative\ binomial\ with\ mean\ n\&_\ and\ variance/
          mean\ ratio\ c . \ 
          NegativeBinomialMLE[{n\_1, \[Ellipsis]}, {None, 
              c}]\ fixes\ c\ at\ some\ definite\ value; \ 
      similarly\ for\ \(\(n\&_\)\(.\)\(\ \)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          NegativeBinomialMLE] = {FullOutput \[Rule] True};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeBinomialMLE[n : {___Integer}, {None, None}, 
          opts___Rule] := \[IndentingNewLine]NegativeBinomialMLE[
          n, {Mean[n], None}, opts];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeBinomialMLE[n : {___Integer}, 
          opts___Rule] := \[IndentingNewLine]NegativeBinomialMLE[
          n, {None, None}, opts];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeBinomialMLE[n : {___Integer}, {nb_?NumberQ, c_?NumberQ}, 
          opts___Rule] := \[IndentingNewLine]If[\(FullOutput /. {opts}\) /. 
            Options[NegativeBinomialMLE], \
\[IndentingNewLine]{NegativeBinomialLogLikelihood[n, {nb, c}, opts], {nb, 
              c}}, \[IndentingNewLine]{nb, c}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeBinomialMLE[n : {___Integer}, {None, c_?NumberQ}, 
          opts___Rule] := 
        Module[{mx = Max[n], K = Length[n], Kl, 
            nbObs = Mean[n], \[IndentingNewLine]bc, nb, 
            nbmle}, \[IndentingNewLine]bc = 
            BinCounts[n, {0, mx, 1}]; \[IndentingNewLine]Kl = 
            Drop[Reverse[
                FoldList[Plus, 0, 
                  Reverse[bc]]], \(-1\)]; \[IndentingNewLine]nbmle = 
            If[c \[Equal] 1, \[IndentingNewLine]nbObs, \[IndentingNewLine]nb /. 
                FindRoot[
                  Log[c]\/\(c - 1\) - \(1\/K\) \((Kl . \(1\/\(\((c - 1)\) 
                                  Range[0, mx - 1] + nb\)\))\), {nb, 
                    nbObs}]]; \[IndentingNewLine]If[\(FullOutput /. {opts}\) /. 
              Options[NegativeBinomialMLE], \
\[IndentingNewLine]{NegativeBinomialLogLikelihood[n, {nbmle, c}, 
                opts], {nbmle, c}}, \[IndentingNewLine]{nbmle, 
              c}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NegativeBinomialMLE[n : {___Integer}, {nb_?NumberQ, None}, 
          opts___Rule] := 
        Module[{mx = Max[n], K = Length[n], Kl, 
            nbObs = Mean[n], \[IndentingNewLine]bc, c, 
            cmle}, \[IndentingNewLine]bc = 
            BinCounts[n, {0, mx, 1}]; \[IndentingNewLine]Kl = 
            Drop[Reverse[
                FoldList[Plus, 0, 
                  Reverse[bc]]], \(-1\)]; \[IndentingNewLine]cmle = 
            c /. FindRoot[
                Log[c]\/\((c - 1)\)\^2 - \((nb - nbObs)\)\/\(c \((c - 1)\)\ \
nb\) - \(1\/\(K \((c - 1)\)\)\) \((Kl . \(1\/\(\((c - 1)\) Range[0, mx - 1] + 
                              nb\)\))\), {c, 
                  Variance[n]\/nbObs}]; \[IndentingNewLine]If[\(FullOutput /. \
{opts}\) /. Options[
                NegativeBinomialMLE], \
\[IndentingNewLine]{NegativeBinomialLogLikelihood[n, {nb, cmle}, opts], {nb, 
                cmle}}, \[IndentingNewLine]{nb, cmle}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(GaussianLogLikelihood[{\(x\_1\) \[Ellipsis]}, {\[Mu], \[Sigma]\
\^2}]\ gives\ the\ log\ likelihood\ for\ the\ sample, \ 
      ignoring\ constants . \ \[Mu], \[Sigma]\^2\ are\ the\ mean\ and\ \
variance\ of\ the\ x\_i . \ 
          GaussianLogLikelihood[{{\(x\_1\) \[Ellipsis]} \[Ellipsis]}, {{\
\[Alpha]\_1, \[Beta]\_1} \[Ellipsis]}, {\[Mu], \[Sigma]\^2}]\ does\ the\ same\
\ for\ an\ additive/multiplicative\ model, \ 
      in\ which\ mean\ and\ variance\ in\ each\ sample\ are\ \[Mu] + \[Alpha]\
\_k, \ \(\[Sigma]\^2\) \[Beta]\_k . \ \ Compiled \[Rule] 
        True\ is\ a\ compiled\ \(\(version\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          GaussianLogLikelihood] = {Compiled \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianLogLikelihood[data : {___?NumberQ}, {m_, v_}, opts___Rule] := 
        If[\(Compiled /. {opts}\) /. 
            Options[GaussianLogLikelihood], \
\[IndentingNewLine]GaussianLogLikelihoodCompiled[data, m, 
            v], \[IndentingNewLine]Module[{n = Length[data], 
              sm = Plus @@ data, dm}, \[IndentingNewLine]dm = 
              data - sm\/n; \(-\(n\/2\)\) \((Log[
                    v] + \(1\/v\) \((\((m - sm\/n)\)\^2 + 
                        dm . dm\/\(n - 1\))\))\)]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianLogLikelihoodCompiled = 
        Compile[{{d, _Real, 1}, {m, _Real}, {v, _Real}}, 
          Module[{n = Length[d], sm = Plus @@ d, dm}, \[IndentingNewLine]dm = 
              d - sm\/n; \(-\(n\/2\)\) \((Log[
                    v] + \(1\/v\) \((\((m - sm\/n)\)\^2 + 
                        dm . dm\/\(n - 1\))\))\)]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianLogLikelihood[data : {___List}, ab : {{_, _} ... }, {m_, v_}, 
          opts___Rule] := \[IndentingNewLine]Plus @@ 
          MapThread[
            GaussianLogLikelihood[#1, {m + #2\[LeftDoubleBracket]1\
\[RightDoubleBracket], v\ #2\[LeftDoubleBracket]2\[RightDoubleBracket]}, 
                opts] &, {data, ab}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(GaussianMLE[{\(x\_1\) \[Ellipsis]}]\ gives\ the\ MLE\ for\ \
\[Mu], \ \[Sigma]\^2, \ 
      the\ mean\ and\ variance\ of\ the\ x\_i . \ 
          GaussianMLE[{{\(x\_1\) \[Ellipsis]} \[Ellipsis]}, {{\[Alpha]\_1, \
\[Beta]\_1} \[Ellipsis]}]\ does\ the\ same\ for\ an\ additive/
          multiplicative\ model, \ 
      in\ which\ mean\ and\ variance\ in\ each\ sample\ are\ \[Mu] + \[Alpha]\
\_k, \ \(\[Sigma]\^2\) \[Beta]\_k . \ \ Compiled \[Rule] 
        True\ is\ a\ compiled\ \(\(version\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(Options[GaussianMLE] = {Compiled \[Rule] False, 
          FullOutput \[Rule] True};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianMLE[data : {___?NumberQ}, opts___Rule] := 
        GaussianMLE[data, {None, None}, opts];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianMLE[data : {___?NumberQ}, {None, None}, 
          opts___Rule] := \[IndentingNewLine]Module[{pars, n, sm, 
            dm}, \[IndentingNewLine]pars = 
            If[\(Compiled /. {opts}\) /. 
                Options[GaussianMLE], \[IndentingNewLine]GaussianMLECompiled[
                data], \[IndentingNewLine]\[IndentingNewLine]n = 
                Length[data]; sm = Plus @@ data\/n; 
              dm = data - sm; {sm, 
                dm . dm\/\(n - 1\)}]; \[IndentingNewLine]If[\(FullOutput /. \
{opts}\) /. Options[GaussianMLE], \[IndentingNewLine]{GaussianLogLikelihood[
                data, pars, opts], 
              pars}, \[IndentingNewLine]pars]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianMLE[data : {___?NumberQ}, {m_?NumberQ, None}, 
          opts___Rule] := \[IndentingNewLine]Module[{pars, n, sm, 
            dm}, \[IndentingNewLine]pars = 
            If[\(Compiled /. {opts}\) /. 
                Options[
                  GaussianMLE], \
\[IndentingNewLine]GaussianMLEVarianceCompiled[data, 
                m], \[IndentingNewLine]dm = data - m; {m, 
                dm . dm\/Length[data]}]; \[IndentingNewLine]If[\(FullOutput /. \
{opts}\) /. Options[GaussianMLE], \[IndentingNewLine]{GaussianLogLikelihood[
                data, pars, opts], 
              pars}, \[IndentingNewLine]pars]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianMLE[data : {___?NumberQ}, {None, v_?NumberQ}, 
          opts___Rule] := \[IndentingNewLine]Module[{pars, n, sm, 
            dm}, \[IndentingNewLine]pars = 
            If[\(Compiled /. {opts}\) /. 
                Options[
                  GaussianMLE], \[IndentingNewLine]GaussianMLEMeanCompiled[
                data, v], \[IndentingNewLine]{Plus @@ data\/Length[data], 
                v}]; \[IndentingNewLine]If[\(FullOutput /. {opts}\) /. 
              Options[GaussianMLE], \[IndentingNewLine]{GaussianLogLikelihood[
                data, pars, opts], 
              pars}, \[IndentingNewLine]pars]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianMLE[data : {___?NumberQ}, {m_?NumberQ, v_?NumberQ}, 
          opts___Rule] := \[IndentingNewLine]If[\(FullOutput /. {opts}\) /. 
            Options[GaussianMLE], \[IndentingNewLine]{GaussianLogLikelihood[
              data, {m, v}, opts], {m, v}}, \[IndentingNewLine]{m, 
            v}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianMLECompiled = 
        Compile[{{d, _Real, 1}}, \[IndentingNewLine]Module[{n = Length[d], 
              sm = Plus @@ d, dm}, \[IndentingNewLine]dm = d - sm\/n; {sm\/n, 
              dm . dm\/\(n - 1\)}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianMLEMeanCompiled = 
        Compile[{{d, _Real, 
              1}, {v, _Real}}, \[IndentingNewLine]{Plus @@ d\/Length[d], 
            v}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianMLEVarianceCompiled = 
        Compile[{{d, _Real, 
              1}, {m, _Real}}, \[IndentingNewLine]Module[{dm = 
                d - m}, \[IndentingNewLine]{m, 
              dm . dm\/Length[d]}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianMLE[data : {___List}, ab : {{_?NumberQ, _?NumberQ} ... }, 
          opts___Rule] := \[IndentingNewLine]GaussianMLE[data, 
          ab, {None, None}, opts];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianMLE[data : {___List}, ab : {{_, _} ... }, {None, None}, 
          opts___Rule] := \[IndentingNewLine]Module[{pars, pd, 
            n = Length /@ data, mxn, nt, mn, tab, mu, ss, nee, 
            dm}, \[IndentingNewLine]If[\(Compiled /. {opts}\) /. 
              Options[GaussianMLE], \[IndentingNewLine]\((mxn = 
                Max[n]; \[IndentingNewLine]pd = 
                If[Min[n] < mxn, \(PadRight[#, mxn, 0] &\) /@ data, 
                  data]; \[IndentingNewLine]pars = 
                GaussianMLEModelCompiled[pd, ab, 
                  n])\), \[IndentingNewLine]\((tab = 
                Transpose[ab]; \[IndentingNewLine]nt = Plus @@ n; 
              mn = \(\((Plus @@ #)\) &\) /@ data\/n; \[IndentingNewLine]\(nee \
= n . \(1\/tab\[LeftDoubleBracket]2\[RightDoubleBracket]\); 
                  mu = n . \((\(mn - tab\[LeftDoubleBracket]1\
\[RightDoubleBracket]\)\/tab\[LeftDoubleBracket]2\[RightDoubleBracket])\)/
                      nee; dm = 
                    data - mn;\)\[IndentingNewLine]ss = \(\((# . #)\) &\) /@ \
dm\/\(n - 1\); \[IndentingNewLine]pars = {mu, \(1\/nt\) \((n . \(\((\((mn - \
tab\[LeftDoubleBracket]1\[RightDoubleBracket])\)\^2 + 
                                  ss)\)\/tab\[LeftDoubleBracket]2\
\[RightDoubleBracket]\))\) - \(mu\^2\) 
                      nee\/nt})\)]; \[IndentingNewLine]If[\(FullOutput /. \
{opts}\) /. Options[GaussianMLE], \[IndentingNewLine]{GaussianLogLikelihood[
                data, ab, pars, opts], 
              pars}, \[IndentingNewLine]pars]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianMLE[data : {___List}, ab : {{_, _} ... }, {m_?NumberQ, None}, 
          opts___Rule] := \[IndentingNewLine]Module[{pars, pd, 
            n = Length /@ data, mxn, nt, mn, tab, mu, ss, nee, 
            dm}, \[IndentingNewLine]If[\(Compiled /. {opts}\) /. 
              Options[GaussianMLE], \[IndentingNewLine]mxn = 
              Max[n]; \[IndentingNewLine]pd = 
              If[Min[n] < mxn, \(PadRight[#, mxn, 0] &\) /@ data, 
                data]; \[IndentingNewLine]pars = 
              GaussianMLEModelVarianceCompiled[pd, ab, n, 
                m], \[IndentingNewLine]tab = 
              Transpose[ab]; \[IndentingNewLine]\((dm = 
                data - m - 
                  tab\[LeftDoubleBracket]1\[RightDoubleBracket]; \
\[IndentingNewLine]pars = {m, \(1\/Plus @@ 
                          n\) \((\(1\/tab\[LeftDoubleBracket]2\
\[RightDoubleBracket]\) . \((\(\((# . #)\) &\) /@ 
                            dm)\))\)})\)]; \[IndentingNewLine]If[\(FullOutput \
/. {opts}\) /. Options[
                GaussianMLE], \[IndentingNewLine]{GaussianLogLikelihood[data, 
                ab, pars, opts], 
              pars}, \[IndentingNewLine]pars]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianMLE[data : {___List}, ab : {{_, _} ... }, {None, v_?NumberQ}, 
          opts___Rule] := \[IndentingNewLine]Module[{pars, pd, 
            n = Length /@ data, mxn, nt, mn, tab, mu, ss, nee, 
            dm}, \[IndentingNewLine]If[\(Compiled /. {opts}\) /. 
              Options[GaussianMLE], \[IndentingNewLine]mxn = 
              Max[n]; \[IndentingNewLine]pd = 
              If[Min[n] < mxn, \(PadRight[#, mxn, 0] &\) /@ data, 
                data]; \[IndentingNewLine]pars = 
              GaussianMLEModelMeanCompiled[pd, ab, n, 
                v], \[IndentingNewLine]tab = 
              Transpose[
                ab]; \[IndentingNewLine]\((mn = \(\((Plus @@ #)\) &\) /@ data\
\/n; \[IndentingNewLine]pars = {n . \((\(mn - tab\[LeftDoubleBracket]1\
\[RightDoubleBracket]\)\/tab\[LeftDoubleBracket]2\[RightDoubleBracket])\)/\((\
n . \(1\/tab\[LeftDoubleBracket]2\[RightDoubleBracket]\))\), 
                  v})\)]; \[IndentingNewLine]If[\(FullOutput /. {opts}\) /. 
              Options[GaussianMLE], \[IndentingNewLine]{GaussianLogLikelihood[
                data, ab, pars, opts], 
              pars}, \[IndentingNewLine]pars]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianMLE[data : {___List}, 
          ab : {{_, _} ... }, {m_?NumberQ, v_?NumberQ}, 
          opts___Rule] := \[IndentingNewLine]If[\(FullOutput /. {opts}\) /. 
            Options[GaussianMLE], \[IndentingNewLine]{GaussianLogLikelihood[
              data, ab, {m, v}, opts], {m, v}}, \[IndentingNewLine]{m, 
            v}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianMLEModelCompiled = 
        Compile[{{d, _Real, 2}, {ab, _Real, 2}, {n, _Integer, 
              1}}, \[IndentingNewLine]Module[{nt = Plus @@ n, mn, 
              tab = Transpose[ab], mu, ss, nee, ssn, 
              nn = n - 
                  1}, \[IndentingNewLine]mn = \(\((Plus @@ #)\) &\) /@ d\/n; \
\[IndentingNewLine]nee = 
              n . \(1\/tab\[LeftDoubleBracket]2\[RightDoubleBracket]\); 
            mu = n . \((\(mn - \
tab\[LeftDoubleBracket]1\[RightDoubleBracket]\)\/tab\[LeftDoubleBracket]2\
\[RightDoubleBracket])\)/
                nee; \[IndentingNewLine]ss = \((\(\((# . #)\) &\) /@ d)\) - 
                n\ \ mn\^2; 
            ssn = ss\/nn; \[IndentingNewLine]{mu, \(1\/nt\) \((n . \(\((\((mn \
- tab\[LeftDoubleBracket]1\[RightDoubleBracket])\)\^2 + 
                              ssn)\)\/tab\[LeftDoubleBracket]2\
\[RightDoubleBracket]\))\) - \(mu\^2\) nee\/nt}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianMLEModelMeanCompiled = 
        Compile[{{d, _Real, 2}, {ab, _Real, 2}, {n, _Integer, 
              1}, {v, _Real}}, \[IndentingNewLine]Module[{mn = \(\((Plus @@ \
#)\) &\) /@ d\/n, 
              tab = Transpose[
                  ab]}, \[IndentingNewLine]{n . \((\(mn - tab\
\[LeftDoubleBracket]1\[RightDoubleBracket]\)\/tab\[LeftDoubleBracket]2\
\[RightDoubleBracket])\)/\((n . \(1\/tab\[LeftDoubleBracket]2\
\[RightDoubleBracket]\))\), v}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GaussianMLEModelVarianceCompiled = 
        Compile[{{d, _Real, 2}, {ab, _Real, 2}, {n, _Integer, 
              1}, {m, _Real}}, \[IndentingNewLine]Module[{tab = 
                Transpose[ab], dm}, \[IndentingNewLine]dm = 
              d - m - tab\[LeftDoubleBracket]1\[RightDoubleBracket]; \
\[IndentingNewLine]{m, \(1\/Plus @@ 
                      n\) \((\(1\/tab\[LeftDoubleBracket]2\
\[RightDoubleBracket]\) . \((\(\((# . #)\) &\) /@ dm)\))\)}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[
      \(MultinomialSamplingCoefficient[{{j\_1, \(k\_1\) \[Ellipsis]}, 
            \[Ellipsis]}]\ gives\ the\ probability\ of\ sampling\ a\ set\ of\ 
        numbers\ {{j\_1, \(k\_1\) \[Ellipsis]}, \[Ellipsis]}\ from\ an\ urn\ 
        containing\ {\[Sum]\_ij\_i, \[Sum]\_i\(k\_i\) \[Ellipsis]}\ of\ each\ 
        \(kind . \)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(MultinomialSamplingProbability[s : {{___} ... }] := 
        Times @@ \((\(\((Multinomial @@ #)\) &\) /@ s)\)\/Multinomial @@ \
\((Plus @@ s)\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Ending", "Subsubsection"],

Cell[BoxData[{
    \(\(End[];\)\), "\n", 
    \(\(EndPackage[];\)\)}], "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1276}, {0, 832}},
AutoGeneratedPackage->Automatic,
WindowSize->{918, 710},
WindowMargins->{{Automatic, 21}, {-1, Automatic}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", 
                  BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    Hyphenation->True,
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 393, 8, 107, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2172, 63, 116, 3, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2313, 70, 224, 3, 58, "Subsubsection"],
Cell[2540, 75, 504, 8, 107, "Input",
  InitializationCell->True],
Cell[3047, 85, 167, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3251, 93, 84, 1, 28, "Subsubsection"],
Cell[3338, 96, 146, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3521, 104, 152, 3, 28, "Subsubsection"],
Cell[3676, 109, 212, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3925, 118, 244, 5, 44, "Subsubsection"],
Cell[4172, 125, 518, 8, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4727, 138, 187, 3, 28, "Subsubsection"],
Cell[4917, 143, 711, 11, 142, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5665, 159, 142, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[5810, 165, 340, 6, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6187, 176, 144, 3, 28, "Subsubsection"],
Cell[6334, 181, 247, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6618, 190, 151, 3, 28, "Subsubsection"],
Cell[6772, 195, 260, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[7069, 205, 147, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[7219, 211, 421, 6, 92, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[7677, 222, 301, 5, 55, "Subsubsection"],
Cell[7981, 229, 359, 7, 73, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8377, 241, 1010, 16, 100, "Subsubsection"],
Cell[9390, 259, 904, 14, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[10331, 278, 312, 6, 28, "Subsubsection",
  InitializationCell->True],
Cell[10646, 286, 273, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[10956, 296, 517, 9, 64, "Subsubsection"],
Cell[11476, 307, 469, 7, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[11982, 319, 165, 4, 28, "Subsubsection"],
Cell[12150, 325, 224, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12411, 334, 179, 4, 28, "Subsubsection"],
Cell[12593, 340, 238, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12868, 349, 688, 11, 65, "Subsubsection"],
Cell[13559, 362, 665, 10, 99, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[14261, 377, 579, 10, 65, "Subsubsection"],
Cell[14843, 389, 678, 10, 112, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[15558, 404, 443, 8, 51, "Subsubsection",
  InitializationCell->True],
Cell[16004, 414, 440, 7, 67, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[16493, 427, 35, 0, 30, "Subsection"],
Cell[16531, 429, 111, 2, 27, "Input",
  InitializationCell->True],
Cell[16645, 433, 104, 2, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[16774, 439, 239, 5, 58, "Subsubsection"],
Cell[17016, 446, 241, 5, 43, "Input",
  InitializationCell->True],
Cell[17260, 453, 348, 7, 75, "Input"],
Cell[17611, 462, 230, 5, 43, "Input",
  InitializationCell->True],
Cell[17844, 469, 1096, 20, 139, "Input",
  InitializationCell->True],
Cell[18943, 491, 177, 3, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[19157, 499, 84, 1, 42, "Subsubsection"],
Cell[19244, 502, 115, 2, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[19396, 509, 152, 3, 28, "Subsubsection"],
Cell[19551, 514, 155, 3, 27, "Input",
  InitializationCell->True],
Cell[19709, 519, 313, 6, 42, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[20059, 530, 243, 5, 44, "Subsubsection"],
Cell[20305, 537, 746, 14, 171, "Input",
  InitializationCell->True],
Cell[21054, 553, 141, 3, 27, "Input",
  InitializationCell->True],
Cell[21198, 558, 1124, 21, 171, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[22359, 584, 192, 3, 28, "Subsubsection"],
Cell[22554, 589, 119, 2, 27, "Input",
  InitializationCell->True],
Cell[22676, 593, 609, 11, 165, "Input",
  InitializationCell->True],
Cell[23288, 606, 1363, 25, 203, "Input",
  InitializationCell->True],
Cell[24654, 633, 1310, 22, 219, "Input",
  InitializationCell->True],
Cell[25967, 657, 166, 3, 27, "Input",
  InitializationCell->True],
Cell[26136, 662, 146, 4, 22, "SubsubsectionIcon",
  InitializationCell->True],
Cell[26285, 668, 140, 3, 27, "Input",
  InitializationCell->True],
Cell[26428, 673, 155, 3, 27, "Input",
  InitializationCell->True],
Cell[26586, 678, 1108, 18, 276, "Input",
  InitializationCell->True],
Cell[27697, 698, 214, 4, 27, "Input",
  InitializationCell->True],
Cell[27914, 704, 443, 9, 91, "Input",
  InitializationCell->True],
Cell[28360, 715, 577, 11, 156, "Input",
  InitializationCell->True],
Cell[28940, 728, 151, 4, 22, "SubsubsectionIcon",
  InitializationCell->True],
Cell[29094, 734, 119, 2, 27, "Input",
  InitializationCell->True],
Cell[29216, 738, 916, 17, 159, "Input",
  InitializationCell->True],
Cell[30135, 757, 538, 9, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[30710, 771, 301, 5, 55, "Subsubsection"],
Cell[31014, 778, 200, 4, 43, "Input",
  InitializationCell->True],
Cell[31217, 784, 359, 7, 62, "Input",
  InitializationCell->True],
Cell[31579, 793, 459, 9, 98, "Input",
  InitializationCell->True],
Cell[32041, 804, 889, 17, 155, "Input",
  InitializationCell->True],
Cell[32933, 823, 203, 4, 27, "Input",
  InitializationCell->True],
Cell[33139, 829, 246, 5, 62, "Input",
  InitializationCell->True],
Cell[33388, 836, 276, 6, 69, "Input",
  InitializationCell->True],
Cell[33667, 844, 477, 10, 62, "Input",
  InitializationCell->True],
Cell[34147, 856, 697, 13, 80, "Input",
  InitializationCell->True],
Cell[34847, 871, 283, 6, 43, "Input",
  InitializationCell->True],
Cell[35133, 879, 344, 8, 59, "Input",
  InitializationCell->True],
Cell[35480, 889, 379, 8, 59, "Input",
  InitializationCell->True],
Cell[35862, 899, 491, 9, 59, "Input",
  InitializationCell->True],
Cell[36356, 910, 317, 6, 43, "Input",
  InitializationCell->True],
Cell[36676, 918, 300, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[37013, 929, 1010, 16, 100, "Subsubsection"],
Cell[38026, 947, 499, 8, 50, "Text"],
Cell[38528, 957, 167, 3, 27, "Input",
  InitializationCell->True],
Cell[38698, 962, 1898, 36, 374, "Input",
  InitializationCell->True],
Cell[40599, 1000, 490, 8, 83, "Input",
  InitializationCell->True],
Cell[41092, 1010, 1256, 24, 282, "Input",
  InitializationCell->True],
Cell[42351, 1036, 1088, 20, 261, "Input",
  InitializationCell->True],
Cell[43442, 1058, 956, 17, 132, "Input",
  InitializationCell->True],
Cell[44401, 1077, 828, 14, 87, "Input",
  InitializationCell->True],
Cell[45232, 1093, 849, 14, 87, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[46118, 1112, 515, 9, 64, "Subsubsection"],
Cell[46636, 1123, 133, 3, 27, "Input",
  InitializationCell->True],
Cell[46772, 1128, 220, 4, 42, "Input",
  InitializationCell->True],
Cell[46995, 1134, 203, 4, 42, "Input",
  InitializationCell->True],
Cell[47201, 1140, 374, 6, 72, "Input",
  InitializationCell->True],
Cell[47578, 1148, 1024, 19, 197, "Input",
  InitializationCell->True],
Cell[48605, 1169, 999, 19, 161, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[49641, 1193, 688, 11, 65, "Subsubsection"],
Cell[50332, 1206, 134, 3, 27, "Input",
  InitializationCell->True],
Cell[50469, 1211, 564, 10, 98, "Input",
  InitializationCell->True],
Cell[51036, 1223, 392, 7, 62, "Input",
  InitializationCell->True],
Cell[51431, 1232, 390, 7, 42, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[51858, 1244, 579, 10, 65, "Subsubsection"],
Cell[52440, 1256, 149, 3, 27, "Input",
  InitializationCell->True],
Cell[52592, 1261, 162, 3, 27, "Input",
  InitializationCell->True],
Cell[52757, 1266, 738, 13, 184, "Input",
  InitializationCell->True],
Cell[53498, 1281, 686, 13, 170, "Input",
  InitializationCell->True],
Cell[54187, 1296, 683, 12, 170, "Input",
  InitializationCell->True],
Cell[54873, 1310, 364, 6, 75, "Input",
  InitializationCell->True],
Cell[55240, 1318, 279, 5, 81, "Input",
  InitializationCell->True],
Cell[55522, 1325, 211, 5, 64, "Input",
  InitializationCell->True],
Cell[55736, 1332, 273, 6, 83, "Input",
  InitializationCell->True],
Cell[56012, 1340, 230, 4, 43, "Input",
  InitializationCell->True],
Cell[56245, 1346, 1601, 26, 345, "Input",
  InitializationCell->True],
Cell[57849, 1374, 1236, 22, 252, "Input",
  InitializationCell->True],
Cell[59088, 1398, 1217, 20, 253, "Input",
  InitializationCell->True],
Cell[60308, 1420, 395, 7, 75, "Input",
  InitializationCell->True],
Cell[60706, 1429, 970, 18, 188, "Input",
  InitializationCell->True],
Cell[61679, 1449, 519, 10, 98, "Input",
  InitializationCell->True],
Cell[62201, 1461, 520, 9, 117, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[62758, 1475, 403, 7, 56, "Subsubsection"],
Cell[63164, 1484, 209, 4, 44, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[63410, 1493, 31, 0, 28, "Subsubsection"],
Cell[63444, 1495, 107, 3, 43, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

