(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     44569,       1060]*)
(*NotebookOutlinePosition[     83563,       2370]*)
(*  CellTagsIndexPosition[     83519,       2366]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    StyleBox[\(BeginPackage["\<Utilities`StructuredModels`\>", \
{"\<Utilities`Matrices`\>", "\<Statistics`DescriptiveStatistics`\>"}];\),
      InitializationCell->True]], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Public parts", "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
DegreesOfFreedom[data,vars,model] gives the number of parameters \
specified by the model\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(DegreesOfFreedom::usage = \
\*"\"\<DegreesOfFreedom[data,vars,{\!\(model\_1\),\[Ellipsis]}] gives the \
number of parameters specified by the models.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
StructuredArray[array, vars, model] creates a transposed array with \
a structure appropriate to the model.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(StructuredArray::usage = "\<StructuredArray[array,vars,model] creates \
a transposed array with a structure appropriate to the model. \>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(\(StructuredLogLikelihoodOld[data, vars, model, initialPars, 
        LogL]\)\(\ \)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(StructuredLogLikelihoodOld::usage = \
\*"\"\<StructuredLogLikelihoodOld[data,vars,model,initialPars,LogL] gives the \
log likelihood, under the constraints specified by the model.  For example, \
StructuredLogLikelihoodOld[data,{line,rep,density},{density,{line,rep}},{\!\(\
z\_0\),{\!\(z\_1\%d\),\[Ellipsis]},{\!\(z\_\(1, \\\\\\\ 1\)\%\(l, \\\\\\\ \
\\\\\\\ r\)\)\[Ellipsis]}},LogL] specifies that the data array is indexed as \
data\[LeftDoubleBracket]line,rep,density\[RightDoubleBracket], and fits a \
model with a common effect \!\(z\^0\),an additive effect of density, \!\(z\^d\
\), and of {line*rep}, \!\(z\^\(l, \\\\\\\ \\\\\\\ r\)\). The log likelihood \
is LogL[data,pars]; this must take a list of independent data values as its \
argument. The array {\!\(z\_0\),{\!\(z\_1\%d\),\[Ellipsis]},{\!\(z\_\(1, \\\\\
\\\ \\\\\\\ 1\)\%\(l, \\\\\\\ \\\\\\\ r\)\)\[Ellipsis]}} gives the parameter \
values.  This scheme can only work when the same model structure applies to \
all variables, and so is not taken further\>\"";\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
StructuredModel[vars,model] replaces the variable names by their \
position in the data array.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(StructuredModel::usage = "\<StructuredModel[vars,model] replaces the \
variable names by their position in the data array.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
StructuredParameter[{i,j,\[Ellipsis]},vars,model,pars] constructs \
the parameter value appropriate to the element {i,j,\[Ellipsis]} in the data \
array, assuming an additive model.  The parameter list is a list with the \
mean effect followed by arrays, corresponding to the components of the model.\
\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(StructuredParameter::usage = \*"\"\<StructuredParameter[{i,j,\
\[Ellipsis]},vars,{model},pars] constructs the parameter value appropriate to \
the element {i,j,\[Ellipsis]} in the data array, assuming an additive model.  \
The parameter list is a list with the mean effect followed by arrays, \
corresponding to the components of the model.  A list of several models can \
be specified, by giving {\!\(model\_1\),\!\(model\_2\)}.  Parameter values \
are returned as lists corresponding to the list of models. \>\"";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(StructuredLogLikelihood[data, vars, model, initialPars, 
          LogL]\ gives\ the\ \ log\ likelihood\ of\ the\ \(\(model\)\(.\)\(\ \
\ \)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(StructuredLogLikelihood::usage = \
\*"\"\<StructuredLogLikelihood[data,vars,model,parameters,LogL]  returns the \
log likelihood.  For example, \
StructuredLogLikelihood[data,{line,rep,density},{density,{line,rep}},{\!\(z\_\
0\),{\!\(z\_1\%d\),\[Ellipsis]},{\!\(z\_\(1, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \
\)\(\\\\\\\\\)\(\\\\\\\ \)\(1\)\)\)\%\(l, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \
\)\(\\\\\\\\\)\(\\\\\\\ \)\(r\)\)\)\)\[Ellipsis]}},LogL] specifies that the \
data array is indexed as data\[LeftDoubleBracket]line,rep,density\
\[RightDoubleBracket], and fits a model with a common effect \!\(z\^0\),an \
additive effect of density, \!\(z\^d\), and of {line*rep}, \!\(z\^\(l, \\\\\\\
\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(r\)\)\)\). The log likelihood is \
LogL[data,pars]; this must take a list of independent data values as its \
argument, and a list pars as its parameters. The array \
{\!\(z\_0\),{\!\(z\_1\%d\),\[Ellipsis]},{\!\(z\_\(1, \\\\\\\ \(\(\\\\\\\\\)\(\
\\\\\\\ \)\(1\)\)\)\%\(l, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \
\)\(\\\\\\\\\)\(\\\\\\\ \)\(r\)\)\)\)\[Ellipsis]}} gives initial parameter \
estimates. A list of multiple models can be specified by giving a list of \
models and a corresponding list of parameter values. \>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[\(StructuredModelReduce[data, vars, model, pars, g]\),
        FontFamily->"Times"], 
      StyleBox["  ",
        FontFamily->"Times"], 
      StyleBox["gives",
        FontFamily->"Times"], 
      StyleBox[" ",
        FontFamily->"Times"], 
      StyleBox["ML",
        FontFamily->"Times"], 
      StyleBox[" ",
        FontFamily->"Times"], 
      StyleBox["estimates",
        FontFamily->"Times"], 
      StyleBox[" ",
        FontFamily->"Times"], 
      StyleBox["based",
        FontFamily->"Times"], 
      StyleBox[" ",
        FontFamily->"Times"], 
      StyleBox["on",
        FontFamily->"Times"], 
      StyleBox[" ",
        FontFamily->"Times"], 
      StyleBox["an",
        FontFamily->"Times"], 
      StyleBox[" ",
        FontFamily->"Times"], 
      StyleBox["estimator",
        FontFamily->"Times"], 
      StyleBox[" ",
        FontFamily->"Times"], 
      RowBox[{
        StyleBox["g",
          FontFamily->"Times"], 
        StyleBox["[",
          FontFamily->"Times"], 
        RowBox[{
          RowBox[{
            StyleBox["{",
              FontFamily->"Times"], 
            RowBox[{
              SubscriptBox[
                StyleBox["data",
                  FontFamily->"Times"], "1"], ",", "\[Ellipsis]"}], "}"}], 
          ",", \({effects\_1, \[Ellipsis]}\)}], "]"}]}]], "Subsubsection"],

Cell[BoxData[
    \(\(StructuredModelReduce::usage = \
\*"\"\<StructuredModelReduce[data,vars,model,pars] generates a flattened \
version of the data, of the form {{\!\(data\_1\),\[Ellipsis]},{\!\(pars\_1\),\
\[Ellipsis]}}.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(StructuredMLE[data, vars, model, initialPars, 
          LogL]\ gives\ the\ MLE, \ 
      under\ the\ constraints\ specified\ by\ the\ \(\(model\)\(.\)\(\ \ \)\)\
\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(StructuredMLE::usage = \
\*"\"\<StructuredMLE[data,vars,model,initialPars,LogL] gives the MLE, under \
the constraints specified by the model.  For example, \
StructuredMLE[data,{line,rep,density},{density,{line,rep}},{\!\(z\_0\),{\!\(z\
\_1\%d\),\[Ellipsis]},{\!\(z\_\(1, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \
\)\(1\)\)\)\%\(l, \\\\\\\ r\)\)\[Ellipsis]}},LogL] specifies that the data \
array is indexed as data\[LeftDoubleBracket]line,rep,density\
\[RightDoubleBracket], and fits a model with a common effect \!\(z\^0\),an \
additive effect of density, \!\(z\^d\), and of {line*rep}, \!\(z\^\(l, \\\\\\\
\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(\\\\\\\\\)\(\\\\\\\ \)\(r\)\)\)\). The log \
likelihood is LogL[data,pars]; this must take a list of independent data \
values as its argument, and a list pars as its parameters. The array \
{\!\(z\_0\),{\!\(z\_1\%d\),\[Ellipsis]},{\!\(z\_\(1, \\\\\\\ 1\)\%\(l, \\\\\\\
\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(r\)\)\)\)\[Ellipsis]}} gives initial parameter \
estimates.  The output is a series of arrays of parameter estimates whose \
structure mirrors that of initialPars. Effects are normalised to sum to zero. \
 ErrorBound\[Rule]\[Epsilon] stops optimisation when the change in \[Epsilon] \
after one cycle is less than \[Epsilon].  The default is \[Epsilon]=0.01.  \
StartingStepSize\[Rule]g gives FindMinimum[] starting values equal to \
g[parameter,j] for the j'th parameter; the default is parameter+{-0.1,0.1}. \
PrintDetails\[Rule]True prints out intermediate values. A list of multiple \
models can be specified by giving a list of models and a corresponding list \
of initial parameter values. \
StructuredMLE[data,vars,model,initialPars,LogL,{j,k}] optimises the \
likelihood w.r.t. the k'th element of the model for the j'th parameter, \
keeping the others fixed. If the model is {} for some parameter, the main \
effect is optimised. StructuredMLE[data,vars,model,initialPars,f,MLE\[Rule]g] \
speeds optimisation by providing a function (or list of functions) \
g[{{\!\(x\_\(1, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(1\)\)\)\)\[Ellipsis]}\
\[Ellipsis]},{{\!\(\[Alpha]\_\(1, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \
\)\(\\\\\\\\\)\(\\\\\\\ \)\(1\)\)\)\)\[Ellipsis]}\[Ellipsis]}] which gives \
the MLE for a structured model.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MainEffect specifies that \
StructuredLogLikelihood[\[Ellipsis],{j,MainEffect}] should optimise the main \
effect of the j'th parameter\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MainEffect::usage = "\<MainEffect specifies that \
StructuredLogLikelihood[\[Ellipsis],{j,MainEffect}] should optimise the main \
effect of the j'th parameter\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ErrorBound\[Rule]\[Epsilon] stops optimisation in \
StructuredLogLikelihood[] when the change in \[Epsilon] after one cycle is \
less than \[Epsilon].\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(ErrorBound::usage = "\<ErrorBound\[Rule]\[Epsilon] stops optimisation \
in StructuredLogLikelihood[] when the change in \[Epsilon] after one cycle is \
less than \[Epsilon].\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
PrintDetails\[Rule]True prints out intermediate values in \
StructuredLogLikelihood[].\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(PrintDetails::usage = "\<PrintDetails\[Rule]True prints out \
intermediate values in StructuredLogLikelihood[].\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
StartingStepSize\[Rule]g determines the starting step sizes for \
each parameter which are supplied to FindMinimum.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(StartingStepSize::usage = 
        StartingStepSize::usage~
          StringJoin~"\<  In StructuredLogLikelihood[], StartingStepSize\
\[Rule]g determines the starting step sizes for each parameter which are \
supplied to FindMinimum.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(StructuredInitialParameters[data, vars, model, 
          f]\ supplies\ initial\ parameter\ values\ which\ are\ constructed\ \
using\ the\ function\ f[
            data] . \ \ A\ list\ of\ parameters\ can\ be\ produced\ using\ \(\
\(StructuredInitialParameters[data, 
            vars, {model\_1, \[Ellipsis]}, {f\_1, \[Ellipsis]}]\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(StructuredInitialParameters::usage = \
\*"\"\<StructuredInitialParameters[data,vars,model,f] supplies initial \
parameter values which are constructed using the function f[data].  A list of \
parameters can be produced using \
StructuredInitialParameters[data,vars,{\!\(model\_1\),\[Ellipsis]},{\!\(f\_1\)\
,\[Ellipsis]}].\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(StructuredVariance[
          pars]\ gives\ the\ variances\ among\ the\ parameter\ list\ in\ pars \
. \ \ StructuredVariance[{pars\_1, 
              pars\_2, \[Ellipsis]}]\ gives\ a\ list\ of\ variances\ \
associated\ with\ parameters\ for\ a\ list\ of\ \(\(models\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(StructuredVariance::usage = \*"\"\<StructuredVariance[pars] gives the \
variances among the parameter list in pars.  \
StructuredVariance[{\!\(pars\_1\),\!\(pars\_2\),\[Ellipsis]}] gives a list of \
variances associated with parameters for a list of models.  \
VarianceComponents\[Rule]True breaks each variance down into its \
components.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Private parts", "Subsection"],

Cell[BoxData[
    \(\(Begin["\<Utilities`StructuredModels`Private`\>"];\)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell["\<\
DegreesOfFreedom[data,vars,model] gives the number of parameters \
specified by the model\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(DegreesOfFreedom[data_List, vars_List, model_List] := 
        Module[{j, mm = model, 
            dims = Dimensions[data]}, \[IndentingNewLine]Do[
            mm = mm /. {vars\[LeftDoubleBracket]
                      j\[RightDoubleBracket] \[Rule] 
                    dims\[LeftDoubleBracket]j\[RightDoubleBracket]}, {j, 
              Length[vars]}]; 
          Table[Plus @@ 
                Replace[
                  mm\[LeftDoubleBracket]
                    j\[RightDoubleBracket], {a__Integer} \[RuleDelayed] 
                    Times[a], 1] - 
              Length[mm\[LeftDoubleBracket]j\[RightDoubleBracket]] + 1, {j, 
              Length[mm]}]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
StructuredArray[array, vars, model] creates a transposed array with \
a structure appropriate to the model.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(StructuredArray[d_List, vars_List, 
          model_List] := \[IndentingNewLine]Module[{m = \(StructuredModel[
                  vars, {model}]\)\[LeftDoubleBracket]1\[RightDoubleBracket], 
            j, nvars = Length[vars], dn, fm, cm, nm, pp, 
            offset = 0}, \[IndentingNewLine]fm = Flatten[m]; 
          cm = Complement[Range[nvars], fm]; \[IndentingNewLine]If[
            Length[fm] > 
              Length[Union[
                  fm]], \[IndentingNewLine]Print["\<Error in StructuredArray: \
model contains repeated elements \>", 
              m]]; \[IndentingNewLine]nm = \(\(Position[
                    fm~Join~cm, #]\)\[LeftDoubleBracket]1, 
                  1\[RightDoubleBracket] &\) /@ 
              Range[nvars]; \[IndentingNewLine]pp = 
            m /. {x_Integer \[RuleDelayed] \(Position[fm~Join~cm, 
                      x]\)\[LeftDoubleBracket]1, 
                    1\[RightDoubleBracket]}; \[IndentingNewLine]dn = 
            Transpose[d, 
              nm]; \[IndentingNewLine]\(\((dn = 
                  Flatten[dn, {Min[#], Max[#]} - offset]; 
                offset = offset + Length[#] - 1)\) &\) /@ 
            pp; \[IndentingNewLine]Flatten[
            dn, {Length[model] + 1, 
              Length[model] + Length[cm] + 1}]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(\(StructuredLogLikelihoodOld[data, vars, model, initialPars, 
        LogL]\)\(\ \)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(StructuredLogLikelihoodOld[data_List, vars_List, model_List, p0_List, 
          f_, opts___Rule] := \[IndentingNewLine]Module[{j, 
            nm = Length[model]}, \[IndentingNewLine]Plus @@ 
            Flatten[MapIndexed[
                f[#1, p0\[LeftDoubleBracket]1\[RightDoubleBracket] + 
                      Sum[p0\[LeftDoubleBracket]j + 1, #2\[LeftDoubleBracket]
                            j\[RightDoubleBracket]\[RightDoubleBracket], {j, 
                          nm}]] &, 
                StructuredArray[data, vars, model], {nm}]]];\)\)], "Input",
  CellLabel->"In[62]:=  (6:34:55 on 3/17/01)"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
StructuredModel[vars,model] replaces the variable names by their \
position in the data array.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(StructuredModel[vars_, model_] := \(StructuredModel[vars, model] = 
          Module[{j, m = model}, \[IndentingNewLine]Do[
              m = m /. vars\[LeftDoubleBracket]j\[RightDoubleBracket] \[Rule] 
                    j, {j, Length[vars]}]; \[IndentingNewLine]Replace[m, 
              x_Integer \[RuleDelayed] {x}, 2]]\);\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
StructuredParameter[{i,j,\[Ellipsis]},vars,model,pars] constructs \
the parameter value appropriate to the element {i,j,\[Ellipsis]} in the data \
array, assuming an additive model.  The parameter list is a list with the \
mean effect followed by arrays, corresponding to the components of the model.\
\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(StructuredParameter[index_List, vars_List, model_List, 
          pars : {{_?\((Not[ListQ[#]] &)\), ___List} ... }] := 
        StructuredParameter[index, StructuredModel[vars, model], 
          pars];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(StructuredParameter[index_List, vars_List, model_List, 
          pars : {_?\((Not[ListQ[#]] &)\), ___List}] := \(StructuredParameter[
            index, vars, {model}, {pars}]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(StructuredParameter[index_List, model_List, 
          pars : {{_?\((Not[ListQ[#]] &)\), ___List} ... }] := 
        Module[{j, k}, \[IndentingNewLine]Table[
            First[pars\[LeftDoubleBracket]j\[RightDoubleBracket]] + 
              Sum[Extract[
                  pars\[LeftDoubleBracket]j, 1 + k\[RightDoubleBracket], 
                  index\[LeftDoubleBracket]model\[LeftDoubleBracket]j, 
                      k\[RightDoubleBracket]\[RightDoubleBracket]], {k, 
                  Length[model\[LeftDoubleBracket]
                      j\[RightDoubleBracket]]}], {j, 
              Length[model]}]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(StructuredLogLikelihoodOlder[data, vars, model, pars, 
          LogL]\ gives\ the\ \ log\ likelihood\ of\ the\ \(\(model\)\(.\)\(\ \
\ \)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell["Perform no optimisation:", "Text"],

Cell[BoxData[
    \(\(StructuredLogLikelihoodOlder[data_List, {}, {{} ... }, {x_}, f_, 
          opts___Rule] := \[IndentingNewLine]f[data, x];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "Make ",
  Cell[BoxData[
      \(TraditionalForm\`StructuredLogLikelihood[\[Ellipsis], model\_1, 
        pars\_1, \[Ellipsis]]\)]],
  " equivalent to the more general form ",
  Cell[BoxData[
      \(TraditionalForm\`StructuredLogLikelihood[\[Ellipsis], {model\_1}, \
{pars\_1}, \[Ellipsis]]\)]]
}], "Text"],

Cell[BoxData[
    \(\(StructuredLogLikelihoodOlder[data_List, vars_List, model_List, 
          p0 : {_?\((Not[ListQ[#]] &)\), ___List}, f_, 
          opts___Rule] := \[IndentingNewLine]StructuredLogLikelihood[data, 
          vars, {model}, {p0}, f, opts];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Construct the appropriate StructuredParameter[] to calculate the \
likelihood of the model:\
\>", "Text"],

Cell[BoxData[
    \(\(StructuredLogLikelihoodOlder[data_List, vars_List, model_List, 
          p0 : {{_?\((Not[ListQ[#]] &)\), ___List} ... }, f_, 
          opts___Rule] := \[IndentingNewLine]Module[{mm = 
              StructuredModel[vars, model], um, cm, nvars = Length[vars], 
            nm = Length[model], num, pp, 
            npars = Length[model]}, \[IndentingNewLine]If[
            nvars \[Equal] 0, \[IndentingNewLine]f[data, 
              Flatten[p0]], \[IndentingNewLine]um = Union[Flatten[mm]]; 
            num = Length[um]; 
            cm = Complement[Range[nvars], um]; \[IndentingNewLine]If[
              cm === {}, \[IndentingNewLine]Plus @@ 
                Flatten[
                  MapIndexed[
                    f[#1, StructuredParameter[#2, vars, model, p0]] &, \ 
                    data, {nvars}]], \[IndentingNewLine]pp = \(\(Position[
                        um~Join~cm, #]\)\[LeftDoubleBracket]1, 
                      1\[RightDoubleBracket] &\) /@ 
                  Range[nvars]; \
\[IndentingNewLine]StructuredLogLikelihoodOlder[
                Flatten[Transpose[data, pp], {num, nvars} + 1], um, mm, p0, 
                f, opts]]]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(StructuredLogLikelihood[data, vars, model, pars, 
          LogL]\ gives\ the\ \ log\ likelihood\ of\ the\ \(\(model\)\(.\)\(\ \
\ \)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(StructuredLogLikelihood[data_List, vars_List, model_List, pars_List, 
          f_] := Plus @@ 
          MapThread[f, 
            StructuredModelReduce[data, vars, model, pars]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[\(StructuredModelReduce[data, vars, model, pars]\),
        FontFamily->"Times"], 
      StyleBox["  ",
        FontFamily->"Times"], 
      StyleBox["gives",
        FontFamily->"Times"], 
      StyleBox[
        RowBox[{
          StyleBox[" ",
            FontFamily->"Times"], " "}]], "a", " ", "flattened", " ", 
      "version", " ", "of", " ", "the", " ", "model"}]], "Subsubsection"],

Cell[TextData[{
  "Make ",
  Cell[BoxData[
      \(TraditionalForm\`StructuredModelReduce[\[Ellipsis], model\_1, 
        pars\_1, \[Ellipsis]]\)]],
  " equivalent to the more general form ",
  Cell[BoxData[
      \(TraditionalForm\`StructuredModelReduce[\[Ellipsis], {model\_1}, {pars\
\_1}, \[Ellipsis]]\)]]
}], "Text"],

Cell[BoxData[
    \(\(StructuredModelReduce[data_List, vars_List, model_List, 
          p0 : {_?\((Not[ListQ[#]] &)\), ___List}, 
          opts___Rule] := \[IndentingNewLine]StructuredModelReduce[data, 
          vars, {model}, {p0}, opts];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Construct the appropriate StructuredParameter[] to calculate the \
likelihood of the model:\
\>", "Text"],

Cell[BoxData[
    \(\(StructuredModelReduce[data_List, vars_List, model_List, 
          p0 : {{_?\((Not[ListQ[#]] &)\), ___List} ... }, 
          opts___Rule] := \[IndentingNewLine]Module[{mm = 
              StructuredModel[vars, model], um, cm, nvars = Length[vars], 
            nm = Length[model], num, pp, npars = Length[model], 
            smr}, \[IndentingNewLine]If[
            nvars \[Equal] 
              0, \[IndentingNewLine]{{data}, {Flatten[
                  p0]}}, \[IndentingNewLine]um = Union[Flatten[mm]]; 
            num = Length[um]; 
            cm = Complement[Range[nvars], um]; \[IndentingNewLine]If[
              cm === {}, \[IndentingNewLine]smr = 
                MapIndexed[{#1, 
                      StructuredParameter[#2, vars, model, p0]} &, \ 
                  data, {nvars}]; \[IndentingNewLine]Transpose[
                Flatten[smr, 
                  nvars - 
                    1]], \[IndentingNewLine]pp = \(\(Position[
                        um~Join~cm, #]\)\[LeftDoubleBracket]1, 
                      1\[RightDoubleBracket] &\) /@ 
                  Range[nvars]; \[IndentingNewLine]StructuredModelReduce[
                Flatten[Transpose[data, pp], {num, nvars} + 1], um, mm, p0, 
                opts]]]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(StructuredMLE[data, vars, model, initialPars, 
          LogL]\ gives\ the\ MLE, \ 
      under\ the\ constraints\ specified\ by\ the\ \(\(model\)\(.\)\(\ \ \)\)\
\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(Options[StructuredMLE] = {ErrorBound \[Rule] 0.01, 
          StartingStepSize \[Rule] \((\((# + {\(-0.1\), 0.1})\) &)\), 
          PrintDetails \[Rule] False, MLE \[Rule] None};\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "Make ",
  Cell[BoxData[
      \(TraditionalForm\`StructuredMLE[\[Ellipsis], model\_1, 
        pars\_1, \[Ellipsis]]\)]],
  " equivalent to the more general form ",
  Cell[BoxData[
      \(TraditionalForm\`StructuredMLE[\[Ellipsis], {model\_1}, {pars\_1}, \
\[Ellipsis]]\)]]
}], "Text"],

Cell[BoxData[{
    \(\(StructuredMLE[data_List, vars_List, model_List, 
          p0 : {_?\((Not[ListQ[#]] &)\), ___List}, f_, k_Integer, 
          opts___Rule] := \[IndentingNewLine]StructuredMLE[data, 
          vars, {model}, {p0}, f, {1, k}, opts];\)\), "\[IndentingNewLine]", 
    \(\(StructuredMLE[data_List, vars_List, model_List, 
          p0 : {_?\((Not[ListQ[#]] &)\), ___List}, f_, MainEffect, 
          opts___Rule] := \[IndentingNewLine]StructuredMLE[data, 
          vars, {model}, {p0}, f, {1, MainEffect}, 
          opts];\)\), "\[IndentingNewLine]", 
    \(\(StructuredMLE[data_List, vars_List, model_List, 
          p0 : {_?\((Not[ListQ[#]] &)\), ___List}, f_, 
          opts___Rule] := \[IndentingNewLine]StructuredMLE[data, 
          vars, {model}, {p0}, f, opts];\)\)}], "Input",
  InitializationCell->True],

Cell["Optimise with respect to {j,k}:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(StructuredMLE[data_List, vars_List, model_List, 
          p0 : {{_?\((Not[ListQ[#]] &)\), ___List} ... }, 
          f_, {j_Integer, k_Integer}, opts___Rule]\), ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({mm = StructuredModel[vars, model], pp0, yy, x, fm, mp, 
              newP, mn, jj, kk, mup, mup2, mu, newM, fmF, smr, 
              nvars = Length[vars], 
              pars0 = Array[0 &, 
                  Length[p0]], \[Gamma] = \(StartingStepSize /. {opts}\) /. 
                  Options[
                    StructuredMLE], \[IndentingNewLine]ml = \(MLE /. {opts}\) \
/. Options[StructuredMLE]}\), ",", "\[IndentingNewLine]", 
            
            RowBox[{\(mp = mm\[LeftDoubleBracket]j, k\[RightDoubleBracket]\), 
              ";", 
              RowBox[{"(*", " ", 
                StyleBox[\(the\ model\ element\ in\ question\),
                  FontWeight->"Plain"], " ", "*)"}], 
              "\[IndentingNewLine]", \(pp0 = 
                Drop[p0\[LeftDoubleBracket]j\[RightDoubleBracket], {k + 1}]\),
               ";", "\[IndentingNewLine]", \(If[
                ml === None, \[IndentingNewLine]pp0 = 
                  ReplacePart[pp0, x + First[pp0], 1]]\), ";", 
              RowBox[{"(*", " ", 
                
                StyleBox[\(residual\ parameters\ after\ removing\ that\ \
element\),
                  FontWeight->"Plain"], " ", "*)"}], 
              "\[IndentingNewLine]", \(newM = mm\), ";", 
              "\[IndentingNewLine]", \(Do[
                newM = DeleteCases[newM, 
                    mp\[LeftDoubleBracket]jj\[RightDoubleBracket], 3], {jj, 
                  Length[mp]}]\), ";", 
              "\[IndentingNewLine]", \(newM = DeleteCases[newM, {}, {2}]\), 
              ";", 
              RowBox[{"(*", 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                StyleBox[\(the\ residual\ model\),
                  FontWeight->"Plain"], 
                StyleBox[" ",
                  FontWeight->"Plain"], "*)"}], "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
                RowBox[{\(ml === None\), ",", "\[IndentingNewLine]", 
                  RowBox[{\(fmF[z_, ii_]\), ":=", 
                    RowBox[{
                      RowBox[{"FindMinimum", "[", "\[IndentingNewLine]", 
                        RowBox[{
                          RowBox[{"-", 
                            RowBox[{
                            "StructuredLogLikelihood", "[", 
                              "\[IndentingNewLine]", 
                              RowBox[{"(*", " ", 
                                
                                StyleBox[\(the\ relevant\ dataset\ that\ \
involves\ the\ element\ #2\ in\ question\),
                                  FontWeight->"Plain"], " ", "*)"}], 
                              "\[IndentingNewLine]", 
                              
                              RowBox[{\(ExtractSubMatrix[data, ii, mp]\), ",",
                                 "\[IndentingNewLine]", \(Delete[
                                  Range[nvars], List /@ mp]\), ",", 
                                "\[IndentingNewLine]", "newM", ",", 
                                "\[IndentingNewLine]", 
                                RowBox[{"(*", " ", 
                                  
                                  StyleBox[\(the\ following\ Table[]\ is\ the\
\ modified\ parameter\ set, \ with\ x\ added\ to\ the\ main\ effect, \ 
                                    and\ only\ the\ relevant\ submatrix\ \
employed\),
                                    FontWeight->"Plain"], 
                                  StyleBox[" ",
                                    FontWeight->"Plain"], "*)"}], 
                                "\[IndentingNewLine]", \(Table[
                                  If[jj \[Equal] 
                                      j, \[IndentingNewLine]pp0, \
\[IndentingNewLine]yy = Prepend[Table[\[IndentingNewLine]\((mu = 
                                        Intersection[
                                        mm\[LeftDoubleBracket]jj, 
                                        kk\[RightDoubleBracket], 
                                        mp]; \[IndentingNewLine]mup = \
\(Position[mm\[LeftDoubleBracket]jj, kk\[RightDoubleBracket], #] &\) /@ 
                                        mu /. {{xx_Integer}} \[RuleDelayed] 
                                        xx; \[IndentingNewLine]mup2 = \
\(Position[mp, #] &\) /@ mu /. {{xx_Integer}} \[RuleDelayed] 
                                        xx; \[IndentingNewLine]\
ExtractSubMatrix[p0\[LeftDoubleBracket]jj, kk + 1\[RightDoubleBracket], 
                                        ii\[LeftDoubleBracket]
                                        mup2\[RightDoubleBracket], 
                                        mup])\), {kk, 
                                        Length[
                                        mm\[LeftDoubleBracket]
                                        jj\[RightDoubleBracket]]}], 
                                        p0\[LeftDoubleBracket]jj, 
                                        1\[RightDoubleBracket]]; \
\[IndentingNewLine]FixedPoint[Replace[#, {{a_?NumberQ, b___, c_?NumberQ, 
                                        d___} \[RuleDelayed] {a + c, b, 
                                        d}}] &, yy]], \[IndentingNewLine]{jj, 
                                    Length[model]}]\), ",", 
                                "\[IndentingNewLine]", "f"}], "]"}]}], 
                          ",", \({x, \[Gamma][z, j]}\)}], "]"}], 
                      "/.", \({_, {x \[Rule] b_}} \[RuleDelayed] b\)}]}], ",",
                   "\[IndentingNewLine]", 
                  RowBox[{\(fmF[z_, ii_]\), ":=", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"smr", "=", 
                          RowBox[{
                          "StructuredModelReduce", "[", "\[IndentingNewLine]",
                             
                            RowBox[{"(*", " ", 
                              
                              StyleBox[\(the\ relevant\ dataset\ that\ \
involves\ the\ element\ #2\ in\ question\),
                                FontWeight->"Plain"], " ", "*)"}], 
                            "\[IndentingNewLine]", 
                            
                            RowBox[{\(ExtractSubMatrix[data, ii, mp]\), ",", 
                              "\[IndentingNewLine]", \(Delete[Range[nvars], 
                                List /@ mp]\), ",", "newM", ",", 
                              "\[IndentingNewLine]", 
                              RowBox[{"(*", " ", 
                                
                                StyleBox[\(the\ following\ Table[]\ is\ the\ \
modified\ parameter\ set, \ with\ only\ the\ relevant\ submatrix\ employed\),
                                  FontWeight->"Plain"], 
                                StyleBox[" ",
                                  FontWeight->"Plain"], "*)"}], 
                              "\[IndentingNewLine]", \(Table[
                                If[jj \[Equal] 
                                    j, \[IndentingNewLine]pp0, \
\[IndentingNewLine]yy = Prepend[Table[\[IndentingNewLine]\((mu = 
                                        Intersection[
                                        mm\[LeftDoubleBracket]jj, 
                                        kk\[RightDoubleBracket], 
                                        mp]; \[IndentingNewLine]mup = \
\(Position[mm\[LeftDoubleBracket]jj, kk\[RightDoubleBracket], #] &\) /@ 
                                        mu /. {{xx_Integer}} \[RuleDelayed] 
                                        xx; \[IndentingNewLine]mup2 = \
\(Position[mp, #] &\) /@ mu /. {{xx_Integer}} \[RuleDelayed] 
                                        xx; \[IndentingNewLine]\
ExtractSubMatrix[p0\[LeftDoubleBracket]jj, kk + 1\[RightDoubleBracket], 
                                        ii\[LeftDoubleBracket]
                                        mup2\[RightDoubleBracket], 
                                        mup])\), {kk, 
                                        Length[
                                        mm\[LeftDoubleBracket]
                                        jj\[RightDoubleBracket]]}], 
                                      p0\[LeftDoubleBracket]jj, 
                                        1\[RightDoubleBracket]]; \
\[IndentingNewLine]FixedPoint[Replace[#, {{a_?NumberQ, b___, c_?NumberQ, 
                                        d___} \[RuleDelayed] {a + c, b, 
                                        d}}] &, yy]], \[IndentingNewLine]{jj, 
                                  Length[model]}]\)}], "]"}]}], ";", 
                        "\[IndentingNewLine]", \(\(ml\[LeftDoubleBracket]
                            j\[RightDoubleBracket]\)[
                          smr\[LeftDoubleBracket]1\[RightDoubleBracket], 
                          smr\[LeftDoubleBracket]2\[RightDoubleBracket], 
                          pars0]\)}], ")"}]}]}], "]"}], ";", 
              "\[IndentingNewLine]", \(fm = 
                MapIndexed[\[IndentingNewLine]fmF, 
                  p0\[LeftDoubleBracket]j, 
                    k + 1\[RightDoubleBracket], {Length[mp]}]\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"(*", " ", 
                StyleBox[\({{L\[Ellipsis]}, {x ... }}\),
                  FontWeight->"Plain"], " ", "*)"}], 
              "\[IndentingNewLine]", \(newP = fm\), ";", 
              "\[IndentingNewLine]", \(mn = Flatten[newP]\), 
              ";", \(mn = Plus @@ mn\/Length[mn]\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"(*", " ", 
                
                StyleBox[\(modify\ the\ parameter\ list\ appropriately, \ 
                  keeping\ means\ at\ zero\),
                  FontWeight->"Plain"], " ", "*)"}], 
              "\[IndentingNewLine]", \(ReplacePart[
                ReplacePart[p0, newP - mn, {j, k + 1}], 
                p0\[LeftDoubleBracket]j, 1\[RightDoubleBracket] + mn, {j, 
                  1}]\)}]}], "\n", " ", "]"}]}], ";"}]], "Input",
  InitializationCell->True],

Cell["Optimise wrt the main effect of element j:", "Text"],

Cell[BoxData[
    \(\(StructuredMLE[data_List, vars_List, model_List, 
          p0 : {{_?\((\(\(\[InvisibleSpace]\)\(! \((ListQ[#1])\)\)\) &)\), \
___List} ... }, f_, {j_Integer, MainEffect}, opts___Rule] := 
        Module[{x, fm, newP, smr, 
            nvars = Length[
                vars], \[Gamma] = \(StartingStepSize \
/. \[InvisibleSpace]{opts}\) /. \[InvisibleSpace]Options[StructuredMLE], 
            ml = \(MLE /. \[InvisibleSpace]{opts}\) \
/. \[InvisibleSpace]Options[StructuredMLE], pars0 = Array[0 &, Length[p0]]}, 
          fm = If[ml === None, \[IndentingNewLine]newP = 
                ReplacePart[p0, 
                  p0\[LeftDoubleBracket]j, 1\[RightDoubleBracket] + x, {j, 
                    1}]; FindMinimum[\(-StructuredLogLikelihood[data, vars, 
                      model, newP, f]\), {x, \[Gamma][
                      p0\[LeftDoubleBracket]j, 1\[RightDoubleBracket], 
                      j]}] /. \[InvisibleSpace]{_, {x \[Rule] 
                        b_}} \[RuleDelayed] b, 
              smr = StructuredModelReduce[data, vars, model, 
                  p0]; \[IndentingNewLine]\(ml\[LeftDoubleBracket]
                  j\[RightDoubleBracket]\)[
                smr\[LeftDoubleBracket]1\[RightDoubleBracket], 
                smr\[LeftDoubleBracket]2\[RightDoubleBracket], 
                pars0]]; \[IndentingNewLine]ReplacePart[p0, 
            p0\[LeftDoubleBracket]j, 1\[RightDoubleBracket] + fm, {j, 
              1}]];\)\)], "Input",
  InitializationCell->True],

Cell["Optimise overall:", "Text"],

Cell[BoxData[
    \(\(StructuredMLE[data_List, vars_List, model_List, 
          p0 : {{_?\((Not[ListQ[#]] &)\), ___List} ... }, f_, 
          opts___Rule] := \[IndentingNewLine]Module[{g, fm, zz, j, k, 
            newL, \[IndentingNewLine]pd = \(PrintDetails /. {opts}\) /. 
                Options[
                  StructuredMLE], \[IndentingNewLine]\[Epsilon] = \
\(ErrorBound /. {opts}\) /. Options[StructuredMLE]}, \[IndentingNewLine]\ 
          g[z_] := \((zz = 
                z\[LeftDoubleBracket]2\[RightDoubleBracket]; \
\[IndentingNewLine]Do[
                If[model\[LeftDoubleBracket]
                      j\[RightDoubleBracket] === {}, \[IndentingNewLine]zz = 
                    StructuredMLE[data, vars, model, zz, f, {j, MainEffect}, 
                      opts], \[IndentingNewLine]Do[
                    zz = StructuredMLE[data, vars, model, zz, f, {j, k}, 
                        opts], {k, 
                      Length[model\[LeftDoubleBracket]
                          j\[RightDoubleBracket]]}]], \[IndentingNewLine]{j, 
                  Length[model]}]; \[IndentingNewLine]newL = 
                StructuredLogLikelihood[data, vars, model, zz, 
                  f]; \[IndentingNewLine]If[pd, 
                Print[newL, Tab, zz]]; \[IndentingNewLine]If[
                newL < z\[LeftDoubleBracket]1\[RightDoubleBracket], 
                Print["\<WARNING: L has decreased\>"]]; \
\[IndentingNewLine]{newL, zz})\); \[IndentingNewLine]\(NestWhile[
              g, {StructuredLogLikelihood[data, vars, model, p0, f], 
                p0}, \[IndentingNewLine]\((\((\((#2\[LeftDoubleBracket]1\
\[RightDoubleBracket] - #1\[LeftDoubleBracket]1\[RightDoubleBracket])\) > \
\[Epsilon])\) || \((#2\[LeftDoubleBracket]1\[RightDoubleBracket] < #1\
\[LeftDoubleBracket]1\[RightDoubleBracket])\))\) &, 2, 
              100]\)\[LeftDoubleBracket]2\[RightDoubleBracket]];\)\)], "Input",\

  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(StructuredInitialParameters[data, vars, model, 
          f]\ \ supplies\ initial\ parameter\ values\ which\ are\ constructed\
\ using\ the\ function\ f[
            data] . \ \ A\ list\ of\ parameters\ can\ be\ produced\ using\ \(\
\(StructuredInitialParameters[data, 
            vars, {model\_1, \[Ellipsis]}, {f\_1, \[Ellipsis]}]\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(StructuredInitialParameters[data_, vars_, model_, 
          f : _?\((Not[
                    ListQ[#]] &)\)] := \[IndentingNewLine]Module[{m = \
\(StructuredModel[vars, {model}]\)\[LeftDoubleBracket]1\[RightDoubleBracket], 
            nvars = Length[vars], cm, j, nm, mn}, \[IndentingNewLine]mn = 
            f[Flatten[data, nvars]]; \[IndentingNewLine]Prepend[
            Table[\[IndentingNewLine]cm = 
                  Complement[Range[nvars], 
                    m\[LeftDoubleBracket]
                      j\[RightDoubleBracket]]; \[IndentingNewLine]nm = \
\(\(Position[m\[LeftDoubleBracket]j\[RightDoubleBracket]~Join~
                            cm, #]\)\[LeftDoubleBracket]1, 
                        1\[RightDoubleBracket] &\) /@ Range[nvars]; \n
                Map[f, Flatten[
                    Transpose[data, 
                      nm], {Length[
                          m\[LeftDoubleBracket]j\[RightDoubleBracket]], 
                        nvars} + 1], {Length[
                      m\[LeftDoubleBracket]
                        j\[RightDoubleBracket]]}], \[IndentingNewLine]{j, 
                  Length[m]}] - mn, mn]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(StructuredInitialParameters[data_, vars_, model_, 
          f_List] := \[IndentingNewLine]MapThread[
          StructuredInitialParameters[data, vars, #1, #2] &, {model, 
            f}];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(StructuredVariance[
          pars]\ gives\ the\ variances\ among\ the\ parameter\ list\ in\ pars \
. \ \ StructuredVariance[{pars\_1, 
              pars\_2, \[Ellipsis]}]\ gives\ a\ list\ of\ variances\ \
associated\ with\ parameters\ for\ a\ list\ of\ \(\(models\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          StructuredVariance] = {VarianceComponents \[Rule] 
            False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(StructuredVariance[x : {_?NumberQ, ___List}, opts___Rule] := 
        If[\(VarianceComponents /. {opts}\) /. 
            Options[StructuredVariance], \[IndentingNewLine]\(Drop[
                VarianceComponents[#], 1] &\) /@ 
            Drop[x, 1], \[IndentingNewLine]\(Variance[Flatten[#]] &\) /@ 
            Drop[x, 1]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(StructuredVariance[x : {{_?NumberQ, ___List} ... }, 
          opts___Rule] := \(StructuredVariance[#, opts] &\) /@ 
          x;\)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ending", "Subsection",
  InitializationCell->True],

Cell["\<\
End[];
\
\>", "Input",
  InitializationCell->True],

Cell["EndPackage[];", "Input",
  InitializationCell->True]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->Automatic,
WindowSize->{773, 681},
WindowMargins->{{Automatic, 24}, {Automatic, 3}},
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    Hyphenation->True,
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 223, 4, 43, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[1965, 57, 62, 1, 46, "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2052, 62, 122, 3, 42, "Subsubsection"],
Cell[2177, 67, 220, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[2434, 76, 140, 3, 28, "Subsubsection"],
Cell[2577, 81, 205, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[2819, 90, 161, 3, 28, "Subsubsection"],
Cell[2983, 95, 1063, 14, 205, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4083, 114, 127, 3, 28, "Subsubsection"],
Cell[4213, 119, 191, 3, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4441, 127, 335, 6, 60, "Subsubsection"],
Cell[4779, 135, 582, 9, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5398, 149, 220, 4, 28, "Subsubsection"],
Cell[5621, 155, 1294, 19, 205, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6952, 179, 1377, 47, 27, "Subsubsection"],
Cell[8332, 228, 272, 5, 60, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8641, 238, 241, 5, 28, "Subsubsection"],
Cell[8885, 245, 2321, 33, 414, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[11243, 283, 168, 4, 28, "Subsubsection"],
Cell[11414, 289, 227, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[11678, 298, 183, 4, 28, "Subsubsection"],
Cell[11864, 304, 242, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12143, 313, 119, 3, 28, "Subsubsection"],
Cell[12265, 318, 180, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12482, 326, 148, 3, 28, "Subsubsection"],
Cell[12633, 331, 302, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12972, 342, 418, 7, 46, "Subsubsection"],
Cell[13393, 351, 393, 7, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[13823, 363, 352, 6, 48, "Subsubsection"],
Cell[14178, 371, 410, 7, 91, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[14637, 384, 35, 0, 30, "Subsection"],
Cell[14675, 386, 141, 3, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[14841, 393, 122, 3, 42, "Subsubsection"],
Cell[14966, 398, 726, 15, 91, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[15729, 418, 140, 3, 42, "Subsubsection"],
Cell[15872, 423, 1344, 25, 187, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[17253, 453, 161, 3, 42, "Subsubsection"],
Cell[17417, 458, 631, 10, 91, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18085, 473, 127, 3, 42, "Subsubsection"],
Cell[18215, 478, 392, 6, 91, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[18644, 489, 335, 6, 74, "Subsubsection"],
Cell[18982, 497, 267, 5, 59, "Input",
  InitializationCell->True],
Cell[19252, 504, 288, 5, 59, "Input",
  InitializationCell->True],
Cell[19543, 511, 674, 12, 91, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[20254, 528, 218, 4, 42, "Subsubsection"],
Cell[20475, 534, 40, 0, 30, "Text"],
Cell[20518, 536, 187, 3, 43, "Input",
  InitializationCell->True],
Cell[20708, 541, 325, 9, 30, "Text"],
Cell[21036, 552, 301, 5, 59, "Input",
  InitializationCell->True],
Cell[21340, 559, 115, 3, 30, "Text"],
Cell[21458, 564, 1221, 22, 219, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[22716, 591, 213, 4, 42, "Subsubsection"],
Cell[22932, 597, 245, 5, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[23214, 607, 433, 12, 41, "Subsubsection"],
Cell[23650, 621, 321, 9, 30, "Text"],
Cell[23974, 632, 285, 5, 59, "Input",
  InitializationCell->True],
Cell[24262, 639, 115, 3, 30, "Text"],
Cell[24380, 644, 1306, 24, 219, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[25723, 673, 241, 5, 42, "Subsubsection"],
Cell[25967, 680, 244, 4, 43, "Input",
  InitializationCell->True],
Cell[26214, 686, 305, 9, 30, "Text"],
Cell[26522, 697, 835, 14, 155, "Input",
  InitializationCell->True],
Cell[27360, 713, 47, 0, 30, "Text"],
Cell[27410, 715, 10294, 184, 1015, "Input",
  InitializationCell->True],
Cell[37707, 901, 58, 0, 30, "Text"],
Cell[37768, 903, 1511, 26, 203, "Input",
  InitializationCell->True],
Cell[39282, 931, 33, 0, 30, "Text"],
Cell[39318, 933, 1942, 33, 283, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[41297, 971, 420, 7, 60, "Subsubsection"],
Cell[41720, 980, 1211, 22, 139, "Input",
  InitializationCell->True],
Cell[42934, 1004, 253, 5, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[43224, 1014, 352, 6, 62, "Subsubsection"],
Cell[43579, 1022, 154, 4, 27, "Input",
  InitializationCell->True],
Cell[43736, 1028, 391, 7, 75, "Input",
  InitializationCell->True],
Cell[44130, 1037, 194, 4, 43, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[44373, 1047, 56, 1, 46, "Subsection",
  InitializationCell->True],
Cell[44432, 1050, 60, 4, 42, "Input",
  InitializationCell->True],
Cell[44495, 1056, 58, 1, 27, "Input",
  InitializationCell->True]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

