(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2106330,      77532]*)
(*NotebookOutlinePosition[   2570667,      89457]*)
(*  CellTagsIndexPosition[   2543593,      88751]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Setting up IndexTags", "Section",
  CellTags->"Setting up IndexTags"],

Cell["\<\
It is important to check that there are no repeated tags, within or \
between BrowserCategories.m files:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(packageSet = {"\<:Genealogies\>", "\<:Multilocus\>", "\<:Using \
packages\>", "\<:Utilities\>"};\)\), "\n", 
    \(\(tagSet = FindTagList /@ packageSet;\)\), "\n", 
    \(ExtractRepeat[Flatten[tagSet]]\)}], "Input"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(InsertIndexTags /@ packageSet;\)\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[\(NotebookObject[\[LeftSkeleton]"Untitled-7"\
\[RightSkeleton]]\),
          NotebookObject[ 
            FrontEndObject[ 
              LinkObject[ "Mathematica 4", 1, 1]], 69]], ",", 
        InterpretationBox[\(NotebookObject[\[LeftSkeleton]"Untitled-8"\
\[RightSkeleton]]\),
          NotebookObject[ 
            FrontEndObject[ 
              LinkObject[ "Mathematica 4", 1, 1]], 72]], ",", 
        InterpretationBox[\(NotebookObject[\[LeftSkeleton]"Untitled-9"\
\[RightSkeleton]]\),
          NotebookObject[ 
            FrontEndObject[ 
              LinkObject[ "Mathematica 4", 1, 1]], 75]], ",", 
        InterpretationBox[\(NotebookObject[\[LeftSkeleton]"Untitled-10"\
\[RightSkeleton]]\),
          NotebookObject[ 
            FrontEndObject[ 
              LinkObject[ "Mathematica 4", 1, 1]], 78]]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The BrowserCatagory cell in each notebook must be set as an \
initialisation cell, and the notebook saved in a new folder.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Fixing duff files", "Subsection"],

Cell["\<\
Annoyingly, the expressions were put into the new \
BrowserCategories.m files by InsertIndexTags as formatted expressions.  These \
have been rewritten as unformatted expressions using \
ConvertFormattedFiles\
\>", "Text"],

Cell[BoxData[
    \(\(\(ConvertFormattedFiles[FindBrowserCategories[#]] &\) /@ 
        packageSet;\)\)], "Input"],

Cell["Even then, string delimiters have to be put in by hand.", "Text"],

Cell["\<\
28/2/01 - May still be a problem, though the index seems to appear \
correctly - an error message is generated.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Checking that the folders contain only files referred to in \
BrowserCategories.m\
\>", "Section",
  CellTags->"Checking files"],

Cell["\<\
These are the files named in BrowserCategories.m but not found in \
the directory, and vice versa:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\((fl = FindNamedFiles[#]; \n
          fnl = FileNameOnly /@ 
              FileNames[\ "\<*.nb\>", 
                ToFileName[{"\<:AddOns:Applications\>", #, \
"\<:Documentation:English\>"}]]; \n{Complement[fl, fnl], 
            Complement[fnl, fl]})\) &\) /@ packageSet\)], "Input"],

Cell[BoxData[
    \({{{}, {}}, {{}, {"BrowserIndex.nb"}}, {{}, {}}, {{}, {}}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Converting hyperlinks to AddOnsLinks", "Section",
  CellTags->"Converting hyperlinks"],

Cell[CellGroupData[{

Cell["Multilocus", "Subsubsection"],

Cell[BoxData[
    \(\(fnl = 
        FileNames[\ "\<*.nb\>", \
"\<:AddOns:Applications:Multilocus:Documentation:English\>"];\)\)], "Input"],

Cell["\<\
This lists the 32 files which contain hyperlinks, and need to be \
converted.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hll = 
        Table[nb = 
            NotebookOpen[
              fnl\[LeftDoubleBracket]
                j\[RightDoubleBracket]]; \[IndentingNewLine]hl = 
            FindHyperlinks[]; \[IndentingNewLine]If[
            Length[hl] > 0, \[IndentingNewLine]Print["\<File \>", j, Tab, 
              fnl\[LeftDoubleBracket]
                j\[RightDoubleBracket]]]; \[IndentingNewLine]\ \ \
NotebookClose[nb]; \[IndentingNewLine]Length[hl] > 0, {j, 
            Length[fnl]}];\)\), "\[IndentingNewLine]", 
    \(fnh = 
      Cases[Transpose[{hll, fnl}], {True, _}] /. {True, a_} \[Rule] 
          a\)}], "Input"],

Cell[BoxData[
    \({":AddOns:Applications:Multilocus:Documentation:English:\
AdmixtureEquilibria.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
AdmixtureOverview.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
AdmixtureRecombination.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
CumulantDocumentation.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
DiploidGenotypeData.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
DisequilibriumDocumentation.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:DriftIntroDoc.\
nb", ":AddOns:Applications:Multilocus:Documentation:English:\
EstimatingDAdmixture.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
EstimatingDAlternative.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
EstimatingDFamilies.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
EstimatingDFullDiploid.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
EstimatingDIntervals.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
EstimatingDMatrix.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
EstimatingDMLEFind.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
EstimatingDMLExample.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
EstimatingDMLMetropolis.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
EstimatingDOverview.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
EstimatingDPairExample.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
EstimatingDSummary.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:GeneticData.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
GenotypeDataSubsets.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
IntroDocumentation.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
IntroductionDocumentation.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
NotationPackageDoc.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
OperationsDocumentation.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
PhenotypesDocumentation.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
PoplnExpectationDoc.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
RecombinationDocumentation.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
ReferenceDocumentation.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
SelectionDocumentation.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
SexualSelectionDoc.nb", 
      ":AddOns:Applications:Multilocus:Documentation:English:\
SymmetricReproduction.nb"}\)], "Output"]
}, Closed]],

Cell["\<\
Various errors occur, so it is best to convert notebooks \
one-by-one.  \"Illegal RHS\" seems not to be a real problem; the troublesome \
one is that links to Refguide aren't converted properly.  These should be \
pasted in from BrowserIndex.nb\
\>", "Text"],

Cell[BoxData[
    \(\(gg[
          j_] := \((nb0 = SelectedNotebook[]; \[IndentingNewLine]nb = 
            NotebookOpen[
              fnh\[LeftDoubleBracket]
                j\[RightDoubleBracket]]; \[IndentingNewLine]NotebookWrite[
            nb0, "\<Converting hyperlinks for \>", 
            fnh\[LeftDoubleBracket]
              j\[RightDoubleBracket]]; \
\[IndentingNewLine]ConvertHyperlinkToAddOnsLink[]; \[IndentingNewLine]nb2 = 
            SelectedNotebook[]; \[IndentingNewLine]nfn = 
            StringReplacePart[
              FileNameOnly[
                fnh\[LeftDoubleBracket]
                  j\[RightDoubleBracket]], "\<NEW\>", {\(-3\), \(-1\)}]; \
\[IndentingNewLine]NotebookSave[nb2, nfn]; \[IndentingNewLine]NotebookClose[
            nb2]; \[IndentingNewLine]NotebookClose[nb])\);\)\)], "Input"],

Cell[BoxData[
    \(gg[32]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fnh\[LeftDoubleBracket]29\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \(":AddOns:Applications:Multilocus:Documentation:English:\
ReferenceDocumentation.nb"\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(nb = 
        NotebookOpen[
          fnh\[LeftDoubleBracket]8\[RightDoubleBracket]];\)\), "\
\[IndentingNewLine]", 
    \(ConvertHyperlinkToAddOnsLink[]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Genealogies", "Subsubsection"],

Cell[BoxData[
    \(\(fnl = 
        FileNames[\ "\<*.nb\>", \
"\<:AddOns:Applications:Genealogies:Documentation:English\>"];\)\)], "Input"],

Cell["\<\
Various errors occur, so it is best to convert notebooks \
one-by-one.  \"Illegal RHS\" seems not to be a real problem; the troublesome \
one is that links to Refguide aren't converted properly.  These should be \
pasted in from BrowserIndex.nb\
\>", "Text"],

Cell[BoxData[
    \(\(gg[
          j_] := \((nb0 = SelectedNotebook[]; \[IndentingNewLine]nb = 
            NotebookOpen[
              fnl\[LeftDoubleBracket]
                j\[RightDoubleBracket]]; \[IndentingNewLine]hl = 
            FindHyperlinks[]; \[IndentingNewLine]If[
            Length[hl] > 0, \[IndentingNewLine]Print[
              nb0, "\<Converting hyperlinks for \>", 
              fnl\[LeftDoubleBracket]
                j\[RightDoubleBracket]]; \
\[IndentingNewLine]ConvertHyperlinkToAddOnsLink[]; \[IndentingNewLine]nb2 = 
              SelectedNotebook[]; \[IndentingNewLine]nfn = 
              StringReplacePart[
                FileNameOnly[
                  fnl\[LeftDoubleBracket]
                    j\[RightDoubleBracket]], "\<NEW\>", {\(-3\), \(-1\)}]; \
\[IndentingNewLine]NotebookSave[nb2, nfn]; \[IndentingNewLine]NotebookClose[
              nb2], \[IndentingNewLine]Print["\<No hyperlinks for \>", 
              FileNameOnly[
                fnl\[LeftDoubleBracket]
                  j\[RightDoubleBracket]]]]; \[IndentingNewLine]NotebookClose[
            nb])\);\)\)], "Input"],

Cell[BoxData[
    \(gg[38]\)], "Input"],

Cell[BoxData[{
    \(\(NotebookObject[\[LeftSkeleton]"\<SettingUp.nb\>"\[RightSkeleton]]\)\
\\\n"\<Converting hyperlinks for \
\>"\ \
"\<:AddOns:Applications:Genealogies:Documentation:English:\
\
StructureGenealogies.nb\>"\), "\[IndentingNewLine]", 
    \(FindIndexTag::"\<noBrowserCategories\>" : "\<No BrowserCategories.m \
found with file \
\!\(FrontEnd`FileName[\(\(\(\({\(\[LeftSkeleton] 1 \
\[RightSkeleton]\)}\)\), \
\"Tree.nb\", \(\(CharacterEncoding -> \
\"MacintoshRoman\"\)\)\)\)]\)\>"\)}], "Input"],

Cell[BoxData[{
    \(\(NotebookObject[\[LeftSkeleton]"\<SettingUp.nb\>"\[RightSkeleton]]\)\
\\\n"\<Converting hyperlinks for \
\>"\ \
"\<:AddOns:Applications:Genealogies:Documentation:English:\
\
StructureGenealogies.nb\>"\), "\[IndentingNewLine]", 
    \(FindIndexTag::"\<noBrowserCategories\>" : "\<No BrowserCategories.m \
found with file \
\!\(FrontEnd`FileName[\(\(\(\({\(\[LeftSkeleton] 1 \
\[RightSkeleton]\)}\)\), \
\"Tree.nb\", \(\(CharacterEncoding -> \
\"MacintoshRoman\"\)\)\)\)]\)\>"\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Using packages", "Subsubsection"],

Cell[BoxData[
    \(\(fnl = 
        FileNames[\ "\<*.nb\>", "\<:AddOns:Applications:Using \
packages:Documentation:English\>"];\)\)], "Input"],

Cell["\<\
Various errors occur, so it is best to convert notebooks \
one-by-one.  \"Illegal RHS\" seems not to be a real problem; the troublesome \
one is that links to Refguide aren't converted properly.  These should be \
pasted in from BrowserIndex.nb\
\>", "Text"],

Cell[BoxData[
    \(\(gg[
          j_] := \((nb0 = SelectedNotebook[]; \[IndentingNewLine]nb = 
            NotebookOpen[
              fnl\[LeftDoubleBracket]
                j\[RightDoubleBracket]]; \[IndentingNewLine]hl = 
            FindHyperlinks[]; \[IndentingNewLine]If[
            Length[hl] > 0, \[IndentingNewLine]Print[
              nb0, "\<Converting hyperlinks for \>", 
              fnl\[LeftDoubleBracket]
                j\[RightDoubleBracket]]; \
\[IndentingNewLine]ConvertHyperlinkToAddOnsLink[]; \[IndentingNewLine]nb2 = 
              SelectedNotebook[]; \[IndentingNewLine]nfn = 
              StringReplacePart[
                FileNameOnly[
                  fnl\[LeftDoubleBracket]
                    j\[RightDoubleBracket]], "\<NEW\>", {\(-3\), \(-1\)}]; \
\[IndentingNewLine]NotebookSave[nb2, nfn]; \[IndentingNewLine]NotebookClose[
              nb2], \[IndentingNewLine]Print["\<No hyperlinks for \>", 
              FileNameOnly[
                fnl\[LeftDoubleBracket]
                  j\[RightDoubleBracket]]]]; \[IndentingNewLine]NotebookClose[
            nb])\);\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gg[5]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("No hyperlinks for \
"\[InvisibleSpace]"ContinuumAncestry.nb"\),
      SequenceForm[ "No hyperlinks for ", "ContinuumAncestry.nb"],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Utilities", "Subsubsection"],

Cell[BoxData[
    \(\(fnl = 
        FileNames[\ "\<*.nb\>", \
"\<:AddOns:Applications:Utilities:Documentation:English\>"];\)\)], "Input"],

Cell["\<\
Various errors occur, so it is best to convert notebooks \
one-by-one.  \"Illegal RHS\" seems not to be a real problem; the troublesome \
one is that links to Refguide aren't converted properly.  These should be \
pasted in from BrowserIndex.nb\
\>", "Text"],

Cell[BoxData[
    \(\(gg[
          j_] := \((nb0 = SelectedNotebook[]; \[IndentingNewLine]nb = 
            NotebookOpen[
              fnl\[LeftDoubleBracket]
                j\[RightDoubleBracket]]; \[IndentingNewLine]hl = 
            FindHyperlinks[]; \[IndentingNewLine]If[
            Length[hl] > 0, \[IndentingNewLine]Print[
              nb0, "\<Converting hyperlinks for \>", 
              fnl\[LeftDoubleBracket]
                j\[RightDoubleBracket]]; \
\[IndentingNewLine]ConvertHyperlinkToAddOnsLink[]; \[IndentingNewLine]nb2 = 
              SelectedNotebook[]; \[IndentingNewLine]nfn = 
              StringReplacePart[
                FileNameOnly[
                  fnl\[LeftDoubleBracket]
                    j\[RightDoubleBracket]], "\<NEW\>", {\(-3\), \(-1\)}]; \
\[IndentingNewLine]NotebookSave[nb2, nfn]; \[IndentingNewLine]NotebookClose[
              nb2], \[IndentingNewLine]Print["\<No hyperlinks for \>", 
              FileNameOnly[
                fnl\[LeftDoubleBracket]
                  j\[RightDoubleBracket]]]]; \[IndentingNewLine]NotebookClose[
            nb])\);\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Making the index: initial set-up", "Section",
  CellTags->"Index initial set-up"],

Cell["\<\
This section sets up the MasterIndexMatrix, based on finding all \
cell tags in the doicumentation files, and some editing by hand.  \
\>", \
"Text"],

Cell[CellGroupData[{

Cell["Listing cell tags", "Subsubsection"],

Cell["\<\
The first step is to list all cell tags in the help files:  \
{{indexTag,celltag}\[Ellipsis]}\
\>", "Text"],

Cell[BoxData[{
    \(\(fn[
          dir_] := \(ToFileName[{"\<:AddOns:Applications\>", 
                dir, "\<:Documentation:English\>"}, \ #] &\) /@ 
          FindNamedFiles[dir];\)\), "\[IndentingNewLine]", 
    \(\(fnl = Flatten[fn /@ packageSet];\)\), "\[IndentingNewLine]", 
    \(\(itl = Flatten[FindTagList /@ packageSet];\)\)}], "Input"],

Cell[BoxData[
    \(\(xtl[s_] := \(xtl[s] = 
          MapThread[\((Print["\<Doing \>", FileNameOnly[#2]]; {#1, 
                  Flatten[ExtractCellTags[#2]]})\) &, 
            Reverse /@ {itl\[LeftDoubleBracket]s\[RightDoubleBracket], 
                fnl\[LeftDoubleBracket]
                  s\[RightDoubleBracket]}]\);\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Chunks", "Subsubsection"],

Cell["\<\
Do in chunks to avoid crashes (an obscure problem with the Front \
End)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(xtl[Range[1, 20]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Finding possible orders\"\>", \
\({"NumberOfPossibleCoalescences", "PossibleCoalescenceOrder", 
                "RandomCoalescenceOrder"}\)},
            {"\<\"Ordered genealogies\"\>", \({"IncidenceMatrix"}\)},
            {"\<\"Deriving the probability\"\>", \({}\)},
            {"\<\"Converting between representations\"\>", \({"ListToMatrix", 
                "MatrixToList", "MutationLabels"}\)},
            {"\<\"Inferring a genealogy\"\>", \({"FindNode", 
                "MatrixToGenealogy"}\)},
            {"\<\"Describing mutation\"\>", \({"GenealogyToMatrix"}\)},
            {"\<\"Population bottlenecks\"\>", \({"DeletedMutations", 
                "RandomBottleneckedGenealogy"}\)},
            {"\<\"Describing mutations\"\>", \({"Mutations", 
                "MutationOrigin", "NumberOfMutations", 
                "MutationInterval"}\)},
            {"\<\"Drawing a genealogy\"\>", \({"MutationRate", 
                "RandomGenealogy"}\)},
            {"\<\"Random families\"\>", \({"RandomFamilies", 
                "RandomPreviousFamily"}\)},
            {"\<\"Distribution of coalescence times\"\>", \
\({"CoalescenceDistribution", "B", "RandomCoalescenceTimes", 
                "NumberOfCoalescences", "TotalLength"}\)},
            {"\<\"The set of all structures\"\>", \({"AllSets", "NewS"}\)},
            {"\<\"Probabilities\"\>", \({"FamilyProbability", 
                "SimplifyFamilies"}\)},
            {"\<\"Family structure\"\>", \({}\)},
            {"\<\"Manipulating genealogies\"\>", \({"AddGenealogy", 
                "AddNode", "CondenseGenealogy", "ExtractGenealogy", 
                "DeleteGenealogy"}\)},
            {"\<\"Constructing genealogies\"\>", \({"Node", 
                "ListToGenealogy", "NodeFunction"}\)},
            {"\<\"Describing genealogies\"\>", \({"CollapseGenealogy", 
                "ExtractInformation", "NumberOfLineages", 
                "TransformInformation", "Nodes", "InternalNodes", 
                "Leaves"}\)},
            {"\<\"Ancestors and descendants\"\>", \({"Ancestors", 
                "Descendants"}\)},
            {"\<\"Plotting genealogies\"\>", \({"NodeFunction", 
                "PlotGenealogy", "MakeGenealogyPlot", "SizeOfGenealogyPlot", 
                "NodeLabels", "LeafLabels", "NodeOffset", "LeafOffset"}\)},
            {"\<\"Structure of genealogies\"\>", \({"Node", 
                "UnrootedGenealogy", "RootedGenealogy"}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "\"\<Estimating the probability\>\"", \
\({"\<MonteCarloProbability\>"}\)},
            {"\"\<Griffiths-Tavare algorithm\>\"", \({}\)},
            {
              "\"\<Exact algorithm\>\"", \({"\<GriffithsTavare\>", "\<Example\
\>"}\)},
            {
              "\"\<Stochastic algorithm\>\"", \({"\<Stochastic GT \
algorithm\>", "\<MonteCarloGriffithsTavare\>", "\<Small example\>", \
"\<Comparison with MonteCarloProbability\>"}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(xtl[Range[25, 30]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Boxing the individuals\"\>", \({"Individuals", "Box", 
                "DistanceSquared", "MakeDistances", "MakeDistanceList", 
                "Neighbours", "NeighbourArray"}\)},
            {"\<\"Initialisation\"\>", \({"InitialiseContinuum", 
                "FindPosition", "ExtractExtant"}\)},
            {"\<\"Global variables\"\>", \({"NumberOfIndividuals", 
                "ExtantIndividuals", "T", "NetFecundity", "NetMortality", 
                "TotalNumber"}\)},
            {"\<\"Describing individuals\"\>", \({"Location", "Density", 
                "Fecundity", "Mortality", "BirthTime", "DeathTime", 
                "Ancestry", "Offspring", "Boxes"}\)},
            {"\<\"Implementation\"\>", \({}\)},
            {"\<\"The model\"\>", \({}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(xtl[Range[31, 40]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Genes and contexts\"\>", \({"Basic notation", 
                "Genes and contexts", "OtherSex", "Stages"}\)},
            {"\<\"Introduction to multilocus algebra\"\>", \({"S5.67.1", 
                "1.1", "Multilocus`Multilocus`"}\)},
            {"\<\"Sampling genealogies\"\>", \({}\)},
            {"\<\"Sampling individuals\"\>", \({"SampleIndividuals"}\)},
            {"\<\"Making a genealogy\"\>", \({"MakeGenealogy"}\)},
            {"\<\"Determining ancestry\"\>", \({"MostRecentCommonAncestor", 
                "Ancestors", "Descendants"}\)},
            {"\<\"Estimating the covariance\"\>", \({}\)},
            {"\<\"An example\"\>", \({}\)},
            {"\<\"Sampling\"\>", \({"InitialiseCovariance", 
                "SampleCovariance", "CovarianceMidPoints", 
                "SpatialCovariance"}\)},
            {"\<\"Iterating  the continuum model\"\>", \({"IterateContinuum", 
                "Birth", "Death"}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(xtl[Range[41, 60]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Life cycle\"\>", \({"NotationPackage", "Stages", "Sex", 
                "SexOfOrigin", "Deme", "Individual"}\)},
            {"\<\"Introduction to selection on diploids\"\>", \({}\)},
            {"\<\"Random drift: cumulants\"\>", \({"NotationPackage", 
                "ToPopulationMoments", "ToPopulationCumulants"}\)},
            {"\<\"Wright-Fisher sampling\"\>", \({}\)},
            {"\<\"Expectations\"\>", \({"multiple arguments", 
                "PopulationExpectation", "PopulationDisequilibrium"}\)},
            {"\<\"Introduction to random drift\"\>", \({"Changing reference \
points", "Cumulants and moments", "Describing a distribution", 
                "Equations for the moments", "Random sampling"}\)},
            {"\<\"Slow change\"\>", \({"NotationPackage", "SlowChange"}\)},
            {"\<\"Fitness\"\>", \({"MakeFitnessSet", 
                "MakeSelectionCoefficient", "NotationPackage", 
                "Obsolete notation", "SelectionCoefficient", "Fitness"}\)},
            {"\<\"Phenotypes\"\>", \({"MakeSelectionCoefficient"}\)},
            {"\<\"Two alleles\"\>", \({"Biallelic", "NotationPackage"}\)},
            {"\<\"Multilocus cumulants\"\>", \({"ToCumulants", 
                "ToMoments"}\)},
            {"\<\"Disequilibrium\"\>", \({"Disequilibrium", "Symmetrise"}\)},
            {"\<\"Changing contexts\"\>", \({"Applying transmission rules", 
                "TransmissionRule", "ChangeContext"}\)},
            {"\<\"Extracting contexts\"\>", \({"ExtractContexts", 
                "ExtractGenes"}\)},
            {"\<\"Selecting contexts\"\>", \({"SelectContexts"}\)},
            {"\<\"Abbreviating contexts\"\>", \({"FullContext", 
                "ShortContext"}\)},
            {"\<\"Stages in the life cycle\"\>", \({"ContextPosition", 
                "ContextComponentQ", "ContextStageQ", "DefineContext", 
                "ContextStructure"}\)},
            {"\<\"Populations\"\>", \({"Expectation", "NotationPackage", 
                "Technicalities", "MeanContribution", "Disequilibrium", 
                "AlleleFrequencyP", "AlleleFrequencyPQ", 
                "AlleleFrequencyQ"}\)},
            {"\<\"Allelic state\"\>", \({"AllelicState", "NotationPackage", 
                "ReferencePoint", "AllelicDeviation"}\)},
            {"\<\"Operations on sets\"\>", \({"Join", "TakeAway", 
                "ExactIntersection", "AddUp", "TimesUp"}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(xtl[Range[61, 80]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Defining fitnesses\"\>", \({"MarginalW", "MeanW"}\)},
            {"\<\"Describing the population\"\>", \({"InitialiseDemes", 
                "ClineWidth", "MeanP", "MeanD"}\)},
            {"\<\"Manipulating genotypes\"\>", \({"ClassToGenotypes", 
                "GenotypePosition"}\)},
            {"\<\"Representing the population\"\>", \({"DiploidPsi", 
                "HaploidSource", "DiploidSource", "S5.24.1", "1.4", 
                "SymmetricModel", "SortByClass"}\)},
            {"\<\"Multilocus references\"\>", \({"Barton 1995", 
                "Barton and Turelli 1991", "Crow and Kimura 1970", 
                "Kirkpatrick and Barton 1997", 
                "Kirkpatrick and Servedio 1998", 
                "Turelli and Barton 1994"}\)},
            {"\<\"Notation package\"\>", \({}\)},
            {"\<\"Notation reference\"\>", \({"NotationPackage"}\)},
            {"\<\"A method to avoid\"\>", \({}\)},
            {"\<\"Explaining the rules\"\>", \({}\)},
            {"\<\"Cautionary notes\"\>", \({}\)},
            {"\<\"Sexual selection\"\>", \({"Complete cycle", 
                "Defining fitnesses", "Random union", "Recombination", 
                "Sexual selection", "subtle problem"}\)},
            {"\<\"Stabilising selection\"\>", \({"Change in D", 
                "Change in mean", "Defining fitness", "Mean fitness", 
                "New mean", "New mean fitness", "Rules"}\)},
            {"\<\"Additive selection\"\>", \({"Defining fitnesses", 
                "Defining rules", "New D", "New mean", "Scaled D"}\)},
            {"\<\"Symmetric sexes\"\>", \({"EquivalentSexes"}\)},
            {"\<\"Complete life cyle\"\>", \({}\)},
            {"\<\"Recombination\"\>", \({"Context-dependent recombination", 
                "Meiosis", "SymmetricRecombination", "Recombination", 
                "RecombinationRate"}\)},
            {"\<\"Selection\"\>", \({"FitnessSet", 
                "SelectionCoefficient"}\)},
            {"\<\"Random union\"\>", \({"RandomUnion"}\)},
            {"\<\"Union of gametes\"\>", \({"UnionOfGametes"}\)},
            {"\<\"Reference points\"\>", \({"ReferencePointMean", 
                "ReferencePointSame", "ReferencePointZero"}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(xtl[Range[81, 100]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Potential problems\"\>", \({"Avoid integers", "pitfall", 
                "Redefining fitness"}\)},
            {"\<\"Adding a neutral gene\"\>", \({"Barrier", "FixedEnds", 
                "IterateNeutral", "StoreNeutral", "IterateNeutral", 
                "Cline"}\)},
            {"\<\"Storing a cline\"\>", \({"SymmetricCline", "StoreExact", 
                "Cline"}\)},
            {"\<\"Iterating a cline\"\>", \({"FixdEnds", "IterateExact", 
                "Cline"}\)},
            {"\<\"Iterating one deme\"\>", \({"IterateExact", 
                "MigrationOrder"}\)},
            {"\<\"Migration in the symmetric model\"\>", \({"FixedEnds", 
                "MigrateExact"}\)},
            {"\<\"Reproduction in the symmetric model\"\>", \({"GameteTable", 
                "NewGametes", "StoreResults", "Gametes", "HeterozygoteB"}\)},
            {"\<\"References for the symmetric model\"\>", \({}\)},
            {"\<\"Limitations\"\>", \({}\)},
            {"\<\"Fitnesses for the symmetric model\"\>", \({"FitnessTable", 
                "MarginalW", "MarginalWTable", "MeanW", "MeanWTable"}\)},
            {"\<\"Describing populations\"\>", \({"BarrierStrength", 
                "ClineGradient", "ClineWidth", "MeanP", "MeanD"}\)},
            {"\<\"Setting up a symmetric cline\"\>", \({"DoubleCline"}\)},
            {"\<\"Setting up a cline\"\>", \({"InitialiseDemes"}\)},
            {"\<\"Genotype frequencies\"\>", \({"DiploidPhenotype", 
                "DiploidPsi", "DiploidSource", "HaploidSource"}\)},
            {"\<\"Recursion checks\"\>", \({"S5.24.1", "1.4"}\)},
            {"\<\"Example: stability\"\>", \({"StabilityDirect", "S5.24.1", 
                "1.4"}\)},
            {"\<\"Example: epistasis\"\>", \({}\)},
            {"\<\"Iterating the recursions\"\>", \({"IterateExact", 
                "StoreExact"}\)},
            {"\<\"Linkage\"\>", \({"Gametes", "GameteTable", "Linkage", 
                "NetRecombination"}\)},
            {"\<\"Reproduction recursions\"\>", \({"Gametes", "GameteTable", 
                "NewGametes", "Gametes", "SymmetricModel"}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(xtl[Range[101, 120]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Recombination in admixture models\"\>", \
\({"MomentAfterRecombination"}\)},
            {"\<\"Migration in admixture models\"\>", \
\({"MomentAfterMigration"}\)},
            {"\<\"Iteration\"\>", \({"MomentNew"}\)},
            {"\<\"Equilibria\"\>", \({"AdmixtureFrequency", 
                "CumulantEquilibrium", "MomentEquilibrium"}\)},
            {"\<\"Overview\"\>", \({}\)},
            {"\<\"References\"\>", \({"Asmussen et al 1987", "Barton 1986", 
                "Barton 2000", "Barton & Gale 1993", "Barton & Shpak 1999", 
                "Barton & Turelli 1991", "Dempster et al 1977", 
                "Edwards 1972", "Goodman et al 1999", 
                "Guiasu & Shenitzer 1985", "Haber 1984", "Hill 1974a", 
                "Hill 1974b", "Hill 1974c", "Kirkpatrick et al 1983", 
                "Kruuk 1997", "Li & Nei 1974", "Long et al 1995", 
                "MacCallum 1994", "MacCallum et al 1998", 
                "Mangel & Hilborn 1996", "Metropolis et al 1954", 
                "Orive & Barton 1999", "Phipps & Brill 1995", 
                "Slatkin & Excoffier 1996", "Turelli & Barton 1994", 
                "Asmussen et al 1987", "Arnold 1996"}\)},
            {"\<\"Summary\"\>", \({}\)},
            {"\<\"Estimating the matrix of moments\"\>", \({"Extension to \
families"}\)},
            {"\<\"A matrix of moments\"\>", \({"g[X] full matrix", 
                "g[X] matrix"}\)},
            {"\<\"Admixture models\"\>", \({}\)},
            {"\<\"Pairs of loci\"\>", \({}\)},
            {"\<\"Alternative methods\"\>", \({"Log-linear models", 
                "Maximum entropy", "Naive MLE"}\)},
            {"\<\"Introduction to estimating D\"\>", \({}\)},
            {"\<\"Spatially varying selection\"\>", \({}\)},
            {"\<\"Faster algorithms\"\>", \({"StabilityKTable"}\)},
            {"\<\"Example: a cline\"\>", \({"StabilityK"}\)},
            {"\<\"Example: one deme\"\>", \({"ExactEigenvalues", 
                "SigmaMatrix", "StabilityK"}\)},
            {"\<\"Making a stability matrix\"\>", \({"StabilityMatrix"}\)},
            {"\<\"Outline\"\>", \({}\)},
            {"\<\"Checks on the symmetric model\"\>", \({}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(xtl[Range[121, 140]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Sampling example\"\>", \({}\)},
            {"\<\"Analysing replicate samples\"\>", \({"DoReplicates"}\)},
            {"\<\"Constrained intervals\"\>", \({"ConstrainedIntervals"}\)},
            {"\<\"Constraints on moments\"\>", \({"MomentLimits"}\)},
            {"\<\"Random walk\"\>", \({}\)},
            {"\<\"Finding the MLE\"\>", \({"FindMLE", "Cumulant"}\)},
            {"\<\"Initial step size\"\>", \({"InitialStep"}\)},
            {"\<\"Estimating moments\"\>", \({"MetropolisDisequilibrium"}\)},
            {"\<\"Metropolis algorithm\"\>", \({"$MetropolisAdjustment"}\)},
            {"\<\"Likelihood\"\>", \({"LogLikelihoodDisequilibrium"}\)},
            {"\<\"MLE example\"\>", \({}\)},
            {"\<\"Internal functions\"\>", \({"AlleleFrequencyPermutations", 
                "dAlleleFrequencyPermutations", "SignMask", 
                "PloidyWeightList"}\)},
            {"\<\"Moments and cumulants\"\>", \({"Cumulant", "Moment"}\)},
            {"\<\"Estimation from families\"\>", \({"EstimateFamilyMoments", 
                "FamilyAlleleFrequencyEstimate", "MToC", "MVariables", 
                "FamilyEffects", "FamilyM", "MFromC", "MToCEquations"}\)},
            {"\<\"Estimating the matrix\"\>", \({"EstimateMoments", "MToC", 
                "MVariables", "Varying divergence", "MFromC", 
                "MToCEquations"}\)},
            {"\<\"Fast calculations\"\>", \({"DiploidGenotypeFrequencyList", 
                "MatrixGamma"}\)},
            {"\<\"Full diploid genotypes\"\>", \({"GenotypeFrequencyConvert", 
                "PositionsList", "PositionsMatrix", 
                "PossibleDiploidGenotypes"}\)},
            {"\<\"Genotype frequencies from moments\"\>", \
\({"DiploidGenotypeFrequency", "HaploidGenotypeFrequency"}\)},
            {"\<\"Moments from genotype frequencies\"\>", \
\({"MomentsFromG"}\)},
            {"\<\"Simplifying the moments\"\>", \({"MomentSimple"}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(xtl[Range[141, 160]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Generating families\"\>", \({"Linkage", "NotationPackage", 
                "RandomFamily", "SegregationRatio"}\)},
            {"\<\"Diploid genotypes\"\>", \({"ObservableGenotype", 
                "PossibleGenotypes"}\)},
            {"\<\"Subsets of loci\"\>", \({"DiploidSubsets", 
                "HaploidSubsets"}\)},
            {"\<\"Listing genotypes\"\>", \({"DiploidTypes", "HaploidTypes", 
                "NotationPackage"}\)},
            {"\<\"Notation\"\>", \({"NotationPackage"}\)},
            {"\<\"Selecting subsets\"\>", \({"NotationPackage", 
                "SelectIndividuals", "SelectLoci"}\)},
            {"\<\"Gene & genotype frequencies\"\>", \
\({"GenotypeFrequencyTable", "AlleleFrequencyMean", "AlleleFrequencyTable", 
                "NetCovariance", "Linkage disequilibrium"}\)},
            {"\<\"Simplifying a dataset\"\>", \({"NotationPackage", 
                "ReducedData"}\)},
            {"\<\"Converting a dataset\"\>", \({"ConvertData", 
                "NotationPackage"}\)},
            {"\<\"Describing a dataset\"\>", \({"NotationPackage", "Ploidy", 
                "NumberOfIndividualsTable", "NumberOfGenesTable", 
                "NumberOfIndividuals", "NumberOfGenes", "NumberOfLoci"}\)},
            {"\<\"Defining a dataset\"\>", \({"NotationPackage", 
                "LocusNames", "Data", "Missing data"}\)},
            {"\<\"Notation for genetic data\"\>", \({"NotationPackage"}\)},
            {"\<\"Obsolete functions\"\>", \({}\)},
            {"\<\"The method\"\>", \({"NotationPackage"}\)},
            {"\<\"Pairwise tables\"\>", \({"MakePairwiseTable", 
                "NotationPackage", "PresentPairwiseTable"}\)},
            {"\<\"Single-locus tables\"\>", \({"MakeOneWayTable", 
                "NotationPackage", "PresentOneWayTable"}\)},
            {"\<\"Pairwise example\"\>", \({}\)},
            {"\<\"Presenting results\"\>", \({"CompareLogL", "PlotLogL", 
                "PresentResults"}\)},
            {"\<\"Setting up replicates\"\>", \({"DrawSamples"}\)},
            {"\<\"Options for DoReplicates\"\>", \({"MethodC", "MethodP"}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(xtl[Range[161, 180]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Multinomial distribution\"\>", \
\({"MultinomialSamplingProbability", "Multinomial sampling wo replacement", 
                "RandomMultinomial"}\)},
            {"\<\"Sampling from arbitrary distributions\"\>", \({"RandomCum"}\
\)},
            {"\<\"Random lists\"\>", \({"Compiled", "RandomList", 
                "Replace"}\)},
            {"\<\"Muddling and subdividing sets\"\>", \({"Muddle", 
                "Subdivide"}\)},
            {"\<\"Random sets\"\>", \({"RandomSet"}\)},
            {"\<\"Variance components\"\>", \({"Table"}\)},
            {"\<\"Marginal tables\"\>", \({"Function", "MarginalTable"}\)},
            {"\<\"Extracting submatrices\"\>", \({"ExtractSubMatrix"}\)},
            {"\<\"Flattening lists at specific levels\"\>", \({"Flatten"}\)},
            {"\<\"Diagonal matrices\"\>", \({"UpperOffDiagonal", 
                "LowerOffDiagonal", "TriDiagonalMatrix"}\)},
            {"\<\"Indexing\"\>", \({}\)},
            {"\<\"Hyperlinks\"\>", \({"ConvertHyperlinkToAddOnsLink", 
                "FindHyperlinks", "FindIndexTag"}\)},
            {"\<\"Automatic Numbering\"\>", \({"Aesthetics", "f eqn", 
                "Finding tags", "Notes", "psi eqn", "psi soln", 
                "Saving the links", "Setting up links to a list of tags", 
                "SA.8.7", "7.2", "FindTags", "NumberedLink"}\)},
            {"\<\"Special notation\"\>", \({"Defining notation", 
                "Setting up packages"}\)},
            {"\<\"Bugs and features\"\>", \({"Clashes between packages", 
                "Incompatibilities", "Manipulating notebooks", 
                "Multilocus notation", "Obsolete EstimatingD", 
                "Pasting hyperlinks", "Repeated \\\\", 
                "Special notation"}\)},
            {"\<\"How the Help Browser works\"\>", \({"Absolute", "Accuracy", 
                "Browser categories", "MasterIndexHeading", "Packages", 
                "Setting up links", "Setting up Master Index"}\)},
            {"\<\"Setting up new help files\"\>", \({"Setting up new help \
files"}\)},
            {"\<\"Setting up the packages\"\>", \({"Setting up the packages"}\
\)},
            {"\<\"Linkage in families\"\>", \({"NetRecombination", 
                "NotationPackage"}\)},
            {"\<\"Genotype probabilities\"\>", \({"GenotypeProbability", 
                "Linkage", "NotationPackage", "ObservableGenotype", 
                "SegregationRatio"}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(xtl[Range[181, 200]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Tagging sets\"\>", \({"Tag", "AddTag", "RemoveTag"}\)},
            {"\<\"Sorting\"\>", \({"SortByHead", "Reverse"}\)},
            {"\<\"ProductSum\"\>", \({"ProductSum", 
                "ProductSum over sets"}\)},
            {"\<\"Symmetrise\"\>", \({"Symmetrise"}\)},
            {"\<\"Flattening lists by pattern\"\>", \({"FlattenList", 
                "PatternFree"}\)},
            {"\<\"Set partitions\"\>", \({"NumberOfSamplePartitions", 
                "NumberOfSetPartitions", "SamplePartition", 
                "SetPartition"}\)},
            {"\<\"Subsets\"\>", \({"Subsets"}\)},
            {"\<\"Locations\"\>", \({"Locations"}\)},
            {"\<\"Join\"\>", \({"Join"}\)},
            {"\<\"ExactIntersection\"\>", \({"ExactIntersection"}\)},
            {"\<\"TakeAway\"\>", \({"SA.8.7", "7.2", "TakeAway"}\)},
            {"\<\"|., ||.\"\>", \({"ReplaceAllSpecial", 
                "ReplacerepeatedSpecial"}\)},
            {"\<\"TimesUp\"\>", \({"Multiple products", "TimesUp"}\)},
            {"\<\"AddUp\"\>", \({"AddUp", "Multiple sums", "SimplifyAddUp", 
                "SimplifyAddUpQ", "Technicalities"}\)},
            {"\<\"Repeated elements\"\>", \({"Repeat", "ExtractRepeat"}\)},
            {"\<\"Overview of set manipulation\"\>", \({}\)},
            {"\<\"Negative binomial likelihoods\"\>", \({"c<1", "Compiled", 
                "multiplicative models", "NegativeBinomialLogLikelihood", 
                "NegativeBinomialMLE", "normalisation", "Normalisation", 
                "Normalised", "Timings"}\)},
            {"\<\"Gaussian likelihoods\"\>", \({"additive models", 
                "GaussianLogLikelihood", "GaussianMLE", "additive models", 
                "FullOutput"}\)},
            {"\<\"Likelihood tests\"\>", \({"LogLikelihoodTest"}\)},
            {"\<\"Negative hypergeometric distribution\"\>", \
\({"NegativeHypergeometricDistribution"}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(xtl[Range[201, 214]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Manipulating options\"\>", \({"DropOptions", 
                "TakeOptions"}\)},
            {"\<\"DivideZero\"\>", \({"DivideZero"}\)},
            {"\<\"Fourier transforms\"\>", \({"FourierNormalisedTable", 
                "InverseFourierNormalisedTable", "FourierNormalised", 
                "InverseFourierNormalised", "TransformedRange"}\)},
            {"\<\"Cumulants\"\>", \({"GeneralizedTransform", "SA.8.7", "7.2", 
                "Distribution", "SA.8.7", "7.2", "Cumulant", "Moment"}\)},
            {"\<\"Useful functions\"\>", \({"StructuredArray", 
                "StructuredModel"}\)},
            {"\<\"Structured parameters\"\>", \({"StructuredParameter"}\)},
            {"\<\"Variance components for a structured model\"\>", \
\({"StructuredVariance", "VarianceComponents"}\)},
            {"\<\"Hierarchical analysis\"\>", \({}\)},
            {"\<\"Options for StructuredMLE\"\>", \({"ErrorBound", 
                "StartingStepSize", "StructuredMLE", "PrintDetails"}\)},
            {"\<\"Initial parameters\"\>", \
\({"StructuredInitialParameters"}\)},
            {"\<\"Degrees of freedom\"\>", \({"DegreesOfFreedom"}\)},
            {"\<\"Simplifying a model\"\>", \({"StructuredModelReduce"}\)},
            {"\<\"Likelihood of a structured model\"\>", \
\({"StructuredLogLikelihood", "StructuredMLE"}\)},
            {"\<\"Example data\"\>", \({}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["The full list", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"xtl", "=", 
        RowBox[{"(", GridBox[{
              {
                "\"\<Finding possible orders\>\"", \
\({"\<NumberOfPossibleCoalescences\>", "\<PossibleCoalescenceOrder\>", \
"\<RandomCoalescenceOrder\>"}\)},
              {"\"\<Ordered genealogies\>\"", \({"\<IncidenceMatrix\>"}\)},
              {"\"\<Deriving the probability\>\"", \({}\)},
              {
                "\"\<Converting between representations\>\"", \
\({"\<ListToMatrix\>", "\<MatrixToList\>", "\<MutationLabels\>"}\)},
              {
                "\"\<Inferring a genealogy\>\"", \({"\<FindNode\>", \
"\<MatrixToGenealogy\>"}\)},
              {"\"\<Describing mutation\>\"", \({"\<GenealogyToMatrix\>"}\)},
              {
                "\"\<Population bottlenecks\>\"", \({"\<DeletedMutations\>", \
"\<RandomBottleneckedGenealogy\>"}\)},
              {
                "\"\<Describing mutations\>\"", \({"\<Mutations\>", \
"\<MutationOrigin\>", "\<NumberOfMutations\>", "\<MutationInterval\>"}\)},
              {
                "\"\<Drawing a genealogy\>\"", \({"\<MutationRate\>", \
"\<RandomGenealogy\>"}\)},
              {
                "\"\<Random families\>\"", \({"\<RandomFamilies\>", \
"\<RandomPreviousFamily\>"}\)},
              {
                "\"\<Distribution of coalescence times\>\"", \
\({"\<CoalescenceDistribution\>", "\<B\>", "\<RandomCoalescenceTimes\>", \
"\<NumberOfCoalescences\>", "\<TotalLength\>"}\)},
              {
                "\"\<The set of all structures\>\"", \({"\<AllSets\>", \
"\<NewS\>"}\)},
              {
                "\"\<Probabilities\>\"", \({"\<FamilyProbability\>", \
"\<SimplifyFamilies\>"}\)},
              {"\"\<Family structure\>\"", \({}\)},
              {
                "\"\<Manipulating genealogies\>\"", \({"\<AddGenealogy\>", \
"\<AddNode\>", "\<CondenseGenealogy\>", "\<ExtractGenealogy\>", \
"\<DeleteGenealogy\>"}\)},
              {
                "\"\<Constructing genealogies\>\"", \({"\<Node\>", \
"\<ListToGenealogy\>", "\<NodeFunction\>"}\)},
              {
                "\"\<Describing genealogies\>\"", \({"\<CollapseGenealogy\>", \
"\<ExtractInformation\>", "\<NumberOfLineages\>", "\<TransformInformation\>", \
"\<Nodes\>", "\<InternalNodes\>", "\<Leaves\>"}\)},
              {
                "\"\<Ancestors and descendants\>\"", \({"\<Ancestors\>", \
"\<Descendants\>"}\)},
              {
                "\"\<Plotting genealogies\>\"", \({"\<NodeFunction\>", \
"\<PlotGenealogy\>", "\<MakeGenealogyPlot\>", "\<SizeOfGenealogyPlot\>", \
"\<NodeLabels\>", "\<LeafLabels\>", "\<NodeOffset\>", "\<LeafOffset\>"}\)},
              {
                "\"\<Structure of genealogies\>\"", \({"\<Node\>", \
"\<UnrootedGenealogy\>", "\<RootedGenealogy\>"}\)},
              {
                "\"\<Estimating the probability\>\"", \
\({"\<MonteCarloProbability\>"}\)},
              {"\"\<Griffiths-Tavare algorithm\>\"", \({}\)},
              {
                "\"\<Exact algorithm\>\"", \({"\<GriffithsTavare\>", \
"\<Example\>"}\)},
              {
                "\"\<Stochastic algorithm\>\"", \({"\<Stochastic GT algorithm\
\>", "\<MonteCarloGriffithsTavare\>", "\<Small example\>", "\<Comparison with \
MonteCarloProbability\>"}\)},
              {
                "\"\<Boxing the individuals\>\"", \({"\<Individuals\>", \
"\<Box\>", "\<DistanceSquared\>", "\<MakeDistances\>", \
"\<MakeDistanceList\>", "\<Neighbours\>", "\<NeighbourArray\>"}\)},
              {
                "\"\<Initialisation\>\"", \({"\<InitialiseContinuum\>", \
"\<FindPosition\>", "\<ExtractExtant\>"}\)},
              {
                "\"\<Global variables\>\"", \({"\<NumberOfIndividuals\>", \
"\<ExtantIndividuals\>", "\<T\>", "\<NetFecundity\>", "\<NetMortality\>", \
"\<TotalNumber\>"}\)},
              {
                "\"\<Describing individuals\>\"", \({"\<Location\>", \
"\<Density\>", "\<Fecundity\>", "\<Mortality\>", "\<BirthTime\>", \
"\<DeathTime\>", "\<Ancestry\>", "\<Offspring\>", "\<Boxes\>"}\)},
              {"\"\<Implementation\>\"", \({}\)},
              {"\"\<The model\>\"", \({}\)},
              {
                "\"\<Genes and contexts\>\"", \({"\<Basic notation\>", \
"\<Genes and contexts\>", "\<OtherSex\>", "\<Stages\>"}\)},
              {
                "\"\<Introduction to multilocus algebra\>\"", \
\({"\<S5.67.1\>", "\<1.1\>", "\<Multilocus`Multilocus`\>"}\)},
              {"\"\<Sampling genealogies\>\"", \({}\)},
              {
                "\"\<Sampling individuals\>\"", \
\({"\<SampleIndividuals\>"}\)},
              {"\"\<Making a genealogy\>\"", \({"\<MakeGenealogy\>"}\)},
              {
                "\"\<Determining ancestry\>\"", \
\({"\<MostRecentCommonAncestor\>", "\<Ancestors\>", "\<Descendants\>"}\)},
              {"\"\<Estimating the covariance\>\"", \({}\)},
              {"\"\<An example\>\"", \({}\)},
              {
                "\"\<Sampling\>\"", \({"\<InitialiseCovariance\>", \
"\<SampleCovariance\>", "\<CovarianceMidPoints\>", \
"\<SpatialCovariance\>"}\)},
              {
                "\"\<Iterating  the continuum model\>\"", \
\({"\<IterateContinuum\>", "\<Birth\>", "\<Death\>"}\)},
              {
                "\"\<Life cycle\>\"", \({"\<NotationPackage\>", "\<Stages\>", \
"\<Sex\>", "\<SexOfOrigin\>", "\<Deme\>", "\<Individual\>"}\)},
              {"\"\<Introduction to selection on diploids\>\"", \({}\)},
              {
                "\"\<Random drift: cumulants\>\"", \({"\<NotationPackage\>", \
"\<ToPopulationMoments\>", "\<ToPopulationCumulants\>"}\)},
              {"\"\<Wright-Fisher sampling\>\"", \({}\)},
              {
                "\"\<Expectations\>\"", \({"\<multiple arguments\>", \
"\<PopulationExpectation\>", "\<PopulationDisequilibrium\>"}\)},
              {
                "\"\<Introduction to random drift\>\"", \({"\<Changing \
reference points\>", "\<Cumulants and moments\>", "\<Describing a \
distribution\>", "\<Equations for the moments\>", "\<Random sampling\>"}\)},
              {
                "\"\<Slow change\>\"", \({"\<NotationPackage\>", \
"\<SlowChange\>"}\)},
              {
                "\"\<Fitness\>\"", \({"\<MakeFitnessSet\>", \
"\<MakeSelectionCoefficient\>", "\<NotationPackage\>", "\<Obsolete \
notation\>", "\<SelectionCoefficient\>", "\<Fitness\>"}\)},
              {"\"\<Phenotypes\>\"", \({"\<MakeSelectionCoefficient\>"}\)},
              {
                "\"\<Two alleles\>\"", \({"\<Biallelic\>", "\<NotationPackage\
\>"}\)},
              {
                "\"\<Multilocus cumulants\>\"", \({"\<ToCumulants\>", \
"\<ToMoments\>"}\)},
              {
                "\"\<Disequilibrium\>\"", \({"\<Disequilibrium\>", \
"\<Symmetrise\>"}\)},
              {
                "\"\<Changing contexts\>\"", \({"\<Applying transmission \
rules\>", "\<TransmissionRule\>", "\<ChangeContext\>"}\)},
              {
                "\"\<Extracting contexts\>\"", \({"\<ExtractContexts\>", \
"\<ExtractGenes\>"}\)},
              {"\"\<Selecting contexts\>\"", \({"\<SelectContexts\>"}\)},
              {
                "\"\<Abbreviating contexts\>\"", \({"\<FullContext\>", \
"\<ShortContext\>"}\)},
              {
                "\"\<Stages in the life cycle\>\"", \({"\<ContextPosition\>", \
"\<ContextComponentQ\>", "\<ContextStageQ\>", "\<DefineContext\>", \
"\<ContextStructure\>"}\)},
              {
                "\"\<Populations\>\"", \({"\<Expectation\>", \
"\<NotationPackage\>", "\<Technicalities\>", "\<MeanContribution\>", \
"\<Disequilibrium\>", "\<AlleleFrequencyP\>", "\<AlleleFrequencyPQ\>", \
"\<AlleleFrequencyQ\>"}\)},
              {
                "\"\<Allelic state\>\"", \({"\<AllelicState\>", \
"\<NotationPackage\>", "\<ReferencePoint\>", "\<AllelicDeviation\>"}\)},
              {
                "\"\<Operations on sets\>\"", \({"\<Join\>", "\<TakeAway\>", \
"\<ExactIntersection\>", "\<AddUp\>", "\<TimesUp\>"}\)},
              {
                "\"\<Defining fitnesses\>\"", \({"\<MarginalW\>", \
"\<MeanW\>"}\)},
              {
                "\"\<Describing the population\>\"", \
\({"\<InitialiseDemes\>", "\<ClineWidth\>", "\<MeanP\>", "\<MeanD\>"}\)},
              {
                "\"\<Manipulating genotypes\>\"", \({"\<ClassToGenotypes\>", \
"\<GenotypePosition\>"}\)},
              {
                "\"\<Representing the population\>\"", \({"\<DiploidPsi\>", "\
\<HaploidSource\>", "\<DiploidSource\>", "\<S5.24.1\>", "\<1.4\>", \
"\<SymmetricModel\>", "\<SortByClass\>"}\)},
              {
                "\"\<Multilocus references\>\"", \({"\<Barton 1995\>", \
"\<Barton and Turelli 1991\>", "\<Crow and Kimura 1970\>", "\<Kirkpatrick and \
Barton 1997\>", "\<Kirkpatrick and Servedio 1998\>", "\<Turelli and Barton \
1994\>"}\)},
              {"\"\<Notation package\>\"", \({}\)},
              {"\"\<Notation reference\>\"", \({"\<NotationPackage\>"}\)},
              {"\"\<A method to avoid\>\"", \({}\)},
              {"\"\<Explaining the rules\>\"", \({}\)},
              {"\"\<Cautionary notes\>\"", \({}\)},
              {
                "\"\<Sexual selection\>\"", \({"\<Complete cycle\>", \
"\<Defining fitnesses\>", "\<Random union\>", "\<Recombination\>", "\<Sexual \
selection\>", "\<subtle problem\>"}\)},
              {
                "\"\<Stabilising selection\>\"", \({"\<Change in D\>", \
"\<Change in mean\>", "\<Defining fitness\>", "\<Mean fitness\>", "\<New mean\
\>", "\<New mean fitness\>", "\<Rules\>"}\)},
              {
                "\"\<Additive selection\>\"", \({"\<Defining fitnesses\>", \
"\<Defining rules\>", "\<New D\>", "\<New mean\>", "\<Scaled D\>"}\)},
              {"\"\<Symmetric sexes\>\"", \({"\<EquivalentSexes\>"}\)},
              {"\"\<Complete life cyle\>\"", \({}\)},
              {
                "\"\<Recombination\>\"", \({"\<Context-dependent \
recombination\>", "\<Meiosis\>", "\<SymmetricRecombination\>", \
"\<Recombination\>", "\<RecombinationRate\>"}\)},
              {
                "\"\<Selection\>\"", \({"\<FitnessSet\>", \
"\<SelectionCoefficient\>"}\)},
              {"\"\<Random union\>\"", \({"\<RandomUnion\>"}\)},
              {"\"\<Union of gametes\>\"", \({"\<UnionOfGametes\>"}\)},
              {
                "\"\<Reference points\>\"", \({"\<ReferencePointMean\>", \
"\<ReferencePointSame\>", "\<ReferencePointZero\>"}\)},
              {
                "\"\<Potential problems\>\"", \({"\<Avoid integers\>", \
"\<pitfall\>", "\<Redefining fitness\>"}\)},
              {
                "\"\<Adding a neutral gene\>\"", \({"\<Barrier\>", \
"\<FixedEnds\>", "\<IterateNeutral\>", "\<StoreNeutral\>", \
"\<IterateNeutral\>", "\<Cline\>"}\)},
              {
                "\"\<Storing a cline\>\"", \({"\<SymmetricCline\>", \
"\<StoreExact\>", "\<Cline\>"}\)},
              {
                "\"\<Iterating a cline\>\"", \({"\<FixdEnds\>", \
"\<IterateExact\>", "\<Cline\>"}\)},
              {
                "\"\<Iterating one deme\>\"", \({"\<IterateExact\>", \
"\<MigrationOrder\>"}\)},
              {
                "\"\<Migration in the symmetric model\>\"", \
\({"\<FixedEnds\>", "\<MigrateExact\>"}\)},
              {
                "\"\<Reproduction in the symmetric model\>\"", \
\({"\<GameteTable\>", "\<NewGametes\>", "\<StoreResults\>", "\<Gametes\>", \
"\<HeterozygoteB\>"}\)},
              {"\"\<References for the symmetric model\>\"", \({}\)},
              {"\"\<Limitations\>\"", \({}\)},
              {
                "\"\<Fitnesses for the symmetric model\>\"", \
\({"\<FitnessTable\>", "\<MarginalW\>", "\<MarginalWTable\>", "\<MeanW\>", \
"\<MeanWTable\>"}\)},
              {
                "\"\<Describing populations\>\"", \({"\<BarrierStrength\>", "\
\<ClineGradient\>", "\<ClineWidth\>", "\<MeanP\>", "\<MeanD\>"}\)},
              {
                "\"\<Setting up a symmetric cline\>\"", \({"\<DoubleCline\>"}\
\)},
              {"\"\<Setting up a cline\>\"", \({"\<InitialiseDemes\>"}\)},
              {
                "\"\<Genotype frequencies\>\"", \({"\<DiploidPhenotype\>", \
"\<DiploidPsi\>", "\<DiploidSource\>", "\<HaploidSource\>"}\)},
              {"\"\<Recursion checks\>\"", \({"\<S5.24.1\>", "\<1.4\>"}\)},
              {
                "\"\<Example: stability\>\"", \({"\<StabilityDirect\>", \
"\<S5.24.1\>", "\<1.4\>"}\)},
              {"\"\<Example: epistasis\>\"", \({}\)},
              {
                "\"\<Iterating the recursions\>\"", \({"\<IterateExact\>", \
"\<StoreExact\>"}\)},
              {
                "\"\<Linkage\>\"", \({"\<Gametes\>", "\<GameteTable\>", \
"\<Linkage\>", "\<NetRecombination\>"}\)},
              {
                "\"\<Reproduction recursions\>\"", \({"\<Gametes\>", \
"\<GameteTable\>", "\<NewGametes\>", "\<Gametes\>", "\<SymmetricModel\>"}\)},
              {
                "\"\<Recombination in admixture models\>\"", \
\({"\<MomentAfterRecombination\>"}\)},
              {
                "\"\<Migration in admixture models\>\"", \
\({"\<MomentAfterMigration\>"}\)},
              {"\"\<Iteration\>\"", \({"\<MomentNew\>"}\)},
              {
                "\"\<Equilibria\>\"", \({"\<AdmixtureFrequency\>", \
"\<CumulantEquilibrium\>", "\<MomentEquilibrium\>"}\)},
              {"\"\<Overview\>\"", \({}\)},
              {
                "\"\<References\>\"", \({"\<Asmussen et al 1987\>", "\<Barton \
1986\>", "\<Barton 2000\>", "\<Barton & Gale 1993\>", "\<Barton & Shpak \
1999\>", "\<Barton & Turelli 1991\>", "\<Dempster et al 1977\>", "\<Edwards \
1972\>", "\<Goodman et al 1999\>", "\<Guiasu & Shenitzer 1985\>", "\<Haber \
1984\>", "\<Hill 1974a\>", "\<Hill 1974b\>", "\<Hill 1974c\>", "\<Kirkpatrick \
et al 1983\>", "\<Kruuk 1997\>", "\<Li & Nei 1974\>", "\<Long et al 1995\>", \
"\<MacCallum 1994\>", "\<MacCallum et al 1998\>", "\<Mangel & Hilborn \
1996\>", "\<Metropolis et al 1954\>", "\<Orive & Barton 1999\>", "\<Phipps & \
Brill 1995\>", "\<Slatkin & Excoffier 1996\>", "\<Turelli & Barton 1994\>", "\
\<Asmussen et al 1987\>", "\<Arnold 1996\>"}\)},
              {"\"\<Summary\>\"", \({}\)},
              {
                "\"\<Estimating the matrix of moments\>\"", \({"\<Extension \
to families\>"}\)},
              {
                "\"\<A matrix of moments\>\"", \({"\<g[X] full matrix\>", \
"\<g[X] matrix\>"}\)},
              {"\"\<Admixture models\>\"", \({}\)},
              {"\"\<Pairs of loci\>\"", \({}\)},
              {
                "\"\<Alternative methods\>\"", \({"\<Log-linear models\>", \
"\<Maximum entropy\>", "\<Naive MLE\>"}\)},
              {"\"\<Introduction to estimating D\>\"", \({}\)},
              {"\"\<Spatially varying selection\>\"", \({}\)},
              {"\"\<Faster algorithms\>\"", \({"\<StabilityKTable\>"}\)},
              {"\"\<Example: a cline\>\"", \({"\<StabilityK\>"}\)},
              {
                "\"\<Example: one deme\>\"", \({"\<ExactEigenvalues\>", \
"\<SigmaMatrix\>", "\<StabilityK\>"}\)},
              {
                "\"\<Making a stability matrix\>\"", \
\({"\<StabilityMatrix\>"}\)},
              {"\"\<Outline\>\"", \({}\)},
              {"\"\<Checks on the symmetric model\>\"", \({}\)},
              {"\"\<Sampling example\>\"", \({}\)},
              {
                "\"\<Analysing replicate samples\>\"", \({"\<DoReplicates\>"}\
\)},
              {
                "\"\<Constrained intervals\>\"", \
\({"\<ConstrainedIntervals\>"}\)},
              {"\"\<Constraints on moments\>\"", \({"\<MomentLimits\>"}\)},
              {"\"\<Random walk\>\"", \({}\)},
              {
                "\"\<Finding the MLE\>\"", \({"\<FindMLE\>", \
"\<Cumulant\>"}\)},
              {"\"\<Initial step size\>\"", \({"\<InitialStep\>"}\)},
              {
                "\"\<Estimating moments\>\"", \
\({"\<MetropolisDisequilibrium\>"}\)},
              {
                "\"\<Metropolis algorithm\>\"", \
\({"\<$MetropolisAdjustment\>"}\)},
              {
                "\"\<Likelihood\>\"", \
\({"\<LogLikelihoodDisequilibrium\>"}\)},
              {"\"\<MLE example\>\"", \({}\)},
              {
                "\"\<Internal functions\>\"", \
\({"\<AlleleFrequencyPermutations\>", "\<dAlleleFrequencyPermutations\>", \
"\<SignMask\>", "\<PloidyWeightList\>"}\)},
              {
                "\"\<Moments and cumulants\>\"", \({"\<Cumulant\>", "\<Moment\
\>"}\)},
              {
                "\"\<Estimation from families\>\"", \
\({"\<EstimateFamilyMoments\>", "\<FamilyAlleleFrequencyEstimate\>", \
"\<MToC\>", "\<MVariables\>", "\<FamilyEffects\>", "\<FamilyM\>", \
"\<MFromC\>", "\<MToCEquations\>"}\)},
              {
                "\"\<Estimating the matrix\>\"", \({"\<EstimateMoments\>", \
"\<MToC\>", "\<MVariables\>", "\<Varying divergence\>", "\<MFromC\>", \
"\<MToCEquations\>"}\)},
              {
                "\"\<Fast calculations\>\"", \
\({"\<DiploidGenotypeFrequencyList\>", "\<MatrixGamma\>"}\)},
              {
                "\"\<Full diploid genotypes\>\"", \
\({"\<GenotypeFrequencyConvert\>", "\<PositionsList\>", \
"\<PositionsMatrix\>", "\<PossibleDiploidGenotypes\>"}\)},
              {
                "\"\<Genotype frequencies from moments\>\"", \
\({"\<DiploidGenotypeFrequency\>", "\<HaploidGenotypeFrequency\>"}\)},
              {
                "\"\<Moments from genotype frequencies\>\"", \
\({"\<MomentsFromG\>"}\)},
              {"\"\<Simplifying the moments\>\"", \({"\<MomentSimple\>"}\)},
              {
                "\"\<Generating families\>\"", \({"\<Linkage\>", \
"\<NotationPackage\>", "\<RandomFamily\>", "\<SegregationRatio\>"}\)},
              {
                "\"\<Diploid genotypes\>\"", \({"\<ObservableGenotype\>", \
"\<PossibleGenotypes\>"}\)},
              {
                "\"\<Subsets of loci\>\"", \({"\<DiploidSubsets\>", \
"\<HaploidSubsets\>"}\)},
              {
                "\"\<Listing genotypes\>\"", \({"\<DiploidTypes\>", \
"\<HaploidTypes\>", "\<NotationPackage\>"}\)},
              {"\"\<Notation\>\"", \({"\<NotationPackage\>"}\)},
              {
                "\"\<Selecting subsets\>\"", \({"\<NotationPackage\>", \
"\<SelectIndividuals\>", "\<SelectLoci\>"}\)},
              {
                "\"\<Gene & genotype frequencies\>\"", \
\({"\<GenotypeFrequencyTable\>", "\<AlleleFrequencyMean\>", \
"\<AlleleFrequencyTable\>", "\<NetCovariance\>", "\<Linkage \
disequilibrium\>"}\)},
              {
                "\"\<Simplifying a dataset\>\"", \({"\<NotationPackage\>", \
"\<ReducedData\>"}\)},
              {
                "\"\<Converting a dataset\>\"", \({"\<ConvertData\>", \
"\<NotationPackage\>"}\)},
              {
                "\"\<Describing a dataset\>\"", \({"\<NotationPackage\>", \
"\<Ploidy\>", "\<NumberOfIndividualsTable\>", "\<NumberOfGenesTable\>", \
"\<NumberOfIndividuals\>", "\<NumberOfGenes\>", "\<NumberOfLoci\>"}\)},
              {
                "\"\<Defining a dataset\>\"", \({"\<NotationPackage\>", \
"\<LocusNames\>", "\<Data\>", "\<Missing data\>"}\)},
              {
                "\"\<Notation for genetic data\>\"", \
\({"\<NotationPackage\>"}\)},
              {"\"\<Obsolete functions\>\"", \({}\)},
              {"\"\<The method\>\"", \({"\<NotationPackage\>"}\)},
              {
                "\"\<Pairwise tables\>\"", \({"\<MakePairwiseTable\>", \
"\<NotationPackage\>", "\<PresentPairwiseTable\>"}\)},
              {
                "\"\<Single-locus tables\>\"", \({"\<MakeOneWayTable\>", \
"\<NotationPackage\>", "\<PresentOneWayTable\>"}\)},
              {"\"\<Pairwise example\>\"", \({}\)},
              {
                "\"\<Presenting results\>\"", \({"\<CompareLogL\>", \
"\<PlotLogL\>", "\<PresentResults\>"}\)},
              {"\"\<Setting up replicates\>\"", \({"\<DrawSamples\>"}\)},
              {
                "\"\<Options for DoReplicates\>\"", \({"\<MethodC\>", \
"\<MethodP\>"}\)},
              {
                "\"\<Multinomial distribution\>\"", \
\({"\<MultinomialSamplingProbability\>", "\<Multinomial sampling wo \
replacement\>", "\<RandomMultinomial\>"}\)},
              {
                "\"\<Sampling from arbitrary distributions\>\"", \
\({"\<RandomCum\>"}\)},
              {
                "\"\<Random lists\>\"", \({"\<Compiled\>", "\<RandomList\>", \
"\<Replace\>"}\)},
              {
                "\"\<Muddling and subdividing sets\>\"", \({"\<Muddle\>", \
"\<Subdivide\>"}\)},
              {"\"\<Random sets\>\"", \({"\<RandomSet\>"}\)},
              {"\"\<Variance components\>\"", \({"\<Table\>"}\)},
              {
                "\"\<Marginal tables\>\"", \({"\<Function\>", \
"\<MarginalTable\>"}\)},
              {
                "\"\<Extracting submatrices\>\"", \
\({"\<ExtractSubMatrix\>"}\)},
              {
                "\"\<Flattening lists at specific levels\>\"", \
\({"\<Flatten\>"}\)},
              {
                "\"\<Diagonal matrices\>\"", \({"\<UpperOffDiagonal\>", \
"\<LowerOffDiagonal\>", "\<TriDiagonalMatrix\>"}\)},
              {"\"\<Indexing\>\"", \({}\)},
              {
                "\"\<Hyperlinks\>\"", \({"\<ConvertHyperlinkToAddOnsLink\>", \
"\<FindHyperlinks\>", "\<FindIndexTag\>"}\)},
              {
                "\"\<Automatic Numbering\>\"", \({"\<Aesthetics\>", "\<f \
eqn\>", "\<Finding tags\>", "\<Notes\>", "\<psi eqn\>", "\<psi soln\>", \
"\<Saving the links\>", "\<Setting up links to a list of tags\>", \
"\<SA.8.7\>", "\<7.2\>", "\<FindTags\>", "\<NumberedLink\>"}\)},
              {
                "\"\<Special notation\>\"", \({"\<Defining notation\>", \
"\<Setting up packages\>"}\)},
              {
                "\"\<Bugs and features\>\"", \({"\<Clashes between \
packages\>", "\<Incompatibilities\>", "\<Manipulating notebooks\>", \
"\<Multilocus notation\>", "\<Obsolete EstimatingD\>", "\<Pasting \
hyperlinks\>", "\<Repeated \\\\\>", "\<Special notation\>"}\)},
              {
                "\"\<How the Help Browser works\>\"", \({"\<Absolute\>", \
"\<Accuracy\>", "\<Browser categories\>", "\<MasterIndexHeading\>", \
"\<Packages\>", "\<Setting up links\>", "\<Setting up Master Index\>"}\)},
              {
                "\"\<Setting up new help files\>\"", \({"\<Setting up new \
help files\>"}\)},
              {
                "\"\<Setting up the packages\>\"", \({"\<Setting up the \
packages\>"}\)},
              {
                "\"\<Linkage in families\>\"", \({"\<NetRecombination\>", \
"\<NotationPackage\>"}\)},
              {
                "\"\<Genotype probabilities\>\"", \
\({"\<GenotypeProbability\>", "\<Linkage\>", "\<NotationPackage\>", \
"\<ObservableGenotype\>", "\<SegregationRatio\>"}\)},
              {
                "\"\<Tagging sets\>\"", \({"\<Tag\>", "\<AddTag\>", \
"\<RemoveTag\>"}\)},
              {"\"\<Sorting\>\"", \({"\<SortByHead\>", "\<Reverse\>"}\)},
              {
                "\"\<ProductSum\>\"", \({"\<ProductSum\>", "\<ProductSum over \
sets\>"}\)},
              {"\"\<Symmetrise\>\"", \({"\<Symmetrise\>"}\)},
              {
                "\"\<Flattening lists by pattern\>\"", \({"\<FlattenList\>", \
"\<PatternFree\>"}\)},
              {
                "\"\<Set partitions\>\"", \({"\<NumberOfSamplePartitions\>", \
"\<NumberOfSetPartitions\>", "\<SamplePartition\>", "\<SetPartition\>"}\)},
              {"\"\<Subsets\>\"", \({"\<Subsets\>"}\)},
              {"\"\<Locations\>\"", \({"\<Locations\>"}\)},
              {"\"\<Join\>\"", \({"\<Join\>"}\)},
              {"\"\<ExactIntersection\>\"", \({"\<ExactIntersection\>"}\)},
              {
                "\"\<TakeAway\>\"", \({"\<SA.8.7\>", "\<7.2\>", \
"\<TakeAway\>"}\)},
              {
                "\"\<|., ||.\>\"", \({"\<ReplaceAllSpecial\>", \
"\<ReplacerepeatedSpecial\>"}\)},
              {
                "\"\<TimesUp\>\"", \({"\<Multiple products\>", "\<TimesUp\>"}\
\)},
              {
                "\"\<AddUp\>\"", \({"\<AddUp\>", "\<Multiple sums\>", \
"\<SimplifyAddUp\>", "\<SimplifyAddUpQ\>", "\<Technicalities\>"}\)},
              {
                "\"\<Repeated elements\>\"", \({"\<Repeat\>", \
"\<ExtractRepeat\>"}\)},
              {"\"\<Overview of set manipulation\>\"", \({}\)},
              {
                "\"\<Negative binomial likelihoods\>\"", \({"\<c<1\>", \
"\<Compiled\>", "\<multiplicative models\>", "\<NegativeBinomialLogLikelihood\
\>", "\<NegativeBinomialMLE\>", "\<normalisation\>", "\<Normalisation\>", \
"\<Normalised\>", "\<Timings\>"}\)},
              {
                "\"\<Gaussian likelihoods\>\"", \({"\<additive models\>", \
"\<GaussianLogLikelihood\>", "\<GaussianMLE\>", "\<additive models\>", \
"\<FullOutput\>"}\)},
              {"\"\<Likelihood tests\>\"", \({"\<LogLikelihoodTest\>"}\)},
              {
                "\"\<Negative hypergeometric distribution\>\"", \
\({"\<NegativeHypergeometricDistribution\>"}\)},
              {
                "\"\<Manipulating options\>\"", \({"\<DropOptions\>", \
"\<TakeOptions\>"}\)},
              {"\"\<DivideZero\>\"", \({"\<DivideZero\>"}\)},
              {
                "\"\<Fourier transforms\>\"", \
\({"\<FourierNormalisedTable\>", "\<InverseFourierNormalisedTable\>", \
"\<FourierNormalised\>", "\<InverseFourierNormalised\>", \
"\<TransformedRange\>"}\)},
              {
                "\"\<Cumulants\>\"", \({"\<GeneralizedTransform\>", "\<SA.8.7\
\>", "\<7.2\>", "\<Distribution\>", "\<SA.8.7\>", "\<7.2\>", "\<Cumulant\>", \
"\<Moment\>"}\)},
              {
                "\"\<Useful functions\>\"", \({"\<StructuredArray\>", \
"\<StructuredModel\>"}\)},
              {
                "\"\<Structured parameters\>\"", \
\({"\<StructuredParameter\>"}\)},
              {
                "\"\<Variance components for a structured model\>\"", \
\({"\<StructuredVariance\>", "\<VarianceComponents\>"}\)},
              {"\"\<Hierarchical analysis\>\"", \({}\)},
              {
                "\"\<Options for StructuredMLE\>\"", \({"\<ErrorBound\>", \
"\<StartingStepSize\>", "\<StructuredMLE\>", "\<PrintDetails\>"}\)},
              {
                "\"\<Initial parameters\>\"", \
\({"\<StructuredInitialParameters\>"}\)},
              {"\"\<Degrees of freedom\>\"", \({"\<DegreesOfFreedom\>"}\)},
              {
                "\"\<Simplifying a model\>\"", \
\({"\<StructuredModelReduce\>"}\)},
              {
                "\"\<Likelihood of a structured model\>\"", \
\({"\<StructuredLogLikelihood\>", "\<StructuredMLE\>"}\)},
              {"\"\<Example data\>\"", \({}\)}
              }], ")"}]}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Editing the list", "Subsubsection"],

Cell[BoxData[
    \(\(ytl = 
        Sort[Flatten[\(xtl /. {it_String, {}} \[Rule] {{None, it, 
                      None}}\) /. {it_String, 
                  cct_List} :> \((\({#, it, #} &\) /@ cct)\), 
            1]];\)\)], "Input"],

Cell[BoxData[
    \(ytl // MatrixForm\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ztl", "=", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"\"\<Multilocus algebra, introduction to\>\"", 
                  "\"\<Introduction to multilocus algebra\>\"", 
                  "\"\<1.1\>\""},
                {"\"\<Deterministic recursions, stability, example of\>\"", 
                  "\"\<Example: stability\>\"", "\"\<1.4\>\""},
                {"\"\<Deterministic recursions, checks\>\"", 
                  "\"\<Recursion checks\>\"", "\"\<1.4\>\""},
                {
                  "\"\<Deterministic recursions, describing the \
population\>\"", "\"\<Representing the population\>\"", "\"\<1.4\>\""},
                {"\"\<Numbering, automatic\>\"", 
                  "\"\<Automatic Numbering\>\"", "\"\<7.2\>\""},
                {"\"\<Cumulants\>\"", "\"\<Cumulants\>\"", "\"\<7.2\>\""},
                {"\"\<Moments\>\"", "\"\<Cumulants\>\"", "\"\<7.2\>\""},
                {"\"\<TakeAway\>\"", "\"\<TakeAway\>\"", "\"\<7.2\>\""},
                {"\"\<AddGenealogy\>\"", "\"\<Manipulating genealogies\>\"", 
                  "\"\<AddGenealogy\>\""},
                {"\"\<Additive models\>\"", "\"\<Gaussian likelihoods\>\"", 
                  "\"\<additive models\>\""},
                {"\"\<AddNode\>\"", "\"\<Manipulating genealogies\>\"", 
                  "\"\<AddNode\>\""},
                {"\"\<AddTag\>\"", "\"\<Tagging sets\>\"", "\"\<AddTag\>\""},
                {"\"\<AddUp\>\"", "\"\<AddUp\>\"", "\"\<AddUp\>\""},
                {"\"\<AddUp\>\"", "\"\<Operations on sets\>\"", 
                  "\"\<AddUp\>\""},
                {"\"\<AdmixtureFrequency\>\"", "\"\<Equilibria\>\"", 
                  "\"\<AdmixtureFrequency\>\""},
                {"\"\<Numbering, aesthetics\>\"", 
                  "\"\<Automatic Numbering\>\"", "\"\<Aesthetics\>\""},
                {"\"\<AlleleFrequencyMean\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<AlleleFrequencyMean\>\""},
                {"\"\<AlleleFrequencyP\>\"", "\"\<Populations\>\"", 
                  "\"\<AlleleFrequencyP\>\""},
                {"\"\<AlleleFrequencyPermutations\>\"", 
                  "\"\<Internal functions\>\"", 
                  "\"\<AlleleFrequencyPermutations\>\""},
                {"\"\<AlleleFrequencyPQ\>\"", "\"\<Populations\>\"", 
                  "\"\<AlleleFrequencyPQ\>\""},
                {"\"\<AlleleFrequencyQ\>\"", "\"\<Populations\>\"", 
                  "\"\<AlleleFrequencyQ\>\""},
                {"\"\<AlleleFrequencyTable\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<AlleleFrequencyTable\>\""},
                {"\"\<AllelicDeviation\>\"", "\"\<Allelic state\>\"", 
                  "\"\<AllelicDeviation\>\""},
                {"\"\<AllelicState\>\"", "\"\<Allelic state\>\"", 
                  "\"\<AllelicState\>\""},
                {"\"\<AllSets\>\"", "\"\<The set of all structures\>\"", 
                  "\"\<AllSets\>\""},
                {"\"\<Ancestors, determining\>\"", 
                  "\"\<Determining ancestry\>\"", "\"\<Ancestors\>\""},
                {"\"\<Ancestry\>\"", "\"\<Describing individuals\>\"", 
                  "\"\<Ancestry\>\""},
                {"\"\<Transmission rules, applying\>\"", 
                  "\"\<Changing contexts\>\"", 
                  "\"\<Applying transmission rules\>\""},
                {"\"\<Arnold 1996\>\"", "\"\<References\>\"", 
                  "\"\<Arnold 1996\>\""},
                {"\"\<Asmussen et al. 1987\>\"", "\"\<References\>\"", 
                  "\"\<Asmussen et al 1987\>\""},
                {"\"\<Asmussen et al. 1987\>\"", "\"\<References\>\"", 
                  "\"\<Asmussen et al 1987\>\""},
                {"\"\<Problems, avoid integers\>\"", 
                  "\"\<Potential problems\>\"", "\"\<Avoid integers\>\""},
                {"\"\<B\>\"", "\"\<Distribution of coalescence times\>\"", 
                  "\"\<B\>\""},
                {"\"\<Barrier\>\"", "\"\<Adding a neutral gene\>\"", 
                  "\"\<Barrier\>\""},
                {"\"\<BarrierStrength\>\"", "\"\<Describing populations\>\"", 
                  "\"\<BarrierStrength\>\""},
                {"\"\<Barton 1986\>\"", "\"\<References\>\"", 
                  "\"\<Barton 1986\>\""},
                {"\"\<Barton 1995\>\"", "\"\<Multilocus references\>\"", 
                  "\"\<Barton 1995\>\""},
                {"\"\<Barton 2000\>\"", "\"\<References\>\"", 
                  "\"\<Barton 2000\>\""},
                {"\"\<Barton and Turelli 1991\>\"", 
                  "\"\<Multilocus references\>\"", 
                  "\"\<Barton and Turelli 1991\>\""},
                {"\"\<Barton & Gale 1993\>\"", "\"\<References\>\"", 
                  "\"\<Barton & Gale 1993\>\""},
                {"\"\<Barton & Shpak 1999\>\"", "\"\<References\>\"", 
                  "\"\<Barton & Shpak 1999\>\""},
                {"\"\<Barton & Turelli 1991\>\"", "\"\<References\>\"", 
                  "\"\<Barton & Turelli 1991\>\""},
                {"\"\<Multilocus algebra, basic notation\>\"", 
                  "\"\<Genes and contexts\>\"", "\"\<Basic notation\>\""},
                {"\"\<Biallelic\>\"", "\"\<Two alleles\>\"", 
                  "\"\<Biallelic\>\""},
                {"\"\<Birth\>\"", "\"\<Iterating  the continuum model\>\"", 
                  "\"\<Birth\>\""},
                {"\"\<BirthTime\>\"", "\"\<Describing individuals\>\"", 
                  "\"\<BirthTime\>\""},
                {"\"\<Box\>\"", "\"\<Boxing the individuals\>\"", 
                  "\"\<Box\>\""},
                {"\"\<Boxes\>\"", "\"\<Describing individuals\>\"", 
                  "\"\<Boxes\>\""},
                {"\"\<Browser categories\>\"", 
                  "\"\<How the Help Browser works\>\"", 
                  "\"\<Browser categories\>\""},
                {"\"\<Negative binomial, c<1\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", "\"\<c<1\>\""},
                {"\"\<ChangeContext\>\"", "\"\<Changing contexts\>\"", 
                  "\"\<ChangeContext\>\""},
                {"\"\<Stabilising selection, change in D\>\"", 
                  "\"\<Stabilising selection\>\"", "\"\<Change in D\>\""},
                {"\"\<Stabilising selection, change in mean\>\"", 
                  "\"\<Stabilising selection\>\"", "\"\<Change in mean\>\""},
                {"\"\<Random drift, changing reference points\>\"", 
                  "\"\<Introduction to random drift\>\"", 
                  "\"\<Changing reference points\>\""},
                {"\"\<Bugs, clashes between packages\>\"", 
                  "\"\<Bugs and features\>\"", 
                  "\"\<Clashes between packages\>\""},
                {"\"\<ClassToGenotypes\>\"", 
                  "\"\<Manipulating genotypes\>\"", 
                  "\"\<ClassToGenotypes\>\""},
                {"\"\<Cline, with neutral gene\>\"", 
                  "\"\<Adding a neutral gene\>\"", "\"\<Cline\>\""},
                {"\"\<Cline, iterating\>\"", "\"\<Iterating a cline\>\"", 
                  "\"\<Cline\>\""},
                {"\"\<Cline, storing\>\"", "\"\<Storing a cline\>\"", 
                  "\"\<Cline\>\""},
                {"\"\<ClineGradient\>\"", "\"\<Describing populations\>\"", 
                  "\"\<ClineGradient\>\""},
                {"\"\<ClineWidth\>\"", "\"\<Describing populations\>\"", 
                  "\"\<ClineWidth\>\""},
                {"\"\<ClineWidth\>\"", "\"\<Describing the population\>\"", 
                  "\"\<ClineWidth\>\""},
                {"\"\<Symmetric model, cline width\>\"", 
                  "\"\<Describing populations\>\"", "\"\<ClineWidth\>\""},
                {"\"\<Deterministic recursions, cline width\>\"", 
                  "\"\<Describing the population\>\"", "\"\<ClineWidth\>\""},
                {"\"\<CoalescenceDistribution\>\"", 
                  "\"\<Distribution of coalescence times\>\"", 
                  "\"\<CoalescenceDistribution\>\""},
                {"\"\<CollapseGenealogy\>\"", 
                  "\"\<Describing genealogies\>\"", 
                  "\"\<CollapseGenealogy\>\""},
                {"\"\<CompareLogL\>\"", "\"\<Presenting results\>\"", 
                  "\"\<CompareLogL\>\""},
                {
                  "\"\<Griffiths-Tavare, stochastic, comparison with \
MonteCarloProbability\>\"", "\"\<Stochastic algorithm\>\"", 
                  "\"\<Comparison with MonteCarloProbability\>\""},
                {"\"\<Negative binomial, compiled\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", 
                  "\"\<Compiled\>\""},
                {"\"\<Random lists, compiled\>\"", "\"\<Random lists\>\"", 
                  "\"\<Compiled\>\""},
                {"\"\<Sexual selection, complete life cycle\>\"", 
                  "\"\<Sexual selection\>\"", "\"\<Complete cycle\>\""},
                {"\"\<CondenseGenealogy\>\"", 
                  "\"\<Manipulating genealogies\>\"", 
                  "\"\<CondenseGenealogy\>\""},
                {"\"\<ConstrainedIntervals\>\"", 
                  "\"\<Constrained intervals\>\"", 
                  "\"\<ConstrainedIntervals\>\""},
                {"\"\<ContextComponentQ\>\"", 
                  "\"\<Stages in the life cycle\>\"", 
                  "\"\<ContextComponentQ\>\""},
                {"\"\<Recombination, context-dependent\>\"", 
                  "\"\<Recombination\>\"", 
                  "\"\<Context-dependent recombination\>\""},
                {"\"\<ContextPosition\>\"", 
                  "\"\<Stages in the life cycle\>\"", 
                  "\"\<ContextPosition\>\""},
                {"\"\<ContextStageQ\>\"", "\"\<Stages in the life cycle\>\"", 
                  "\"\<ContextStageQ\>\""},
                {"\"\<ContextStructure\>\"", 
                  "\"\<Stages in the life cycle\>\"", 
                  "\"\<ContextStructure\>\""},
                {"\"\<ConvertData\>\"", "\"\<Converting a dataset\>\"", 
                  "\"\<ConvertData\>\""},
                {"\"\<ConvertHyperlinkToAddOnsLink\>\"", 
                  "\"\<Hyperlinks\>\"", 
                  "\"\<ConvertHyperlinkToAddOnsLink\>\""},
                {"\"\<CovarianceMidPoints\>\"", "\"\<Sampling\>\"", 
                  "\"\<CovarianceMidPoints\>\""},
                {"\"\<Crow and Kimura 1970\>\"", 
                  "\"\<Multilocus references\>\"", 
                  "\"\<Crow and Kimura 1970\>\""},
                {"\"\<Cumulants\>\"", "\"\<Cumulants\>\"", 
                  "\"\<Cumulant\>\""},
                {"\"\<Estimating D, MLE, cumulants\>\"", 
                  "\"\<Finding the MLE\>\"", "\"\<Cumulant\>\""},
                {"\"\<Cumulant\>\"", "\"\<Moments and cumulants\>\"", 
                  "\"\<Cumulant\>\""},
                {"\"\<CumulantEquilibrium\>\"", "\"\<Equilibria\>\"", 
                  "\"\<CumulantEquilibrium\>\""},
                {"\"\<Random drift, cumulants and moments\>\"", 
                  "\"\<Introduction to random drift\>\"", 
                  "\"\<Cumulants and moments\>\""},
                {"\"\<dAlleleFrequencyPermutations\>\"", 
                  "\"\<Internal functions\>\"", 
                  "\"\<dAlleleFrequencyPermutations\>\""},
                {"\"\<Datasets, defining\>\"", "\"\<Defining a dataset\>\"", 
                  "\"\<Data\>\""},
                {"\"\<Data\>\"", "\"\<Defining a dataset\>\"", 
                  "\"\<Data\>\""},
                {"\"\<Death\>\"", "\"\<Iterating  the continuum model\>\"", 
                  "\"\<Death\>\""},
                {"\"\<DeathTime\>\"", "\"\<Describing individuals\>\"", 
                  "\"\<DeathTime\>\""},
                {"\"\<DefineContext\>\"", "\"\<Stages in the life cycle\>\"", 
                  "\"\<DefineContext\>\""},
                {"\"\<Stabilising selection, defining fitness\>\"", 
                  "\"\<Stabilising selection\>\"", 
                  "\"\<Defining fitness\>\""},
                {"\"\<Additive selection, defining fitnesses\>\"", 
                  "\"\<Additive selection\>\"", 
                  "\"\<Defining fitnesses\>\""},
                {"\"\<Sexual selection, defining fitnesses\>\"", 
                  "\"\<Sexual selection\>\"", "\"\<Defining fitnesses\>\""},
                {"\"\<Special notation\>\"", "\"\<Special notation\>\"", 
                  "\"\<Defining notation\>\""},
                {"\"\<Additive selection, defining rules\>\"", 
                  "\"\<Additive selection\>\"", "\"\<Defining rules\>\""},
                {"\"\<DegreesOfFreedom\>\"", "\"\<Degrees of freedom\>\"", 
                  "\"\<DegreesOfFreedom\>\""},
                {"\"\<Random genealogies, population bottlenecks\>\"", 
                  "\"\<Population bottlenecks\>\"", "None"},
                {"\"\<DeletedMutations\>\"", 
                  "\"\<Population bottlenecks\>\"", 
                  "\"\<DeletedMutations\>\""},
                {"\"\<DeleteGenealogy\>\"", 
                  "\"\<Manipulating genealogies\>\"", 
                  "\"\<DeleteGenealogy\>\""},
                {"\"\<Deme\>\"", "\"\<Life cycle\>\"", "\"\<Deme\>\""},
                {"\"\<Dempster et al 1977\>\"", "\"\<References\>\"", 
                  "\"\<Dempster et al 1977\>\""},
                {"\"\<Density\>\"", "\"\<Describing individuals\>\"", 
                  "\"\<Density\>\""},
                {"\"\<Descendants\>\"", "\"\<Ancestors and descendants\>\"", 
                  "\"\<Descendants\>\""},
                {"\"\<Descendants, determining\>\"", 
                  "\"\<Determining ancestry\>\"", "\"\<Descendants\>\""},
                {"\"\<Random drift, describing a distribution\>\"", 
                  "\"\<Introduction to random drift\>\"", 
                  "\"\<Describing a distribution\>\""},
                {"\"\<DiploidGenotypeFrequency\>\"", 
                  "\"\<Genotype frequencies from moments\>\"", 
                  "\"\<DiploidGenotypeFrequency\>\""},
                {"\"\<DiploidGenotypeFrequencyList\>\"", 
                  "\"\<Fast calculations\>\"", 
                  "\"\<DiploidGenotypeFrequencyList\>\""},
                {"\"\<DiploidPhenotype\>\"", "\"\<Genotype frequencies\>\"", 
                  "\"\<DiploidPhenotype\>\""},
                {"\"\<DiploidPsi\>\"", "\"\<Genotype frequencies\>\"", 
                  "\"\<DiploidPsi\>\""},
                {"\"\<DiploidPsi\>\"", "\"\<Representing the population\>\"", 
                  "\"\<DiploidPsi\>\""},
                {"\"\<DiploidSource\>\"", "\"\<Genotype frequencies\>\"", 
                  "\"\<DiploidSource\>\""},
                {"\"\<DiploidSource\>\"", 
                  "\"\<Representing the population\>\"", 
                  "\"\<DiploidSource\>\""},
                {"\"\<DiploidSubsets\>\"", "\"\<Subsets of loci\>\"", 
                  "\"\<DiploidSubsets\>\""},
                {"\"\<DiploidTypes\>\"", "\"\<Listing genotypes\>\"", 
                  "\"\<DiploidTypes\>\""},
                {"\"\<Disequilibrium\>\"", "\"\<Disequilibrium\>\"", 
                  "\"\<Disequilibrium\>\""},
                {"\"\<Disequilibrium\>\"", "\"\<Populations\>\"", 
                  "\"\<Disequilibrium\>\""},
                {"\"\<DistanceSquared\>\"", "\"\<Boxing the individuals\>\"", 
                  "\"\<DistanceSquared\>\""},
                {"\"\<Distribution\>\"", "\"\<Cumulants\>\"", 
                  "\"\<Distribution\>\""},
                {"\"\<DivideZero\>\"", "\"\<DivideZero\>\"", 
                  "\"\<DivideZero\>\""},
                {"\"\<DoReplicates\>\"", 
                  "\"\<Analysing replicate samples\>\"", 
                  "\"\<DoReplicates\>\""},
                {"\"\<DoubleCline\>\"", 
                  "\"\<Setting up a symmetric cline\>\"", 
                  "\"\<DoubleCline\>\""},
                {"\"\<DrawSamples\>\"", "\"\<Setting up replicates\>\"", 
                  "\"\<DrawSamples\>\""},
                {"\"\<DropOptions\>\"", "\"\<Manipulating options\>\"", 
                  "\"\<DropOptions\>\""},
                {"\"\<Edwards 1972\>\"", "\"\<References\>\"", 
                  "\"\<Edwards 1972\>\""},
                {"\"\<Random drift, equations for the moments\>\"", 
                  "\"\<Introduction to random drift\>\"", 
                  "\"\<Equations for the moments\>\""},
                {"\"\<EquivalentSexes\>\"", "\"\<Symmetric sexes\>\"", 
                  "\"\<EquivalentSexes\>\""},
                {"\"\<ErrorBound\>\"", "\"\<Options for StructuredMLE\>\"", 
                  "\"\<ErrorBound\>\""},
                {"\"\<EstimateFamilyMoments\>\"", 
                  "\"\<Estimation from families\>\"", 
                  "\"\<EstimateFamilyMoments\>\""},
                {"\"\<EstimateMoments\>\"", "\"\<Estimating the matrix\>\"", 
                  "\"\<EstimateMoments\>\""},
                {"\"\<ExactEigenvalues\>\"", "\"\<Example: one deme\>\"", 
                  "\"\<ExactEigenvalues\>\""},
                {"\"\<ExactIntersection\>\"", "\"\<ExactIntersection\>\"", 
                  "\"\<ExactIntersection\>\""},
                {"\"\<ExactIntersection\>\"", "\"\<Operations on sets\>\"", 
                  "\"\<ExactIntersection\>\""},
                {"\"\<Deterministic recursions, epistasis, example of\>\"", 
                  "\"\<Exact algorithm\>\"", "\"\<Example\>\""},
                {"\"\<Expectation\>\"", "\"\<Populations\>\"", 
                  "\"\<Expectation\>\""},
                {"\"\<ExtantIndividuals\>\"", "\"\<Global variables\>\"", 
                  "\"\<ExtantIndividuals\>\""},
                {"\"\<Estimating D, moments, families\>\"", 
                  "\"\<Estimating the matrix of moments\>\"", 
                  "\"\<Extension to families\>\""},
                {"\"\<ExtractContexts\>\"", "\"\<Extracting contexts\>\"", 
                  "\"\<ExtractContexts\>\""},
                {"\"\<ExtractExtant\>\"", "\"\<Initialisation\>\"", 
                  "\"\<ExtractExtant\>\""},
                {"\"\<ExtractGenealogy\>\"", 
                  "\"\<Manipulating genealogies\>\"", 
                  "\"\<ExtractGenealogy\>\""},
                {"\"\<ExtractGenes\>\"", "\"\<Extracting contexts\>\"", 
                  "\"\<ExtractGenes\>\""},
                {"\"\<ExtractInformation\>\"", 
                  "\"\<Describing genealogies\>\"", 
                  "\"\<ExtractInformation\>\""},
                {"\"\<ExtractRepeat\>\"", "\"\<Repeated elements\>\"", 
                  "\"\<ExtractRepeat\>\""},
                {"\"\<ExtractSubMatrix\>\"", 
                  "\"\<Extracting submatrices\>\"", 
                  "\"\<ExtractSubMatrix\>\""},
                {"\"\<FamilyAlleleFrequencyEstimate\>\"", 
                  "\"\<Estimation from families\>\"", 
                  "\"\<FamilyAlleleFrequencyEstimate\>\""},
                {"\"\<FamilyEffects\>\"", "\"\<Estimation from families\>\"", 
                  "\"\<FamilyEffects\>\""},
                {"\"\<FamilyM\>\"", "\"\<Estimation from families\>\"", 
                  "\"\<FamilyM\>\""},
                {"\"\<FamilyProbability\>\"", "\"\<Probabilities\>\"", 
                  "\"\<FamilyProbability\>\""},
                {"\"\<Fecundity\>\"", "\"\<Describing individuals\>\"", 
                  "\"\<Fecundity\>\""},
                {"\"\<FindHyperlinks\>\"", "\"\<Hyperlinks\>\"", 
                  "\"\<FindHyperlinks\>\""},
                {"\"\<FindIndexTag\>\"", "\"\<Hyperlinks\>\"", 
                  "\"\<FindIndexTag\>\""},
                {"\"\<Tags, finding\>\"", "\"\<Automatic Numbering\>\"", 
                  "\"\<Finding tags\>\""},
                {"\"\<FindMLE\>\"", "\"\<Finding the MLE\>\"", 
                  "\"\<FindMLE\>\""},
                {"\"\<FindNode\>\"", "\"\<Inferring a genealogy\>\"", 
                  "\"\<FindNode\>\""},
                {"\"\<FindPosition\>\"", "\"\<Initialisation\>\"", 
                  "\"\<FindPosition\>\""},
                {"\"\<FindTags\>\"", "\"\<Automatic Numbering\>\"", 
                  "\"\<FindTags\>\""},
                {"\"\<Multilocus algebra, fitness\>\"", "\"\<Fitness\>\"", 
                  "\"\<Fitness\>\""},
                {"\"\<FitnessSet\>\"", "\"\<Selection\>\"", 
                  "\"\<FitnessSet\>\""},
                {"\"\<FitnessTable\>\"", 
                  "\"\<Fitnesses for the symmetric model\>\"", 
                  "\"\<FitnessTable\>\""},
                {"\"\<FixdEnds\>\"", "\"\<Iterating a cline\>\"", 
                  "\"\<FixdEnds\>\""},
                {"\"\<FixedEnds\>\"", "\"\<Adding a neutral gene\>\"", 
                  "\"\<FixedEnds\>\""},
                {"\"\<FixedEnds\>\"", 
                  "\"\<Migration in the symmetric model\>\"", 
                  "\"\<FixedEnds\>\""},
                {"\"\<Flatten\>\"", 
                  "\"\<Flattening lists at specific levels\>\"", 
                  "\"\<Flatten\>\""},
                {"\"\<FlattenList\>\"", 
                  "\"\<Flattening lists by pattern\>\"", 
                  "\"\<FlattenList\>\""},
                {"\"\<FourierNormalised\>\"", "\"\<Fourier transforms\>\"", 
                  "\"\<FourierNormalised\>\""},
                {"\"\<FourierNormalisedTable\>\"", 
                  "\"\<Fourier transforms\>\"", 
                  "\"\<FourierNormalisedTable\>\""},
                {"\"\<FullContext\>\"", "\"\<Abbreviating contexts\>\"", 
                  "\"\<FullContext\>\""},
                {"\"\<FullOutput\>\"", "\"\<Gaussian likelihoods\>\"", 
                  "\"\<FullOutput\>\""},
                {"\"\<Function\>\"", "\"\<Marginal tables\>\"", 
                  "\"\<Function\>\""},
                {"\"\<Gametes, linkage\>\"", "\"\<Linkage\>\"", 
                  "\"\<Gametes\>\""},
                {"\"\<Gametes\>\"", 
                  "\"\<Reproduction in the symmetric model\>\"", 
                  "\"\<Gametes\>\""},
                {"\"\<Gametes\>\"", "\"\<Reproduction recursions\>\"", 
                  "\"\<Gametes\>\""},
                {"\"\<GameteTable, linkage\>\"", "\"\<Linkage\>\"", 
                  "\"\<GameteTable\>\""},
                {"\"\<GameteTable\>\"", 
                  "\"\<Reproduction in the symmetric model\>\"", 
                  "\"\<GameteTable\>\""},
                {"\"\<GameteTable\>\"", "\"\<Reproduction recursions\>\"", 
                  "\"\<GameteTable\>\""},
                {"\"\<GaussianLogLikelihood\>\"", 
                  "\"\<Gaussian likelihoods\>\"", 
                  "\"\<GaussianLogLikelihood\>\""},
                {"\"\<GaussianMLE\>\"", "\"\<Gaussian likelihoods\>\"", 
                  "\"\<GaussianMLE\>\""},
                {"\"\<GenealogyToMatrix\>\"", "\"\<Describing mutation\>\"", 
                  "\"\<GenealogyToMatrix\>\""},
                {"\"\<GeneralizedTransform\>\"", "\"\<Cumulants\>\"", 
                  "\"\<GeneralizedTransform\>\""},
                {"\"\<Genes and contexts\>\"", "\"\<Genes and contexts\>\"", 
                  "\"\<Genes and contexts\>\""},
                {"\"\<GenotypeFrequencyConvert\>\"", 
                  "\"\<Full diploid genotypes\>\"", 
                  "\"\<GenotypeFrequencyConvert\>\""},
                {"\"\<GenotypeFrequencyTable\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<GenotypeFrequencyTable\>\""},
                {"\"\<GenotypePosition\>\"", 
                  "\"\<Manipulating genotypes\>\"", 
                  "\"\<GenotypePosition\>\""},
                {"\"\<GenotypeProbability\>\"", 
                  "\"\<Genotype probabilities\>\"", 
                  "\"\<GenotypeProbability\>\""},
                {"\"\<Goodman et al 1999\>\"", "\"\<References\>\"", 
                  "\"\<Goodman et al 1999\>\""},
                {"\"\<Griffiths-Tavare\>\"", "\"\<Exact algorithm\>\"", 
                  "\"\<GriffithsTavare\>\""},
                {"\"\<Guiasu & Shenitzer 1985\>\"", "\"\<References\>\"", 
                  "\"\<Guiasu & Shenitzer 1985\>\""},
                {"\"\<Moments, matrix of\>\"", "\"\<A matrix of moments\>\"", 
                  "\"\<g[X] full matrix\>\""},
                {"\"\<Moments, full description by\>\"", 
                  "\"\<A matrix of moments\>\"", "\"\<g[X] matrix\>\""},
                {"\"\<Moments, reduced description by\>\"", 
                  "\"\<A matrix of moments\>\"", "\"\<g[X] matrix\>\""},
                {"\"\<Moments, extension to description by\>\"", 
                  "\"\<References\>\"", "\"\<Haber 1984\>\""},
                {"\"\<Moments, estimating the matrix of\>\"", 
                  "\"\<Estimating the matrix of moments\>\"", 
                  "\"\<Estimating the matrix\>\""},
                {"\"\<Moments, simple method for estimating\>\"", 
                  "\"\<Estimating the matrix of moments\>\"", 
                  "\"\<extension to families\>\""},
                {"\"\<Moments,ML estimation of\>\"", 
                  "\"\<Estimating the matrix of moments\>\"", 
                  "\"\<simple method\>\""},
                {"\"\<Moments, extension to estimation of\>\"", 
                  "\"\<Estimating the matrix of moments\>\"", "\"\<MLE\>\""},
                {"\"\<HaploidGenotypeFrequency\>\"", 
                  "\"\<Genotype frequencies from moments\>\"", 
                  "\"\<HaploidGenotypeFrequency\>\""},
                {"\"\<HaploidSource\>\"", "\"\<Genotype frequencies\>\"", 
                  "\"\<HaploidSource\>\""},
                {"\"\<HaploidSource\>\"", 
                  "\"\<Representing the population\>\"", 
                  "\"\<HaploidSource\>\""},
                {"\"\<HaploidSubsets\>\"", "\"\<Subsets of loci\>\"", 
                  "\"\<HaploidSubsets\>\""},
                {"\"\<HaploidTypes\>\"", "\"\<Listing genotypes\>\"", 
                  "\"\<HaploidTypes\>\""},
                {"\"\<HeterozygoteB\>\"", 
                  "\"\<Reproduction in the symmetric model\>\"", 
                  "\"\<HeterozygoteB\>\""},
                {"\"\<Hill 1974a\>\"", "\"\<References\>\"", 
                  "\"\<Hill 1974a\>\""},
                {"\"\<Hill 1974b\>\"", "\"\<References\>\"", 
                  "\"\<Hill 1974b\>\""},
                {"\"\<Hill 1974c\>\"", "\"\<References\>\"", 
                  "\"\<Hill 1974c\>\""},
                {"\"\<IncidenceMatrix\>\"", "\"\<Ordered genealogies\>\"", 
                  "\"\<IncidenceMatrix\>\""},
                {"\"\<Bugs, incompatibilities\>\"", 
                  "\"\<Bugs and features\>\"", "\"\<Incompatibilities\>\""},
                {"\"\<Life cycle\>\"", "\"\<Life cycle\>\"", "None"},
                {"\"\<Selection on diploids, life cycle\>\"", 
                  "\"\<Life cycle\>\"", "None"},
                {"\"\<Individual\>\"", "\"\<Life cycle\>\"", 
                  "\"\<Individual\>\""},
                {"\"\<Individuals\>\"", "\"\<Boxing the individuals\>\"", 
                  "\"\<Individuals\>\""},
                {"\"\<InitialiseContinuum\>\"", "\"\<Initialisation\>\"", 
                  "\"\<InitialiseContinuum\>\""},
                {"\"\<InitialiseCovariance\>\"", "\"\<Sampling\>\"", 
                  "\"\<InitialiseCovariance\>\""},
                {"\"\<Symmetric model, cline, setting up\>\"", 
                  "\"\<Setting up a cline\>\"", "None"},
                {"\"\<InitialiseDemes\>\"", 
                  "\"\<Describing the population\>\"", 
                  "\"\<InitialiseDemes\>\""},
                {"\"\<InitialiseDemes\>\"", "\"\<Setting up a cline\>\"", 
                  "\"\<InitialiseDemes\>\""},
                {"\"\<InitialStep\>\"", "\"\<Initial step size\>\"", 
                  "\"\<InitialStep\>\""},
                {"\"\<InternalNodes\>\"", "\"\<Describing genealogies\>\"", 
                  "\"\<InternalNodes\>\""},
                {"\"\<InverseFourierNormalised\>\"", 
                  "\"\<Fourier transforms\>\"", 
                  "\"\<InverseFourierNormalised\>\""},
                {"\"\<InverseFourierNormalisedTable\>\"", 
                  "\"\<Fourier transforms\>\"", 
                  "\"\<InverseFourierNormalisedTable\>\""},
                {"\"\<IterateContinuum\>\"", 
                  "\"\<Iterating  the continuum model\>\"", 
                  "\"\<IterateContinuum\>\""},
                {"\"\<IterateExact\>\"", "\"\<Iterating a cline\>\"", 
                  "\"\<IterateExact\>\""},
                {"\"\<IterateExact\>\"", "\"\<Iterating one deme\>\"", 
                  "\"\<IterateExact\>\""},
                {"\"\<IterateExact\>\"", "\"\<Iterating the recursions\>\"", 
                  "\"\<IterateExact\>\""},
                {"\"\<IterateNeutral\>\"", "\"\<Adding a neutral gene\>\"", 
                  "\"\<IterateNeutral\>\""},
                {"\"\<IterateNeutral\>\"", "\"\<Adding a neutral gene\>\"", 
                  "\"\<IterateNeutral\>\""},
                {"\"\<Join\>\"", "\"\<Join\>\"", "\"\<Join\>\""},
                {"\"\<Join\>\"", "\"\<Operations on sets\>\"", 
                  "\"\<Join\>\""},
                {"\"\<Kirkpatrick and Barton 1997\>\"", 
                  "\"\<Multilocus references\>\"", 
                  "\"\<Kirkpatrick and Barton 1997\>\""},
                {"\"\<Kirkpatrick and Servedio 1998\>\"", 
                  "\"\<Multilocus references\>\"", 
                  "\"\<Kirkpatrick and Servedio 1998\>\""},
                {"\"\<Kirkpatrick et al. 1983\>\"", "\"\<References\>\"", 
                  "\"\<Kirkpatrick et al 1983\>\""},
                {"\"\<Kruuk 1997\>\"", "\"\<References\>\"", 
                  "\"\<Kruuk 1997\>\""},
                {"\"\<LeafLabels\>\"", "\"\<Plotting genealogies\>\"", 
                  "\"\<LeafLabels\>\""},
                {"\"\<LeafOffset\>\"", "\"\<Plotting genealogies\>\"", 
                  "\"\<LeafOffset\>\""},
                {"\"\<Leaves\>\"", "\"\<Describing genealogies\>\"", 
                  "\"\<Leaves\>\""},
                {"\"\<Li & Nei 1974\>\"", "\"\<References\>\"", 
                  "\"\<Li & Nei 1974\>\""},
                {"\"\<Linkage\>\"", "\"\<Generating families\>\"", 
                  "\"\<Linkage\>\""},
                {"\"\<Linkage\>\"", "\"\<Genotype probabilities\>\"", 
                  "\"\<Linkage\>\""},
                {"\"\<Linkage\>\"", "\"\<Linkage\>\"", "\"\<Linkage\>\""},
                {"\"\<Linkage disequilibrium\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<Linkage disequilibrium\>\""},
                {"\"\<Disequilibrium\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<Linkage disequilibrium\>\""},
                {"\"\<ListToGenealogy\>\"", 
                  "\"\<Constructing genealogies\>\"", 
                  "\"\<ListToGenealogy\>\""},
                {"\"\<ListToMatrix\>\"", 
                  "\"\<Converting between representations\>\"", 
                  "\"\<ListToMatrix\>\""},
                {"\"\<Location\>\"", "\"\<Describing individuals\>\"", 
                  "\"\<Location\>\""},
                {"\"\<Locations\>\"", "\"\<Locations\>\"", 
                  "\"\<Locations\>\""},
                {"\"\<LocusNames\>\"", "\"\<Defining a dataset\>\"", 
                  "\"\<LocusNames\>\""},
                {"\"\<LogLikelihoodDisequilibrium\>\"", "\"\<Likelihood\>\"", 
                  "\"\<LogLikelihoodDisequilibrium\>\""},
                {"\"\<LogLikelihoodTest\>\"", "\"\<Likelihood tests\>\"", 
                  "\"\<LogLikelihoodTest\>\""},
                {"\"\<Log-linear models\>\"", "\"\<Alternative methods\>\"", 
                  "\"\<Log-linear models\>\""},
                {"\"\<Estimating D, alternative methods\>\"", 
                  "\"\<Alternative methods\>\"", 
                  "\"\<Log-linear models\>\""},
                {"\"\<Log-linear models\>\"", "\"\<Alternative methods\>\"", 
                  "None"},
                {"\"\<Long et al 1995\>\"", "\"\<References\>\"", 
                  "\"\<Long et al 1995\>\""},
                {"\"\<LowerOffDiagonal\>\"", "\"\<Diagonal matrices\>\"", 
                  "\"\<LowerOffDiagonal\>\""},
                {"\"\<MacCallum 1994\>\"", "\"\<References\>\"", 
                  "\"\<MacCallum 1994\>\""},
                {"\"\<MacCallum et al. 1998\>\"", "\"\<References\>\"", 
                  "\"\<MacCallum et al 1998\>\""},
                {"\"\<MakeDistanceList\>\"", 
                  "\"\<Boxing the individuals\>\"", 
                  "\"\<MakeDistanceList\>\""},
                {"\"\<MakeDistances\>\"", "\"\<Boxing the individuals\>\"", 
                  "\"\<MakeDistances\>\""},
                {"\"\<MakeFitnessSet\>\"", "\"\<Fitness\>\"", 
                  "\"\<MakeFitnessSet\>\""},
                {"\"\<MakeGenealogy\>\"", "\"\<Making a genealogy\>\"", 
                  "\"\<MakeGenealogy\>\""},
                {"\"\<MakeGenealogyPlot\>\"", "\"\<Plotting genealogies\>\"", 
                  "\"\<MakeGenealogyPlot\>\""},
                {"\"\<MakeOneWayTable\>\"", "\"\<Single-locus tables\>\"", 
                  "\"\<MakeOneWayTable\>\""},
                {"\"\<MakePairwiseTable\>\"", "\"\<Pairwise tables\>\"", 
                  "\"\<MakePairwiseTable\>\""},
                {"\"\<MakeSelectionCoefficient\>\"", "\"\<Fitness\>\"", 
                  "\"\<MakeSelectionCoefficient\>\""},
                {"\"\<MakeSelectionCoefficient\>\"", "\"\<Phenotypes\>\"", 
                  "\"\<MakeSelectionCoefficient\>\""},
                {"\"\<Mangel & Hilborn 1996\>\"", "\"\<References\>\"", 
                  "\"\<Mangel & Hilborn 1996\>\""},
                {"\"\<Bugs, manipulating notebooks\>\"", 
                  "\"\<Bugs and features\>\"", 
                  "\"\<Manipulating notebooks\>\""},
                {"\"\<MarginalTable\>\"", "\"\<Marginal tables\>\"", 
                  "\"\<MarginalTable\>\""},
                {"\"\<MarginalW\>\"", "\"\<Defining fitnesses\>\"", 
                  "\"\<MarginalW\>\""},
                {"\"\<MarginalW\>\"", 
                  "\"\<Fitnesses for the symmetric model\>\"", 
                  "\"\<MarginalW\>\""},
                {"\"\<MarginalWTable\>\"", 
                  "\"\<Fitnesses for the symmetric model\>\"", 
                  "\"\<MarginalWTable\>\""},
                {"\"\<Help Browser\>\"", 
                  "\"\<How the Help Browser works\>\"", 
                  "\"\<MasterIndexHeading\>\""},
                {"\"\<MatrixGamma\>\"", "\"\<Fast calculations\>\"", 
                  "\"\<MatrixGamma\>\""},
                {"\"\<MatrixToGenealogy\>\"", 
                  "\"\<Inferring a genealogy\>\"", 
                  "\"\<MatrixToGenealogy\>\""},
                {"\"\<MatrixToList\>\"", 
                  "\"\<Converting between representations\>\"", 
                  "\"\<MatrixToList\>\""},
                {"\"\<Estimating D, maximum entropy\>\"", 
                  "\"\<Alternative methods\>\"", "\"\<Maximum entropy\>\""},
                {"\"\<MeanContribution\>\"", "\"\<Populations\>\"", 
                  "\"\<MeanContribution\>\""},
                {"\"\<MeanD\>\"", "\"\<Describing populations\>\"", 
                  "\"\<MeanD\>\""},
                {"\"\<MeanD\>\"", "\"\<Describing the population\>\"", 
                  "\"\<MeanD\>\""},
                {"\"\<Symmetric model, mean disequilibrium\>\"", 
                  "\"\<Describing populations\>\"", "\"\<MeanD\>\""},
                {"\"\<Deterministic recursions, mean disequilibrium\>\"", 
                  "\"\<Describing the population\>\"", "\"\<MeanD\>\""},
                {"\"\<Stabilising selection,mean fitness\>\"", 
                  "\"\<Stabilising selection\>\"", "\"\<Mean fitness\>\""},
                {"\"\<Symmetric model, mean allele frequency\>\"", 
                  "\"\<Describing populations\>\"", "\"\<MeanP\>\""},
                {"\"\<Deterministic recursions, mean allele frequency\>\"", 
                  "\"\<Describing the population\>\"", "\"\<MeanP\>\""},
                {"\"\<MeanP\>\"", "\"\<Describing populations\>\"", 
                  "\"\<MeanP\>\""},
                {"\"\<MeanP\>\"", "\"\<Describing the population\>\"", 
                  "\"\<MeanP\>\""},
                {"\"\<MeanW\>\"", "\"\<Defining fitnesses\>\"", 
                  "\"\<MeanW\>\""},
                {"\"\<MeanW\>\"", 
                  "\"\<Fitnesses for the symmetric model\>\"", 
                  "\"\<MeanW\>\""},
                {"\"\<Deterministic recursions, mean fitness\>\"", 
                  "\"\<Defining fitnesses\>\"", "\"\<MeanW\>\""},
                {"\"\<Symmetric model, mean fitness\>\"", 
                  "\"\<Fitnesses for the symmetric model\>\"", 
                  "\"\<MeanW\>\""},
                {"\"\<MeanWTable\>\"", 
                  "\"\<Fitnesses for the symmetric model\>\"", 
                  "\"\<MeanWTable\>\""},
                {"\"\<Symmetric model, mean fitness table\>\"", 
                  "\"\<Fitnesses for the symmetric model\>\"", 
                  "\"\<MeanWTable\>\""},
                {"\"\<Meiosis\>\"", "\"\<Recombination\>\"", 
                  "\"\<Meiosis\>\""},
                {"\"\<MethodC\>\"", "\"\<Options for DoReplicates\>\"", 
                  "\"\<MethodC\>\""},
                {"\"\<MethodP\>\"", "\"\<Options for DoReplicates\>\"", 
                  "\"\<MethodP\>\""},
                {"\"\<MetropolisDisequilibrium\>\"", 
                  "\"\<Estimating moments\>\"", 
                  "\"\<MetropolisDisequilibrium\>\""},
                {"\"\<Metropolis et al. 1954\>\"", "\"\<References\>\"", 
                  "\"\<Metropolis et al 1954\>\""},
                {"\"\<MFromC\>\"", "\"\<Estimating the matrix\>\"", 
                  "\"\<MFromC\>\""},
                {"\"\<MFromC\>\"", "\"\<Estimation from families\>\"", 
                  "\"\<MFromC\>\""},
                {"\"\<MigrateExact\>\"", 
                  "\"\<Migration in the symmetric model\>\"", 
                  "\"\<MigrateExact\>\""},
                {"\"\<MigrationOrder\>\"", "\"\<Iterating one deme\>\"", 
                  "\"\<MigrationOrder\>\""},
                {"\"\<Missing data\>\"", "\"\<Defining a dataset\>\"", 
                  "\"\<Missing data\>\""},
                {"\"\<Data, missing\>\"", "\"\<Defining a dataset\>\"", 
                  "\"\<Missing data\>\""},
                {"\"\<Moment\>\"", "\"\<Cumulants\>\"", "\"\<Moment\>\""},
                {"\"\<Moment\>\"", "\"\<Moments and cumulants\>\"", 
                  "\"\<Moment\>\""},
                {"\"\<MomentAfterMigration\>\"", 
                  "\"\<Migration in admixture models\>\"", 
                  "\"\<MomentAfterMigration\>\""},
                {"\"\<MomentAfterRecombination\>\"", 
                  "\"\<Recombination in admixture models\>\"", 
                  "\"\<MomentAfterRecombination\>\""},
                {"\"\<MomentEquilibrium\>\"", "\"\<Equilibria\>\"", 
                  "\"\<MomentEquilibrium\>\""},
                {"\"\<MomentLimits\>\"", "\"\<Constraints on moments\>\"", 
                  "\"\<MomentLimits\>\""},
                {"\"\<MomentNew\>\"", "\"\<Iteration\>\"", 
                  "\"\<MomentNew\>\""},
                {"\"\<MomentsFromG\>\"", 
                  "\"\<Moments from genotype frequencies\>\"", 
                  "\"\<MomentsFromG\>\""},
                {"\"\<MomentSimple\>\"", "\"\<Simplifying the moments\>\"", 
                  "\"\<MomentSimple\>\""},
                {"\"\<MonteCarloGriffithsTavare\>\"", 
                  "\"\<Stochastic algorithm\>\"", 
                  "\"\<MonteCarloGriffithsTavare\>\""},
                {"\"\<Griffiths-Tavare, stochastic algorithm\>\"", 
                  "\"\<Stochastic algorithm\>\"", 
                  "\"\<MonteCarloGriffithsTavare\>\""},
                {"\"\<MonteCarloProbability\>\"", 
                  "\"\<Estimating the probability\>\"", 
                  "\"\<MonteCarloProbability\>\""},
                {"\"\<Mortality\>\"", "\"\<Describing individuals\>\"", 
                  "\"\<Mortality\>\""},
                {"\"\<MostRecentCommonAncestor\>\"", 
                  "\"\<Determining ancestry\>\"", 
                  "\"\<MostRecentCommonAncestor\>\""},
                {"\"\<MToC\>\"", "\"\<Estimating the matrix\>\"", 
                  "\"\<MToC\>\""},
                {"\"\<MToC\>\"", "\"\<Estimation from families\>\"", 
                  "\"\<MToC\>\""},
                {"\"\<MToCEquations\>\"", "\"\<Estimating the matrix\>\"", 
                  "\"\<MToCEquations\>\""},
                {"\"\<MToCEquations\>\"", "\"\<Estimation from families\>\"", 
                  "\"\<MToCEquations\>\""},
                {"\"\<Muddle\>\"", "\"\<Muddling and subdividing sets\>\"", 
                  "\"\<Muddle\>\""},
                {"\"\<Multilocus algebra, introduction to\>\"", 
                  "\"\<Introduction to multilocus algebra\>\"", 
                  "\"\<Multilocus`Multilocus`\>\""},
                {"\"\<Bugs, multilocus notation\>\"", 
                  "\"\<Bugs and features\>\"", 
                  "\"\<Multilocus notation\>\""},
                {"\"\<Multilocus notation, bugs\>\"", 
                  "\"\<Bugs and features\>\"", 
                  "\"\<Multilocus notation\>\""},
                {"\"\<MultinomialSamplingProbability\>\"", 
                  "\"\<Multinomial distribution\>\"", 
                  "\"\<MultinomialSamplingProbability\>\""},
                {"\"\<Multinomial sampling, without replacement\>\"", 
                  "\"\<Multinomial distribution\>\"", 
                  "\"\<Multinomial sampling wo replacement\>\""},
                {"\"\<Random drift, population expectations\>\"", 
                  "\"\<Expectations\>\"", "None"},
                {"\"\<PopulationExpectation, multiple arguments\>\"", 
                  "\"\<Expectations\>\"", "\"\<multiple arguments\>\""},
                {"\"\<Multiple arguments, in PopulationExpectation\>\"", 
                  "\"\<Expectations\>\"", "\"\<multiple arguments\>\""},
                {"\"\<TimesUp, multiple products\>\"", "\"\<TimesUp\>\"", 
                  "\"\<Multiple products\>\""},
                {"\"\<AddUp, multiple sums\>\"", "\"\<AddUp\>\"", 
                  "\"\<Multiple sums\>\""},
                {"\"\<Products, multiple\>\"", "\"\<TimesUp\>\"", 
                  "\"\<Multiple products\>\""},
                {"\"\<Sums, multiple\>\"", "\"\<AddUp\>\"", 
                  "\"\<Multiple sums\>\""},
                {"\"\<Negative binomial, multiplicative models\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", 
                  "\"\<multiplicative models\>\""},
                {"\"\<Multiplicative models, in negative binomial\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", 
                  "\"\<multiplicative models\>\""},
                {"\"\<MutationInterval\>\"", "\"\<Describing mutations\>\"", 
                  "\"\<MutationInterval\>\""},
                {"\"\<MutationLabels\>\"", 
                  "\"\<Converting between representations\>\"", 
                  "\"\<MutationLabels\>\""},
                {"\"\<MutationOrigin\>\"", "\"\<Describing mutations\>\"", 
                  "\"\<MutationOrigin\>\""},
                {"\"\<MutationRate\>\"", "\"\<Drawing a genealogy\>\"", 
                  "\"\<MutationRate\>\""},
                {"\"\<Mutations\>\"", "\"\<Describing mutations\>\"", 
                  "\"\<Mutations\>\""},
                {"\"\<MVariables\>\"", "\"\<Estimating the matrix\>\"", 
                  "\"\<MVariables\>\""},
                {"\"\<MVariables\>\"", "\"\<Estimation from families\>\"", 
                  "\"\<MVariables\>\""},
                {"\"\<Estimating D, naive MLE\>\"", 
                  "\"\<Alternative methods\>\"", "\"\<Naive MLE\>\""},
                {"\"\<NegativeBinomialLogLikelihood\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", 
                  "\"\<NegativeBinomialLogLikelihood\>\""},
                {"\"\<NegativeBinomialMLE\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", 
                  "\"\<NegativeBinomialMLE\>\""},
                {"\"\<NegativeHypergeometricDistribution\>\"", 
                  "\"\<Negative hypergeometric distribution\>\"", 
                  "\"\<NegativeHypergeometricDistribution\>\""},
                {"\"\<NeighbourArray\>\"", "\"\<Boxing the individuals\>\"", 
                  "\"\<NeighbourArray\>\""},
                {"\"\<Neighbours\>\"", "\"\<Boxing the individuals\>\"", 
                  "\"\<Neighbours\>\""},
                {"\"\<NetCovariance\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<NetCovariance\>\""},
                {"\"\<NetFecundity\>\"", "\"\<Global variables\>\"", 
                  "\"\<NetFecundity\>\""},
                {"\"\<NetMortality\>\"", "\"\<Global variables\>\"", 
                  "\"\<NetMortality\>\""},
                {"\"\<NetRecombination\>\"", "\"\<Linkage\>\"", 
                  "\"\<NetRecombination\>\""},
                {"\"\<NetRecombination\>\"", "\"\<Linkage in families\>\"", 
                  "\"\<NetRecombination\>\""},
                {"\"\<Additive selection, new D\>\"", 
                  "\"\<Additive selection\>\"", "\"\<New D\>\""},
                {"\"\<NewGametes\>\"", 
                  "\"\<Reproduction in the symmetric model\>\"", 
                  "\"\<NewGametes\>\""},
                {"\"\<NewGametes\>\"", "\"\<Reproduction recursions\>\"", 
                  "\"\<NewGametes\>\""},
                {"\"\<Symmetric model, new gametes\>\"", 
                  "\"\<Reproduction in the symmetric model\>\"", 
                  "\"\<NewGametes\>\""},
                {"\"\<Deterministic recursions, new gametes\>\"", 
                  "\"\<Reproduction recursions\>\"", "\"\<NewGametes\>\""},
                {"\"\<Additive selection, new mean\>\"", 
                  "\"\<Additive selection\>\"", "\"\<New mean\>\""},
                {"\"\<Stabilising selection, new mean\>\"", 
                  "\"\<Stabilising selection\>\"", "\"\<New mean\>\""},
                {"\"\<Stabilising selection, new mean fitness\>\"", 
                  "\"\<Stabilising selection\>\"", 
                  "\"\<New mean fitness\>\""},
                {"\"\<NewS\>\"", "\"\<The set of all structures\>\"", 
                  "\"\<NewS\>\""},
                {"\"\<Family structure, set of all\>\"", 
                  "\"\<The set of all structures\>\"", "\"\<NewS\>\""},
                {"\"\<Node\>\"", "\"\<Constructing genealogies\>\"", 
                  "\"\<Node\>\""},
                {"\"\<Node\>\"", "\"\<Structure of genealogies\>\"", 
                  "\"\<Node\>\""},
                {"\"\<NodeFunction\>\"", "\"\<Constructing genealogies\>\"", 
                  "\"\<NodeFunction\>\""},
                {"\"\<NodeFunction\>\"", "\"\<Plotting genealogies\>\"", 
                  "\"\<NodeFunction\>\""},
                {"\"\<NodeLabels\>\"", "\"\<Plotting genealogies\>\"", 
                  "\"\<NodeLabels\>\""},
                {"\"\<NodeOffset\>\"", "\"\<Plotting genealogies\>\"", 
                  "\"\<NodeOffset\>\""},
                {"\"\<Nodes\>\"", "\"\<Describing genealogies\>\"", 
                  "\"\<Nodes\>\""},
                {"\"\<Normalisation\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", 
                  "\"\<Normalisation\>\""},
                {"\"\<Negative binomial, normalisation\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", 
                  "\"\<Normalisation\>\""},
                {"\"\<Normalised\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", 
                  "\"\<Normalised\>\""},
                {"\"\<Genotypes, notation for\>\"", "\"\<Notation\>\"", 
                  "\"\<NotationPackage\>\""},
                {"\"\<Data, notation for\>\"", 
                  "\"\<Notation for genetic data\>\"", 
                  "\"\<NotationPackage\>\""},
                {"\"\<Notation, genotypes\>\"", "\"\<Notation\>\"", 
                  "\"\<NotationPackage\>\""},
                {"\"\<Notation, data\>\"", 
                  "\"\<Notation for genetic data\>\"", 
                  "\"\<NotationPackage\>\""},
                {"\"\<Notation, reference\>\"", "\"\<Notation reference\>\"", 
                  "\"\<NotationPackage\>\""},
                {"\"\<Numbering, notes on\>\"", 
                  "\"\<Automatic Numbering\>\"", "\"\<Notes\>\""},
                {"\"\<NumberedLink\>\"", "\"\<Automatic Numbering\>\"", 
                  "\"\<NumberedLink\>\""},
                {"\"\<NumberOfCoalescences\>\"", 
                  "\"\<Distribution of coalescence times\>\"", 
                  "\"\<NumberOfCoalescences\>\""},
                {"\"\<NumberOfGenes\>\"", "\"\<Describing a dataset\>\"", 
                  "\"\<NumberOfGenes\>\""},
                {"\"\<NumberOfGenesTable\>\"", 
                  "\"\<Describing a dataset\>\"", 
                  "\"\<NumberOfGenesTable\>\""},
                {"\"\<NumberOfIndividuals\>\"", 
                  "\"\<Describing a dataset\>\"", 
                  "\"\<NumberOfIndividuals\>\""},
                {"\"\<NumberOfIndividuals\>\"", "\"\<Global variables\>\"", 
                  "\"\<NumberOfIndividuals\>\""},
                {"\"\<NumberOfIndividualsTable\>\"", 
                  "\"\<Describing a dataset\>\"", 
                  "\"\<NumberOfIndividualsTable\>\""},
                {"\"\<NumberOfLineages\>\"", 
                  "\"\<Describing genealogies\>\"", 
                  "\"\<NumberOfLineages\>\""},
                {"\"\<NumberOfLoci\>\"", "\"\<Describing a dataset\>\"", 
                  "\"\<NumberOfLoci\>\""},
                {"\"\<NumberOfMutations\>\"", "\"\<Describing mutations\>\"", 
                  "\"\<NumberOfMutations\>\""},
                {"\"\<NumberOfPossibleCoalescences\>\"", 
                  "\"\<Finding possible orders\>\"", 
                  "\"\<NumberOfPossibleCoalescences\>\""},
                {"\"\<NumberOfSamplePartitions\>\"", 
                  "\"\<Set partitions\>\"", 
                  "\"\<NumberOfSamplePartitions\>\""},
                {"\"\<NumberOfSetPartitions\>\"", "\"\<Set partitions\>\"", 
                  "\"\<NumberOfSetPartitions\>\""},
                {"\"\<Observable genotype\>\"", "\"\<Diploid genotypes\>\"", 
                  "\"\<ObservableGenotype\>\""},
                {"\"\<Observable genotype\>\"", 
                  "\"\<Genotype probabilities\>\"", 
                  "\"\<ObservableGenotype\>\""},
                {"\"\<Genotype, observable\>\"", "\"\<Diploid genotypes\>\"", 
                  "\"\<ObservableGenotype\>\""},
                {"\"\<Genotype, observable\>\"", 
                  "\"\<Genotype probabilities\>\"", 
                  "\"\<ObservableGenotype\>\""},
                {"\"\<Obsolete, Estimating D\>\"", 
                  "\"\<Bugs and features\>\"", 
                  "\"\<Obsolete EstimatingD\>\""},
                {"\"\<Bugs, Estimating D\>\"", "\"\<Bugs and features\>\"", 
                  "\"\<Obsolete EstimatingD\>\""},
                {"\"\<Estimating D, obsolete\>\"", 
                  "\"\<Bugs and features\>\"", 
                  "\"\<Obsolete EstimatingD\>\""},
                {"\"\<Obsolete, fitness\>\"", "\"\<Fitness\>\"", 
                  "\"\<Obsolete notation\>\""},
                {"\"\<Offspring\>\"", "\"\<Describing individuals\>\"", 
                  "\"\<Offspring\>\""},
                {"\"\<Orive & Barton 1999\>\"", "\"\<References\>\"", 
                  "\"\<Orive & Barton 1999\>\""},
                {"\"\<OtherSex\>\"", "\"\<Genes and contexts\>\"", 
                  "\"\<OtherSex\>\""},
                {"\"\<Packages, help\>\"", 
                  "\"\<How the Help Browser works\>\"", "\"\<Packages\>\""},
                {"\"\<Bugs, pasting hyperlinks\>\"", 
                  "\"\<Bugs and features\>\"", "\"\<Pasting hyperlinks\>\""},
                {"\"\<Hyperlinks, bugs in pasting\>\"", 
                  "\"\<Bugs and features\>\"", "\"\<Pasting hyperlinks\>\""},
                {"\"\<PatternFree\>\"", 
                  "\"\<Flattening lists by pattern\>\"", 
                  "\"\<PatternFree\>\""},
                {"\"\<FlattenList, PatternFree\>\"", 
                  "\"\<Flattening lists by pattern\>\"", 
                  "\"\<PatternFree\>\""},
                {"\"\<Phipps & Brill 1995\>\"", "\"\<References\>\"", 
                  "\"\<Phipps & Brill 1995\>\""},
                {"\"\<Ploidy\>\"", "\"\<Describing a dataset\>\"", 
                  "\"\<Ploidy\>\""},
                {"\"\<PloidyWeightList\>\"", "\"\<Internal functions\>\"", 
                  "\"\<PloidyWeightList\>\""},
                {"\"\<PlotGenealogy\>\"", "\"\<Plotting genealogies\>\"", 
                  "\"\<PlotGenealogy\>\""},
                {"\"\<PlotLogL\>\"", "\"\<Presenting results\>\"", 
                  "\"\<PlotLogL\>\""},
                {"\"\<PopulationDisequilibrium\>\"", "\"\<Expectations\>\"", 
                  "\"\<PopulationDisequilibrium\>\""},
                {"\"\<PopulationExpectation\>\"", "\"\<Expectations\>\"", 
                  "\"\<PopulationExpectation\>\""},
                {"\"\<Random drift, population disequilibrium\>\"", 
                  "\"\<Expectations\>\"", 
                  "\"\<PopulationDisequilibrium\>\""},
                {"\"\<Random drift, population expectation\>\"", 
                  "\"\<Expectations\>\"", "\"\<PopulationExpectation\>\""},
                {"\"\<Disequilibrium, population\>\"", 
                  "\"\<Expectations\>\"", 
                  "\"\<PopulationDisequilibrium\>\""},
                {"\"\<Expectation, population\>\"", "\"\<Expectations\>\"", 
                  "\"\<PopulationExpectation\>\""},
                {"\"\<PositionsList\>\"", "\"\<Full diploid genotypes\>\"", 
                  "\"\<PositionsList\>\""},
                {"\"\<PositionsMatrix\>\"", "\"\<Full diploid genotypes\>\"", 
                  "\"\<PositionsMatrix\>\""},
                {"\"\<PossibleCoalescenceOrder\>\"", 
                  "\"\<Finding possible orders\>\"", 
                  "\"\<PossibleCoalescenceOrder\>\""},
                {"\"\<PossibleDiploidGenotypes\>\"", 
                  "\"\<Full diploid genotypes\>\"", 
                  "\"\<PossibleDiploidGenotypes\>\""},
                {"\"\<PossibleGenotypes\>\"", "\"\<Diploid genotypes\>\"", 
                  "\"\<PossibleGenotypes\>\""},
                {"\"\<PresentOneWayTable\>\"", "\"\<Single-locus tables\>\"", 
                  "\"\<PresentOneWayTable\>\""},
                {"\"\<PresentPairwiseTable\>\"", "\"\<Pairwise tables\>\"", 
                  "\"\<PresentPairwiseTable\>\""},
                {"\"\<PresentResults\>\"", "\"\<Presenting results\>\"", 
                  "\"\<PresentResults\>\""},
                {"\"\<PrintDetails\>\"", "\"\<Options for StructuredMLE\>\"", 
                  "\"\<PrintDetails\>\""},
                {"\"\<ProductSum\>\"", "\"\<ProductSum\>\"", 
                  "\"\<ProductSum\>\""},
                {"\"\<ProductSum over sets\>\"", "\"\<ProductSum\>\"", 
                  "\"\<ProductSum over sets\>\""},
                {"\"\<RandomBottleneckedGenealogy\>\"", 
                  "\"\<Population bottlenecks\>\"", 
                  "\"\<RandomBottleneckedGenealogy\>\""},
                {"\"\<RandomCoalescenceOrder\>\"", 
                  "\"\<Finding possible orders\>\"", 
                  "\"\<RandomCoalescenceOrder\>\""},
                {"\"\<RandomCoalescenceTimes\>\"", 
                  "\"\<Distribution of coalescence times\>\"", 
                  "\"\<RandomCoalescenceTimes\>\""},
                {"\"\<RandomCum\>\"", 
                  "\"\<Sampling from arbitrary distributions\>\"", 
                  "\"\<RandomCum\>\""},
                {"\"\<RandomFamilies\>\"", "\"\<Random families\>\"", 
                  "\"\<RandomFamilies\>\""},
                {"\"\<RandomFamily\>\"", "\"\<Generating families\>\"", 
                  "\"\<RandomFamily\>\""},
                {"\"\<RandomGenealogy\>\"", "\"\<Drawing a genealogy\>\"", 
                  "\"\<RandomGenealogy\>\""},
                {"\"\<RandomList\>\"", "\"\<Random lists\>\"", 
                  "\"\<RandomList\>\""},
                {"\"\<RandomMultinomial\>\"", 
                  "\"\<Multinomial distribution\>\"", 
                  "\"\<RandomMultinomial\>\""},
                {"\"\<RandomPreviousFamily\>\"", "\"\<Random families\>\"", 
                  "\"\<RandomPreviousFamily\>\""},
                {"\"\<Random sampling\>\"", 
                  "\"\<Introduction to random drift\>\"", 
                  "\"\<Random sampling\>\""},
                {"\"\<RandomSet\>\"", "\"\<Random sets\>\"", 
                  "\"\<RandomSet\>\""},
                {"\"\<Random union\>\"", "\"\<Sexual selection\>\"", 
                  "\"\<Random union\>\""},
                {"\"\<RandomUnion\>\"", "\"\<Random union\>\"", 
                  "\"\<RandomUnion\>\""},
                {"\"\<Recombination\>\"", "\"\<Recombination\>\"", 
                  "\"\<Recombination\>\""},
                {"\"\<Recombination\>\"", "\"\<Sexual selection\>\"", 
                  "\"\<Recombination\>\""},
                {"\"\<Sexual selection, recombination\>\"", 
                  "\"\<Sexual selection\>\"", "\"\<Recombination\>\""},
                {"\"\<RecombinationRate\>\"", "\"\<Recombination\>\"", 
                  "\"\<RecombinationRate\>\""},
                {"\"\<Problems, redefining fitness\>\"", 
                  "\"\<Potential problems\>\"", 
                  "\"\<Redefining fitness\>\""},
                {"\"\<ReducedData\>\"", "\"\<Simplifying a dataset\>\"", 
                  "\"\<ReducedData\>\""},
                {"\"\<Fitness, problems redefining\>\"", 
                  "\"\<Potential problems\>\"", 
                  "\"\<Redefining fitness\>\""},
                {"\"\<ReferencePoint\>\"", "\"\<Allelic state\>\"", 
                  "\"\<ReferencePoint\>\""},
                {"\"\<ReferencePointMean\>\"", "\"\<Reference points\>\"", 
                  "\"\<ReferencePointMean\>\""},
                {"\"\<ReferencePointSame\>\"", "\"\<Reference points\>\"", 
                  "\"\<ReferencePointSame\>\""},
                {"\"\<ReferencePointZero\>\"", "\"\<Reference points\>\"", 
                  "\"\<ReferencePointZero\>\""},
                {"\"\<RemoveTag\>\"", "\"\<Tagging sets\>\"", 
                  "\"\<RemoveTag\>\""},
                {"\"\<Repeat\>\"", "\"\<Repeated elements\>\"", 
                  "\"\<Repeat\>\""},
                {"\"\<Bugs, repeated \\\\\\\\\>\"", 
                  "\"\<Bugs and features\>\"", "\"\<Repeated \\\\\\\\\>\""},
                {"\"\<\\\\\\, bugs with\>\"", "\"\<Bugs and features\>\"", 
                  "\"\<Repeated \\\\\\\\\>\""},
                {"\"\<Replace\>\"", "\"\<Random lists\>\"", 
                  "\"\<Replace\>\""},
                {"\"\<RandomList, sampling without replacement\>\"", 
                  "\"\<Random lists\>\"", "\"\<Replace\>\""},
                {"\"\<Sampling, without replacement\>\"", 
                  "\"\<Random lists\>\"", "\"\<Replace\>\""},
                {"\"\<|., ReplaceAllSpecial\>\"", "\"\<|., ||.\>\"", 
                  "\"\<ReplaceAllSpecial\>\""},
                {"\"\<ReplaceRepeatedSpecial, ||.\>\"", "\"\<|., ||.\>\"", 
                  "\"\<ReplacerepeatedSpecial\>\""},
                {"\"\<||., ReplaceRepeatedSpecial\>\"", "\"\<|., ||.\>\"", 
                  "\"\<ReplaceAllSpecial\>\""},
                {"\"\<ReplaceAllSpecial, |.\>\"", "\"\<|., ||.\>\"", 
                  "\"\<ReplaceAllSpecial\>\""},
                {"\"\<Reverse\>\"", "\"\<Sorting\>\"", "\"\<Reverse\>\""},
                {"\"\<RootedGenealogy\>\"", 
                  "\"\<Structure of genealogies\>\"", 
                  "\"\<RootedGenealogy\>\""},
                {"\"\<Rules\>\"", "\"\<Stabilising selection\>\"", 
                  "\"\<Rules\>\""},
                {"\"\<SampleCovariance\>\"", "\"\<Sampling\>\"", 
                  "\"\<SampleCovariance\>\""},
                {"\"\<SampleIndividuals\>\"", "\"\<Sampling individuals\>\"", 
                  "\"\<SampleIndividuals\>\""},
                {"\"\<SamplePartition\>\"", "\"\<Set partitions\>\"", 
                  "\"\<SamplePartition\>\""},
                {"\"\<Numbering, saving links\>\"", 
                  "\"\<Automatic Numbering\>\"", "\"\<Saving the links\>\""},
                {"\"\<Hyperlinks, saving\>\"", "\"\<Automatic Numbering\>\"", 
                  "\"\<Saving the links\>\""},
                {"\"\<Additive selection, scaled D\>\"", 
                  "\"\<Additive selection\>\"", "\"\<Scaled D\>\""},
                {"\"\<SegregationRatio\>\"", "\"\<Generating families\>\"", 
                  "\"\<SegregationRatio\>\""},
                {"\"\<SegregationRatio\>\"", 
                  "\"\<Genotype probabilities\>\"", 
                  "\"\<SegregationRatio\>\""},
                {"\"\<RandomFamily, segregation ratio\>\"", 
                  "\"\<Generating families\>\"", "\"\<SegregationRatio\>\""},
                {"\"\<GenotypeProbability, segregation ratio\>\"", 
                  "\"\<Genotype probabilities\>\"", 
                  "\"\<SegregationRatio\>\""},
                {"\"\<SelectContexts\>\"", "\"\<Selecting contexts\>\"", 
                  "\"\<SelectContexts\>\""},
                {"\"\<SelectIndividuals\>\"", "\"\<Selecting subsets\>\"", 
                  "\"\<SelectIndividuals\>\""},
                {"\"\<SelectionCoefficient\>\"", "\"\<Fitness\>\"", 
                  "\"\<SelectionCoefficient\>\""},
                {"\"\<SelectionCoefficient\>\"", "\"\<Selection\>\"", 
                  "\"\<SelectionCoefficient\>\""},
                {"\"\<SelectLoci\>\"", "\"\<Selecting subsets\>\"", 
                  "\"\<SelectLoci\>\""},
                {"\"\<SetPartition\>\"", "\"\<Set partitions\>\"", 
                  "\"\<SetPartition\>\""},
                {"\"\<Help Browser, setting up hyperlinks\>\"", 
                  "\"\<How the Help Browser works\>\"", 
                  "\"\<Setting up links\>\""},
                {"\"\<Hyperlinks, setting up\>\"", 
                  "\"\<How the Help Browser works\>\"", 
                  "\"\<Setting up links\>\""},
                {"\"\<Tags, setting up hyperlinks to\>\"", 
                  "\"\<Automatic Numbering\>\"", 
                  "\"\<Setting up links to a list of tags\>\""},
                {"\"\<Hyperlinks, to cell tags\>\"", 
                  "\"\<Automatic Numbering\>\"", 
                  "\"\<Setting up links to a list of tags\>\""},
                {"\"\<Index, setting up\>\"", 
                  "\"\<How the Help Browser works\>\"", 
                  "\"\<Setting up Master Index\>\""},
                {"\"\<Help browser, setting up new files\>\"", 
                  "\"\<Setting up new help files\>\"", 
                  "\"\<Setting up new help files\>\""},
                {"\"\<Packages, setting up\>\"", "\"\<Special notation\>\"", 
                  "\"\<Setting up packages\>\""},
                {"\"\<Packages, setting up\>\"", 
                  "\"\<Setting up the packages\>\"", 
                  "\"\<Setting up the packages\>\""},
                {"\"\<Sex\>\"", "\"\<Life cycle\>\"", "\"\<Sex\>\""},
                {"\"\<SexOfOrigin\>\"", "\"\<Life cycle\>\"", 
                  "\"\<SexOfOrigin\>\""},
                {"\"\<Sexual selection\>\"", "\"\<Sexual selection\>\"", 
                  "\"\<Sexual selection\>\""},
                {"\"\<ShortContext\>\"", "\"\<Abbreviating contexts\>\"", 
                  "\"\<ShortContext\>\""},
                {"\"\<SigmaMatrix\>\"", "\"\<Example: one deme\>\"", 
                  "\"\<SigmaMatrix\>\""},
                {"\"\<SignMask\>\"", "\"\<Internal functions\>\"", 
                  "\"\<SignMask\>\""},
                {"\"\<SimplifyAddUp\>\"", "\"\<AddUp\>\"", 
                  "\"\<SimplifyAddUp\>\""},
                {"\"\<SimplifyAddUpQ\>\"", "\"\<AddUp\>\"", 
                  "\"\<SimplifyAddUpQ\>\""},
                {"\"\<SimplifyFamilies\>\"", "\"\<Probabilities\>\"", 
                  "\"\<SimplifyFamilies\>\""},
                {"\"\<SizeOfGenealogyPlot\>\"", 
                  "\"\<Plotting genealogies\>\"", 
                  "\"\<SizeOfGenealogyPlot\>\""},
                {"\"\<Slatkin & Excoffier 1996\>\"", "\"\<References\>\"", 
                  "\"\<Slatkin & Excoffier 1996\>\""},
                {"\"\<SlowChange\>\"", "\"\<Slow change\>\"", 
                  "\"\<SlowChange\>\""},
                {"\"\<Griffiths-Tavare, stochastic example\>\"", 
                  "\"\<Stochastic algorithm\>\"", "\"\<Small example\>\""},
                {"\"\<SortByClass\>\"", 
                  "\"\<Representing the population\>\"", 
                  "\"\<SortByClass\>\""},
                {"\"\<SortByHead\>\"", "\"\<Sorting\>\"", 
                  "\"\<SortByHead\>\""},
                {"\"\<SpatialCovariance\>\"", "\"\<Sampling\>\"", 
                  "\"\<SpatialCovariance\>\""},
                {"\"\<Bugs, special notation\>\"", 
                  "\"\<Bugs and features\>\"", "\"\<Special notation\>\""},
                {"\"\<StabilityDirect\>\"", "\"\<Example: stability\>\"", 
                  "\"\<StabilityDirect\>\""},
                {"\"\<StabilityK\>\"", "\"\<Example: a cline\>\"", 
                  "\"\<StabilityK\>\""},
                {"\"\<StabilityK\>\"", "\"\<Example: one deme\>\"", 
                  "\"\<StabilityK\>\""},
                {"\"\<StabilityKTable\>\"", "\"\<Faster algorithms\>\"", 
                  "\"\<StabilityKTable\>\""},
                {"\"\<StabilityMatrix\>\"", 
                  "\"\<Making a stability matrix\>\"", 
                  "\"\<StabilityMatrix\>\""},
                {"\"\<Stages\>\"", "\"\<Genes and contexts\>\"", 
                  "\"\<Stages\>\""},
                {"\"\<Stages\>\"", "\"\<Life cycle\>\"", "\"\<Stages\>\""},
                {"\"\<Life cycle, stages in\>\"", 
                  "\"\<Genes and contexts\>\"", "\"\<Stages\>\""},
                {"\"\<Life cycle, stages in\>\"", "\"\<Life cycle\>\"", 
                  "\"\<Stages\>\""},
                {"\"\<Multilocus algebra, stages in life cycle\>\"", 
                  "\"\<Genes and contexts\>\"", "\"\<Stages\>\""},
                {"\"\<Multilocus algebra, stages in life cycle\>\"", 
                  "\"\<Life cycle\>\"", "\"\<Stages\>\""},
                {"\"\<StartingStepSize\>\"", 
                  "\"\<Options for StructuredMLE\>\"", 
                  "\"\<StartingStepSize\>\""},
                {"\"\<Griffiths-Tavare, stochastic algorithm\>\"", 
                  "\"\<Stochastic algorithm\>\"", 
                  "\"\<Stochastic GT algorithm\>\""},
                {"\"\<StoreExact\>\"", "\"\<Iterating the recursions\>\"", 
                  "\"\<StoreExact\>\""},
                {"\"\<StoreExact\>\"", "\"\<Storing a cline\>\"", 
                  "\"\<StoreExact\>\""},
                {"\"\<StoreNeutral\>\"", "\"\<Adding a neutral gene\>\"", 
                  "\"\<StoreNeutral\>\""},
                {"\"\<StoreResults\>\"", 
                  "\"\<Reproduction in the symmetric model\>\"", 
                  "\"\<StoreResults\>\""},
                {"\"\<StructuredArray\>\"", "\"\<Useful functions\>\"", 
                  "\"\<StructuredArray\>\""},
                {"\"\<StructuredInitialParameters\>\"", 
                  "\"\<Initial parameters\>\"", 
                  "\"\<StructuredInitialParameters\>\""},
                {"\"\<StructuredLogLikelihood\>\"", 
                  "\"\<Likelihood of a structured model\>\"", 
                  "\"\<StructuredLogLikelihood\>\""},
                {"\"\<StructuredMLE\>\"", 
                  "\"\<Likelihood of a structured model\>\"", 
                  "\"\<StructuredMLE\>\""},
                {"\"\<StructuredMLE\>\"", 
                  "\"\<Options for StructuredMLE\>\"", 
                  "\"\<StructuredMLE\>\""},
                {"\"\<StructuredModel\>\"", "\"\<Useful functions\>\"", 
                  "\"\<StructuredModel\>\""},
                {"\"\<StructuredModelReduce\>\"", 
                  "\"\<Simplifying a model\>\"", 
                  "\"\<StructuredModelReduce\>\""},
                {"\"\<StructuredParameter\>\"", 
                  "\"\<Structured parameters\>\"", 
                  "\"\<StructuredParameter\>\""},
                {"\"\<StructuredVariance\>\"", 
                  "\"\<Variance components for a structured model\>\"", 
                  "\"\<StructuredVariance\>\""},
                {"\"\<Subdivide\>\"", 
                  "\"\<Muddling and subdividing sets\>\"", 
                  "\"\<Subdivide\>\""},
                {"\"\<Subsets\>\"", "\"\<Subsets\>\"", "\"\<Subsets\>\""},
                {"\"\<Sexual selection, subtle problem\>\"", 
                  "\"\<Sexual selection\>\"", "\"\<subtle problem\>\""},
                {"\"\<SymmetricCline\>\"", "\"\<Storing a cline\>\"", 
                  "\"\<SymmetricCline\>\""},
                {"\"\<SymmetricModel\>\"", 
                  "\"\<Representing the population\>\"", 
                  "\"\<SymmetricModel\>\""},
                {"\"\<SymmetricModel\>\"", "\"\<Reproduction recursions\>\"", 
                  "\"\<SymmetricModel\>\""},
                {"\"\<SymmetricRecombination\>\"", "\"\<Recombination\>\"", 
                  "\"\<SymmetricRecombination\>\""},
                {"\"\<Symmetrise\>\"", "\"\<Disequilibrium\>\"", 
                  "\"\<Symmetrise\>\""},
                {"\"\<Symmetrise\>\"", "\"\<Symmetrise\>\"", 
                  "\"\<Symmetrise\>\""},
                {"\"\<Time, T\>\"", "\"\<Global variables\>\"", "\"\<T\>\""},
                {"\"\<T, time\>\"", "\"\<Global variables\>\"", "\"\<T\>\""},
                {"\"\<VarianceComponents, Table option\>\"", 
                  "\"\<Variance components\>\"", "\"\<Table\>\""},
                {"\"\<Table, option for VarianceComponents\>\"", 
                  "\"\<Variance components\>\"", "\"\<Table\>\""},
                {"\"\<Tag\>\"", "\"\<Tagging sets\>\"", "\"\<Tag\>\""},
                {"\"\<TakeAway\>\"", "\"\<Operations on sets\>\"", 
                  "\"\<TakeAway\>\""},
                {"\"\<TakeAway\>\"", "\"\<TakeAway\>\"", "\"\<TakeAway\>\""},
                {"\"\<TakeOptions\>\"", "\"\<Manipulating options\>\"", 
                  "\"\<TakeOptions\>\""},
                {"\"\<AddUp, technicalities\>\"", "\"\<AddUp\>\"", 
                  "\"\<Technicalities\>\""},
                {"\"\<Multilocus algebra, technicalities\>\"", 
                  "\"\<Populations\>\"", "\"\<Technicalities\>\""},
                {"\"\<TimesUp\>\"", "\"\<Operations on sets\>\"", 
                  "\"\<TimesUp\>\""},
                {"\"\<TimesUp\>\"", "\"\<TimesUp\>\"", "\"\<TimesUp\>\""},
                {"\"\<Negative binomial, timings\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", 
                  "\"\<Timings\>\""},
                {"\"\<ToCumulants\>\"", "\"\<Multilocus cumulants\>\"", 
                  "\"\<ToCumulants\>\""},
                {"\"\<ToMoments\>\"", "\"\<Multilocus cumulants\>\"", 
                  "\"\<ToMoments\>\""},
                {"\"\<ToPopulationCumulants\>\"", 
                  "\"\<Random drift: cumulants\>\"", 
                  "\"\<ToPopulationCumulants\>\""},
                {"\"\<ToPopulationMoments\>\"", 
                  "\"\<Random drift: cumulants\>\"", 
                  "\"\<ToPopulationMoments\>\""},
                {"\"\<TotalLength\>\"", 
                  "\"\<Distribution of coalescence times\>\"", 
                  "\"\<TotalLength\>\""},
                {"\"\<TotalNumber\>\"", "\"\<Global variables\>\"", 
                  "\"\<TotalNumber\>\""},
                {"\"\<TransformedRange\>\"", "\"\<Fourier transforms\>\"", 
                  "\"\<TransformedRange\>\""},
                {"\"\<TransformInformation\>\"", 
                  "\"\<Describing genealogies\>\"", 
                  "\"\<TransformInformation\>\""},
                {"\"\<TransmissionRule\>\"", "\"\<Changing contexts\>\"", 
                  "\"\<TransmissionRule\>\""},
                {"\"\<TriDiagonalMatrix\>\"", "\"\<Diagonal matrices\>\"", 
                  "\"\<TriDiagonalMatrix\>\""},
                {"\"\<Turelli and Barton 1994\>\"", 
                  "\"\<Multilocus references\>\"", 
                  "\"\<Turelli and Barton 1994\>\""},
                {"\"\<Turelli & Barton 1994\>\"", "\"\<References\>\"", 
                  "\"\<Turelli & Barton 1994\>\""},
                {"\"\<UnionOfGametes\>\"", "\"\<Union of gametes\>\"", 
                  "\"\<UnionOfGametes\>\""},
                {"\"\<UnrootedGenealogy\>\"", 
                  "\"\<Structure of genealogies\>\"", 
                  "\"\<UnrootedGenealogy\>\""},
                {"\"\<UpperOffDiagonal\>\"", "\"\<Diagonal matrices\>\"", 
                  "\"\<UpperOffDiagonal\>\""},
                {"\"\<VarianceComponents\>\"", 
                  "\"\<Variance components for a structured model\>\"", 
                  "\"\<VarianceComponents\>\""},
                {"\"\<Estimating D, varying divergence\>\"", 
                  "\"\<Estimating the matrix\>\"", 
                  "\"\<Varying divergence\>\""},
                {"\"\<$MetropolisAdjustment\>\"", 
                  "\"\<Metropolis algorithm\>\"", 
                  "\"\<$MetropolisAdjustment\>\""},
                {"\"\<Admixture models\>\"", "\"\<Admixture models\>\"", 
                  "None"},
                {"\"\<Estimating D, admixture models\>\"", 
                  "\"\<Admixture models\>\"", "None"},
                {"\"\<Selection on diploids, a method to avoid\>\"", 
                  "\"\<A method to avoid\>\"", "None"},
                {"\"\<Continuous populations, example\>\"", 
                  "\"\<An example\>\"", "None"},
                {"\"\<Selection on diploids, cautionary notes\>\"", 
                  "\"\<Cautionary notes\>\"", "None"},
                {"\"\<Symmetric model, checks\>\"", 
                  "\"\<Checks on the symmetric model\>\"", "None"},
                {"\"\<Selection on diploids, complete life cycle\>\"", 
                  "\"\<Complete life cyle\>\"", "None"},
                {"\"\<Genealogies, probability of\>\"", 
                  "\"\<Deriving the probability\>\"", "None"},
                {"\"\<Continuous populations, estimating covariance\>\"", 
                  "\"\<Estimating the covariance\>\"", "None"},
                {"\"\<Covariance, in continuous populations\>\"", 
                  "\"\<Estimating the covariance\>\"", "None"},
                {"\"\<Structured models, example\>\"", "\"\<Example data\>\"",
                   "None"},
                {"\"\<Deterministic recursions, epistasis, example of\>\"", 
                  "\"\<Example: epistasis\>\"", "None"},
                {"\"\<Selection on diploids, explaining the rules\>\"", 
                  "\"\<Explaining the rules\>\"", "None"},
                {"\"\<Genealogies, family structure\>\"", 
                  "\"\<Family structure\>\"", "None"},
                {"\"\<Griffiths-Tavare\>\"", 
                  "\"\<Griffiths-Tavare algorithm\>\"", "None"},
                {"\"\<Structured models, hierarchical analysis\>\"", 
                  "\"\<Hierarchical analysis\>\"", "None"},
                {"\"\<Continuous populations, implementation\>\"", 
                  "\"\<Implementation\>\"", "None"},
                {"\"\<Estimating D, introduction\>\"", 
                  "\"\<Introduction to estimating D\>\"", "None"},
                {"\"\<Selection on diploids, introduction\>\"", 
                  "\"\<Introduction to selection on diploids\>\"", "None"},
                {"\"\<Symmetric model, limitations\>\"", 
                  "\"\<Limitations\>\"", "None"},
                {"\"\<Estimating D, maximum likelihood, example of\>\"", 
                  "\"\<MLE example\>\"", "None"},
                {"\"\<Notation package\>\"", "\"\<Notation package\>\"", 
                  "None"},
                {"\"\<Estimating D, obsolete\>\"", 
                  "\"\<Obsolete functions\>\"", "None"},
                {"\"\<Symmetric model, stability of\>\"", "\"\<Outline\>\"", 
                  "None"},
                {"\"\<Admixture models\>\"", "\"\<Overview\>\"", "None"},
                {"\"\<Set manipulation, overview\>\"", 
                  "\"\<Overview of set manipulation\>\"", "None"},
                {"\"\<Estimating D, pairs of loci\>\"", 
                  "\"\<Pairs of loci\>\"", "None"},
                {"\"\<Estimating D, pairs of loci, example of\>\"", 
                  "\"\<Pairwise example\>\"", "None"},
                {"\"\<Metropolis algorithm, estimating D\>\"", 
                  "\"\<Random walk\>\"", "None"},
                {"\"\<Estimating D, Metropolis random walk\>\"", 
                  "\"\<Random walk\>\"", "None"},
                {"\"\<Random walk, in estimating D\>\"", 
                  "\"\<Random walk\>\"", "None"},
                {"\"\<Symmetric model, references\>\"", 
                  "\"\<References for the symmetric model\>\"", "None"},
                {"\"\<Estimating D, random sampling, example of\>\"", 
                  "\"\<Sampling example\>\"", "None"},
                {"\"\<Random sampling, example in estimating D\>\"", 
                  "\"\<Sampling example\>\"", "None"},
                {"\"\<Genealogies, sampling\>\"", 
                  "\"\<Sampling genealogies\>\"", "None"},
                {"\"\<Random sampling, of genealogies\>\"", 
                  "\"\<Sampling genealogies\>\"", "None"},
                {"\"\<Symmetric model, spatially varying selection\>\"", 
                  "\"\<Spatially varying selection\>\"", "None"},
                {"\"\<Spatially varying selection, in symmetric model\>\"", 
                  "\"\<Spatially varying selection\>\"", "None"},
                {"\"\<Estimating D, summary\>\"", "\"\<Summary\>\"", "None"},
                {"\"\<Continuous populations, the model\>\"", 
                  "\"\<The model\>\"", "None"},
                {"\"\<Random drift, Wright-Fisher sampling\>\"", 
                  "\"\<Wright-Fisher sampling\>\"", "None"},
                {"\"\<Wright-Fisher sampling\>\"", 
                  "\"\<Wright-Fisher sampling\>\"", "None"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)]}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Further editing by hand", "Subsubsection"],

Cell[BoxData[
    \(MasterIndexMatrixRaw = Sort[Union[ztl]] // MatrixForm\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generating the index", "Section",
  CellTags->"Generating the index"],

Cell["\<\
This section generates a full index from the MasterIndexMatrix, \
which is defined at the end of the notebook.\
\>", "Text"],

Cell[CellGroupData[{

Cell["The index", "Subsubsection"],

Cell["\<\
To change or add to the index:
\t- Edit MasterIndexMatrix (at the end of this notebook) as necessary
\t- Evaluate Initialisation 
\t- Scan[MakeIndexEntry,ProcessIndexMatrix[MasterIndexMatrix]];
\t- Paste the output into \
Multilocus:Documentation:English:BrowserIndex.nb\
\>", "Text"],

Cell[BoxData[
    \(\(Scan[MakeIndexEntry, 
        ProcessIndexMatrix[MasterIndexMatrix]];\)\)], "Input"],

Cell[TextData[{
  "|.",
  ",",
  " ReplaceAllSpecial",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"|."],

Cell[TextData[{
  "\\\\",
  ",",
  " bugs with",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Repeated \\\\"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\\\\"],

Cell[TextData[{
  "<>",
  ",",
  " Expectation",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Expectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"<>"],

Cell[TextData[{
  "||.",
  ",",
  " ReplaceRepeatedSpecial",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"||."],

Cell[TextData[{
  "AddAncestors",
  ",",
  " to ancestral graphs",
  ", ",
  ButtonBox["Ancestors & descendants",
    ButtonData:>{"Ancestors & descendants", "AddAncestors"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddAncestors"],

Cell[TextData[{
  "AddCoalescentLineage",
  ",",
  " to ancestral graph",
  ", ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "AddCoalescentLineage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddCoalescentLineage"],

Cell[TextData[{
  "AddDescendants",
  ",",
  " to ancestral graphs",
  ", ",
  ButtonBox["Ancestors & descendants",
    ButtonData:>{"Ancestors & descendants", "AddDescendants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddDescendants"],

Cell[TextData[{
  "AddGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddGenealogy"],

Cell[TextData[{
  "Additive models",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "additive models"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive models"],

Cell[TextData[{
  "Additive selection",
  ",",
  " defining fitnesses",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive selection"],

Cell[TextData[{
  " defining rules",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Defining rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new D",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "New D"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "New mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " scaled D",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Scaled D"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive selection"],

Cell[TextData[{
  "AddMutation",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddMutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddMutation"],

Cell[TextData[{
  "AddNode",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddNode"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddNode"],

Cell[TextData[{
  "AddRecombinantLineages",
  ",",
  " to ancestral graph",
  ", ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "AddRecombinantLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddRecombinantLineages"],

Cell[TextData[{
  "AddTag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "AddTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddTag"],

Cell[TextData[{
  "AddUp",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "AddUp"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "AddUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddUp"],

Cell[TextData[{
  " multiple sums",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Multiple sums"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over subsets",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Subsets"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Technicalities"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddUp"],

Cell[TextData[{
  "AdmixtureFrequency",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "AdmixtureFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AdmixtureFrequency"],

Cell[TextData[{
  "Admixture models",
  ",",
  " ",
  ButtonBox["Admixture models",
    ButtonData:>{"Admixture models", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview",
    ButtonData:>{"Overview", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Admixture models"],

Cell[TextData[{
  " changing sex",
  ", ",
  ButtonBox["Changing sex",
    ButtonData:>{"Changing sex", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " equilibria",
  ", ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " iteration",
  ", ",
  ButtonBox["Iteration",
    ButtonData:>{"Iteration", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " migration",
  ", ",
  ButtonBox["Migration in admixture models",
    ButtonData:>{"Migration in admixture models", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " recombination",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Admixture models"],

Cell[TextData[{
  "Adults",
  ",",
  " \[GothicCapitalA], \[AliasIndicator]goA\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Adults"],

Cell[TextData[{
  "Allele frequencies",
  ",",
  " definition of fitness",
  ", ",
  ButtonBox["Allele frequencies:fitnesses",
    ButtonData:>{"Allele frequencies:fitnesses", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Allele frequencies"],

Cell[TextData[{
  "AlleleFrequencies",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "AlleleFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencies"],

Cell[TextData[{
  "AlleleFrequencyMean",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyMean"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyMean"],

Cell[TextData[{
  "AlleleFrequencyP",
  ",",
  " \[GothicP], \[AliasIndicator]gop\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyP"],

Cell[TextData[{
  "AlleleFrequencyPermutations",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "AlleleFrequencyPermutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyPermutations"],

Cell[TextData[{
  "AlleleFrequencyPQ",
  ",",
  " \[GothicP]\[GothicQ], \[AliasIndicator]gop\[AliasIndicator]\
\[AliasIndicator]goq\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyPQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyPQ"],

Cell[TextData[{
  "AlleleFrequencyQ",
  ",",
  " \[GothicQ], \[AliasIndicator]goq\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyQ"],

Cell[TextData[{
  "AlleleFrequencyTable",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyTable"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "AlleleFrequencyTable"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyTable"],

Cell[TextData[{
  "AllelicDeviation",
  ",",
  " \[Zeta], \[AliasIndicator]z\[AliasIndicator]",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicDeviation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllelicDeviation"],

Cell[TextData[{
  "AllelicState",
  ",",
  " X",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicState"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllelicState"],

Cell[TextData[{
  "AllEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "AllEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllEvents"],

Cell[TextData[{
  "AllSets",
  ",",
  " ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "AllSets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllSets"],

Cell[TextData[{
  "Ancestors",
  ",",
  " determining",
  ", ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "Ancestors"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestors"],

Cell[TextData[{
  " in ancestral graphs",
  ", ",
  ButtonBox["Ancestors & descendants",
    ButtonData:>{"Ancestors & descendants", "Ancestors"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestors"],

Cell[TextData[{
  "AncestralGraphPattern",
  ",",
  " ",
  ButtonBox["Representing ancestral graphs",
    ButtonData:>{"Representing ancestral graphs", "AncestralGraphPattern"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AncestralGraphPattern"],

Cell[TextData[{
  "Ancestral graphs",
  ",",
  " describing",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestral graphs"],

Cell[TextData[{
  " genealogies in",
  ", ",
  ButtonBox["Extracting genealogies",
    ButtonData:>{"Extracting genealogies", "ExtractGenealogy"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction",
  ", ",
  ButtonBox["Ancestral graph introduction",
    ButtonData:>{"Ancestral graph introduction", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " plotting",
  ", ",
  ButtonBox["Plotting ancestral graphs",
    ButtonData:>{"Plotting ancestral graphs", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " random",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " representing",
  ", ",
  ButtonBox["Representing ancestral graphs",
    ButtonData:>{"Representing ancestral graphs", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestral graphs"],

Cell[TextData[{
  "AncestralLineage",
  ",",
  " ",
  ButtonBox["Representing ancestral graphs",
    ButtonData:>{"Representing ancestral graphs", "AncestralLineage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AncestralLineage"],

Cell[TextData[{
  "AncestralLineagePattern",
  ",",
  " ",
  ButtonBox["Representing ancestral graphs",
    ButtonData:>{"Representing ancestral graphs", "AncestralLineagePattern"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AncestralLineagePattern"],

Cell[TextData[{
  "Ancestry",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Ancestry"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestry"],

Cell[TextData[{
  "Arbitrary sets of loci",
  ",",
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Arbitrary sets of loci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Arbitrary sets of loci"],

Cell[TextData[{
  "Arnold 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Arnold 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Arnold 1996"],

Cell[TextData[{
  "Asmussen and Orive 2000",
  ",",
  " ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["References",
    ButtonData:>{"References", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Asmussen and Orive 2000"],

Cell[TextData[{
  "Asmussen et al. 1987",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Asmussen et al 1987"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Asmussen et al. 1987"],

Cell[TextData[{
  "B",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "B"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"B"],

Cell[TextData[{
  "Baake 2001",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Baake"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["References",
    ButtonData:>{"References", "Baake 2001"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Baake 2001"],

Cell[TextData[{
  "BackgroundStyle",
  ",",
  " option for PlotSegments",
  ", ",
  ButtonBox["Plotting ancestral graphs",
    ButtonData:>{"Plotting ancestral graphs", "BackgroundStyle"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BackgroundStyle"],

Cell[TextData[{
  "Barrier",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", "Barrier"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barrier"],

Cell[TextData[{
  "BarrierStrength",
  ",",
  " ",
  ButtonBox["Describing populations",
    ButtonData:>{"Describing populations", "BarrierStrength"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BarrierStrength"],

Cell[TextData[{
  "Barton 1986",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton 1986"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 1986"],

Cell[TextData[{
  "Barton 1995",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Barton 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 1995"],

Cell[TextData[{
  "Barton 2000",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 2000"],

Cell[TextData[{
  "Barton and Turelli 1991",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Barton and Turelli 1991"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton and Turelli 1991"],

Cell[TextData[{
  "Barton & Gale 1993",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Gale 1993"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Gale 1993"],

Cell[TextData[{
  "Barton & Shpak 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Shpak 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Shpak 1999"],

Cell[TextData[{
  "Barton & Turelli 1991",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Turelli 1991"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Turelli 1991"],

Cell[TextData[{
  "Bennett 1954",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Bennett 1954"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bennett 1954"],

Cell[TextData[{
  "BennettB",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "BennettB"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BennettB"],

Cell[TextData[{
  "BennettC",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "BennettC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BennettC"],

Cell[TextData[{
  "BennettExpansion",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "BennettExpansion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BennettExpansion"],

Cell[TextData[{
  "Biallelic",
  ",",
  " ",
  ButtonBox["Two alleles",
    ButtonData:>{"Two alleles", "Biallelic"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Biallelic"],

Cell[TextData[{
  " selection coefficients",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Biallelic"],

Cell[TextData[{
  "BiallelicMutation",
  ",",
  " ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "BiallelicMutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BiallelicMutation"],

Cell[TextData[{
  " Mutation option",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Mutation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BiallelicMutation"],

Cell[TextData[{
  "Binary integers",
  ",",
  " ",
  ButtonBox["Set combinations",
    ButtonData:>{"Set combinations", "SetOfCombinations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Binary integers"],

Cell[TextData[{
  "Birth",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "Birth"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Birth"],

Cell[TextData[{
  "BirthTime",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "BirthTime"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BirthTime"],

Cell[TextData[{
  "Boundary conditions",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Boundary conditions"],

Cell[TextData[{
  "Box",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Box"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Box"],

Cell[TextData[{
  "Boxes",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Boxes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Boxes"],

Cell[TextData[{
  "Browser categories",
  ",",
  " ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Browser categories"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Browser categories"],

Cell[TextData[{
  "Bugs",
  ",",
  " applying rules",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bugs"],

Cell[TextData[{
  " clashes between packages",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Clashes between packages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " estimating D",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " incompatibilities",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Incompatibilities"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " manipulating notebooks",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Manipulating notebooks"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " multilocus notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Multilocus notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " numerical error with AlleleFrequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Numerical bug"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pasting hyperlinks",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Pasting hyperlinks"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " repeated \\\\",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Repeated \\\\"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " special notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with style sheets",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Style sheets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bugs"],

Cell[TextData[{
  "ChangeContext",
  ",",
  "\[CirclePlus], \[AliasIndicator]c+\[AliasIndicator]",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "ChangeContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ChangeContext"],

Cell[TextData[{
  "ChangeSex",
  ",",
  " ",
  ButtonBox["Changing sex",
    ButtonData:>{"Changing sex", "ChangeSex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ChangeSex"],

Cell[TextData[{
  "ClassToGenotypes",
  ",",
  " ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "ClassToGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClassToGenotypes"],

Cell[TextData[{
  "Cline",
  ",",
  " example of",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cline"],

Cell[TextData[{
  " in allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: spatially varying selection",
    ButtonData:>{"Symmetric stability: spatially varying selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: setting up a symmetric cline",
    ButtonData:>{"Simulating individuals: setting up a symmetric cline", 
      None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: setting up a symmetric cline",
    ButtonData:>{"Symmetric model: setting up a symmetric cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with neutral marker",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", "Cline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cline"],

Cell[TextData[{
  "ClineGradient",
  ",",
  "  for genotype frequencies",
  ", ",
  ButtonBox["ClineGradient: setting up a cline",
    ButtonData:>{"ClineGradient: setting up a cline", "ClineGradient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineGradient"],

Cell[TextData[{
  "ClineWidth",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineWidth"],

Cell[TextData[{
  "  for genotype frequencies",
  ", ",
  ButtonBox["Recursions: setting up a cline",
    ButtonData:>{"Recursions: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineWidth"],

Cell[TextData[{
  "CoalesceLineages",
  ",",
  " ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "CoalesceLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CoalesceLineages"],

Cell[TextData[{
  "CoalescenceDistribution",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", 
      "CoalescenceDistribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CoalescenceDistribution"],

Cell[TextData[{
  "CoalescenceEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "CoalescenceEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CoalescenceEvents"],

Cell[TextData[{
  "Coalescence times",
  ",",
  " random, for ancestral graphs",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", "RandomCoalescenceTimes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Coalescence times"],

Cell[TextData[{
  "CoalescentLineages",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "CoalescentLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CoalescentLineages"],

Cell[TextData[{
  "Coalescing lineages",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "CoalesceLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Coalescing lineages"],

Cell[TextData[{
  "CollapseGenealogy",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "CollapseGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CollapseGenealogy"],

Cell[TextData[{
  "Combinations",
  ",",
  " set of",
  ", ",
  ButtonBox["Set combinations",
    ButtonData:>{"Set combinations", "SetOfCombinations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Combinations"],

Cell[TextData[{
  "Combine",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Combine"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Combine"],

Cell[TextData[{
  "CompareLogL",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "CompareLogL"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CompareLogL"],

Cell[TextData[{
  "Compiled",
  ",",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Compiled"],

Cell[TextData[{
  "Compiling",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Compiling"],

Cell[TextData[{
  "CondenseGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "CondenseGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CondenseGenealogy"],

Cell[TextData[{
  "CondenseMatrix",
  ",",
  " ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", "CondenseMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CondenseMatrix"],

Cell[TextData[{
  "ConfigurationSet",
  ",",
  " ",
  ButtonBox["Set combinations",
    ButtonData:>{"Set combinations", "ConfigurationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConfigurationSet"],

Cell[TextData[{
  "ConstrainedIntervals",
  ",",
  " ",
  ButtonBox["Constrained intervals",
    ButtonData:>{"Constrained intervals", "ConstrainedIntervals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstrainedIntervals"],

Cell[TextData[{
  "ConstructMutateList",
  ",",
  " ",
  ButtonBox["Allele frequencies: mutation",
    ButtonData:>{"Allele frequencies: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: mutation",
    ButtonData:>{"Simulating individuals: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstructMutateList"],

Cell[TextData[{
  "ConstructMutateMatrix",
  ",",
  " ",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "ConstructMutateMatrix"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "ConstructMutateMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstructMutateMatrix"],

Cell[TextData[{
  "ContextComponentQ",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextComponentQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextComponentQ"],

Cell[TextData[{
  "ContextPosition",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextPosition"],

Cell[TextData[{
  "ContextStageQ",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextStageQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextStageQ"],

Cell[TextData[{
  "ContextStructure",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextStructure"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextStructure"],

Cell[TextData[{
  "Continuous populations",
  ",",
  " estimating covariance",
  ", ",
  ButtonBox["Estimating the covariance",
    ButtonData:>{"Estimating the covariance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Continuous populations"],

Cell[TextData[{
  " example",
  ", ",
  ButtonBox["An example",
    ButtonData:>{"An example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " implementation",
  ", ",
  ButtonBox["Implementation",
    ButtonData:>{"Implementation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving results",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "Saving results"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " the model",
  ", ",
  ButtonBox["The model",
    ButtonData:>{"The model", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Continuous populations"],

Cell[TextData[{
  "ContinuumVariables",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "ContinuumVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContinuumVariables"],

Cell[TextData[{
  "ConvertData",
  ",",
  " ",
  ButtonBox["Converting a dataset",
    ButtonData:>{"Converting a dataset", "ConvertData"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConvertData"],

Cell[TextData[{
  "ConvertHyperlinkToAddOnsLink",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "ConvertHyperlinkToAddOnsLink"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConvertHyperlinkToAddOnsLink"],

Cell[TextData[{
  "Converting",
  ",",
  " between representations",
  ", ",
  ButtonBox["Allele frequencies: converting",
    ButtonData:>{"Allele frequencies: converting", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Converting"],

Cell[TextData[{
  "CountHeterozygotes",
  ",",
  " ",
  ButtonBox["Recursions:manipulation",
    ButtonData:>{"Recursions:manipulation", "CountHeterozygotes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CountHeterozygotes"],

Cell[TextData[{
  "Covariance",
  ",",
  " in continuous populations",
  ", ",
  ButtonBox["Estimating the covariance",
    ButtonData:>{"Estimating the covariance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Covariance"],

Cell[TextData[{
  "CovarianceMidPoints",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "CovarianceMidPoints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CovarianceMidPoints"],

Cell[TextData[{
  "Crow and Kimura 1970",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Crow and Kimura 1970"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Crow and Kimura 1970"],

Cell[TextData[{
  "Cumulant",
  ",",
  " ",
  ButtonBox["Moments and cumulants",
    ButtonData:>{"Moments and cumulants", "Cumulant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cumulant"],

Cell[TextData[{
  "CumulantDisequilibrium",
  ",",
  " \[GothicK], \[AliasIndicator]gok\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "CumulantDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantDisequilibrium"],

Cell[TextData[{
  "CumulantEquilibrium",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "CumulantEquilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantEquilibrium"],

Cell[TextData[{
  "CumulantPopulationDisequilibrium",
  ",",
  " \[GothicCapitalK], \[AliasIndicator]goK\[AliasIndicator]",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantPopulationDisequilibrium"],

Cell[TextData[{
  "CumulantReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "CumulantReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantReduced"],

Cell[TextData[{
  "Cumulants",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "7.2"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Cumulant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cumulants"],

Cell[TextData[{
  "Cytoplasmic inheritance",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cytoplasmic inheritance"],

Cell[TextData[{
  " and migration",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Cytonuclear associations"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " examples of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cytoplasmic inheritance"],

Cell[TextData[{
  "CytoplasmicLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CytoplasmicLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CytoplasmicLoci"],

Cell[TextData[{
  "dAlleleFrequencyPermutations",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "dAlleleFrequencyPermutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"dAlleleFrequencyPermutations"],

Cell[TextData[{
  "Data",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Data"],

Cell[TextData[{
  " missing",
  ", ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Missing data"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notation for",
  ", ",
  ButtonBox["Notation for genetic data",
    ButtonData:>{"Notation for genetic data", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Data"],

Cell[TextData[{
  "Datasets",
  ",",
  " defining",
  ", ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Datasets"],

Cell[TextData[{
  "Dawson 2000",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Bennett"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["References",
    ButtonData:>{"References", "Dawson 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dawson 2000"],

Cell[TextData[{
  "Death",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "Death"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Death"],

Cell[TextData[{
  "DeathTime",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "DeathTime"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeathTime"],

Cell[TextData[{
  "DefineContext",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "DefineContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DefineContext"],

Cell[TextData[{
  "DegreesOfFreedom",
  ",",
  " ",
  ButtonBox["Degrees of freedom",
    ButtonData:>{"Degrees of freedom", "DegreesOfFreedom"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DegreesOfFreedom"],

Cell[TextData[{
  "DeletedMutations",
  ",",
  " ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", "DeletedMutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeletedMutations"],

Cell[TextData[{
  "DeleteGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "DeleteGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeleteGenealogy"],

Cell[TextData[{
  "DeleteNullLineages",
  ",",
  " option for RandomGenealogy",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", "DeleteNullLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeleteNullLineages"],

Cell[TextData[{
  " option for RecombineLineage",
  ", ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "DeleteNullLineages"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeleteNullLineages"],

Cell[TextData[{
  "Deme",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Deme"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Deme"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Deme"],

Cell[TextData[{
  "DemeSize",
  ",",
  " compiling",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "Deme size (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DemeSize"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for MigrateExact",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DemeSize"],

Cell[TextData[{
  "Dempster et al 1977",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Dempster et al 1977"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dempster et al 1977"],

Cell[TextData[{
  "Density",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Density"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Density"],

Cell[TextData[{
  "Descendants",
  ",",
  " ",
  ButtonBox["Ancestors and descendants",
    ButtonData:>{"Ancestors and descendants", "Descendants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Descendants"],

Cell[TextData[{
  " determining",
  ", ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "Descendants"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in ancestral graphs",
  ", ",
  ButtonBox["Ancestors & descendants",
    ButtonData:>{"Ancestors & descendants", "Descendants"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Descendants"],

Cell[TextData[{
  "Dicytonuclear associations",
  ",",
  " ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dicytonuclear associations"],

Cell[TextData[{
  "Diploid",
  ",",
  " option for MomentFromG",
  ", ",
  ButtonBox["Moments from genotype frequencies",
    ButtonData:>{"Moments from genotype frequencies", "Diploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Diploid"],

Cell[TextData[{
  "DiploidConstraints",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidConstraints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidConstraints"],

Cell[TextData[{
  "DiploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidFrequencies"],

Cell[TextData[{
  "DiploidGenotypeFrequency",
  ",",
  " ",
  ButtonBox["Genotype frequencies from moments",
    ButtonData:>{"Genotype frequencies from moments", 
      "DiploidGenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequency"],

Cell[TextData[{
  "DiploidGenotypeFrequencyList",
  ",",
  " ",
  ButtonBox["Fast calculations",
    ButtonData:>{"Fast calculations", "DiploidGenotypeFrequencyList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyList"],

Cell[TextData[{
  "DiploidGenotypeFrequencyReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyReduced"],

Cell[TextData[{
  "DiploidGenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyTable"],

Cell[TextData[{
  "DiploidIndividuals",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidIndividuals"],

Cell[TextData[{
  "DiploidPhenotype",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidPhenotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidPhenotype"],

Cell[TextData[{
  "DiploidPsi",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidPsi"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "DiploidPsi"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidPsi"],

Cell[TextData[{
  "DiploidRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidRepresentations"],

Cell[TextData[{
  "DiploidSource",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidSource"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "DiploidSource"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidSource"],

Cell[TextData[{
  "DiploidSubsets",
  ",",
  " ",
  ButtonBox["Subsets of loci",
    ButtonData:>{"Subsets of loci", "DiploidSubsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidSubsets"],

Cell[TextData[{
  "DiploidTypes",
  ",",
  " ",
  ButtonBox["Listing genotypes",
    ButtonData:>{"Listing genotypes", "DiploidTypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidTypes"],

Cell[TextData[{
  "Disequilibrium",
  ",",
  " Baake's measure",
  ", ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Baake"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Disequilibrium"],

Cell[TextData[{
  " Bennett's principal components",
  ", ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Bennett"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " \[GothicCapitalD], \[AliasIndicator]\[GothicCapitalD]\[AliasIndicator]",
  ", ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Disequilibrium"],

Cell[TextData[{
  "DisequilibriumMean",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumMean"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumMean"],

Cell[TextData[{
  "DisequilibriumTable",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumTable"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumTable"],

Cell[TextData[{
  "Dispersal",
  ",",
  " in continuum simulations",
  ", ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dispersal"],

Cell[TextData[{
  "DistanceSquared",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "DistanceSquared"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DistanceSquared"],

Cell[TextData[{
  "Distribution",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Distribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Distribution"],

Cell[TextData[{
  "DivideZero",
  ",",
  " ",
  ButtonBox["DivideZero",
    ButtonData:>{"DivideZero", "DivideZero"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DivideZero"],

Cell[TextData[{
  "DoReplicates",
  ",",
  " ",
  ButtonBox["Analysing replicate samples",
    ButtonData:>{"Analysing replicate samples", "DoReplicates"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoReplicates"],

Cell[TextData[{
  "DoubleCline",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a symmetric cline",
    ButtonData:>{"Allele frequencies: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoubleCline"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: setting up a symmetric cline",
    ButtonData:>{"Simulating individuals: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a symmetric cline",
    ButtonData:>{"Symmetric model: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoubleCline"],

Cell[TextData[{
  "DrawSamples",
  ",",
  " ",
  ButtonBox["Setting up replicates",
    ButtonData:>{"Setting up replicates", "DrawSamples"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DrawSamples"],

Cell[TextData[{
  "DropOptions",
  ",",
  " ",
  ButtonBox["Manipulating options",
    ButtonData:>{"Manipulating options", "DropOptions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DropOptions"],

Cell[TextData[{
  "Edwards 1972",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Edwards 1972"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Edwards 1972"],

Cell[TextData[{
  "EmptySets",
  ",",
  "option for PartitionSet",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "EmptySets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EmptySets"],

Cell[TextData[{
  "Epistasis",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Epistasis"],

Cell[TextData[{
  "EquivalentSexes",
  ",",
  " obsolete form of SymmetricSexes",
  ", ",
  ButtonBox["Symmetric sexes",
    ButtonData:>{"Symmetric sexes", "SymmetricSexes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EquivalentSexes"],

Cell[TextData[{
  "ErrorBound",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "ErrorBound"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ErrorBound"],

Cell[TextData[{
  "EstimateFamilyMoments",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "EstimateFamilyMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EstimateFamilyMoments"],

Cell[TextData[{
  "EstimateMoments",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "EstimateMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EstimateMoments"],

Cell[TextData[{
  "Estimating D",
  ",",
  " admixture models",
  ", ",
  ButtonBox["Admixture models",
    ButtonData:>{"Admixture models", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Estimating D"],

Cell[TextData[{
  " alternative methods",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Log-linear models"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction",
  ", ",
  ButtonBox["Introduction to estimating D",
    ButtonData:>{"Introduction to estimating D", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " maximum entropy",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Maximum entropy"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " maximum likelihood, example of",
  ", ",
  ButtonBox["MLE example",
    ButtonData:>{"MLE example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Metropolis random walk",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MLE, cumulants",
  ", ",
  ButtonBox["Finding the MLE",
    ButtonData:>{"Finding the MLE", "Cumulant"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " moments, families",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "Extension to families"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " naive MLE",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Naive MLE"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " obsolete",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pairs of loci",
  ", ",
  ButtonBox["Pairs of loci",
    ButtonData:>{"Pairs of loci", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pairs of loci, example of",
  ", ",
  ButtonBox["Pairwise example",
    ButtonData:>{"Pairwise example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " random sampling, example of",
  ", ",
  ButtonBox["Sampling example",
    ButtonData:>{"Sampling example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " summary",
  ", ",
  ButtonBox["Summary",
    ButtonData:>{"Summary", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " varying divergence",
  ", ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "Varying divergence"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Estimating D"],

Cell[TextData[{
  "ExactEigenvalues",
  ",",
  " ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "ExactEigenvalues"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactEigenvalues"],

Cell[TextData[{
  "ExactIntersection",
  ",",
  " \[Wedge], \[AliasIndicator]^\[AliasIndicator]",
  ", ",
  ButtonBox["ExactIntersection",
    ButtonData:>{"ExactIntersection", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactIntersection"],

Cell[TextData[{
  "ExactProbability",
  ",",
  " ",
  ButtonBox["Exact probability",
    ButtonData:>{"Exact probability", "ExactProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactProbability"],

Cell[TextData[{
  "Expectation",
  ",",
  " <>",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Expectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Expectation"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Expectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population, \[LeftDoubleBracketingBar] \[RightDoubleBracketingBar], \
\[AliasIndicator]l||\[AliasIndicator] \[AliasIndicator]r||\[AliasIndicator]",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Expectation"],

Cell[TextData[{
  "ExponentialF",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExponentialF"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "ExponentialF"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExponentialF"],

Cell[TextData[{
  "ExtantIndividuals",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "ExtantIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtantIndividuals"],

Cell[TextData[{
  "ExtractContexts",
  ",",
  " \[Chi], \[AliasIndicator]c\[AliasIndicator]",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractContexts"],

Cell[TextData[{
  "ExtractExtant",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "ExtractExtant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractExtant"],

Cell[TextData[{
  "ExtractGenealogy",
  ",",
  " ",
  ButtonBox["Extracting genealogies",
    ButtonData:>{"Extracting genealogies", "ExtractGenealogy"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "ExtractGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractGenealogy"],

Cell[TextData[{
  "ExtractGenes",
  ",",
  " \[Gamma], \[AliasIndicator]g\[AliasIndicator]",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractGenes"],

Cell[TextData[{
  "ExtractInformation",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "ExtractInformation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractInformation"],

Cell[TextData[{
  " from ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "ExtractInformation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractInformation"],

Cell[TextData[{
  "ExtractLabel",
  ",",
  " from ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "ExtractLabel"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractLabel"],

Cell[TextData[{
  "ExtractLineagesEndingAtT",
  ",",
  " from ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "ExtractLineagesEndingAtT"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractLineagesEndingAtT"],

Cell[TextData[{
  "ExtractLineagesStartingAtT",
  ",",
  " from ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "ExtractLineagesStartingAtT"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractLineagesStartingAtT"],

Cell[TextData[{
  "ExtractRepeat",
  ",",
  " ",
  ButtonBox["Repeated elements",
    ButtonData:>{"Repeated elements", "ExtractRepeat"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractRepeat"],

Cell[TextData[{
  "ExtractSubMatrix",
  ",",
  " ",
  ButtonBox["Extracting submatrices",
    ButtonData:>{"Extracting submatrices", "ExtractSubMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractSubMatrix"],

Cell[TextData[{
  "FamilyAlleleFrequencyEstimate",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyAlleleFrequencyEstimate"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyAlleleFrequencyEstimate"],

Cell[TextData[{
  "FamilyEffects",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyEffects"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyEffects"],

Cell[TextData[{
  "FamilyM",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyM"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyM"],

Cell[TextData[{
  "FamilyProbability",
  ",",
  " ",
  ButtonBox["Probabilities",
    ButtonData:>{"Probabilities", "FamilyProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyProbability"],

Cell[TextData[{
  "Family structure",
  ",",
  " set of all",
  ", ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "NewS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Family structure"],

Cell[TextData[{
  "Fecundity",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Fecundity"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fecundity"],

Cell[TextData[{
  "FindHyperlinks",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "FindHyperlinks"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindHyperlinks"],

Cell[TextData[{
  "FindIndexTag",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "FindIndexTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindIndexTag"],

Cell[TextData[{
  "FindMLE",
  ",",
  " ",
  ButtonBox["Finding the MLE",
    ButtonData:>{"Finding the MLE", "FindMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindMLE"],

Cell[TextData[{
  "FindNode",
  ",",
  " ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", "FindNode"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindNode"],

Cell[TextData[{
  "FindPosition",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "FindPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindPosition"],

Cell[TextData[{
  "FindTags",
  ",",
  " ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "FindTags"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindTags"],

Cell[TextData[{
  "Fitness",
  ",",
  " definition for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:fitnesses",
    ButtonData:>{"Allele frequencies:fitnesses", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fitness"],

Cell[TextData[{
  " in individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " problems redefining",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Redefining fitness"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fitness"],

Cell[TextData[{
  "FitnessSet",
  ",",
  " \[DoubleStruckCapitalW], \[AliasIndicator]dsW\[AliasIndicator]",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "FitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessSet"],

Cell[TextData[{
  "FitnessTable",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessTable"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessTable"],

Cell[TextData[{
  "FixedEnds",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FixedEnds"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for MigrateExact",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FixedEnds"],

Cell[TextData[{
  "Flatten",
  ",",
  " ",
  ButtonBox["Flattening lists at specific levels",
    ButtonData:>{"Flattening lists at specific levels", "Flatten"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Flatten"],

Cell[TextData[{
  "FlattenList",
  ",",
  " ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "FlattenList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FlattenList"],

Cell[TextData[{
  " PatternFree",
  ", ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "PatternFree"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FlattenList"],

Cell[TextData[{
  "FourierNormalised",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "FourierNormalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FourierNormalised"],

Cell[TextData[{
  "FourierNormalisedTable",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "FourierNormalisedTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FourierNormalisedTable"],

Cell[TextData[{
  "FrequencyRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "FrequencyRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FrequencyRepresentations"],

Cell[TextData[{
  "FromBaake",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "FromBaake"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FromBaake"],

Cell[TextData[{
  "FromBennett",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "FromBennett"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FromBennett"],

Cell[TextData[{
  "FromBennettExpression",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "FromBennettExpression"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FromBennettExpression"],

Cell[TextData[{
  "FullContext",
  ",",
  " ",
  ButtonBox["Abbreviating contexts",
    ButtonData:>{"Abbreviating contexts", "FullContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullContext"],

Cell[TextData[{
  "FullGenotypeFrequencyReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullGenotypeFrequencyReduced"],

Cell[TextData[{
  "FullGenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullGenotypeFrequencyTable"],

Cell[TextData[{
  "FullOutput",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "FullOutput"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullOutput"],

Cell[TextData[{
  "Function",
  ",",
  " ",
  ButtonBox["Marginal tables",
    ButtonData:>{"Marginal tables", "Function"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Function"],

Cell[TextData[{
  "Gametes",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "Gametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gametes"],

Cell[TextData[{
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new, \!\(\(\[GothicCapitalG]\^*\)\), \
\[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, \[GothicCapitalG]new",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " \[GothicCapitalG], \[AliasIndicator]goG\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gametes"],

Cell[TextData[{
  "GameteTable",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "GameteTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GameteTable"],

Cell[TextData[{
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "GameteTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "GameteTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GameteTable"],

Cell[TextData[{
  "GaussianLogLikelihood",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "GaussianLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GaussianLogLikelihood"],

Cell[TextData[{
  "GaussianMLE",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "GaussianMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GaussianMLE"],

Cell[TextData[{
  "Genealogies",
  ",",
  " exact probability",
  ", ",
  ButtonBox["Exact probability",
    ButtonData:>{"Exact probability", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genealogies"],

Cell[TextData[{
  " extracting from ancestral graphs",
  ", ",
  ButtonBox["Extracting genealogies",
    ButtonData:>{"Extracting genealogies", "ExtractGenealogy"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " family structure",
  ", ",
  ButtonBox["Family structure",
    ButtonData:>{"Family structure", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " generating functions",
  ", ",
  ButtonBox["Deriving recursions for the MGF",
    ButtonData:>{"Deriving recursions for the MGF", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " probability of",
  ", ",
  ButtonBox["Deriving the probability",
    ButtonData:>{"Deriving the probability", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sampling",
  ", ",
  ButtonBox["Sampling genealogies",
    ButtonData:>{"Sampling genealogies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genealogies"],

Cell[TextData[{
  "Genealogy",
  ",",
  " rooting",
  ", ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", "SwapStates"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "RootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genealogy"],

Cell[TextData[{
  "GenealogyToMatrix",
  ",",
  " ",
  ButtonBox["Describing mutation",
    ButtonData:>{"Describing mutation", "GenealogyToMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenealogyToMatrix"],

Cell[TextData[{
  "GeneralizedTransform",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "GeneralizedTransform"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GeneralizedTransform"],

Cell[TextData[{
  "Generating functions",
  ",",
  " examples",
  ", ",
  ButtonBox["Examples of the MGF",
    ButtonData:>{"Examples of the MGF", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Generating functions"],

Cell[TextData[{
  " for cumulants",
  ", ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "GeneralizedTransform"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genealogies",
  ", ",
  ButtonBox["Deriving recursions for the MGF",
    ButtonData:>{"Deriving recursions for the MGF", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Generating functions"],

Cell[TextData[{
  "Genes and contexts",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Genes and contexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genes and contexts"],

Cell[TextData[{
  "Genome",
  ",",
  " set of all positions in, \[DoubleStruckCapitalG], \[AliasIndicator]dsG\
\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genome"],

Cell[TextData[{
  "Genotype",
  ",",
  " in continuum simulations",
  ", ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Genotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype"],

Cell[TextData[{
  " observable",
  ", ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for InitialiseContinuum",
  ", ",
  ButtonBox["Initialisation",
    ButtonData:>{"Initialisation", "Genotype"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype"],

Cell[TextData[{
  "Genotype frequencies",
  ",",
  " recursions",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype frequencies"],

Cell[TextData[{
  "GenotypeFrequencyArguments",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "GenotypeFrequencyArguments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyArguments"],

Cell[TextData[{
  "GenotypeFrequencyConvert",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "GenotypeFrequencyConvert"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyConvert"],

Cell[TextData[{
  "GenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyTable"],

Cell[TextData[{
  "GenotypePosition",
  ",",
  " ",
  ButtonBox["Recursions:manipulation",
    ButtonData:>{"Recursions:manipulation", "GenotypePosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypePosition"],

Cell[TextData[{
  "GenotypeProbability",
  ",",
  " ",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "GenotypeProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeProbability"],

Cell[TextData[{
  " segregation ratio",
  ", ",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeProbability"],

Cell[TextData[{
  "Genotypes",
  ",",
  " notation for",
  ", ",
  ButtonBox["Notation",
    ButtonData:>{"Notation", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotypes"],

Cell[TextData[{
  "GlobalContinuumVariables",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "GlobalContinuumVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GlobalContinuumVariables"],

Cell[TextData[{
  "Gnew",
  ",",
  " \!\(\(\[GothicCapitalG]\^*\)\), \[AliasIndicator]goG\[AliasIndicator]\
\[ControlKey]^*, new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gnew"],

Cell[TextData[{
  "Goodman et al 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Goodman et al 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Goodman et al 1999"],

Cell[TextData[{
  "Graphs",
  ",",
  " ancestral",
  ", ",
  ButtonBox["Ancestral graph introduction",
    ButtonData:>{"Ancestral graph introduction", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Graphs"],

Cell[TextData[{
  "Griffiths-Tavare",
  ",",
  " ",
  ButtonBox["Exact algorithm",
    ButtonData:>{"Exact algorithm", "GriffithsTavare"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Griffiths-Tavare algorithm",
    ButtonData:>{"Griffiths-Tavare algorithm", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Griffiths-Tavare"],

Cell[TextData[{
  " stochastic algorithm",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "MonteCarloGriffithsTavare"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "Stochastic GT algorithm"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stochastic, comparison with MonteCarloProbability",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", 
      "Comparison with MonteCarloProbability"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stochastic example",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "Small example"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Griffiths-Tavare"],

Cell[TextData[{
  "Guiasu & Shenitzer 1985",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Guiasu & Shenitzer 1985"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Guiasu & Shenitzer 1985"],

Cell[TextData[{
  "HaploidConstraints",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "HaploidConstraints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidConstraints"],

Cell[TextData[{
  "HaploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidFrequencies"],

Cell[TextData[{
  "HaploidGenotypeFrequency",
  ",",
  " ",
  ButtonBox["Genotype frequencies from moments",
    ButtonData:>{"Genotype frequencies from moments", 
      "HaploidGenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidGenotypeFrequency"],

Cell[TextData[{
  "HaploidIndividuals",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidIndividuals"],

Cell[TextData[{
  "HaploidRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidRepresentations"],

Cell[TextData[{
  "Haploids",
  ",",
  " selection on",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Haploids"],

Cell[TextData[{
  "HaploidSource",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "HaploidSource"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "HaploidSource"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidSource"],

Cell[TextData[{
  "HaploidSubsets",
  ",",
  " ",
  ButtonBox["Subsets of loci",
    ButtonData:>{"Subsets of loci", "HaploidSubsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidSubsets"],

Cell[TextData[{
  "HaploidTypes",
  ",",
  " ",
  ButtonBox["Listing genotypes",
    ButtonData:>{"Listing genotypes", "HaploidTypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidTypes"],

Cell[TextData[{
  "Help browser",
  ",",
  " setting up new files",
  ", ",
  ButtonBox["Setting up new help files",
    ButtonData:>{"Setting up new help files", "Setting up new help files"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help browser"],

Cell[TextData[{
  "Help Browser",
  ",",
  " ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "MasterIndexHeading"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help Browser"],

Cell[TextData[{
  " setting up hyperlinks",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up links"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help Browser"],

Cell[TextData[{
  "Hermaphrodites",
  ",",
  " \[GothicCapitalH], \[AliasIndicator]goH\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hermaphrodites"],

Cell[TextData[{
  "HeterozygoteB",
  ",",
  " ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "HeterozygoteB"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HeterozygoteB"],

Cell[TextData[{
  "Hill 1974a",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974a"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974a"],

Cell[TextData[{
  "Hill 1974b",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974b"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974b"],

Cell[TextData[{
  "Hill 1974c",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974c"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974c"],

Cell[TextData[{
  "Hudson 1990",
  ",",
  " ",
  ButtonBox["Ancestral graph introduction",
    ButtonData:>{"Ancestral graph introduction", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Ancestral graph references",
    ButtonData:>{"Ancestral graph references", "Hudson 1990"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hudson 1990"],

Cell[TextData[{
  "Hypergeometric model",
  ",",
  " ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hypergeometric model"],

Cell[TextData[{
  "Hyperlinks",
  ",",
  " bugs in pasting",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Pasting hyperlinks"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hyperlinks"],

Cell[TextData[{
  " saving",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Saving the links"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " setting up",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up links"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " to cell tags",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Setting up links to a list of tags"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hyperlinks"],

Cell[TextData[{
  "IncidenceMatrix",
  ",",
  " ",
  ButtonBox["Ordered genealogies",
    ButtonData:>{"Ordered genealogies", "IncidenceMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IncidenceMatrix"],

Cell[TextData[{
  "Index",
  ",",
  " setting up",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up Master Index"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Index"],

Cell[TextData[{
  "Individual",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Individual"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Individual"],

Cell[TextData[{
  "IndividualContinuumVariables",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "IndividualContinuumVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IndividualContinuumVariables"],

Cell[TextData[{
  "IndividualRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "IndividualRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IndividualRepresentations"],

Cell[TextData[{
  "Individuals",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Individuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Individuals"],

Cell[TextData[{
  "Infinite sites mutation",
  ",",
  " ",
  ButtonBox["Describing mutation",
    ButtonData:>{"Describing mutation", "None"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Infinite sites mutation"],

Cell[TextData[{
  "InformationFunction",
  ",",
  " option for CoalesceLineages",
  ", ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "InformationFunctionC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InformationFunction"],

Cell[TextData[{
  " option for ExtractGenealogy",
  ", ",
  ButtonBox["Extracting genealogies",
    ButtonData:>{"Extracting genealogies", "InformationFunction"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for RecombineLineage",
  ", ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "InformationFunctionR"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InformationFunction"],

Cell[TextData[{
  "InitialiseContinuum",
  ",",
  " ",
  ButtonBox["Initialisation",
    ButtonData:>{"Initialisation", "InitialiseContinuum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseContinuum"],

Cell[TextData[{
  "InitialiseCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "InitialiseCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseCovariance"],

Cell[TextData[{
  "InitialiseDemes",
  ",",
  " ",
  ButtonBox["Describing the population",
    ButtonData:>{"Describing the population", "InitialiseDemes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Setting up a cline",
    ButtonData:>{"Setting up a cline", "InitialiseDemes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseDemes"],

Cell[TextData[{
  "InitialStep",
  ",",
  " ",
  ButtonBox["Initial step size",
    ButtonData:>{"Initial step size", "InitialStep"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialStep"],

Cell[TextData[{
  "InitialStepReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "InitialStepReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialStepReduced"],

Cell[TextData[{
  "InternalNodes",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "InternalNodes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InternalNodes"],

Cell[TextData[{
  "IntervalCombine",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalCombine"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IntervalCombine"],

Cell[TextData[{
  "IntervalPosition",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IntervalPosition"],

Cell[TextData[{
  "InverseFourierNormalised",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "InverseFourierNormalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InverseFourierNormalised"],

Cell[TextData[{
  "InverseFourierNormalisedTable",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "InverseFourierNormalisedTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InverseFourierNormalisedTable"],

Cell[TextData[{
  "Island model",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Island model"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Island model"],

Cell[TextData[{
  "IterateContinuum",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "IterateContinuum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateContinuum"],

Cell[TextData[{
  "IterateExact",
  ",",
  " example",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateExact"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for allele frequency clines",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "IterateExact"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequency clines",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateExact"],

Cell[TextData[{
  "Join",
  ",",
  " ",
  ButtonBox["Join",
    ButtonData:>{"Join", "Join"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "Join"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Join"],

Cell[TextData[{
  "Junctions",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "Junctions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Junctions"],

Cell[TextData[{
  "JunctionStyle",
  ",",
  " option for PlotSegments",
  ", ",
  ButtonBox["Plotting ancestral graphs",
    ButtonData:>{"Plotting ancestral graphs", "JunctionStyle"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"JunctionStyle"],

Cell[TextData[{
  "Juveniles",
  ",",
  " \[GothicCapitalJ], \[AliasIndicator]goJ\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Juveniles"],

Cell[TextData[{
  "Kirkpatrick and Barton 1997",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick and Barton 1997"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick and Barton 1997"],

Cell[TextData[{
  "Kirkpatrick and Servedio 1998",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick and Servedio 1998"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick and Servedio 1998"],

Cell[TextData[{
  "Kirkpatrick et al.",
  ",",
  " ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick et al."},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al."],

Cell[TextData[{
  " arbitrary sets of loci",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Arbitrary sets of loci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Expectation",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Expectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " migration",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " mutation",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " permutations in defining coefficients",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Permutations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Permutations"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " phenotypes",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " position",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Contexts and positions"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "position"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " QLE",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " quasi-linkage equilibrium",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " random drift",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Random drift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference values",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Describing genotypes and populations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Reference values"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " relation with",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Multilocus MS"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " scripts and faces",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Scripts and faces"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " selection",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sets in subscripts",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets in subscripts"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sets of loci",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets of loci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stabilising selection",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", 
      "Natural selection on an additive polygenic trait"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages and contexts",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Stages and contexts"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " transmission rules",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Transmission"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Transmission rules"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al."],

Cell[TextData[{
  "Kirkpatrick et al. 1983",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Kirkpatrick et al 1983"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al. 1983"],

Cell[TextData[{
  "Kruuk 1997",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Kruuk 1997"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kruuk 1997"],

Cell[TextData[{
  "LeafEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "LeafEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LeafEvents"],

Cell[TextData[{
  "LeafLabels",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "LeafLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LeafLabels"],

Cell[TextData[{
  "LeafOffset",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "LeafOffset"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LeafOffset"],

Cell[TextData[{
  "Leaves",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "Leaves"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Leaves"],

Cell[TextData[{
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "Leaves"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Leaves"],

Cell[TextData[{
  "Life cycle",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Life cycle"],

Cell[TextData[{
  " adults",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete",
  ", ",
  ButtonBox["Complete life cycle",
    ButtonData:>{"Complete life cycle", "Complete rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " hermaphrodites",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " juveniles",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages in",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with cytoplasmic inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with sex linkage",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " zygotes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Life cycle"],

Cell[TextData[{
  "LineagesPresent",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "LineagesPresent"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LineagesPresent"],

Cell[TextData[{
  "Li & Nei 1974",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Li & Nei 1974"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Li & Nei 1974"],

Cell[TextData[{
  "Linkage",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Linkage",
    ButtonData:>{"Linkage", "Linkage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage"],

Cell[TextData[{
  " in numerical models",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Linkage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage"],

Cell[TextData[{
  "Linkage disequilibrium",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage disequilibrium"],

Cell[TextData[{
  "LinkedRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "LinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LinkedRecombination"],

Cell[TextData[{
  "ListToGenealogy",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "ListToGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ListToGenealogy"],

Cell[TextData[{
  "ListToMatrix",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "ListToMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ListToMatrix"],

Cell[TextData[{
  "Location",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Location"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Location"],

Cell[TextData[{
  "Locations",
  ",",
  " ",
  ButtonBox["Locations",
    ButtonData:>{"Locations", "Locations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Locations"],

Cell[TextData[{
  "LocusNames",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "LocusNames"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LocusNames"],

Cell[TextData[{
  "LogLikelihoodDisequilibrium",
  ",",
  " ",
  ButtonBox["Likelihood",
    ButtonData:>{"Likelihood", "LogLikelihoodDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodDisequilibrium"],

Cell[TextData[{
  "LogLikelihoodDisequilibriumReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "LogLikelihoodDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodDisequilibriumReduced"],

Cell[TextData[{
  "LogLikelihoodTest",
  ",",
  " ",
  ButtonBox["Likelihood tests",
    ButtonData:>{"Likelihood tests", "LogLikelihoodTest"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodTest"],

Cell[TextData[{
  "Log-linear models",
  ",",
  " ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Log-linear models"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Log-linear models"],

Cell[TextData[{
  "Long et al 1995",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Long et al 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Long et al 1995"],

Cell[TextData[{
  "LowerOffDiagonal",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "LowerOffDiagonal"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LowerOffDiagonal"],

Cell[TextData[{
  "MacCallum 1994",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "MacCallum 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MacCallum 1994"],

Cell[TextData[{
  "MacCallum et al. 1998",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "MacCallum et al 1998"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MacCallum et al. 1998"],

Cell[TextData[{
  "MakeCline",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeCline"],

Cell[TextData[{
  "  for genotype frequencies",
  ", ",
  ButtonBox["Recursions: setting up a cline",
    ButtonData:>{"Recursions: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeCline"],

Cell[TextData[{
  "MakeDiploid",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDiploid"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDiploid"],

Cell[TextData[{
  "MakeDistanceList",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "MakeDistanceList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDistanceList"],

Cell[TextData[{
  "MakeDistances",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "MakeDistances"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDistances"],

Cell[TextData[{
  "MakeFitnessSet",
  ",",
  " ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "MakeFitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeFitnessSet"],

Cell[TextData[{
  " with multiple alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeFitnessSet"],

Cell[TextData[{
  "MakeGenealogy",
  ",",
  " ",
  ButtonBox["Making a genealogy",
    ButtonData:>{"Making a genealogy", "MakeGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeGenealogy"],

Cell[TextData[{
  "MakeGenealogyPlot",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "MakeGenealogyPlot"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeGenealogyPlot"],

Cell[TextData[{
  "MakeHaploid",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeHaploid"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeHaploid"],

Cell[TextData[{
  "MakeIndividuals",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: converting",
    ButtonData:>{"Allele frequencies: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeIndividuals"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeIndividuals"],

Cell[TextData[{
  "MakeOneWayTable",
  ",",
  " ",
  ButtonBox["Single-locus tables",
    ButtonData:>{"Single-locus tables", "MakeOneWayTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeOneWayTable"],

Cell[TextData[{
  "MakePairwiseTable",
  ",",
  " ",
  ButtonBox["Pairwise tables",
    ButtonData:>{"Pairwise tables", "MakePairwiseTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePairwiseTable"],

Cell[TextData[{
  "MakePopulation",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePopulation"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "MakePopulation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: representation",
    ButtonData:>{"Symmetric model: representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePopulation"],

Cell[TextData[{
  "MakeSelectionCoefficient",
  ",",
  " ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeSelectionCoefficient"],

Cell[TextData[{
  " with multiple alleles",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with two alleles",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeSelectionCoefficient"],

Cell[TextData[{
  "Mangel & Hilborn 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Mangel & Hilborn 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mangel & Hilborn 1996"],

Cell[TextData[{
  "MapLength",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "MapLength"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MapLength"],

Cell[TextData[{
  "MapPosition",
  ",",
  " option for AncestorList",
  ", ",
  ButtonBox["Ancestors & descendants",
    ButtonData:>{"Ancestors & descendants", "MapPositionA"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MapPosition"],

Cell[TextData[{
  " option for DescendantList",
  ", ",
  ButtonBox["Ancestors & descendants",
    ButtonData:>{"Ancestors & descendants", "MapPositionD"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MapPosition"],

Cell[TextData[{
  "Marginal fitness",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Marginal fitness"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Marginal fitness"],

Cell[TextData[{
  "MarginalTable",
  ",",
  " ",
  ButtonBox["Marginal tables",
    ButtonData:>{"Marginal tables", "MarginalTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalTable"],

Cell[TextData[{
  "MarginalW",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalW"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalW"],

Cell[TextData[{
  "MaternalLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MaternalLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MaternalLoci"],

Cell[TextData[{
  "MatrixGamma",
  ",",
  " ",
  ButtonBox["Fast calculations",
    ButtonData:>{"Fast calculations", "MatrixGamma"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixGamma"],

Cell[TextData[{
  "MatrixToGenealogy",
  ",",
  " ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", "MatrixToGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixToGenealogy"],

Cell[TextData[{
  "MatrixToList",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "MatrixToList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixToList"],

Cell[TextData[{
  "MeanContribution",
  ",",
  " \[GothicM], \[AliasIndicator]gom\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "MeanContribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanContribution"],

Cell[TextData[{
  "Mean fitness",
  ",",
  " ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mean fitness"],

Cell[TextData[{
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mean fitness"],

Cell[TextData[{
  "MeanW",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanW"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanW"],

Cell[TextData[{
  "Meiosis",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Meiosis"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Meiosis"],

Cell[TextData[{
  " in numerical models",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Meiosis"],

Cell[TextData[{
  "MethodC",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MethodC"],

Cell[TextData[{
  "MethodP",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MethodP"],

Cell[TextData[{
  "Metropolis algorithm",
  ",",
  " estimating D",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Metropolis algorithm"],

Cell[TextData[{
  "MetropolisDisequilibrium",
  ",",
  " ",
  ButtonBox["Estimating moments",
    ButtonData:>{"Estimating moments", "MetropolisDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MetropolisDisequilibrium"],

Cell[TextData[{
  "MetropolisDisequilibriumReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MetropolisDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MetropolisDisequilibriumReduced"],

Cell[TextData[{
  "Metropolis et al. 1954",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Metropolis et al 1954"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Metropolis et al. 1954"],

Cell[TextData[{
  "MFromC",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MFromC"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MFromC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MFromC"],

Cell[TextData[{
  "Migrate",
  ",",
  " ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Migrate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migrate"],

Cell[TextData[{
  "MigrateExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrateExact"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrateExact"],

Cell[TextData[{
  "Migration",
  ",",
  " and cytoplasmic inheritance",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Cytonuclear associations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migration"],

Cell[TextData[{
  " and sexual selection",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Sexual selection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " context-dependent",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Context-dependent migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " example of",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotype-dependent",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Genotype-dependent migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of constant numbers",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "Constant numbers"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of haploids",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Haploid migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of juvenile diploids",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Juvenile diploid migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of pollen",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of seeds",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with sindividuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migration"],

Cell[TextData[{
  "MigrationOrder",
  ",",
  "for genotype frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationOrder"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "MigrationOrder"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationOrder"],

Cell[TextData[{
  "MigrationRate",
  ",",
  " \[CapitalMu], \[AliasIndicator]M\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationRate"],

Cell[TextData[{
  "MigrationSet",
  ",",
  " \[DoubleStruckCapitalM], \[AliasIndicator]dsM\[AliasIndicator]",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "MigrationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationSet"],

Cell[TextData[{
  "MissingCombination",
  ",",
  " ",
  ButtonBox["Validity of a mutation matrix",
    ButtonData:>{"Validity of a mutation matrix", "MissingCombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MissingCombination"],

Cell[TextData[{
  "Missing data",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Missing data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Missing data"],

Cell[TextData[{
  "Moment",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Moment"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Moments and cumulants",
    ButtonData:>{"Moments and cumulants", "Moment"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moment"],

Cell[TextData[{
  "MomentAfterMigration",
  ",",
  " ",
  ButtonBox["Migration in admixture models",
    ButtonData:>{"Migration in admixture models", "MomentAfterMigration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentAfterMigration"],

Cell[TextData[{
  "MomentAfterRecombination",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", 
      "MomentAfterRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentAfterRecombination"],

Cell[TextData[{
  "MomentEquilibrium",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "MomentEquilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentEquilibrium"],

Cell[TextData[{
  "MomentGeneratingFunction",
  ",",
  " deriving",
  ", ",
  ButtonBox["Deriving recursions for the MGF",
    ButtonData:>{"Deriving recursions for the MGF", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentGeneratingFunction"],

Cell[TextData[{
  " examples",
  ", ",
  ButtonBox["Examples of the MGF",
    ButtonData:>{"Examples of the MGF", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genealogies",
  ", ",
  ButtonBox["Calculating the MGF",
    ButtonData:>{"Calculating the MGF", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over topologies",
  ", ",
  ButtonBox["Calculating over topologies",
    ButtonData:>{"Calculating over topologies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentGeneratingFunction"],

Cell[TextData[{
  "MomentLimits",
  ",",
  " ",
  ButtonBox["Constraints on moments",
    ButtonData:>{"Constraints on moments", "MomentLimits"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentLimits"],

Cell[TextData[{
  "MomentNew",
  ",",
  " ",
  ButtonBox["Iteration",
    ButtonData:>{"Iteration", "MomentNew"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentNew"],

Cell[TextData[{
  "MomentReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MomentReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentReduced"],

Cell[TextData[{
  "Moments",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "7.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moments"],

Cell[TextData[{
  " estimating the matrix of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "Estimating the matrix"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " extension to description by",
  ", ",
  ButtonBox["References",
    ButtonData:>{"References", "Haber 1984"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " extension to estimation of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "MLE"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " full description by",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " matrix of",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] full matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "ML estimation of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "simple method"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reduced description by",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " simple method for estimating",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "extension to families"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moments"],

Cell[TextData[{
  "MomentsFromG",
  ",",
  " ",
  ButtonBox["Moments from genotype frequencies",
    ButtonData:>{"Moments from genotype frequencies", "MomentsFromG"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentsFromG"],

Cell[TextData[{
  "MomentSimple",
  ",",
  " ",
  ButtonBox["Simplifying the moments",
    ButtonData:>{"Simplifying the moments", "MomentSimple"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentSimple"],

Cell[TextData[{
  "MonteCarloGriffithsTavare",
  ",",
  " ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "MonteCarloGriffithsTavare"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MonteCarloGriffithsTavare"],

Cell[TextData[{
  "MonteCarloProbability",
  ",",
  " ",
  ButtonBox["Estimating the probability",
    ButtonData:>{"Estimating the probability", "MonteCarloProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MonteCarloProbability"],

Cell[TextData[{
  "Mortality",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Mortality"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mortality"],

Cell[TextData[{
  "MostRecentCommonAncestor",
  ",",
  " ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "MostRecentCommonAncestor"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MostRecentCommonAncestor"],

Cell[TextData[{
  "MToC",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MToC"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MToC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MToC"],

Cell[TextData[{
  "MToCEquations",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MToCEquations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MToCEquations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MToCEquations"],

Cell[TextData[{
  "Muddle",
  ",",
  " ",
  ButtonBox["Muddling and subdividing sets",
    ButtonData:>{"Muddling and subdividing sets", "Muddle"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Muddle"],

Cell[TextData[{
  "Multilocus algebra",
  ",",
  " basic notation",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Basic notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus algebra"],

Cell[TextData[{
  " fitness",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction to",
  ", ",
  ButtonBox["Introduction to multilocus algebra",
    ButtonData:>{"Introduction to multilocus algebra", "1.1"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Introduction to multilocus algebra",
    ButtonData:>{"Introduction to multilocus algebra", 
      "Multilocus`Multilocus`"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages in life cycle",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Technicalities"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus algebra"],

Cell[TextData[{
  "Multilocus MS",
  ",",
  " relation with",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Multilocus MS"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus MS"],

Cell[TextData[{
  "Multilocus notation",
  ",",
  " bugs",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Multilocus notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus notation"],

Cell[TextData[{
  "Multinomial sampling",
  ",",
  " without replacement",
  ", ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", 
      "Multinomial sampling wo replacement"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multinomial sampling"],

Cell[TextData[{
  "MultinomialSamplingProbability",
  ",",
  " ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", 
      "MultinomialSamplingProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MultinomialSamplingProbability"],

Cell[TextData[{
  "Multiple alleles",
  ",",
  " and selection coefficients",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple alleles"],

Cell[TextData[{
  " MakeFitnessSet",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " mutation",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " representation of",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " selection on",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple alleles"],

Cell[TextData[{
  "Multiple arguments",
  ",",
  " in PopulationExpectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "multiple arguments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple arguments"],

Cell[TextData[{
  "Multiplicative models",
  ",",
  " in negative binomial",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "multiplicative models"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiplicative models"],

Cell[TextData[{
  "MUS",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MUS"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MUS"],

Cell[TextData[{
  "Mutate",
  ",",
  " allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: mutation",
    ButtonData:>{"Allele frequencies: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutate"],

Cell[TextData[{
  "genotype frequencies",
  ", ",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " individuals",
  ", ",
  ButtonBox["Simulating individuals: mutation",
    ButtonData:>{"Simulating individuals: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric model",
  ", ",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutate"],

Cell[TextData[{
  "MutateCompiled",
  ",",
  " ",
  ButtonBox["Allele frequencies: mutation",
    ButtonData:>{"Allele frequencies: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: mutation",
    ButtonData:>{"Simulating individuals: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutateCompiled"],

Cell[TextData[{
  "Mutation",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Mutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutation"],

Cell[TextData[{
  " Mutations, in multilocus genetics",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for BiallelicMutation",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies: reproduction",
    ButtonData:>{"Allele frequencies: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: reproduction",
    ButtonData:>{"Recursions: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutation"],

Cell[TextData[{
  "MutationInterval",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "MutationInterval"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationInterval"],

Cell[TextData[{
  "MutationLabels",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "MutationLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationLabels"],

Cell[TextData[{
  "MutationOrigin",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "MutationOrigin"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationOrigin"],

Cell[TextData[{
  "MutationRate",
  ",",
  " ",
  ButtonBox["Drawing a genealogy",
    ButtonData:>{"Drawing a genealogy", "MutationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationRate"],

Cell[TextData[{
  "Mutations",
  ",",
  " adding to a genealogy",
  ", ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddMutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutations"],

Cell[TextData[{
  " consistency with a genealogy",
  ", ",
  ButtonBox["Validity of a mutation matrix",
    ButtonData:>{"Validity of a mutation matrix", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " inferring genealogies from",
  ", ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "infinite site",
  ", ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "Mutations"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in genealogies",
  ", ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "Mutations"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutations"],

Cell[TextData[{
  "MVariables",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MVariables"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MVariables"],

Cell[TextData[{
  "Negative binomial",
  ",",
  " c<1",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "c<1"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Negative binomial"],

Cell[TextData[{
  " compiled",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " multiplicative models",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "multiplicative models"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " normalisation",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalisation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " timings",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Timings"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Negative binomial"],

Cell[TextData[{
  "NegativeBinomialLogLikelihood",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", 
      "NegativeBinomialLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeBinomialLogLikelihood"],

Cell[TextData[{
  "NegativeBinomialMLE",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "NegativeBinomialMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeBinomialMLE"],

Cell[TextData[{
  "NegativeHypergeometricDistribution",
  ",",
  " ",
  ButtonBox["Negative hypergeometric distribution",
    ButtonData:>{"Negative hypergeometric distribution", 
      "NegativeHypergeometricDistribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeHypergeometricDistribution"],

Cell[TextData[{
  "NeighbourArray",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "NeighbourArray"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NeighbourArray"],

Cell[TextData[{
  "Neighbours",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Neighbours"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Neighbours"],

Cell[TextData[{
  "NetCovariance",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "NetCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetCovariance"],

Cell[TextData[{
  "NetFecundity",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NetFecundity"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetFecundity"],

Cell[TextData[{
  "NetMortality",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NetMortality"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetMortality"],

Cell[TextData[{
  "NetRecombination",
  ",",
  " ",
  ButtonBox["Linkage",
    ButtonData:>{"Linkage", "NetRecombination"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Linkage in families",
    ButtonData:>{"Linkage in families", "NetRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetRecombination"],

Cell[TextData[{
  " in multilocus genetics",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "NetRecombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "NetRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetRecombination"],

Cell[TextData[{
  "Neutral marker",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Neutral marker"],

Cell[TextData[{
  "NeutralRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "NeutralRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NeutralRepresentations"],

Cell[TextData[{
  "NewGametes",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewGametes"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Mutation option",
  ", ",
  ButtonBox["Allele frequencies: reproduction",
    ButtonData:>{"Allele frequencies: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: reproduction",
    ButtonData:>{"Recursions: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " truncation selection",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", 
      "TruncationSelection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewGametes"],

Cell[TextData[{
  "NewS",
  ",",
  " ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "NewS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewS"],

Cell[TextData[{
  "Node",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "Node"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "Node"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Node"],

Cell[TextData[{
  "NodeFunction",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "NodeFunction"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeFunction"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeFunction"],

Cell[TextData[{
  " option for ExactProbability",
  ", ",
  ButtonBox["Exact probability",
    ButtonData:>{"Exact probability", "NodeFunction"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeFunction"],

Cell[TextData[{
  "NodeLabels",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeLabels"],

Cell[TextData[{
  "NodeOffset",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeOffset"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeOffset"],

Cell[TextData[{
  "Nodes",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "Nodes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Nodes"],

Cell[TextData[{
  "NonMendelian",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonMendelian"],

Cell[TextData[{
  " examples of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonMendelian"],

Cell[TextData[{
  "NonNeutralRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "NonNeutralRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonNeutralRepresentations"],

Cell[TextData[{
  "NonSymmetricRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "NonSymmetricRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonSymmetricRepresentations"],

Cell[TextData[{
  "Normalisation",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalisation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Normalisation"],

Cell[TextData[{
  "Normalised",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Normalised"],

Cell[TextData[{
  "Notation",
  ",",
  " clearing definitions",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "Clearing definitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation"],

Cell[TextData[{
  " data",
  ", ",
  ButtonBox["Notation for genetic data",
    ButtonData:>{"Notation for genetic data", "NotationPackage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining new",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "Defining new notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotypes",
  ", ",
  ButtonBox["Notation",
    ButtonData:>{"Notation", "NotationPackage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation"],

Cell[TextData[{
  "Notation Package",
  ",",
  " ",
  ButtonBox["Notation package",
    ButtonData:>{"Notation package", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation Package"],

Cell[TextData[{
  "Null lineages",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", "DeleteNullLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Null lineages"],

Cell[TextData[{
  "NullLineages",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "NullLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NullLineages"],

Cell[TextData[{
  "NullRecombinationEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "NullRecombinationEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NullRecombinationEvents"],

Cell[TextData[{
  "NumberedLink",
  ",",
  " ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "NumberedLink"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberedLink"],

Cell[TextData[{
  "Numbering",
  ",",
  " aesthetics",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Aesthetics"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numbering"],

Cell[TextData[{
  " automatic",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "7.2"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notes on",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Notes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving links",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Saving the links"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numbering"],

Cell[TextData[{
  "NumberOfCoalescences",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "NumberOfCoalescences"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfCoalescences"],

Cell[TextData[{
  "NumberOfGenes",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenes"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenes"],

Cell[TextData[{
  "NumberOfGenesTable",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfGenesTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenesTable"],

Cell[TextData[{
  "NumberOfIndividuals",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfIndividuals"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NumberOfIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfIndividuals"],

Cell[TextData[{
  "NumberOfIndividualsTable",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfIndividualsTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfIndividualsTable"],

Cell[TextData[{
  "NumberOfLineages",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "NumberOfLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfLineages"],

Cell[TextData[{
  "NumberOfLoci",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfLoci"],

Cell[TextData[{
  "NumberOfMutations",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "NumberOfMutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfMutations"],

Cell[TextData[{
  "NumberOfPossibleCoalescences",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "NumberOfPossibleCoalescences"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfPossibleCoalescences"],

Cell[TextData[{
  "NumberOfSamplePartitions",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "NumberOfSamplePartitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfSamplePartitions"],

Cell[TextData[{
  "NumberOfSetPartitions",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "NumberOfSetPartitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfSetPartitions"],

Cell[TextData[{
  "NumericalModel",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "NumericalModel"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumericalModel"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "NumericalModel"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumericalModel"],

Cell[TextData[{
  "Numerical models",
  ",",
  " genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numerical models"],

Cell[TextData[{
  " of allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " overview",
  ", ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " problems",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " problems with migration",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "Constant numbers"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric",
  ", ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numerical models"],

Cell[TextData[{
  "Observable genotype",
  ",",
  " ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Observable genotype"],

Cell[TextData[{
  "Obsolete",
  ",",
  " Combine",
  ", ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Separate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Obsolete"],

Cell[TextData[{
  " CumulantReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "CumulantReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidConstraints",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidConstraints"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidGenotypeFrequencyReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidGenotypeFrequencyTable",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Estimating D",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " fitness",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Obsolete notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " FullGenotypeFrequencyReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " FullGenotypeFrequencyTable",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " GenotypeFrequencyArguments",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "GenotypeFrequencyArguments"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " HaploidConstraints",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "HaploidConstraints"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " InitialStepReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "InitialStepReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " IntervalCombine",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalCombine"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " IntervalPosition",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalPosition"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " LogLikelihoodDisequilibriumReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "LogLikelihoodDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MetropolisDisequilibriumReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MetropolisDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MomentReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MomentReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Obsolete"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Separate",
  ", ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Combine"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " SetPartition",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SetPartition"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Obsolete"],

Cell[TextData[{
  "Offspring",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Offspring"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Offspring"],

Cell[TextData[{
  "Ordered",
  ",",
  "option for PartitionSet",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "Ordered"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ordered"],

Cell[TextData[{
  "Orive & Barton 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Orive & Barton 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Orive & Barton 1999"],

Cell[TextData[{
  "OtherSex",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "OtherSex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"OtherSex"],

Cell[TextData[{
  "Packages",
  ",",
  " help",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Packages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Packages"],

Cell[TextData[{
  " overview of",
  ", ",
  ButtonBox["Overview of the packages",
    ButtonData:>{"Overview of the packages", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving using PackageSaver",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " setting up",
  ", ",
  ButtonBox["Setting up the packages",
    ButtonData:>{"Setting up the packages", "Setting up the packages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Special notation",
    ButtonData:>{"Special notation", "Setting up packages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " versions of",
  ", ",
  ButtonBox["Versions",
    ButtonData:>{"Versions", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Packages"],

Cell[TextData[{
  "PackageSaver",
  ",",
  " ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PackageSaver"],

Cell[TextData[{
  "Partitions",
  ",",
  " of sets",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "PartitionSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Partitions"],

Cell[TextData[{
  " standard form",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartition"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " testing for standard form",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartitionQ"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Partitions"],

Cell[TextData[{
  "PartitionSet",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "PartitionSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PartitionSet"],

Cell[TextData[{
  "Paternal inheritance",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Paternal inheritance"],

Cell[TextData[{
  "PaternalLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaternalLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaternalLoci"],

Cell[TextData[{
  "PatternFree",
  ",",
  " ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "PatternFree"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PatternFree"],

Cell[TextData[{
  "Permutations",
  ",",
  "option for PartitionSet",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "Permutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Permutations"],

Cell[TextData[{
  "Permutations in defining coefficients",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Permutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Permutations in defining coefficients"],

Cell[TextData[{
  "Phenotypes",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Phenotypes"],

Cell[TextData[{
  "Phipps & Brill 1995",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Phipps & Brill 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Phipps & Brill 1995"],

Cell[TextData[{
  "Ploidy",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "Ploidy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ploidy"],

Cell[TextData[{
  "PloidyWeightList",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "PloidyWeightList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PloidyWeightList"],

Cell[TextData[{
  "PlotGenealogy",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "PlotGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PlotGenealogy"],

Cell[TextData[{
  "PlotLogL",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "PlotLogL"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PlotLogL"],

Cell[TextData[{
  "PlotSegments",
  ",",
  " of ancestral graphs",
  ", ",
  ButtonBox["Plotting ancestral graphs",
    ButtonData:>{"Plotting ancestral graphs", "PlotSegments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PlotSegments"],

Cell[TextData[{
  "Plotting",
  ",",
  " ancestral graphs",
  ", ",
  ButtonBox["Plotting ancestral graphs",
    ButtonData:>{"Plotting ancestral graphs", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Plotting"],

Cell[TextData[{
  "PopulationDisequilibrium",
  ",",
  "\[GothicCapitalC], \[AliasIndicator]goC\[AliasIndicator]",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationDisequilibrium"],

Cell[TextData[{
  "PopulationExpectation",
  ",",
  " ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationExpectation"],

Cell[TextData[{
  " multiple arguments",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "multiple arguments"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationExpectation"],

Cell[TextData[{
  "PopulationRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "PopulationRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationRepresentations"],

Cell[TextData[{
  "Position",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "position"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "position"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Position"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "position"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Contexts and positions"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Position"],

Cell[TextData[{
  "PositionsList",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PositionsList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PositionsList"],

Cell[TextData[{
  "PositionsMatrix",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PositionsMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PositionsMatrix"],

Cell[TextData[{
  "PossibleCoalescenceOrder",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "PossibleCoalescenceOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleCoalescenceOrder"],

Cell[TextData[{
  "PossibleDiploidGenotypes",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PossibleDiploidGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleDiploidGenotypes"],

Cell[TextData[{
  "PossibleGenotypes",
  ",",
  " ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "PossibleGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleGenotypes"],

Cell[TextData[{
  "PossibleRootings",
  ",",
  " ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", "PossibleRootings"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleRootings"],

Cell[TextData[{
  "PowerF",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PowerF"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "PowerF"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PowerF"],

Cell[TextData[{
  "PresentOneWayTable",
  ",",
  " ",
  ButtonBox["Single-locus tables",
    ButtonData:>{"Single-locus tables", "PresentOneWayTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentOneWayTable"],

Cell[TextData[{
  "PresentPairwiseTable",
  ",",
  " ",
  ButtonBox["Pairwise tables",
    ButtonData:>{"Pairwise tables", "PresentPairwiseTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentPairwiseTable"],

Cell[TextData[{
  "PresentResults",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "PresentResults"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentResults"],

Cell[TextData[{
  "Principal components",
  ",",
  " Bennett's measure of disequilibrium",
  ", ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Bennett"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Principal components"],

Cell[TextData[{
  "PrintDetails",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "PrintDetails"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PrintDetails"],

Cell[TextData[{
  " option for RandomGenealogy",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", 
      "PrintDetails, option for RandomGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PrintDetails"],

Cell[TextData[{
  "Problems",
  ",",
  " avoid integers",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Avoid integers"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Problems"],

Cell[TextData[{
  " redefining fitness",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Allele frequencies"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Redefining fitness"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "StoreResults (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Problems"],

Cell[TextData[{
  "Products",
  ",",
  " multiple",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Multiple products"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Products"],

Cell[TextData[{
  "ProductSum",
  ",",
  " ",
  ButtonBox["ProductSum",
    ButtonData:>{"ProductSum", "ProductSum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ProductSum"],

Cell[TextData[{
  " over sets",
  ", ",
  ButtonBox["ProductSum",
    ButtonData:>{"ProductSum", "ProductSum over sets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ProductSum"],

Cell[TextData[{
  "QLE",
  ",",
  " haploid selection example",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", "QLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"QLE"],

Cell[TextData[{
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"QLE"],

Cell[TextData[{
  "Quasi-linkage equilibrium",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Quasi-linkage equilibrium"],

Cell[TextData[{
  "RandomBottleneckedGenealogy",
  ",",
  " ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", "RandomBottleneckedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomBottleneckedGenealogy"],

Cell[TextData[{
  "RandomCoalescenceOrder",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "RandomCoalescenceOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCoalescenceOrder"],

Cell[TextData[{
  "RandomCoalescenceTimes",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", 
      "RandomCoalescenceTimes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCoalescenceTimes"],

Cell[TextData[{
  " for ancestral graphs",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", "RandomCoalescenceTimes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCoalescenceTimes"],

Cell[TextData[{
  "RandomCum",
  ",",
  " ",
  ButtonBox["Sampling from arbitrary distributions",
    ButtonData:>{"Sampling from arbitrary distributions", "RandomCum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCum"],

Cell[TextData[{
  "Random drift",
  ",",
  " changing reference points",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Changing reference points"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random drift"],

Cell[TextData[{
  " cumulants and moments",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " describing a distribution",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Describing a distribution"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " equations for the moments",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Equations for the moments"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in a cline",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: drift",
    ButtonData:>{"Allele frequencies: drift", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of genotype frequencies",
  ", ",
  ButtonBox["Recursions: drift",
    ButtonData:>{"Recursions: drift", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population disequilibrium",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population expectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population expectations",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Wright-Fisher sampling",
  ", ",
  ButtonBox["Wright-Fisher sampling",
    ButtonData:>{"Wright-Fisher sampling", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random drift"],

Cell[TextData[{
  "RandomDrift",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: drift",
    ButtonData:>{"Recursions: drift", "RandomDrift"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomDrift"],

Cell[TextData[{
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "RandomDrift"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomDrift"],

Cell[TextData[{
  "RandomFamilies",
  ",",
  " ",
  ButtonBox["Random families",
    ButtonData:>{"Random families", "RandomFamilies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamilies"],

Cell[TextData[{
  "RandomFamily",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "RandomFamily"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamily"],

Cell[TextData[{
  " segregation ratio",
  ", ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamily"],

Cell[TextData[{
  "Random genealogies",
  ",",
  " population bottlenecks",
  ", ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random genealogies"],

Cell[TextData[{
  "RandomGenealogy",
  ",",
  " ",
  ButtonBox["Drawing a genealogy",
    ButtonData:>{"Drawing a genealogy", "RandomGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomGenealogy"],

Cell[TextData[{
  " for ancestral graphs",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", "RandomGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomGenealogy"],

Cell[TextData[{
  "RandomList",
  ",",
  " ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "RandomList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomList"],

Cell[TextData[{
  " sampling without replacement",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomList"],

Cell[TextData[{
  "Random lists",
  ",",
  " compiled",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random lists"],

Cell[TextData[{
  "RandomMating",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "RandomMating"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomMating"],

Cell[TextData[{
  "RandomMultinomial",
  ",",
  " ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", "RandomMultinomial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomMultinomial"],

Cell[TextData[{
  "RandomPreviousFamily",
  ",",
  " ",
  ButtonBox["Random families",
    ButtonData:>{"Random families", "RandomPreviousFamily"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomPreviousFamily"],

Cell[TextData[{
  "Random sampling",
  ",",
  " ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Random sampling"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random sampling"],

Cell[TextData[{
  " example in estimating D",
  ", ",
  ButtonBox["Sampling example",
    ButtonData:>{"Sampling example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of genealogies",
  ", ",
  ButtonBox["Sampling genealogies",
    ButtonData:>{"Sampling genealogies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random sampling"],

Cell[TextData[{
  "RandomSet",
  ",",
  " ",
  ButtonBox["Random sets",
    ButtonData:>{"Random sets", "RandomSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomSet"],

Cell[TextData[{
  "Random union",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Random union"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random union"],

Cell[TextData[{
  " in admixture models",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "RandomUnionObsolete"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random union"],

Cell[TextData[{
  "RandomUnion",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnion"],

Cell[TextData[{
  "RandomUnionMethod",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnionMethod"],

Cell[TextData[{
  "RandomUnionObsolete",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnionObsolete"],

Cell[TextData[{
  "Random walk",
  ",",
  " in estimating D",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random walk"],

Cell[TextData[{
  "RecombinantLineages",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "RecombinantLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinantLineages"],

Cell[TextData[{
  "Recombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Recombination"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Recombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombination"],

Cell[TextData[{
  " across several linked loci",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "NetRecombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " between linked loci",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "LinkedRecombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " context-dependent",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Context-dependent recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotype-dependent",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Genotype-dependent recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in admixture models",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "Recombined"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " no linkage",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "UnlinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombination"],

Cell[TextData[{
  "RecombinationEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "RecombinationEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinationEvents"],

Cell[TextData[{
  "RecombinationRate",
  ",",
  " \[GothicR], \[AliasIndicator]gor\[AliasIndicator]",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinationRate"],

Cell[TextData[{
  "RecombinationSet",
  ",",
  " \[DoubleStruckCapitalR], \[AliasIndicator]dsR\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinationSet"],

Cell[TextData[{
  "Recombined",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "Recombined"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombined"],

Cell[TextData[{
  "RecombineLineage",
  ",",
  " ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "RecombineLineage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombineLineage"],

Cell[TextData[{
  "ReducedData",
  ",",
  " ",
  ButtonBox["Simplifying a dataset",
    ButtonData:>{"Simplifying a dataset", "ReducedData"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReducedData"],

Cell[TextData[{
  "ReferencePoint",
  ",",
  " \[WeierstrassP], \[AliasIndicator]wp\[AliasIndicator]",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePoint"],

Cell[TextData[{
  "ReferencePointMean",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointMean"],

Cell[TextData[{
  " cytoplasmic inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " paternal inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sex-linkage",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointMean"],

Cell[TextData[{
  "ReferencePointSame",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointSame"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointSame"],

Cell[TextData[{
  "ReferencePointZero",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointZero"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointZero"],

Cell[TextData[{
  "References",
  ",",
  " for ancestral graphs",
  ", ",
  ButtonBox["Ancestral graph references",
    ButtonData:>{"Ancestral graph references", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"References"],

Cell[TextData[{
  "Reference values",
  ",",
  " ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Reference values"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reference values"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Reference values"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Describing genotypes and populations"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reference values"],

Cell[TextData[{
  "RemoveTag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "RemoveTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RemoveTag"],

Cell[TextData[{
  "Repeat",
  ",",
  " ",
  ButtonBox["Repeated elements",
    ButtonData:>{"Repeated elements", "Repeat"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Repeat"],

Cell[TextData[{
  "Replace",
  ",",
  " ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Replace"],

Cell[TextData[{
  "ReplaceAllSpecial",
  ",",
  " |.",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReplaceAllSpecial"],

Cell[TextData[{
  "ReplaceRepeatedSpecial",
  ",",
  " ||.",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceRepeatedSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReplaceRepeatedSpecial"],

Cell[TextData[{
  "Representations",
  ",",
  " converting between",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Representations"],

Cell[TextData[{
  "of populations",
  ", ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "Representing the population"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Representations"],

Cell[TextData[{
  "Reproduction",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reproduction"],

Cell[TextData[{
  "Reverse",
  ",",
  " ",
  ButtonBox["Sorting",
    ButtonData:>{"Sorting", "Reverse"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reverse"],

Cell[TextData[{
  "Root",
  ",",
  " of a genealogy",
  ", ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "RootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Root"],

Cell[TextData[{
  "RootedGenealogy",
  ",",
  " ",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "RootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RootedGenealogy"],

Cell[TextData[{
  "RootEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "RootEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RootEvents"],

Cell[TextData[{
  "Rootings",
  ",",
  " of a genealogy, possible",
  ", ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", "PossibleRootings"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Rootings"],

Cell[TextData[{
  "Rules",
  ",",
  " ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Rules"],

Cell[TextData[{
  " non-evaluation of",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Rules"],

Cell[TextData[{
  "SampleCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "SampleCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SampleCovariance"],

Cell[TextData[{
  "SampleIndividuals",
  ",",
  " ",
  ButtonBox["Sampling individuals",
    ButtonData:>{"Sampling individuals", "SampleIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SampleIndividuals"],

Cell[TextData[{
  "SamplePartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SamplePartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SamplePartition"],

Cell[TextData[{
  "Sampling",
  ",",
  " without replacement",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sampling"],

Cell[TextData[{
  "Scripts and faces",
  ",",
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Scripts and faces"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Scripts and faces"],

Cell[TextData[{
  "Segments",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "Segments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Segments"],

Cell[TextData[{
  "SegmentStyle",
  ",",
  " option for PlotSegments",
  ", ",
  ButtonBox["Plotting ancestral graphs",
    ButtonData:>{"Plotting ancestral graphs", "SegmentStyle"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SegmentStyle"],

Cell[TextData[{
  "SegregationRatio",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SegregationRatio"],

Cell[TextData[{
  "SelectContext",
  ",",
  " \[CircleDot], \[AliasIndicator]c.\[AliasIndicator]",
  ", ",
  ButtonBox["Selecting contexts",
    ButtonData:>{"Selecting contexts", "SelectContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectContext"],

Cell[TextData[{
  "SelectIndividuals",
  ",",
  " ",
  ButtonBox["Selecting subsets",
    ButtonData:>{"Selecting subsets", "SelectIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectIndividuals"],

Cell[TextData[{
  "Selection",
  ",",
  " ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Selection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection"],

Cell[TextData[{
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on genotype frequencies",
  ", ",
  ButtonBox["Recursions: fitnesses",
    ButtonData:>{"Recursions: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on multiple alleles",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Technicalities"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " truncation",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "TruncationSelection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with two alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection"],

Cell[TextData[{
  "SelectionCoefficient",
  ",",
  " \[GothicA], \[AliasIndicator]goa\[AliasIndicator]",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionCoefficient"],

Cell[TextData[{
  "Selection coefficients",
  ",",
  " as defined in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Permutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection coefficients"],

Cell[TextData[{
  " making",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with multiple alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection coefficients"],

Cell[TextData[{
  "SelectionExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionExact"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: fitnesses",
    ButtonData:>{"Recursions: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionExact"],

Cell[TextData[{
  "Selection on diploids",
  ",",
  " a method to avoid",
  ", ",
  ButtonBox["A method to avoid",
    ButtonData:>{"A method to avoid", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection on diploids"],

Cell[TextData[{
  " cautionary notes",
  ", ",
  ButtonBox["Cautionary notes",
    ButtonData:>{"Cautionary notes", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete life cycle",
  ", ",
  ButtonBox["Complete life cyle",
    ButtonData:>{"Complete life cyle", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " explaining the rules",
  ", ",
  ButtonBox["Explaining the rules",
    ButtonData:>{"Explaining the rules", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction",
  ", ",
  ButtonBox["Introduction to selection on diploids",
    ButtonData:>{"Introduction to selection on diploids", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " life cycle",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection on diploids"],

Cell[TextData[{
  "SelectionRate",
  ",",
  " \[GothicS],\[AliasIndicator]gos\[AliasIndicator]",
  ", ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SelectionRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionRate"],

Cell[TextData[{
  "SelectLoci",
  ",",
  " ",
  ButtonBox["Selecting subsets",
    ButtonData:>{"Selecting subsets", "SelectLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectLoci"],

Cell[TextData[{
  "Selfing",
  ",",
  " ",
  ButtonBox["Selfing",
    ButtonData:>{"Selfing", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selfing"],

Cell[TextData[{
  "Separate",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Separate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Separate"],

Cell[TextData[{
  "Servedio",
  ",",
  " Maria",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", "Servedio"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Servedio"],

Cell[TextData[{
  "Set",
  ",",
  " of all positions affecting a trait, \[DoubleStruckCapitalZ], \
\[AliasIndicator]dsZ\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set"],

Cell[TextData[{
  " of all positions in genome, \[DoubleStruckCapitalG], \[AliasIndicator]dsG\
\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set"],

Cell[TextData[{
  "Set manipulation",
  ",",
  " overview",
  ", ",
  ButtonBox["Overview of set manipulation",
    ButtonData:>{"Overview of set manipulation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set manipulation"],

Cell[TextData[{
  "SetOfCombinations",
  ",",
  " ",
  ButtonBox["Set combinations",
    ButtonData:>{"Set combinations", "SetOfCombinations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SetOfCombinations"],

Cell[TextData[{
  "SetPartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SetPartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SetPartition"],

Cell[TextData[{
  "Sets of loci",
  ",",
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets of loci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sets of loci"],

Cell[TextData[{
  "Sex",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Sex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex"],

Cell[TextData[{
  "Sex linkage",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex linkage"],

Cell[TextData[{
  " examples of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex linkage"],

Cell[TextData[{
  "SexOfOrigin",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "SexOfOrigin"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SexOfOrigin"],

Cell[TextData[{
  "Sexual selection",
  ",",
  " ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Sexual selection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sexual selection"],

Cell[TextData[{
  " and migration",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Sexual selection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete life cycle",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Complete cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining fitnesses",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Sexual selection by female choice"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "on haploids",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " recombination",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " subtle problem",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "subtle problem"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sexual selection"],

Cell[TextData[{
  "ShortContext",
  ",",
  " ",
  ButtonBox["Abbreviating contexts",
    ButtonData:>{"Abbreviating contexts", "ShortContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ShortContext"],

Cell[TextData[{
  "SigmaMatrix",
  ",",
  " ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "SigmaMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SigmaMatrix"],

Cell[TextData[{
  "SignMask",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "SignMask"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SignMask"],

Cell[TextData[{
  "SimplifyAddUp",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "SimplifyAddUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyAddUp"],

Cell[TextData[{
  "SimplifyAddUpQ",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "SimplifyAddUpQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyAddUpQ"],

Cell[TextData[{
  "SimplifyFamilies",
  ",",
  " ",
  ButtonBox["Probabilities",
    ButtonData:>{"Probabilities", "SimplifyFamilies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyFamilies"],

Cell[TextData[{
  "Simulating individuals",
  ",",
  " recursions",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Simulating individuals"],

Cell[TextData[{
  " representation",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reproduction",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Simulating individuals"],

Cell[TextData[{
  "SizeOfGenealogyPlot",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "SizeOfGenealogyPlot"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SizeOfGenealogyPlot"],

Cell[TextData[{
  "Slatkin & Excoffier 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Slatkin & Excoffier 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Slatkin & Excoffier 1996"],

Cell[TextData[{
  "SlowChange",
  ",",
  " ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SlowChange"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SlowChange"],

Cell[TextData[{
  "SortByClass",
  ",",
  " ",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "SortByClass"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByClass"],

Cell[TextData[{
  " genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "SortByClass"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByClass"],

Cell[TextData[{
  "SortByHead",
  ",",
  " ",
  ButtonBox["Sorting",
    ButtonData:>{"Sorting", "SortByHead"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByHead"],

Cell[TextData[{
  "SpatialCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "SpatialCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SpatialCovariance"],

Cell[TextData[{
  "Spatially varying selection",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Spatially varying selection",
    ButtonData:>{"Spatially varying selection", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Spatially varying selection"],

Cell[TextData[{
  "Special notation",
  ",",
  " ",
  ButtonBox["Special notation",
    ButtonData:>{"Special notation", "Defining notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Special notation"],

Cell[TextData[{
  "SplitSet",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SplitSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SplitSet"],

Cell[TextData[{
  "Stabilising selection",
  ",",
  " change in D",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Change in D"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stabilising selection"],

Cell[TextData[{
  " change in mean",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Change in mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Defining fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", 
      "Natural selection on an additive polygenic trait"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "mean fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Mean fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "New mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "New mean fitness"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stabilising selection"],

Cell[TextData[{
  "Stability",
  ",",
  " of numerical models",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stability"],

Cell[TextData[{
  " of symmetric model",
  ", ",
  ButtonBox["Symmetric stability: outline",
    ButtonData:>{"Symmetric stability: outline", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stability"],

Cell[TextData[{
  "StabilityDirect",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", "StabilityDirect"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityDirect"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", "StabilityDirect"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityDirect"],

Cell[TextData[{
  "StabilityK",
  ",",
  " ",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", "StabilityK"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "StabilityK"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityK"],

Cell[TextData[{
  "StabilityKTable",
  ",",
  " ",
  ButtonBox["Symmetric stability: faster algorithms",
    ButtonData:>{"Symmetric stability: faster algorithms", "StabilityKTable"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityKTable"],

Cell[TextData[{
  "StabilityMatrix",
  ",",
  " ",
  ButtonBox["Making a stability matrix",
    ButtonData:>{"Making a stability matrix", "StabilityMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityMatrix"],

Cell[TextData[{
  "Stage",
  ",",
  " \[Sampi], \[AliasIndicator]sa\[AliasIndicator]",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stage"],

Cell[TextData[{
  "Stages",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stages"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Stages and contexts"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stages"],

Cell[TextData[{
  "StandardPartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StandardPartition"],

Cell[TextData[{
  "StandardPartitionQ",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartitionQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StandardPartitionQ"],

Cell[TextData[{
  "StartingStepSize",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "StartingStepSize"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StartingStepSize"],

Cell[TextData[{
  "Stepping-stone migration",
  ",",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", 
      "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone migration"],

Cell[TextData[{
  "Stepping-stone model",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", 
      "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone model"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "Nearest-neighbour migration"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone model"],

Cell[TextData[{
  "StoreExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreExact"],

Cell[TextData[{
  " for allele frequency clines",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequency clines",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreExact"],

Cell[TextData[{
  "StoreResults",
  ",",
  " option for GameteTable",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreResults"],

Cell[TextData[{
  " option for NewGametes",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " use when compiling",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "StoreResults (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreResults"],

Cell[TextData[{
  "StructuredArray",
  ",",
  " ",
  ButtonBox["Useful functions",
    ButtonData:>{"Useful functions", "StructuredArray"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredArray"],

Cell[TextData[{
  "StructuredInitialParameters",
  ",",
  " ",
  ButtonBox["Initial parameters",
    ButtonData:>{"Initial parameters", "StructuredInitialParameters"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredInitialParameters"],

Cell[TextData[{
  "StructuredLogLikelihood",
  ",",
  " ",
  ButtonBox["Likelihood of a structured model",
    ButtonData:>{"Likelihood of a structured model", 
      "StructuredLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredLogLikelihood"],

Cell[TextData[{
  "StructuredMLE",
  ",",
  " ",
  ButtonBox["Likelihood of a structured model",
    ButtonData:>{"Likelihood of a structured model", "StructuredMLE"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "StructuredMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredMLE"],

Cell[TextData[{
  "StructuredModel",
  ",",
  " ",
  ButtonBox["Useful functions",
    ButtonData:>{"Useful functions", "StructuredModel"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredModel"],

Cell[TextData[{
  "StructuredModelReduce",
  ",",
  " ",
  ButtonBox["Simplifying a model",
    ButtonData:>{"Simplifying a model", "StructuredModelReduce"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredModelReduce"],

Cell[TextData[{
  "Structured models",
  ",",
  " example",
  ", ",
  ButtonBox["Example data",
    ButtonData:>{"Example data", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Structured models"],

Cell[TextData[{
  " hierarchical analysis",
  ", ",
  ButtonBox["Hierarchical analysis",
    ButtonData:>{"Hierarchical analysis", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Structured models"],

Cell[TextData[{
  "StructuredParameter",
  ",",
  " ",
  ButtonBox["Structured parameters",
    ButtonData:>{"Structured parameters", "StructuredParameter"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredParameter"],

Cell[TextData[{
  "StructuredVariance",
  ",",
  " ",
  ButtonBox["Variance components for a structured model",
    ButtonData:>{"Variance components for a structured model", 
      "StructuredVariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredVariance"],

Cell[TextData[{
  "Style sheets",
  ",",
  " bugs with",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Style sheets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Style sheets"],

Cell[TextData[{
  "Subdivide",
  ",",
  " ",
  ButtonBox["Muddling and subdividing sets",
    ButtonData:>{"Muddling and subdividing sets", "Subdivide"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subdivide"],

Cell[TextData[{
  "Subscripts",
  ",",
  " as written in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets in subscripts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subscripts"],

Cell[TextData[{
  "Subsets",
  ",",
  " ",
  ButtonBox["Subsets",
    ButtonData:>{"Subsets", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subsets"],

Cell[TextData[{
  " option for AddUp",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Subsets"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for TimesUp",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subsets"],

Cell[TextData[{
  "Sums",
  ",",
  " multiple",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Multiple sums"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sums"],

Cell[TextData[{
  "SwapStates",
  ",",
  " ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", "SwapStates"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SwapStates"],

Cell[TextData[{
  "Symmetric cline",
  ",",
  " in allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a symmetric cline",
    ButtonData:>{"Allele frequencies: setting up a symmetric cline", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric cline"],

Cell[TextData[{
  " in genotype frequencies",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric cline"],

Cell[TextData[{
  "SymmetricDiploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricDiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricDiploidFrequencies"],

Cell[TextData[{
  "SymmetricHaploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricHaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricHaploidFrequencies"],

Cell[TextData[{
  "Symmetric model",
  ",",
  " adding a neutral marker",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: limitations",
    ButtonData:>{"Symmetric model: limitations", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric model"],

Cell[TextData[{
  " cline example",
  ", ",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: spatially varying selection",
    ButtonData:>{"Symmetric stability: spatially varying selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " limitations",
  ", ",
  ButtonBox["Symmetric model: limitations",
    ButtonData:>{"Symmetric model: limitations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " one deme example",
  ", ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "overview",
  ", ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " references",
  ", ",
  ButtonBox["Symmetric model: references",
    ButtonData:>{"Symmetric model: references", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reproduction",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Symmetric stability: outline",
    ButtonData:>{"Symmetric stability: outline", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric model"],

Cell[TextData[{
  "SymmetricNeutralDiploidFrequencies",
  ",",
  " ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricNeutralDiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricNeutralDiploidFrequencies"],

Cell[TextData[{
  "SymmetricNeutralHaploidFrequencies",
  ",",
  " ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricNeutralHaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricNeutralHaploidFrequencies"],

Cell[TextData[{
  "SymmetricRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "SymmetricRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricRecombination"],

Cell[TextData[{
  "SymmetricRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "SymmetricRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricRepresentations"],

Cell[TextData[{
  "SymmetricSexes",
  ",",
  " ",
  ButtonBox["Symmetric sexes",
    ButtonData:>{"Symmetric sexes", "SymmetricSexes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricSexes"],

Cell[TextData[{
  "Symmetrise",
  ",",
  " ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Symmetrise"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetrise",
    ButtonData:>{"Symmetrise", "Symmetrise"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetrise"],

Cell[TextData[{
  "T",
  ",",
  " time",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "T"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"T"],

Cell[TextData[{
  "Table",
  ",",
  " option for VarianceComponents",
  ", ",
  ButtonBox["Variance components",
    ButtonData:>{"Variance components", "Table"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Table"],

Cell[TextData[{
  "Tag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Tag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tag"],

Cell[TextData[{
  "Tags",
  ",",
  " finding",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Finding tags"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tags"],

Cell[TextData[{
  " setting up hyperlinks to",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Setting up links to a list of tags"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tags"],

Cell[TextData[{
  "TakeAway, \[Backslash], \[AliasIndicator]\[AliasIndicator], ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TakeAway"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TakeAway",
    ButtonData:>{"TakeAway", "TakeAway"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TakeAway"],

Cell[TextData[{
  "TakeOptions",
  ",",
  " ",
  ButtonBox["Manipulating options",
    ButtonData:>{"Manipulating options", "TakeOptions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TakeOptions"],

Cell[TextData[{
  "Time",
  ",",
  " T",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "T"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Time"],

Cell[TextData[{
  "TimesOfEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "TimesOfEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimesOfEvents"],

Cell[TextData[{
  "TimespanOfJunction",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "TimespanOfJunction"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimespanOfJunction"],

Cell[TextData[{
  "TimespanOfLineage",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "TimespanOfLineage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimespanOfLineage"],

Cell[TextData[{
  "TimesUp",
  ",",
  " ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TimesUp"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "TimesUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimesUp"],

Cell[TextData[{
  " multiple products",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Multiple products"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over subsets",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimesUp"],

Cell[TextData[{
  "ToBaake",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "ToBaake"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToBaake"],

Cell[TextData[{
  "ToBennett",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "ToBennett"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToBennett"],

Cell[TextData[{
  "ToBennettExpression",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "ToBennettExpression"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToBennettExpression"],

Cell[TextData[{
  "ToCumulants",
  ",",
  " ",
  ButtonBox["Multilocus cumulants",
    ButtonData:>{"Multilocus cumulants", "ToCumulants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToCumulants"],

Cell[TextData[{
  "ToMoments",
  ",",
  " ",
  ButtonBox["Multilocus cumulants",
    ButtonData:>{"Multilocus cumulants", "ToMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToMoments"],

Cell[TextData[{
  "ToPopulationCumulants",
  ",",
  " ",
  ButtonBox["Random drift: cumulants",
    ButtonData:>{"Random drift: cumulants", "ToPopulationCumulants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToPopulationCumulants"],

Cell[TextData[{
  "ToPopulationMoments",
  ",",
  " ",
  ButtonBox["Random drift: cumulants",
    ButtonData:>{"Random drift: cumulants", "ToPopulationMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToPopulationMoments"],

Cell[TextData[{
  "TotalLength",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "TotalLength"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalLength"],

Cell[TextData[{
  "TotalNumber",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "TotalNumber"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalNumber"],

Cell[TextData[{
  "Trait",
  ",",
  " set of all positions affecting, \[DoubleStruckCapitalZ], \
\[AliasIndicator]dsZ\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Trait"],

Cell[TextData[{
  "TransformedRange",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "TransformedRange"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransformedRange"],

Cell[TextData[{
  "TransformInformation",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "TransformInformation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransformInformation"],

Cell[TextData[{
  "TransmissionRule",
  ",",
  " ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "TransmissionRule"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransmissionRule"],

Cell[TextData[{
  "Transmission rules",
  ",",
  " applying",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "Applying transmission rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Transmission rules"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Transmission rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " distinct from Mathematica rules",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "Transmission vs Mathematica rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Transmission"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Transmission rules"],

Cell[TextData[{
  "TriDiagonalMatrix",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "TriDiagonalMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TriDiagonalMatrix"],

Cell[TextData[{
  "TruncationSelection",
  ",",
  " option for NewGametes",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", 
      "TruncationSelection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TruncationSelection"],

Cell[TextData[{
  "option for SelectionExact",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "TruncationSelection"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TruncationSelection"],

Cell[TextData[{
  "Turelli and Barton 1994",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Turelli and Barton 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Turelli and Barton 1994"],

Cell[TextData[{
  "Turelli & Barton 1994",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Turelli & Barton 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Turelli & Barton 1994"],

Cell[TextData[{
  "Two alleles",
  ",",
  " ",
  ButtonBox["Two alleles",
    ButtonData:>{"Two alleles", "Biallelic"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Two alleles"],

Cell[TextData[{
  " selection coefficients",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Two alleles"],

Cell[TextData[{
  "UMS",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UMS"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UMS"],

Cell[TextData[{
  "UnionOfGametes",
  ",",
  " ",
  ButtonBox["Union of gametes",
    ButtonData:>{"Union of gametes", "UnionOfGametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnionOfGametes"],

Cell[TextData[{
  "UnlinkedRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "UnlinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnlinkedRecombination"],

Cell[TextData[{
  "UnrootedGenealogy",
  ",",
  " ",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "UnrootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnrootedGenealogy"],

Cell[TextData[{
  "UpperOffDiagonal",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "UpperOffDiagonal"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UpperOffDiagonal"],

Cell[TextData[{
  "USM",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"USM"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"USM"],

Cell[TextData[{
  "ValidMatrixQ",
  ",",
  " ",
  ButtonBox["Validity of a mutation matrix",
    ButtonData:>{"Validity of a mutation matrix", "ValidMatrixQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ValidMatrixQ"],

Cell[TextData[{
  "VarianceComponents",
  ",",
  " ",
  ButtonBox["Variance components for a structured model",
    ButtonData:>{"Variance components for a structured model", 
      "VarianceComponents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"VarianceComponents"],

Cell[TextData[{
  " Table option",
  ", ",
  ButtonBox["Variance components",
    ButtonData:>{"Variance components", "Table"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"VarianceComponents"],

Cell[TextData[{
  "Versions",
  ",",
  " of applications packages",
  ", ",
  ButtonBox["Versions",
    ButtonData:>{"Versions", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Versions"],

Cell[TextData[{
  "Wiuf & Hein 1999",
  ",",
  " ",
  ButtonBox["Ancestral graph introduction",
    ButtonData:>{"Ancestral graph introduction", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Ancestral graph references",
    ButtonData:>{"Ancestral graph references", "Wiuf & Hein 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Wiuf & Hein 1999"],

Cell[TextData[{
  "WLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"WLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"WLinkedLoci"],

Cell[TextData[{
  "Wright-Fisher sampling",
  ",",
  " ",
  ButtonBox["Wright-Fisher sampling",
    ButtonData:>{"Wright-Fisher sampling", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Wright-Fisher sampling"],

Cell[TextData[{
  "X",
  ",",
  " AllelicState",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicState"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"X"],

Cell[TextData[{
  "XLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"XLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"XLinkedLoci"],

Cell[TextData[{
  "YLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"YLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"YLinkedLoci"],

Cell[TextData[{
  "ZLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ZLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ZLinkedLoci"],

Cell[TextData[{
  "Zygotes",
  ",",
  " \[GothicCapitalZ], \[AliasIndicator]goZ\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Zygotes"],

Cell[TextData[{
  "\[GothicA]",
  ",",
  " \[AliasIndicator]goa\[AliasIndicator], SelectionCoefficient",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicA]"],

Cell[TextData[{
  "\[GothicCapitalA]",
  ",",
  " \[AliasIndicator]goA\[AliasIndicator], adults",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalA]"],

Cell[TextData[{
  "\[GothicCapitalC]",
  ",",
  " \[AliasIndicator]goC\[AliasIndicator], PopulationDisequilibrium",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalC]"],

Cell[TextData[{
  "\[GothicCapitalD]",
  ",",
  " \[AliasIndicator]\[GothicCapitalD]\[AliasIndicator], Disequilibrium",
  ", ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalD]"],

Cell[TextData[{
  "\!\(\(\[GothicCapitalG]\^*\)\)",
  ",",
  " \[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, \
\[GothicCapitalG]new, new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\!\(\(\[GothicCapitalG]\^*\)\)"],

Cell[TextData[{
  "\[GothicCapitalG]",
  ",",
  " \[AliasIndicator]goG\[AliasIndicator], Gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalG]"],

Cell[TextData[{
  "\[GothicCapitalH]",
  ",",
  " \[AliasIndicator]goH\[AliasIndicator], hermaphrodites",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalH]"],

Cell[TextData[{
  "\[GothicCapitalJ]",
  ",",
  " \[AliasIndicator]goJ\[AliasIndicator], juveniles",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalJ]"],

Cell[TextData[{
  "\[GothicK]",
  ",",
  " \[AliasIndicator]gok\[AliasIndicator], CumulantDisequilibrium",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "CumulantDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicK]"],

Cell[TextData[{
  "\[GothicCapitalK]",
  ",",
  " \[AliasIndicator]goK\[AliasIndicator], CumulantPopulationDisequilibrium",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalK]"],

Cell[TextData[{
  "\[GothicM]",
  ",",
  " \[AliasIndicator]gom\[AliasIndicator], MeanContribution",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "MeanContribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicM]"],

Cell[TextData[{
  "\[GothicP]",
  ",",
  " \[AliasIndicator]gop\[AliasIndicator], AlleleFrequencyP",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicP]"],

Cell[TextData[{
  "\[GothicP]\[GothicQ]",
  ",",
  " \[AliasIndicator]gop\[AliasIndicator]\[AliasIndicator]goq\[AliasIndicator]\
, AlleleFrequencyPQ",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyPQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicP]\[GothicQ]"],

Cell[TextData[{
  "\[GothicQ]",
  ",",
  " \[AliasIndicator]goq\[AliasIndicator], AlleleFrequencyQ",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicQ]"],

Cell[TextData[{
  "\[GothicR]",
  ",",
  " \[AliasIndicator]gor\[AliasIndicator], RecombinationRate",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicR]"],

Cell[TextData[{
  "\[GothicS]",
  ",",
  "\[AliasIndicator]gos\[AliasIndicator], SelectionRate",
  ", ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SelectionRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicS]"],

Cell[TextData[{
  "\[GothicCapitalZ]",
  ",",
  " \[AliasIndicator]goZ\[AliasIndicator], Zygotes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalZ]"],

Cell[TextData[{
  "\[DoubleStruckCapitalG]",
  ",",
  " \[AliasIndicator]dsG\[AliasIndicator], set of all positions in genome",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalG]"],

Cell[TextData[{
  "\[DoubleStruckCapitalM]",
  ",",
  " \[AliasIndicator]dsM\[AliasIndicator], MigrationSet",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "MigrationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalM]"],

Cell[TextData[{
  "\[DoubleStruckCapitalR]",
  ",",
  " \[AliasIndicator]dsR\[AliasIndicator], RecombinationSet",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalR]"],

Cell[TextData[{
  "\[DoubleStruckCapitalW]",
  ",",
  " \[AliasIndicator]dsW\[AliasIndicator], FitnessSet",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "FitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalW]"],

Cell[TextData[{
  "\[DoubleStruckCapitalZ]",
  ",",
  " \[AliasIndicator]dsZ\[AliasIndicator], set of all positions affecting a \
trait",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalZ]"],

Cell[TextData[{
  "\[Gamma]",
  ",",
  " \[AliasIndicator]g\[AliasIndicator], ExtractGenes",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Gamma]"],

Cell[TextData[{
  "\[Zeta]",
  ",",
  " \[AliasIndicator]z\[AliasIndicator], AllelicDeviation",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicDeviation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Zeta]"],

Cell[TextData[{
  "\[CapitalMu]",
  ",",
  " \[AliasIndicator]M\[AliasIndicator], MigrationRate",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CapitalMu]"],

Cell[TextData[{
  "\[Chi]",
  ",",
  " \[AliasIndicator]c\[AliasIndicator], ExtractContexts",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Chi]"],

Cell[TextData[{
  "\[Sampi]",
  ",",
  " \[AliasIndicator]sa\[AliasIndicator], Stage",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Sampi]"],

Cell[TextData[{
  "$MetropolisAdjustment",
  ",",
  " ",
  ButtonBox["Metropolis algorithm",
    ButtonData:>{"Metropolis algorithm", "$MetropolisAdjustment"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$MetropolisAdjustment"],

Cell[TextData[{
  "\[WeierstrassP]",
  ",",
  " \[AliasIndicator]wp\[AliasIndicator], ReferencePoint",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[WeierstrassP]"],

Cell[TextData[{
  "\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]",
  ",",
  " \[AliasIndicator]l||\[AliasIndicator] \[AliasIndicator]r||\
\[AliasIndicator], population expectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],

Cell[TextData[{
  "\[CircleDot]",
  ",",
  " \[AliasIndicator]c.\[AliasIndicator], SelectContext",
  ", ",
  ButtonBox["Selecting contexts",
    ButtonData:>{"Selecting contexts", "SelectContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CircleDot]"],

Cell[TextData[{
  "\[Backslash], \[AliasIndicator]\[AliasIndicator], TakeAway, ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TakeAway"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TakeAway",
    ButtonData:>{"TakeAway", "TakeAway"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Backslash]"],

Cell[TextData[{
  "\[Wedge]",
  ",",
  " \[AliasIndicator]^\[AliasIndicator], ExactIntersection",
  ", ",
  ButtonBox["ExactIntersection",
    ButtonData:>{"ExactIntersection", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Wedge]"],

Cell[TextData[{
  "\[CirclePlus]",
  ",",
  " \[AliasIndicator]c+\[AliasIndicator], ChangeContext",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "ChangeContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CirclePlus]"]
}, Closed]],

Cell[CellGroupData[{

Cell["Index Sept 2002", "Subsubsection"],

Cell[BoxData[
    \(\(Scan[MakeIndexEntry, 
        ProcessIndexMatrix[MasterIndexMatrix]];\)\)], "Input"],

Cell[TextData[{
  "|.",
  ",",
  " ReplaceAllSpecial",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"|."],

Cell[TextData[{
  "\\\\",
  ",",
  " bugs with",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Repeated \\\\"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\\\\"],

Cell[TextData[{
  "<>",
  ",",
  " Expectation",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Expectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"<>"],

Cell[TextData[{
  "||.",
  ",",
  " ReplaceRepeatedSpecial",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"||."],

Cell[TextData[{
  "AddAncestors",
  ",",
  " to ancestral graphs",
  ", ",
  ButtonBox["Ancestors & descendants",
    ButtonData:>{"Ancestors & descendants", "AddAncestors"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddAncestors"],

Cell[TextData[{
  "AddCoalescentLineage",
  ",",
  " to ancestral graph",
  ", ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "AddCoalescentLineage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddCoalescentLineage"],

Cell[TextData[{
  "AddDescendants",
  ",",
  " to ancestral graphs",
  ", ",
  ButtonBox["Ancestors & descendants",
    ButtonData:>{"Ancestors & descendants", "AddDescendants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddDescendants"],

Cell[TextData[{
  "AddGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddGenealogy"],

Cell[TextData[{
  "Additive models",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "additive models"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive models"],

Cell[TextData[{
  "Additive selection",
  ",",
  " defining fitnesses",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive selection"],

Cell[TextData[{
  " defining rules",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Defining rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new D",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "New D"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "New mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " scaled D",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Scaled D"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive selection"],

Cell[TextData[{
  "AddMutation",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddMutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddMutation"],

Cell[TextData[{
  "AddNode",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddNode"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddNode"],

Cell[TextData[{
  "AddRecombinantLineages",
  ",",
  " to ancestral graph",
  ", ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "AddRecombinantLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddRecombinantLineages"],

Cell[TextData[{
  "AddTag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "AddTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddTag"],

Cell[TextData[{
  "AddUp",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "AddUp"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "AddUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddUp"],

Cell[TextData[{
  " multiple sums",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Multiple sums"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over subsets",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Subsets"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Technicalities"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddUp"],

Cell[TextData[{
  "AdmixtureFrequency",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "AdmixtureFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AdmixtureFrequency"],

Cell[TextData[{
  "Admixture models",
  ",",
  " ",
  ButtonBox["Admixture models",
    ButtonData:>{"Admixture models", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview",
    ButtonData:>{"Overview", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Admixture models"],

Cell[TextData[{
  " changing sex",
  ", ",
  ButtonBox["Changing sex",
    ButtonData:>{"Changing sex", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " equilibria",
  ", ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " iteration",
  ", ",
  ButtonBox["Iteration",
    ButtonData:>{"Iteration", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " migration",
  ", ",
  ButtonBox["Migration in admixture models",
    ButtonData:>{"Migration in admixture models", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " recombination",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Admixture models"],

Cell[TextData[{
  "Adults",
  ",",
  " \[GothicCapitalA], \[AliasIndicator]goA\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Adults"],

Cell[TextData[{
  "Allele frequencies",
  ",",
  " definition of fitness",
  ", ",
  ButtonBox["Allele frequencies:fitnesses",
    ButtonData:>{"Allele frequencies:fitnesses", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Allele frequencies"],

Cell[TextData[{
  " extracting",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "AlleleFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Allele frequencies"],

Cell[TextData[{
  "AlleleFrequencies",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "AlleleFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencies"],

Cell[TextData[{
  "AlleleFrequency",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "AlleleFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequency"],

Cell[TextData[{
  "AlleleFrequencyMean",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyMean"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", "AlleleFrequencyMean"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyMean"],

Cell[TextData[{
  "AlleleFrequencyP",
  ",",
  " \[GothicP], \[AliasIndicator]gop\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyP"],

Cell[TextData[{
  "AlleleFrequencyPermutations",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "AlleleFrequencyPermutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyPermutations"],

Cell[TextData[{
  "AlleleFrequencyPQ",
  ",",
  " \[GothicP]\[GothicQ], \[AliasIndicator]gop\[AliasIndicator]\
\[AliasIndicator]goq\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyPQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyPQ"],

Cell[TextData[{
  "AlleleFrequencyQ",
  ",",
  " \[GothicQ], \[AliasIndicator]goq\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyQ"],

Cell[TextData[{
  "AlleleFrequencyTable",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyTable"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", 
      "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with null alleles",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "NulAllele"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyTable"],

Cell[TextData[{
  "AllelicDeviation",
  ",",
  " \[Zeta], \[AliasIndicator]z\[AliasIndicator]",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicDeviation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllelicDeviation"],

Cell[TextData[{
  "AllelicState",
  ",",
  " X",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicState"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllelicState"],

Cell[TextData[{
  "AllEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "AllEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllEvents"],

Cell[TextData[{
  "AllSets",
  ",",
  " ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "AllSets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllSets"],

Cell[TextData[{
  "Ancestors",
  ",",
  " determining",
  ", ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "Ancestors"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestors"],

Cell[TextData[{
  " in ancestral graphs",
  ", ",
  ButtonBox["Ancestors & descendants",
    ButtonData:>{"Ancestors & descendants", "Ancestors"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestors"],

Cell[TextData[{
  "AncestralGraphPattern",
  ",",
  " ",
  ButtonBox["Representing ancestral graphs",
    ButtonData:>{"Representing ancestral graphs", "AncestralGraphPattern"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AncestralGraphPattern"],

Cell[TextData[{
  "Ancestral graphs",
  ",",
  " describing",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestral graphs"],

Cell[TextData[{
  " genealogies in",
  ", ",
  ButtonBox["Extracting genealogies",
    ButtonData:>{"Extracting genealogies", "ExtractGenealogy"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction",
  ", ",
  ButtonBox["Ancestral graphs introduction",
    ButtonData:>{"Ancestral graphs introduction", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " plotting",
  ", ",
  ButtonBox["Plotting ancestral graphs",
    ButtonData:>{"Plotting ancestral graphs", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " random",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " representing",
  ", ",
  ButtonBox["Representing ancestral graphs",
    ButtonData:>{"Representing ancestral graphs", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestral graphs"],

Cell[TextData[{
  "AncestralLineage",
  ",",
  " ",
  ButtonBox["Representing ancestral graphs",
    ButtonData:>{"Representing ancestral graphs", "AncestralLineage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AncestralLineage"],

Cell[TextData[{
  "AncestralLineagePattern",
  ",",
  " ",
  ButtonBox["Representing ancestral graphs",
    ButtonData:>{"Representing ancestral graphs", "AncestralLineagePattern"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AncestralLineagePattern"],

Cell[TextData[{
  "Ancestry",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Ancestry"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestry"],

Cell[TextData[{
  "Arbitrary sets of loci",
  ",",
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Arbitrary sets of loci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Arbitrary sets of loci"],

Cell[TextData[{
  "Arnold 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Arnold 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Arnold 1996"],

Cell[TextData[{
  "Asmussen and Orive 2000",
  ",",
  " ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["References",
    ButtonData:>{"References", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Asmussen and Orive 2000"],

Cell[TextData[{
  "Asmussen et al. 1987",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Asmussen et al 1987"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Asmussen et al. 1987"],

Cell[TextData[{
  "B",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "B"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"B"],

Cell[TextData[{
  "Baake 2001",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Baake"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["References",
    ButtonData:>{"References", "Baake 2001"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Baake 2001"],

Cell[TextData[{
  "BackgroundStyle",
  ",",
  " option for PlotSegments",
  ", ",
  ButtonBox["Plotting ancestral graphs",
    ButtonData:>{"Plotting ancestral graphs", "BackgroundStyle"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BackgroundStyle"],

Cell[TextData[{
  "Barrier",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", "Barrier"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barrier"],

Cell[TextData[{
  "BarrierStrength",
  ",",
  " ",
  ButtonBox["Describing populations",
    ButtonData:>{"Describing populations", "BarrierStrength"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BarrierStrength"],

Cell[TextData[{
  "Barton 1986",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton 1986"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 1986"],

Cell[TextData[{
  "Barton 1995",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Barton 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 1995"],

Cell[TextData[{
  "Barton 2000",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 2000"],

Cell[TextData[{
  "Barton and Turelli 1991",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Barton and Turelli 1991"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton and Turelli 1991"],

Cell[TextData[{
  "Barton & Gale 1993",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Gale 1993"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Gale 1993"],

Cell[TextData[{
  "Barton & Shpak 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Shpak 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Shpak 1999"],

Cell[TextData[{
  "Barton & Turelli 1991",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Turelli 1991"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Turelli 1991"],

Cell[TextData[{
  "Bennett 1954",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Bennett 1954"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bennett 1954"],

Cell[TextData[{
  "BennettB",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "BennettB"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BennettB"],

Cell[TextData[{
  "BennettC",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "BennettC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BennettC"],

Cell[TextData[{
  "BennettExpansion",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "BennettExpansion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BennettExpansion"],

Cell[TextData[{
  "Biallelic",
  ",",
  " ",
  ButtonBox["Two alleles",
    ButtonData:>{"Two alleles", "Biallelic"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Biallelic"],

Cell[TextData[{
  " selection coefficients",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Biallelic"],

Cell[TextData[{
  "BiallelicMutation",
  ",",
  " ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "BiallelicMutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BiallelicMutation"],

Cell[TextData[{
  " Mutation option",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Mutation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BiallelicMutation"],

Cell[TextData[{
  "Binary integers",
  ",",
  " ",
  ButtonBox["Set combinations",
    ButtonData:>{"Set combinations", "SetOfCombinations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Binary integers"],

Cell[TextData[{
  "Birth",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "Birth"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Birth"],

Cell[TextData[{
  "BirthTime",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "BirthTime"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BirthTime"],

Cell[TextData[{
  "Boundary conditions",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Boundary conditions"],

Cell[TextData[{
  "Box",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Box"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Box"],

Cell[TextData[{
  "Boxes",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Boxes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Boxes"],

Cell[TextData[{
  "Browser categories",
  ",",
  " ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Browser categories"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Browser categories"],

Cell[TextData[{
  "Bugs",
  ",",
  " applying rules",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bugs"],

Cell[TextData[{
  " clashes between packages",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Clashes between packages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " estimating D",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " incompatibilities",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Incompatibilities"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " manipulating notebooks",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Manipulating notebooks"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " multilocus notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Multilocus notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " numerical error with AlleleFrequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Numerical bug"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pasting hyperlinks",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Pasting hyperlinks"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " repeated \\\\",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Repeated \\\\"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " special notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with style sheets",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Style sheets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bugs"],

Cell[TextData[{
  "ChangeContext",
  ",",
  "\[CirclePlus], \[AliasIndicator]c+\[AliasIndicator]",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "ChangeContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ChangeContext"],

Cell[TextData[{
  "ChangeSex",
  ",",
  " ",
  ButtonBox["Changing sex",
    ButtonData:>{"Changing sex", "ChangeSex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ChangeSex"],

Cell[TextData[{
  "ClassToGenotypes",
  ",",
  " ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "ClassToGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClassToGenotypes"],

Cell[TextData[{
  "Cline",
  ",",
  " example of",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cline"],

Cell[TextData[{
  " in allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: spatially varying selection",
    ButtonData:>{"Symmetric stability: spatially varying selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: setting up a symmetric cline",
    ButtonData:>{"Simulating individuals: setting up a symmetric cline", 
      None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: setting up a symmetric cline",
    ButtonData:>{"Symmetric model: setting up a symmetric cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with neutral marker",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", "Cline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cline"],

Cell[TextData[{
  "ClineGradient",
  ",",
  "  for genotype frequencies",
  ", ",
  ButtonBox["ClineGradient: setting up a cline",
    ButtonData:>{"ClineGradient: setting up a cline", "ClineGradient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineGradient"],

Cell[TextData[{
  "ClineWidth",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineWidth"],

Cell[TextData[{
  "  for genotype frequencies",
  ", ",
  ButtonBox["Recursions: setting up a cline",
    ButtonData:>{"Recursions: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineWidth"],

Cell[TextData[{
  "CoalesceLineages",
  ",",
  " ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "CoalesceLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CoalesceLineages"],

Cell[TextData[{
  "CoalescenceDistribution",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", 
      "CoalescenceDistribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CoalescenceDistribution"],

Cell[TextData[{
  "CoalescenceEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "CoalescenceEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CoalescenceEvents"],

Cell[TextData[{
  "Coalescence times",
  ",",
  " random, for ancestral graphs",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", "RandomCoalescenceTimes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Coalescence times"],

Cell[TextData[{
  "CoalescentLineages",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "CoalescentLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CoalescentLineages"],

Cell[TextData[{
  "Coalescing lineages",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "CoalesceLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Coalescing lineages"],

Cell[TextData[{
  "CollapseGenealogy",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "CollapseGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CollapseGenealogy"],

Cell[TextData[{
  "Combinations",
  ",",
  " set of",
  ", ",
  ButtonBox["Set combinations",
    ButtonData:>{"Set combinations", "SetOfCombinations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Combinations"],

Cell[TextData[{
  "Combine",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Combine"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Combine"],

Cell[TextData[{
  "CompareLogL",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "CompareLogL"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CompareLogL"],

Cell[TextData[{
  "Compiled",
  ",",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Compiled"],

Cell[TextData[{
  "Compiling",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Compiling"],

Cell[TextData[{
  "CondenseGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "CondenseGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CondenseGenealogy"],

Cell[TextData[{
  "CondenseMatrix",
  ",",
  " ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", "CondenseMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CondenseMatrix"],

Cell[TextData[{
  "ConfigurationSet",
  ",",
  " ",
  ButtonBox["Set combinations",
    ButtonData:>{"Set combinations", "ConfigurationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConfigurationSet"],

Cell[TextData[{
  "ConstrainedIntervals",
  ",",
  " ",
  ButtonBox["Constrained intervals",
    ButtonData:>{"Constrained intervals", "ConstrainedIntervals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstrainedIntervals"],

Cell[TextData[{
  "ConstructMutateList",
  ",",
  " ",
  ButtonBox["Allele frequencies: mutation",
    ButtonData:>{"Allele frequencies: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: mutation",
    ButtonData:>{"Simulating individuals: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstructMutateList"],

Cell[TextData[{
  "ConstructMutateMatrix",
  ",",
  " ",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "ConstructMutateMatrix"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "ConstructMutateMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstructMutateMatrix"],

Cell[TextData[{
  "ContextComponentQ",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextComponentQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextComponentQ"],

Cell[TextData[{
  "ContextPosition",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextPosition"],

Cell[TextData[{
  "ContextStageQ",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextStageQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextStageQ"],

Cell[TextData[{
  "ContextStructure",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextStructure"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextStructure"],

Cell[TextData[{
  "Continuous populations",
  ",",
  " estimating covariance",
  ", ",
  ButtonBox["Estimating the covariance",
    ButtonData:>{"Estimating the covariance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Continuous populations"],

Cell[TextData[{
  " example",
  ", ",
  ButtonBox["An example",
    ButtonData:>{"An example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " implementation",
  ", ",
  ButtonBox["Implementation",
    ButtonData:>{"Implementation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving results",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "Saving results"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " the model",
  ", ",
  ButtonBox["The model",
    ButtonData:>{"The model", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Continuous populations"],

Cell[TextData[{
  "ContinuumVariables",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "ContinuumVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContinuumVariables"],

Cell[TextData[{
  "ConvertData",
  ",",
  " ",
  ButtonBox["Converting a dataset",
    ButtonData:>{"Converting a dataset", "ConvertData"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConvertData"],

Cell[TextData[{
  "ConvertHyperlinkToAddOnsLink",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "ConvertHyperlinkToAddOnsLink"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConvertHyperlinkToAddOnsLink"],

Cell[TextData[{
  "Converting",
  ",",
  " between representations",
  ", ",
  ButtonBox["Allele frequencies: converting",
    ButtonData:>{"Allele frequencies: converting", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Converting"],

Cell[TextData[{
  "CountHeterozygotes",
  ",",
  " ",
  ButtonBox["Recursions:manipulation",
    ButtonData:>{"Recursions:manipulation", "CountHeterozygotes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CountHeterozygotes"],

Cell[TextData[{
  "Covariance",
  ",",
  " in continuous populations",
  ", ",
  ButtonBox["Estimating the covariance",
    ButtonData:>{"Estimating the covariance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Covariance"],

Cell[TextData[{
  "CovarianceMidPoints",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "CovarianceMidPoints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CovarianceMidPoints"],

Cell[TextData[{
  "Crow and Kimura 1970",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Crow and Kimura 1970"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Crow and Kimura 1970"],

Cell[TextData[{
  "Cumulant",
  ",",
  " ",
  ButtonBox["Moments and cumulants",
    ButtonData:>{"Moments and cumulants", "Cumulant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cumulant"],

Cell[TextData[{
  "CumulantDisequilibrium",
  ",",
  " \[GothicK], \[AliasIndicator]gok\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "CumulantDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantDisequilibrium"],

Cell[TextData[{
  "CumulantEquilibrium",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "CumulantEquilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantEquilibrium"],

Cell[TextData[{
  "CumulantPopulationDisequilibrium",
  ",",
  " \[GothicCapitalK], \[AliasIndicator]goK\[AliasIndicator]",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantPopulationDisequilibrium"],

Cell[TextData[{
  "CumulantReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "CumulantReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantReduced"],

Cell[TextData[{
  "Cumulants",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "7.2"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Cumulant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cumulants"],

Cell[TextData[{
  "Cytoplasmic inheritance",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cytoplasmic inheritance"],

Cell[TextData[{
  " and migration",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Cytonuclear associations"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " examples of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cytoplasmic inheritance"],

Cell[TextData[{
  "CytoplasmicLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CytoplasmicLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CytoplasmicLoci"],

Cell[TextData[{
  "dAlleleFrequencyPermutations",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "dAlleleFrequencyPermutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"dAlleleFrequencyPermutations"],

Cell[TextData[{
  "Data",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Data"],

Cell[TextData[{
  " missing",
  ", ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Missing data"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notation for",
  ", ",
  ButtonBox["Notation for genetic data",
    ButtonData:>{"Notation for genetic data", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Data"],

Cell[TextData[{
  "Datasets",
  ",",
  " defining",
  ", ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Datasets"],

Cell[TextData[{
  "Dawson 2000",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Bennett"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["References",
    ButtonData:>{"References", "Dawson 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dawson 2000"],

Cell[TextData[{
  "Death",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "Death"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Death"],

Cell[TextData[{
  "DeathTime",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "DeathTime"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeathTime"],

Cell[TextData[{
  "DefineContext",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "DefineContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DefineContext"],

Cell[TextData[{
  "DegreesOfFreedom",
  ",",
  " ",
  ButtonBox["Degrees of freedom",
    ButtonData:>{"Degrees of freedom", "DegreesOfFreedom"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DegreesOfFreedom"],

Cell[TextData[{
  "DeletedMutations",
  ",",
  " ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", "DeletedMutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeletedMutations"],

Cell[TextData[{
  "DeleteGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "DeleteGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeleteGenealogy"],

Cell[TextData[{
  "DeleteNullLineages",
  ",",
  " option for RandomGenealogy",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", "DeleteNullLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeleteNullLineages"],

Cell[TextData[{
  " option for RecombineLineage",
  ", ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "DeleteNullLineages"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeleteNullLineages"],

Cell[TextData[{
  "Deme",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Deme"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Deme"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Deme"],

Cell[TextData[{
  "DemeSize",
  ",",
  " compiling",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "Deme size (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DemeSize"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for MigrateExact",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DemeSize"],

Cell[TextData[{
  "Dempster et al 1977",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Dempster et al 1977"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dempster et al 1977"],

Cell[TextData[{
  "Density",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Density"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Density"],

Cell[TextData[{
  "Descendants",
  ",",
  " ",
  ButtonBox["Ancestors and descendants",
    ButtonData:>{"Ancestors and descendants", "Descendants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Descendants"],

Cell[TextData[{
  " determining",
  ", ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "Descendants"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in ancestral graphs",
  ", ",
  ButtonBox["Ancestors & descendants",
    ButtonData:>{"Ancestors & descendants", "Descendants"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Descendants"],

Cell[TextData[{
  "Dicytonuclear associations",
  ",",
  " ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dicytonuclear associations"],

Cell[TextData[{
  "Diploid",
  ",",
  " option for MomentFromG",
  ", ",
  ButtonBox["Moments from genotype frequencies",
    ButtonData:>{"Moments from genotype frequencies", "Diploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Diploid"],

Cell[TextData[{
  "DiploidConstraints",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidConstraints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidConstraints"],

Cell[TextData[{
  "DiploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidFrequencies"],

Cell[TextData[{
  "DiploidGenotypeFrequency",
  ",",
  " ",
  ButtonBox["Genotype frequencies from moments",
    ButtonData:>{"Genotype frequencies from moments", 
      "DiploidGenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequency"],

Cell[TextData[{
  "DiploidGenotypeFrequencyList",
  ",",
  " ",
  ButtonBox["Fast calculations",
    ButtonData:>{"Fast calculations", "DiploidGenotypeFrequencyList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyList"],

Cell[TextData[{
  "DiploidGenotypeFrequencyReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyReduced"],

Cell[TextData[{
  "DiploidGenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyTable"],

Cell[TextData[{
  "DiploidIndividuals",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidIndividuals"],

Cell[TextData[{
  "DiploidPhenotype",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidPhenotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidPhenotype"],

Cell[TextData[{
  "DiploidPsi",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidPsi"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "DiploidPsi"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidPsi"],

Cell[TextData[{
  "DiploidRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidRepresentations"],

Cell[TextData[{
  "DiploidSource",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidSource"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "DiploidSource"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidSource"],

Cell[TextData[{
  "DiploidSubsets",
  ",",
  " ",
  ButtonBox["Subsets of loci",
    ButtonData:>{"Subsets of loci", "DiploidSubsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidSubsets"],

Cell[TextData[{
  "DiploidTypes",
  ",",
  " ",
  ButtonBox["Listing genotypes",
    ButtonData:>{"Listing genotypes", "DiploidTypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidTypes"],

Cell[TextData[{
  "Disequilibrium",
  ",",
  " Baake's measure",
  ", ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Baake"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Disequilibrium"],

Cell[TextData[{
  " Bennett's principal components",
  ", ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Bennett"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " \[GothicCapitalD], \[AliasIndicator]\[GothicCapitalD]\[AliasIndicator]",
  ", ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Disequilibrium"],

Cell[TextData[{
  "DisequilibriumMean",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumMean"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumMean"],

Cell[TextData[{
  "DisequilibriumTable",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", "DisequilibriumTable"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumTable"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumTable"],

Cell[TextData[{
  "Dispersal",
  ",",
  " in continuum simulations",
  ", ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dispersal"],

Cell[TextData[{
  "DistanceSquared",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "DistanceSquared"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DistanceSquared"],

Cell[TextData[{
  "Distribution",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Distribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Distribution"],

Cell[TextData[{
  "DivideZero",
  ",",
  " ",
  ButtonBox["DivideZero",
    ButtonData:>{"DivideZero", "DivideZero"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DivideZero"],

Cell[TextData[{
  "DoReplicates",
  ",",
  " ",
  ButtonBox["Analysing replicate samples",
    ButtonData:>{"Analysing replicate samples", "DoReplicates"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoReplicates"],

Cell[TextData[{
  "DoubleCline",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a symmetric cline",
    ButtonData:>{"Allele frequencies: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoubleCline"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: setting up a symmetric cline",
    ButtonData:>{"Simulating individuals: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a symmetric cline",
    ButtonData:>{"Symmetric model: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoubleCline"],

Cell[TextData[{
  "DrawSamples",
  ",",
  " ",
  ButtonBox["Setting up replicates",
    ButtonData:>{"Setting up replicates", "DrawSamples"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DrawSamples"],

Cell[TextData[{
  "DropOptions",
  ",",
  " ",
  ButtonBox["Manipulating options",
    ButtonData:>{"Manipulating options", "DropOptions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DropOptions"],

Cell[TextData[{
  "Edwards 1972",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Edwards 1972"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Edwards 1972"],

Cell[TextData[{
  "EmptySets",
  ",",
  "option for PartitionSet",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "EmptySets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EmptySets"],

Cell[TextData[{
  "Epistasis",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Epistasis"],

Cell[TextData[{
  "EquivalentSexes",
  ",",
  " obsolete form of SymmetricSexes",
  ", ",
  ButtonBox["Symmetric sexes",
    ButtonData:>{"Symmetric sexes", "SymmetricSexes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EquivalentSexes"],

Cell[TextData[{
  "ErrorBound",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "ErrorBound"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ErrorBound"],

Cell[TextData[{
  "EstimateFamilyMoments",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "EstimateFamilyMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EstimateFamilyMoments"],

Cell[TextData[{
  "EstimateMoments",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "EstimateMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EstimateMoments"],

Cell[TextData[{
  "Estimating D",
  ",",
  " admixture models",
  ", ",
  ButtonBox["Admixture models",
    ButtonData:>{"Admixture models", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Estimating D"],

Cell[TextData[{
  " alternative methods",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Log-linear models"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction",
  ", ",
  ButtonBox["Introduction to estimating D",
    ButtonData:>{"Introduction to estimating D", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " maximum entropy",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Maximum entropy"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " maximum likelihood, example of",
  ", ",
  ButtonBox["MLE example",
    ButtonData:>{"MLE example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Metropolis random walk",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MLE, cumulants",
  ", ",
  ButtonBox["Finding the MLE",
    ButtonData:>{"Finding the MLE", "Cumulant"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " moments, families",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "Extension to families"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " naive MLE",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Naive MLE"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " obsolete",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pairs of loci",
  ", ",
  ButtonBox["Pairs of loci",
    ButtonData:>{"Pairs of loci", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pairs of loci, example of",
  ", ",
  ButtonBox["Pairwise example",
    ButtonData:>{"Pairwise example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " random sampling, example of",
  ", ",
  ButtonBox["Sampling example",
    ButtonData:>{"Sampling example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " summary",
  ", ",
  ButtonBox["Summary",
    ButtonData:>{"Summary", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " varying divergence",
  ", ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "Varying divergence"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Estimating D"],

Cell[TextData[{
  "ExactEigenvalues",
  ",",
  " ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "ExactEigenvalues"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactEigenvalues"],

Cell[TextData[{
  "ExactIntersection",
  ",",
  " \[Wedge], \[AliasIndicator]^\[AliasIndicator]",
  ", ",
  ButtonBox["ExactIntersection",
    ButtonData:>{"ExactIntersection", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactIntersection"],

Cell[TextData[{
  "ExactProbability",
  ",",
  " ",
  ButtonBox["Exact probability",
    ButtonData:>{"Exact probability", "ExactProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactProbability"],

Cell[TextData[{
  "Expectation",
  ",",
  " <>",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Expectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Expectation"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Expectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population, \[LeftDoubleBracketingBar] \[RightDoubleBracketingBar], \
\[AliasIndicator]l||\[AliasIndicator] \[AliasIndicator]r||\[AliasIndicator]",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Expectation"],

Cell[TextData[{
  "ExponentialF",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExponentialF"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "ExponentialF"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExponentialF"],

Cell[TextData[{
  "ExtantIndividuals",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "ExtantIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtantIndividuals"],

Cell[TextData[{
  "ExtractContexts",
  ",",
  " \[Chi], \[AliasIndicator]c\[AliasIndicator]",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractContexts"],

Cell[TextData[{
  "ExtractExtant",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "ExtractExtant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractExtant"],

Cell[TextData[{
  "ExtractGenealogy",
  ",",
  " ",
  ButtonBox["Extracting genealogies",
    ButtonData:>{"Extracting genealogies", "ExtractGenealogy"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "ExtractGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractGenealogy"],

Cell[TextData[{
  "ExtractGenes",
  ",",
  " \[Gamma], \[AliasIndicator]g\[AliasIndicator]",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractGenes"],

Cell[TextData[{
  "ExtractInformation",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "ExtractInformation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractInformation"],

Cell[TextData[{
  " from ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "ExtractInformation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractInformation"],

Cell[TextData[{
  "ExtractLabel",
  ",",
  " from ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "ExtractLabel"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractLabel"],

Cell[TextData[{
  "ExtractLineagesEndingAtT",
  ",",
  " from ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "ExtractLineagesEndingAtT"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractLineagesEndingAtT"],

Cell[TextData[{
  "ExtractLineagesStartingAtT",
  ",",
  " from ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "ExtractLineagesStartingAtT"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractLineagesStartingAtT"],

Cell[TextData[{
  "ExtractRepeat",
  ",",
  " ",
  ButtonBox["Repeated elements",
    ButtonData:>{"Repeated elements", "ExtractRepeat"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractRepeat"],

Cell[TextData[{
  "ExtractSubMatrix",
  ",",
  " ",
  ButtonBox["Extracting submatrices",
    ButtonData:>{"Extracting submatrices", "ExtractSubMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractSubMatrix"],

Cell[TextData[{
  "FamilyAlleleFrequencyEstimate",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyAlleleFrequencyEstimate"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyAlleleFrequencyEstimate"],

Cell[TextData[{
  "FamilyEffects",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyEffects"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyEffects"],

Cell[TextData[{
  "FamilyM",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyM"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyM"],

Cell[TextData[{
  "FamilyProbability",
  ",",
  " ",
  ButtonBox["Probabilities",
    ButtonData:>{"Probabilities", "FamilyProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyProbability"],

Cell[TextData[{
  "Family structure",
  ",",
  " set of all",
  ", ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "NewS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Family structure"],

Cell[TextData[{
  "Fecundity",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Fecundity"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fecundity"],

Cell[TextData[{
  "FindHyperlinks",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "FindHyperlinks"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindHyperlinks"],

Cell[TextData[{
  "FindIndexTag",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "FindIndexTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindIndexTag"],

Cell[TextData[{
  "FindMLE",
  ",",
  " ",
  ButtonBox["Finding the MLE",
    ButtonData:>{"Finding the MLE", "FindMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindMLE"],

Cell[TextData[{
  "FindNode",
  ",",
  " ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", "FindNode"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindNode"],

Cell[TextData[{
  "FindPosition",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "FindPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindPosition"],

Cell[TextData[{
  "FindTags",
  ",",
  " ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "FindTags"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindTags"],

Cell[TextData[{
  "Fitness",
  ",",
  " definition for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:fitnesses",
    ButtonData:>{"Allele frequencies:fitnesses", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fitness"],

Cell[TextData[{
  " in individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " problems redefining",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Redefining fitness"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fitness"],

Cell[TextData[{
  "FitnessSet",
  ",",
  " \[DoubleStruckCapitalW], \[AliasIndicator]dsW\[AliasIndicator]",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "FitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessSet"],

Cell[TextData[{
  "FitnessTable",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessTable"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessTable"],

Cell[TextData[{
  "FixedEnds",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FixedEnds"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for MigrateExact",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FixedEnds"],

Cell[TextData[{
  "Flatten",
  ",",
  " ",
  ButtonBox["Flattening lists at specific levels",
    ButtonData:>{"Flattening lists at specific levels", "Flatten"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Flatten"],

Cell[TextData[{
  "FlattenList",
  ",",
  " ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "FlattenList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FlattenList"],

Cell[TextData[{
  " PatternFree",
  ", ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "PatternFree"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FlattenList"],

Cell[TextData[{
  "FourierNormalised",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "FourierNormalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FourierNormalised"],

Cell[TextData[{
  "FourierNormalisedTable",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "FourierNormalisedTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FourierNormalisedTable"],

Cell[TextData[{
  "FrequencyRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "FrequencyRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FrequencyRepresentations"],

Cell[TextData[{
  "FromBaake",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "FromBaake"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FromBaake"],

Cell[TextData[{
  "FromBennett",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "FromBennett"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FromBennett"],

Cell[TextData[{
  "FromBennettExpression",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "FromBennettExpression"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FromBennettExpression"],

Cell[TextData[{
  "FullContext",
  ",",
  " ",
  ButtonBox["Abbreviating contexts",
    ButtonData:>{"Abbreviating contexts", "FullContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullContext"],

Cell[TextData[{
  "FullGenotypeFrequencyReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullGenotypeFrequencyReduced"],

Cell[TextData[{
  "FullGenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullGenotypeFrequencyTable"],

Cell[TextData[{
  "FullOutput",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "FullOutput"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullOutput"],

Cell[TextData[{
  "Function",
  ",",
  " ",
  ButtonBox["Marginal tables",
    ButtonData:>{"Marginal tables", "Function"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Function"],

Cell[TextData[{
  "Gametes",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "Gametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gametes"],

Cell[TextData[{
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new, \!\(\(\[GothicCapitalG]\^*\)\), \
\[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, \[GothicCapitalG]new",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " \[GothicCapitalG], \[AliasIndicator]goG\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gametes"],

Cell[TextData[{
  "GameteTable",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "GameteTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GameteTable"],

Cell[TextData[{
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "GameteTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "GameteTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GameteTable"],

Cell[TextData[{
  "GaussianLogLikelihood",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "GaussianLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GaussianLogLikelihood"],

Cell[TextData[{
  "GaussianMLE",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "GaussianMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GaussianMLE"],

Cell[TextData[{
  "Genealogies",
  ",",
  " exact probability",
  ", ",
  ButtonBox["Exact probability",
    ButtonData:>{"Exact probability", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genealogies"],

Cell[TextData[{
  " extracting from ancestral graphs",
  ", ",
  ButtonBox["Extracting genealogies",
    ButtonData:>{"Extracting genealogies", "ExtractGenealogy"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " family structure",
  ", ",
  ButtonBox["Family structure",
    ButtonData:>{"Family structure", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " generating functions",
  ", ",
  ButtonBox["Deriving recursions for the MGF",
    ButtonData:>{"Deriving recursions for the MGF", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " probability of",
  ", ",
  ButtonBox["Deriving the probability",
    ButtonData:>{"Deriving the probability", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sampling",
  ", ",
  ButtonBox["Sampling genealogies",
    ButtonData:>{"Sampling genealogies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genealogies"],

Cell[TextData[{
  "Genealogy",
  ",",
  " rooting",
  ", ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", "SwapStates"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "RootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genealogy"],

Cell[TextData[{
  "GenealogyToMatrix",
  ",",
  " ",
  ButtonBox["Describing mutation",
    ButtonData:>{"Describing mutation", "GenealogyToMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenealogyToMatrix"],

Cell[TextData[{
  "GeneralizedTransform",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "GeneralizedTransform"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GeneralizedTransform"],

Cell[TextData[{
  "Generating functions",
  ",",
  " examples",
  ", ",
  ButtonBox["Examples of the MGF",
    ButtonData:>{"Examples of the MGF", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Generating functions"],

Cell[TextData[{
  " for cumulants",
  ", ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "GeneralizedTransform"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genealogies",
  ", ",
  ButtonBox["Deriving recursions for the MGF",
    ButtonData:>{"Deriving recursions for the MGF", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Generating functions"],

Cell[TextData[{
  "Genes and contexts",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Genes and contexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genes and contexts"],

Cell[TextData[{
  "Genome",
  ",",
  " set of all positions in, \[DoubleStruckCapitalG], \[AliasIndicator]dsG\
\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genome"],

Cell[TextData[{
  "Genotype",
  ",",
  " in continuum simulations",
  ", ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Genotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype"],

Cell[TextData[{
  " observable",
  ", ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for InitialiseContinuum",
  ", ",
  ButtonBox["Initialisation",
    ButtonData:>{"Initialisation", "Genotype"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype"],

Cell[TextData[{
  "Genotype frequencies",
  ",",
  " recursions",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype frequencies"],

Cell[TextData[{
  "Genotype frequency",
  ",",
  " of a given genotype",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype frequency"],

Cell[TextData[{
  "GenotypeFrequency",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequency"],

Cell[TextData[{
  "GenotypeFrequencyArguments",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "GenotypeFrequencyArguments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyArguments"],

Cell[TextData[{
  "GenotypeFrequencyConvert",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "GenotypeFrequencyConvert"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyConvert"],

Cell[TextData[{
  "GenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyTable"],

Cell[TextData[{
  "GenotypePosition",
  ",",
  " ",
  ButtonBox["Recursions:manipulation",
    ButtonData:>{"Recursions:manipulation", "GenotypePosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypePosition"],

Cell[TextData[{
  "GenotypeProbability",
  ",",
  " ",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "GenotypeProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeProbability"],

Cell[TextData[{
  " segregation ratio",
  ", ",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeProbability"],

Cell[TextData[{
  "Genotypes",
  ",",
  " notation for",
  ", ",
  ButtonBox["Notation",
    ButtonData:>{"Notation", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotypes"],

Cell[TextData[{
  "GlobalContinuumVariables",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "GlobalContinuumVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GlobalContinuumVariables"],

Cell[TextData[{
  "Gnew",
  ",",
  " \!\(\(\[GothicCapitalG]\^*\)\), \[AliasIndicator]goG\[AliasIndicator]\
\[ControlKey]^*, new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gnew"],

Cell[TextData[{
  "Goodman et al 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Goodman et al 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Goodman et al 1999"],

Cell[TextData[{
  "Graphs",
  ",",
  " ancestral",
  ", ",
  ButtonBox["Ancestral graph introduction",
    ButtonData:>{"Ancestral graph introduction", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Graphs"],

Cell[TextData[{
  "Griffiths-Tavare",
  ",",
  " ",
  ButtonBox["Exact algorithm",
    ButtonData:>{"Exact algorithm", "GriffithsTavare"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Griffiths-Tavare algorithm",
    ButtonData:>{"Griffiths-Tavare algorithm", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Griffiths-Tavare"],

Cell[TextData[{
  " stochastic algorithm",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "MonteCarloGriffithsTavare"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "Stochastic GT algorithm"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stochastic, comparison with MonteCarloProbability",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", 
      "Comparison with MonteCarloProbability"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stochastic example",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "Small example"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Griffiths-Tavare"],

Cell[TextData[{
  "Guiasu & Shenitzer 1985",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Guiasu & Shenitzer 1985"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Guiasu & Shenitzer 1985"],

Cell[TextData[{
  "HaploidConstraints",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "HaploidConstraints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidConstraints"],

Cell[TextData[{
  "HaploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidFrequencies"],

Cell[TextData[{
  "HaploidGenotypeFrequency",
  ",",
  " ",
  ButtonBox["Genotype frequencies from moments",
    ButtonData:>{"Genotype frequencies from moments", 
      "HaploidGenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidGenotypeFrequency"],

Cell[TextData[{
  "HaploidIndividuals",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidIndividuals"],

Cell[TextData[{
  "HaploidRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidRepresentations"],

Cell[TextData[{
  "Haploids",
  ",",
  " selection on",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Haploids"],

Cell[TextData[{
  "HaploidSource",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "HaploidSource"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "HaploidSource"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidSource"],

Cell[TextData[{
  "HaploidSubsets",
  ",",
  " ",
  ButtonBox["Subsets of loci",
    ButtonData:>{"Subsets of loci", "HaploidSubsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidSubsets"],

Cell[TextData[{
  "HaploidTypes",
  ",",
  " ",
  ButtonBox["Listing genotypes",
    ButtonData:>{"Listing genotypes", "HaploidTypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidTypes"],

Cell[TextData[{
  "Help browser",
  ",",
  " setting up new files",
  ", ",
  ButtonBox["Setting up new help files",
    ButtonData:>{"Setting up new help files", "Setting up new help files"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help browser"],

Cell[TextData[{
  "Help Browser",
  ",",
  " ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "MasterIndexHeading"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help Browser"],

Cell[TextData[{
  " setting up hyperlinks",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up links"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help Browser"],

Cell[TextData[{
  "Hermaphrodites",
  ",",
  " \[GothicCapitalH], \[AliasIndicator]goH\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hermaphrodites"],

Cell[TextData[{
  "HeterozygoteB",
  ",",
  " ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "HeterozygoteB"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HeterozygoteB"],

Cell[TextData[{
  "Hill 1974a",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974a"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974a"],

Cell[TextData[{
  "Hill 1974b",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974b"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974b"],

Cell[TextData[{
  "Hill 1974c",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974c"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974c"],

Cell[TextData[{
  "Hudson 1990",
  ",",
  " ",
  ButtonBox["Ancestral graph references",
    ButtonData:>{"Ancestral graph references", "Hudson 1990"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Ancestral graphs introduction",
    ButtonData:>{"Ancestral graphs introduction", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hudson 1990"],

Cell[TextData[{
  "Hypergeometric model",
  ",",
  " ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hypergeometric model"],

Cell[TextData[{
  "Hyperlinks",
  ",",
  " bugs in pasting",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Pasting hyperlinks"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hyperlinks"],

Cell[TextData[{
  " saving",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Saving the links"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " setting up",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up links"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " to cell tags",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Setting up links to a list of tags"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hyperlinks"],

Cell[TextData[{
  "IncidenceMatrix",
  ",",
  " ",
  ButtonBox["Ordered genealogies",
    ButtonData:>{"Ordered genealogies", "IncidenceMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IncidenceMatrix"],

Cell[TextData[{
  "Index",
  ",",
  " setting up",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up Master Index"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Index"],

Cell[TextData[{
  "Individual",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Individual"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Individual"],

Cell[TextData[{
  "IndividualContinuumVariables",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "IndividualContinuumVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IndividualContinuumVariables"],

Cell[TextData[{
  "IndividualRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "IndividualRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IndividualRepresentations"],

Cell[TextData[{
  "Individuals",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Individuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Individuals"],

Cell[TextData[{
  "InferParentalGenotypes",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "InferParentalGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InferParentalGenotypes"],

Cell[TextData[{
  "Infinite sites mutation",
  ",",
  " ",
  ButtonBox["Describing mutation",
    ButtonData:>{"Describing mutation", "None"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Infinite sites mutation"],

Cell[TextData[{
  "InformationFunction",
  ",",
  " option for CoalesceLineages",
  ", ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "InformationFunctionC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InformationFunction"],

Cell[TextData[{
  " option for ExtractGenealogy",
  ", ",
  ButtonBox["Extracting genealogies",
    ButtonData:>{"Extracting genealogies", "InformationFunction"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for RecombineLineage",
  ", ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "InformationFunctionR"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InformationFunction"],

Cell[TextData[{
  "InitialiseContinuum",
  ",",
  " ",
  ButtonBox["Initialisation",
    ButtonData:>{"Initialisation", "InitialiseContinuum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseContinuum"],

Cell[TextData[{
  "InitialiseCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "InitialiseCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseCovariance"],

Cell[TextData[{
  "InitialiseDemes",
  ",",
  " ",
  ButtonBox["Describing the population",
    ButtonData:>{"Describing the population", "InitialiseDemes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Setting up a cline",
    ButtonData:>{"Setting up a cline", "InitialiseDemes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseDemes"],

Cell[TextData[{
  "InitialStep",
  ",",
  " ",
  ButtonBox["Initial step size",
    ButtonData:>{"Initial step size", "InitialStep"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialStep"],

Cell[TextData[{
  "InitialStepReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "InitialStepReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialStepReduced"],

Cell[TextData[{
  "InternalNodes",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "InternalNodes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InternalNodes"],

Cell[TextData[{
  "IntervalCombine",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalCombine"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IntervalCombine"],

Cell[TextData[{
  "IntervalPosition",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IntervalPosition"],

Cell[TextData[{
  "InverseFourierNormalised",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "InverseFourierNormalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InverseFourierNormalised"],

Cell[TextData[{
  "InverseFourierNormalisedTable",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "InverseFourierNormalisedTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InverseFourierNormalisedTable"],

Cell[TextData[{
  "Island model",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Island model"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Island model"],

Cell[TextData[{
  "IterateContinuum",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "IterateContinuum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateContinuum"],

Cell[TextData[{
  "IterateExact",
  ",",
  " example",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateExact"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for allele frequency clines",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "IterateExact"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequency clines",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateExact"],

Cell[TextData[{
  "Join",
  ",",
  " ",
  ButtonBox["Join",
    ButtonData:>{"Join", "Join"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "Join"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Join"],

Cell[TextData[{
  "Junctions",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "Junctions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Junctions"],

Cell[TextData[{
  "JunctionStyle",
  ",",
  " option for PlotSegments",
  ", ",
  ButtonBox["Plotting ancestral graphs",
    ButtonData:>{"Plotting ancestral graphs", "JunctionStyle"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"JunctionStyle"],

Cell[TextData[{
  "Juveniles",
  ",",
  " \[GothicCapitalJ], \[AliasIndicator]goJ\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Juveniles"],

Cell[TextData[{
  "Kirkpatrick and Barton 1997",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick and Barton 1997"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick and Barton 1997"],

Cell[TextData[{
  "Kirkpatrick and Servedio 1998",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick and Servedio 1998"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick and Servedio 1998"],

Cell[TextData[{
  "Kirkpatrick et al.",
  ",",
  " ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick et al."},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al."],

Cell[TextData[{
  " arbitrary sets of loci",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Arbitrary sets of loci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Expectation",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Expectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " migration",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " mutation",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " permutations in defining coefficients",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Permutations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Permutations"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " phenotypes",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " position",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Contexts and positions"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "position"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " QLE",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " quasi-linkage equilibrium",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " random drift",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Random drift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference values",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Describing genotypes and populations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Reference values"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " relation with",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Multilocus MS"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " scripts and faces",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Scripts and faces"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " selection",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sets in subscripts",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets in subscripts"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sets of loci",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets of loci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stabilising selection",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", 
      "Natural selection on an additive polygenic trait"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages and contexts",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Stages and contexts"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " transmission rules",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Transmission"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Transmission rules"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al."],

Cell[TextData[{
  "Kirkpatrick et al. 1983",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Kirkpatrick et al 1983"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al. 1983"],

Cell[TextData[{
  "Kruuk 1997",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Kruuk 1997"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kruuk 1997"],

Cell[TextData[{
  "LeafEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "LeafEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LeafEvents"],

Cell[TextData[{
  "LeafLabels",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "LeafLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LeafLabels"],

Cell[TextData[{
  "LeafOffset",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "LeafOffset"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LeafOffset"],

Cell[TextData[{
  "Leaves",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "Leaves"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Leaves"],

Cell[TextData[{
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "Leaves"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Leaves"],

Cell[TextData[{
  "Life cycle",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Life cycle"],

Cell[TextData[{
  " adults",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete",
  ", ",
  ButtonBox["Complete life cycle",
    ButtonData:>{"Complete life cycle", "Complete rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " hermaphrodites",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " juveniles",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages in",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with cytoplasmic inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with sex linkage",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " zygotes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Life cycle"],

Cell[TextData[{
  "LineagesPresent",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "LineagesPresent"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LineagesPresent"],

Cell[TextData[{
  "Li & Nei 1974",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Li & Nei 1974"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Li & Nei 1974"],

Cell[TextData[{
  "Linkage",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Linkage",
    ButtonData:>{"Linkage", "Linkage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage"],

Cell[TextData[{
  " in numerical models",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Linkage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage"],

Cell[TextData[{
  "Linkage disequilibrium",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage disequilibrium"],

Cell[TextData[{
  "LinkedRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "LinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LinkedRecombination"],

Cell[TextData[{
  "ListToGenealogy",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "ListToGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ListToGenealogy"],

Cell[TextData[{
  "ListToMatrix",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "ListToMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ListToMatrix"],

Cell[TextData[{
  "Location",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Location"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Location"],

Cell[TextData[{
  "Locations",
  ",",
  " ",
  ButtonBox["Locations",
    ButtonData:>{"Locations", "Locations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Locations"],

Cell[TextData[{
  "LocusNames",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "LocusNames"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LocusNames"],

Cell[TextData[{
  "LogLikelihoodDisequilibrium",
  ",",
  " ",
  ButtonBox["Likelihood",
    ButtonData:>{"Likelihood", "LogLikelihoodDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodDisequilibrium"],

Cell[TextData[{
  "LogLikelihoodDisequilibriumReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "LogLikelihoodDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodDisequilibriumReduced"],

Cell[TextData[{
  "LogLikelihoodTest",
  ",",
  " ",
  ButtonBox["Likelihood tests",
    ButtonData:>{"Likelihood tests", "LogLikelihoodTest"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodTest"],

Cell[TextData[{
  "Log-linear models",
  ",",
  " ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Log-linear models"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Log-linear models"],

Cell[TextData[{
  "Long et al 1995",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Long et al 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Long et al 1995"],

Cell[TextData[{
  "LowerOffDiagonal",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "LowerOffDiagonal"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LowerOffDiagonal"],

Cell[TextData[{
  "MacCallum 1994",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "MacCallum 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MacCallum 1994"],

Cell[TextData[{
  "MacCallum et al. 1998",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "MacCallum et al 1998"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MacCallum et al. 1998"],

Cell[TextData[{
  "MakeCline",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeCline"],

Cell[TextData[{
  "  for genotype frequencies",
  ", ",
  ButtonBox["Recursions: setting up a cline",
    ButtonData:>{"Recursions: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeCline"],

Cell[TextData[{
  "MakeDiploid",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDiploid"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDiploid"],

Cell[TextData[{
  "MakeDistanceList",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "MakeDistanceList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDistanceList"],

Cell[TextData[{
  "MakeDistances",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "MakeDistances"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDistances"],

Cell[TextData[{
  "MakeFitnessSet",
  ",",
  " ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "MakeFitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeFitnessSet"],

Cell[TextData[{
  " with multiple alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeFitnessSet"],

Cell[TextData[{
  "MakeGenealogy",
  ",",
  " ",
  ButtonBox["Making a genealogy",
    ButtonData:>{"Making a genealogy", "MakeGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeGenealogy"],

Cell[TextData[{
  "MakeGenealogyPlot",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "MakeGenealogyPlot"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeGenealogyPlot"],

Cell[TextData[{
  "MakeHaploid",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeHaploid"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeHaploid"],

Cell[TextData[{
  "MakeIndividuals",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: converting",
    ButtonData:>{"Allele frequencies: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeIndividuals"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeIndividuals"],

Cell[TextData[{
  "MakeOneWayTable",
  ",",
  " ",
  ButtonBox["Single-locus tables",
    ButtonData:>{"Single-locus tables", "MakeOneWayTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeOneWayTable"],

Cell[TextData[{
  "MakePairwiseTable",
  ",",
  " ",
  ButtonBox["Pairwise tables",
    ButtonData:>{"Pairwise tables", "MakePairwiseTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePairwiseTable"],

Cell[TextData[{
  "MakePopulation",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePopulation"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "MakePopulation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: representation",
    ButtonData:>{"Symmetric model: representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePopulation"],

Cell[TextData[{
  "MakeSelectionCoefficient",
  ",",
  " ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeSelectionCoefficient"],

Cell[TextData[{
  " with multiple alleles",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with two alleles",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeSelectionCoefficient"],

Cell[TextData[{
  "Mangel & Hilborn 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Mangel & Hilborn 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mangel & Hilborn 1996"],

Cell[TextData[{
  "MapLength",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "MapLength"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MapLength"],

Cell[TextData[{
  "MapPosition",
  ",",
  " option for AncestorList",
  ", ",
  ButtonBox["Ancestors & descendants",
    ButtonData:>{"Ancestors & descendants", "MapPositionA"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MapPosition"],

Cell[TextData[{
  " option for DescendantList",
  ", ",
  ButtonBox["Ancestors & descendants",
    ButtonData:>{"Ancestors & descendants", "MapPositionD"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MapPosition"],

Cell[TextData[{
  "Marginal fitness",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Marginal fitness"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Marginal fitness"],

Cell[TextData[{
  "MarginalTable",
  ",",
  " ",
  ButtonBox["Marginal tables",
    ButtonData:>{"Marginal tables", "MarginalTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalTable"],

Cell[TextData[{
  "MarginalW",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalW"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalW"],

Cell[TextData[{
  "MaternalLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MaternalLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MaternalLoci"],

Cell[TextData[{
  "MatrixGamma",
  ",",
  " ",
  ButtonBox["Fast calculations",
    ButtonData:>{"Fast calculations", "MatrixGamma"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixGamma"],

Cell[TextData[{
  "MatrixToGenealogy",
  ",",
  " ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", "MatrixToGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixToGenealogy"],

Cell[TextData[{
  "MatrixToList",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "MatrixToList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixToList"],

Cell[TextData[{
  "MeanContribution",
  ",",
  " \[GothicM], \[AliasIndicator]gom\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "MeanContribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanContribution"],

Cell[TextData[{
  "Mean fitness",
  ",",
  " ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mean fitness"],

Cell[TextData[{
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mean fitness"],

Cell[TextData[{
  "MeanW",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanW"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanW"],

Cell[TextData[{
  "Meiosis",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Meiosis"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Meiosis"],

Cell[TextData[{
  " in numerical models",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Meiosis"],

Cell[TextData[{
  "MethodC",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MethodC"],

Cell[TextData[{
  "MethodP",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MethodP"],

Cell[TextData[{
  "Metropolis algorithm",
  ",",
  " estimating D",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Metropolis algorithm"],

Cell[TextData[{
  "MetropolisDisequilibrium",
  ",",
  " ",
  ButtonBox["Estimating moments",
    ButtonData:>{"Estimating moments", "MetropolisDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MetropolisDisequilibrium"],

Cell[TextData[{
  "MetropolisDisequilibriumReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MetropolisDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MetropolisDisequilibriumReduced"],

Cell[TextData[{
  "Metropolis et al. 1954",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Metropolis et al 1954"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Metropolis et al. 1954"],

Cell[TextData[{
  "MFromC",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MFromC"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MFromC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MFromC"],

Cell[TextData[{
  "Migrate",
  ",",
  " ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Migrate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migrate"],

Cell[TextData[{
  "MigrateExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrateExact"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrateExact"],

Cell[TextData[{
  "Migration",
  ",",
  " and cytoplasmic inheritance",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Cytonuclear associations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migration"],

Cell[TextData[{
  " and sexual selection",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Sexual selection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " context-dependent",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Context-dependent migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " example of",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotype-dependent",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Genotype-dependent migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of constant numbers",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "Constant numbers"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of haploids",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Haploid migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of juvenile diploids",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Juvenile diploid migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of pollen",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of seeds",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with sindividuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migration"],

Cell[TextData[{
  "MigrationOrder",
  ",",
  "for genotype frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationOrder"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "MigrationOrder"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationOrder"],

Cell[TextData[{
  "MigrationRate",
  ",",
  " \[CapitalMu], \[AliasIndicator]M\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationRate"],

Cell[TextData[{
  "MigrationSet",
  ",",
  " \[DoubleStruckCapitalM], \[AliasIndicator]dsM\[AliasIndicator]",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "MigrationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationSet"],

Cell[TextData[{
  "MissingCombination",
  ",",
  " ",
  ButtonBox["Validity of a mutation matrix",
    ButtonData:>{"Validity of a mutation matrix", "MissingCombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MissingCombination"],

Cell[TextData[{
  "Missing data",
  ",",
  " estimating allele frequencies with nulls",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "NullAllele"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Missing data"],

Cell[TextData[{
  " estimating genotype frequencies with nulls",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequency"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notation",
  ", ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Missing data"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Missing data"],

Cell[TextData[{
  "MissingData",
  ",",
  " option for AlleleFrequencyTable",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "NullAllele"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MissingData"],

Cell[TextData[{
  " option for GenotypeFrequency",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MissingData"],

Cell[TextData[{
  "Moment",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Moment"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Moments and cumulants",
    ButtonData:>{"Moments and cumulants", "Moment"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moment"],

Cell[TextData[{
  "MomentAfterMigration",
  ",",
  " ",
  ButtonBox["Migration in admixture models",
    ButtonData:>{"Migration in admixture models", "MomentAfterMigration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentAfterMigration"],

Cell[TextData[{
  "MomentAfterRecombination",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", 
      "MomentAfterRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentAfterRecombination"],

Cell[TextData[{
  "MomentEquilibrium",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "MomentEquilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentEquilibrium"],

Cell[TextData[{
  "MomentGeneratingFunction",
  ",",
  " deriving",
  ", ",
  ButtonBox["Deriving recursions for the MGF",
    ButtonData:>{"Deriving recursions for the MGF", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentGeneratingFunction"],

Cell[TextData[{
  " examples",
  ", ",
  ButtonBox["Examples of the MGF",
    ButtonData:>{"Examples of the MGF", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genealogies",
  ", ",
  ButtonBox["Calculating the MGF",
    ButtonData:>{"Calculating the MGF", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over topologies",
  ", ",
  ButtonBox["Calculating over topologies",
    ButtonData:>{"Calculating over topologies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentGeneratingFunction"],

Cell[TextData[{
  "MomentLimits",
  ",",
  " ",
  ButtonBox["Constraints on moments",
    ButtonData:>{"Constraints on moments", "MomentLimits"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentLimits"],

Cell[TextData[{
  "MomentNew",
  ",",
  " ",
  ButtonBox["Iteration",
    ButtonData:>{"Iteration", "MomentNew"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentNew"],

Cell[TextData[{
  "MomentReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MomentReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentReduced"],

Cell[TextData[{
  "Moments",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "7.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moments"],

Cell[TextData[{
  " estimating the matrix of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "Estimating the matrix"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " extension to description by",
  ", ",
  ButtonBox["References",
    ButtonData:>{"References", "Haber 1984"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " extension to estimation of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "MLE"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " full description by",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " matrix of",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] full matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "ML estimation of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "simple method"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reduced description by",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " simple method for estimating",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "extension to families"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moments"],

Cell[TextData[{
  "MomentsFromG",
  ",",
  " ",
  ButtonBox["Moments from genotype frequencies",
    ButtonData:>{"Moments from genotype frequencies", "MomentsFromG"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentsFromG"],

Cell[TextData[{
  "MomentSimple",
  ",",
  " ",
  ButtonBox["Simplifying the moments",
    ButtonData:>{"Simplifying the moments", "MomentSimple"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentSimple"],

Cell[TextData[{
  "MonteCarloGriffithsTavare",
  ",",
  " ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "MonteCarloGriffithsTavare"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MonteCarloGriffithsTavare"],

Cell[TextData[{
  "MonteCarloProbability",
  ",",
  " ",
  ButtonBox["Estimating the probability",
    ButtonData:>{"Estimating the probability", "MonteCarloProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MonteCarloProbability"],

Cell[TextData[{
  "Mortality",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Mortality"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mortality"],

Cell[TextData[{
  "MostRecentCommonAncestor",
  ",",
  " ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "MostRecentCommonAncestor"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MostRecentCommonAncestor"],

Cell[TextData[{
  "MToC",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MToC"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MToC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MToC"],

Cell[TextData[{
  "MToCEquations",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MToCEquations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MToCEquations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MToCEquations"],

Cell[TextData[{
  "Muddle",
  ",",
  " ",
  ButtonBox["Muddling and subdividing sets",
    ButtonData:>{"Muddling and subdividing sets", "Muddle"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Muddle"],

Cell[TextData[{
  "Multilocus algebra",
  ",",
  " basic notation",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Basic notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus algebra"],

Cell[TextData[{
  " fitness",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction to",
  ", ",
  ButtonBox["Introduction to multilocus algebra",
    ButtonData:>{"Introduction to multilocus algebra", "1.1"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Introduction to multilocus algebra",
    ButtonData:>{"Introduction to multilocus algebra", 
      "Multilocus`Multilocus`"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages in life cycle",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Technicalities"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus algebra"],

Cell[TextData[{
  "Multilocus MS",
  ",",
  " relation with",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Multilocus MS"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus MS"],

Cell[TextData[{
  "Multilocus notation",
  ",",
  " bugs",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Multilocus notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus notation"],

Cell[TextData[{
  "Multinomial sampling",
  ",",
  " without replacement",
  ", ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", 
      "Multinomial sampling wo replacement"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multinomial sampling"],

Cell[TextData[{
  "MultinomialSamplingProbability",
  ",",
  " ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", 
      "MultinomialSamplingProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MultinomialSamplingProbability"],

Cell[TextData[{
  "Multiple alleles",
  ",",
  " and selection coefficients",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple alleles"],

Cell[TextData[{
  " MakeFitnessSet",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " mutation",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " representation of",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " selection on",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple alleles"],

Cell[TextData[{
  "Multiple arguments",
  ",",
  " in PopulationExpectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "multiple arguments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple arguments"],

Cell[TextData[{
  "Multiplicative models",
  ",",
  " in negative binomial",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "multiplicative models"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiplicative models"],

Cell[TextData[{
  "MUS",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MUS"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MUS"],

Cell[TextData[{
  "Mutate",
  ",",
  " allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: mutation",
    ButtonData:>{"Allele frequencies: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutate"],

Cell[TextData[{
  "genotype frequencies",
  ", ",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " individuals",
  ", ",
  ButtonBox["Simulating individuals: mutation",
    ButtonData:>{"Simulating individuals: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric model",
  ", ",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutate"],

Cell[TextData[{
  "MutateCompiled",
  ",",
  " ",
  ButtonBox["Allele frequencies: mutation",
    ButtonData:>{"Allele frequencies: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: mutation",
    ButtonData:>{"Simulating individuals: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutateCompiled"],

Cell[TextData[{
  "Mutation",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Mutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutation"],

Cell[TextData[{
  " Mutations, in multilocus genetics",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for BiallelicMutation",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies: reproduction",
    ButtonData:>{"Allele frequencies: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: reproduction",
    ButtonData:>{"Recursions: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutation"],

Cell[TextData[{
  "MutationInterval",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "MutationInterval"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationInterval"],

Cell[TextData[{
  "MutationLabels",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "MutationLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationLabels"],

Cell[TextData[{
  "MutationOrigin",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "MutationOrigin"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationOrigin"],

Cell[TextData[{
  "MutationRate",
  ",",
  " ",
  ButtonBox["Drawing a genealogy",
    ButtonData:>{"Drawing a genealogy", "MutationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationRate"],

Cell[TextData[{
  "Mutations",
  ",",
  " adding to a genealogy",
  ", ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddMutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutations"],

Cell[TextData[{
  " consistency with a genealogy",
  ", ",
  ButtonBox["Validity of a mutation matrix",
    ButtonData:>{"Validity of a mutation matrix", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " inferring genealogies from",
  ", ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "infinite site",
  ", ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "Mutations"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in genealogies",
  ", ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "Mutations"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutations"],

Cell[TextData[{
  "MVariables",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MVariables"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MVariables"],

Cell[TextData[{
  "Negative binomial",
  ",",
  " c<1",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "c<1"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Negative binomial"],

Cell[TextData[{
  " compiled",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " multiplicative models",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "multiplicative models"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " normalisation",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalisation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " timings",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Timings"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Negative binomial"],

Cell[TextData[{
  "NegativeBinomialLogLikelihood",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", 
      "NegativeBinomialLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeBinomialLogLikelihood"],

Cell[TextData[{
  "NegativeBinomialMLE",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "NegativeBinomialMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeBinomialMLE"],

Cell[TextData[{
  "NegativeHypergeometricDistribution",
  ",",
  " ",
  ButtonBox["Negative hypergeometric distribution",
    ButtonData:>{"Negative hypergeometric distribution", 
      "NegativeHypergeometricDistribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeHypergeometricDistribution"],

Cell[TextData[{
  "NeighbourArray",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "NeighbourArray"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NeighbourArray"],

Cell[TextData[{
  "Neighbours",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Neighbours"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Neighbours"],

Cell[TextData[{
  "NetCovariance",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "NetCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetCovariance"],

Cell[TextData[{
  "NetFecundity",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NetFecundity"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetFecundity"],

Cell[TextData[{
  "NetMortality",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NetMortality"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetMortality"],

Cell[TextData[{
  "NetRecombination",
  ",",
  " ",
  ButtonBox["Linkage",
    ButtonData:>{"Linkage", "NetRecombination"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Linkage in families",
    ButtonData:>{"Linkage in families", "NetRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetRecombination"],

Cell[TextData[{
  " in multilocus genetics",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "NetRecombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "NetRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetRecombination"],

Cell[TextData[{
  "Neutral marker",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Neutral marker"],

Cell[TextData[{
  "NeutralRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "NeutralRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NeutralRepresentations"],

Cell[TextData[{
  "NewGametes",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewGametes"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Mutation option",
  ", ",
  ButtonBox["Allele frequencies: reproduction",
    ButtonData:>{"Allele frequencies: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: reproduction",
    ButtonData:>{"Recursions: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " truncation selection",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", 
      "TruncationSelection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewGametes"],

Cell[TextData[{
  "NewS",
  ",",
  " ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "NewS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewS"],

Cell[TextData[{
  "Node",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "Node"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "Node"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Node"],

Cell[TextData[{
  "NodeFunction",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "NodeFunction"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeFunction"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeFunction"],

Cell[TextData[{
  " option for ExactProbability",
  ", ",
  ButtonBox["Exact probability",
    ButtonData:>{"Exact probability", "NodeFunction"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeFunction"],

Cell[TextData[{
  "NodeLabels",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeLabels"],

Cell[TextData[{
  "NodeOffset",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeOffset"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeOffset"],

Cell[TextData[{
  "Nodes",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "Nodes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Nodes"],

Cell[TextData[{
  "NonMendelian",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonMendelian"],

Cell[TextData[{
  " examples of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonMendelian"],

Cell[TextData[{
  "NonNeutralRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "NonNeutralRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonNeutralRepresentations"],

Cell[TextData[{
  "NonSymmetricRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "NonSymmetricRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonSymmetricRepresentations"],

Cell[TextData[{
  "Normalisation",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalisation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Normalisation"],

Cell[TextData[{
  "Normalised",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Normalised"],

Cell[TextData[{
  "Notation",
  ",",
  " clearing definitions",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "Clearing definitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation"],

Cell[TextData[{
  " data",
  ", ",
  ButtonBox["Notation for genetic data",
    ButtonData:>{"Notation for genetic data", "NotationPackage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining new",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "Defining new notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotypes",
  ", ",
  ButtonBox["Notation",
    ButtonData:>{"Notation", "NotationPackage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation"],

Cell[TextData[{
  "Notation Package",
  ",",
  " ",
  ButtonBox["Notation package",
    ButtonData:>{"Notation package", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation Package"],

Cell[TextData[{
  "NullAllele",
  ",",
  " option for AlleleFrequencyTable",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "NullAllele"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NullAllele"],

Cell[TextData[{
  " option for GenotypeFrequency",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NullAllele"],

Cell[TextData[{
  "Null alleles",
  ",",
  " estimating allele frequencies",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "NullAllele"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Null alleles"],

Cell[TextData[{
  " estimating genotype frequencies",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Null alleles"],

Cell[TextData[{
  "Null lineages",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", "DeleteNullLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Null lineages"],

Cell[TextData[{
  "NullLineages",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "NullLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NullLineages"],

Cell[TextData[{
  "NullRecombinationEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "NullRecombinationEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NullRecombinationEvents"],

Cell[TextData[{
  "NumberedLink",
  ",",
  " ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "NumberedLink"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberedLink"],

Cell[TextData[{
  "Numbering",
  ",",
  " aesthetics",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Aesthetics"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numbering"],

Cell[TextData[{
  " automatic",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "7.2"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notes on",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Notes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving links",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Saving the links"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numbering"],

Cell[TextData[{
  "NumberOfCoalescences",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "NumberOfCoalescences"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfCoalescences"],

Cell[TextData[{
  "NumberOfGenes",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenes"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenes"],

Cell[TextData[{
  "NumberOfGenesTable",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfGenesTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenesTable"],

Cell[TextData[{
  "NumberOfIndividuals",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfIndividuals"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NumberOfIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfIndividuals"],

Cell[TextData[{
  "NumberOfIndividualsTable",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfIndividualsTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfIndividualsTable"],

Cell[TextData[{
  "NumberOfLineages",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "NumberOfLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfLineages"],

Cell[TextData[{
  "NumberOfLoci",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfLoci"],

Cell[TextData[{
  "NumberOfMutations",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "NumberOfMutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfMutations"],

Cell[TextData[{
  "NumberOfPossibleCoalescences",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "NumberOfPossibleCoalescences"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfPossibleCoalescences"],

Cell[TextData[{
  "NumberOfSamplePartitions",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "NumberOfSamplePartitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfSamplePartitions"],

Cell[TextData[{
  "NumberOfSetPartitions",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "NumberOfSetPartitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfSetPartitions"],

Cell[TextData[{
  "NumericalModel",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", "NumericalModel"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumericalModel"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "NumericalModel"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumericalModel"],

Cell[TextData[{
  "Numerical models",
  ",",
  " genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numerical models"],

Cell[TextData[{
  " of allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " overview",
  ", ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " problems",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " problems with migration",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "Constant numbers"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric",
  ", ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numerical models"],

Cell[TextData[{
  "Observable genotype",
  ",",
  " ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Observable genotype"],

Cell[TextData[{
  "Obsolete",
  ",",
  " Combine",
  ", ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Separate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Obsolete"],

Cell[TextData[{
  " CumulantReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "CumulantReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidConstraints",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidConstraints"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidGenotypeFrequencyReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidGenotypeFrequencyTable",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Estimating D",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " fitness",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Obsolete notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " FullGenotypeFrequencyReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " FullGenotypeFrequencyTable",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " GenotypeFrequencyArguments",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "GenotypeFrequencyArguments"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " HaploidConstraints",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "HaploidConstraints"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " InitialStepReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "InitialStepReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " IntervalCombine",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalCombine"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " IntervalPosition",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalPosition"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " LogLikelihoodDisequilibriumReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "LogLikelihoodDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MetropolisDisequilibriumReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MetropolisDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MomentReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MomentReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Obsolete"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Separate",
  ", ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Combine"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " SetPartition",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SetPartition"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Obsolete"],

Cell[TextData[{
  "Offspring",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Offspring"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Offspring"],

Cell[TextData[{
  "Ordered",
  ",",
  "option for PartitionSet",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "Ordered"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ordered"],

Cell[TextData[{
  "Orive & Barton 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Orive & Barton 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Orive & Barton 1999"],

Cell[TextData[{
  "OtherSex",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "OtherSex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"OtherSex"],

Cell[TextData[{
  "Packages",
  ",",
  " help",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Packages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Packages"],

Cell[TextData[{
  " overview of",
  ", ",
  ButtonBox["Overview of the packages",
    ButtonData:>{"Overview of the packages", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving using PackageSaver",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " setting up",
  ", ",
  ButtonBox["Setting up the packages",
    ButtonData:>{"Setting up the packages", "Setting up the packages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Special notation",
    ButtonData:>{"Special notation", "Setting up packages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " versions of",
  ", ",
  ButtonBox["Versions",
    ButtonData:>{"Versions", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Packages"],

Cell[TextData[{
  "PackageSaver",
  ",",
  " ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PackageSaver"],

Cell[TextData[{
  "ParentalGenotypes",
  ",",
  " ",
  ButtonBox["Inferring parents",
    ButtonData:>{"Inferring parents", "ParentalGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ParentalGenotypes"],

Cell[TextData[{
  "Partitions",
  ",",
  " of sets",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "PartitionSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Partitions"],

Cell[TextData[{
  " standard form",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartition"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " testing for standard form",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartitionQ"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Partitions"],

Cell[TextData[{
  "PartitionSet",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "PartitionSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PartitionSet"],

Cell[TextData[{
  "Paternal inheritance",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Paternal inheritance"],

Cell[TextData[{
  "PaternalLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaternalLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaternalLoci"],

Cell[TextData[{
  "PatternFree",
  ",",
  " ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "PatternFree"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PatternFree"],

Cell[TextData[{
  "Permutations",
  ",",
  "option for PartitionSet",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "Permutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Permutations"],

Cell[TextData[{
  "Permutations in defining coefficients",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Permutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Permutations in defining coefficients"],

Cell[TextData[{
  "Phenotypes",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Phenotypes"],

Cell[TextData[{
  "Phipps & Brill 1995",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Phipps & Brill 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Phipps & Brill 1995"],

Cell[TextData[{
  "Ploidy",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "Ploidy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ploidy"],

Cell[TextData[{
  "PloidyWeightList",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "PloidyWeightList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PloidyWeightList"],

Cell[TextData[{
  "PlotGenealogy",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "PlotGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PlotGenealogy"],

Cell[TextData[{
  "PlotLogL",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "PlotLogL"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PlotLogL"],

Cell[TextData[{
  "PlotSegments",
  ",",
  " of ancestral graphs",
  ", ",
  ButtonBox["Plotting ancestral graphs",
    ButtonData:>{"Plotting ancestral graphs", "PlotSegments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PlotSegments"],

Cell[TextData[{
  "Plotting",
  ",",
  " ancestral graphs",
  ", ",
  ButtonBox["Plotting ancestral graphs",
    ButtonData:>{"Plotting ancestral graphs", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Plotting"],

Cell[TextData[{
  "PopulationDisequilibrium",
  ",",
  "\[GothicCapitalC], \[AliasIndicator]goC\[AliasIndicator]",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationDisequilibrium"],

Cell[TextData[{
  "PopulationExpectation",
  ",",
  " ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationExpectation"],

Cell[TextData[{
  " multiple arguments",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "multiple arguments"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationExpectation"],

Cell[TextData[{
  "PopulationRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "PopulationRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationRepresentations"],

Cell[TextData[{
  "Position",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "position"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "position"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Position"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "position"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Contexts and positions"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Position"],

Cell[TextData[{
  "PositionsList",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PositionsList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PositionsList"],

Cell[TextData[{
  "PositionsMatrix",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PositionsMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PositionsMatrix"],

Cell[TextData[{
  "PossibleCoalescenceOrder",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "PossibleCoalescenceOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleCoalescenceOrder"],

Cell[TextData[{
  "PossibleDiploidGenotypes",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PossibleDiploidGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleDiploidGenotypes"],

Cell[TextData[{
  "PossibleGenotypes",
  ",",
  " ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "PossibleGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleGenotypes"],

Cell[TextData[{
  "PossibleRootings",
  ",",
  " ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", "PossibleRootings"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleRootings"],

Cell[TextData[{
  "PowerF",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PowerF"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "PowerF"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PowerF"],

Cell[TextData[{
  "PresentOneWayTable",
  ",",
  " ",
  ButtonBox["Single-locus tables",
    ButtonData:>{"Single-locus tables", "PresentOneWayTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentOneWayTable"],

Cell[TextData[{
  "PresentPairwiseTable",
  ",",
  " ",
  ButtonBox["Pairwise tables",
    ButtonData:>{"Pairwise tables", "PresentPairwiseTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentPairwiseTable"],

Cell[TextData[{
  "PresentResults",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "PresentResults"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentResults"],

Cell[TextData[{
  "Principal components",
  ",",
  " Bennett's measure of disequilibrium",
  ", ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Bennett"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Principal components"],

Cell[TextData[{
  "PrintDetails",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "PrintDetails"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PrintDetails"],

Cell[TextData[{
  " option for RandomGenealogy",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", 
      "PrintDetails, option for RandomGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PrintDetails"],

Cell[TextData[{
  "Problems",
  ",",
  " avoid integers",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Avoid integers"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Problems"],

Cell[TextData[{
  " redefining fitness",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Allele frequencies"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Redefining fitness"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "StoreResults (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Problems"],

Cell[TextData[{
  "Products",
  ",",
  " multiple",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Multiple products"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Products"],

Cell[TextData[{
  "ProductSum",
  ",",
  " ",
  ButtonBox["ProductSum",
    ButtonData:>{"ProductSum", "ProductSum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ProductSum"],

Cell[TextData[{
  " over sets",
  ", ",
  ButtonBox["ProductSum",
    ButtonData:>{"ProductSum", "ProductSum over sets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ProductSum"],

Cell[TextData[{
  "QLE",
  ",",
  " haploid selection example",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", "QLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"QLE"],

Cell[TextData[{
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"QLE"],

Cell[TextData[{
  "Quasi-linkage equilibrium",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Quasi-linkage equilibrium"],

Cell[TextData[{
  "RandomBottleneckedGenealogy",
  ",",
  " ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", "RandomBottleneckedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomBottleneckedGenealogy"],

Cell[TextData[{
  "RandomCoalescenceOrder",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "RandomCoalescenceOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCoalescenceOrder"],

Cell[TextData[{
  "RandomCoalescenceTimes",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", 
      "RandomCoalescenceTimes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCoalescenceTimes"],

Cell[TextData[{
  " for ancestral graphs",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", "RandomCoalescenceTimes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCoalescenceTimes"],

Cell[TextData[{
  "RandomCum",
  ",",
  " ",
  ButtonBox["Sampling from arbitrary distributions",
    ButtonData:>{"Sampling from arbitrary distributions", "RandomCum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCum"],

Cell[TextData[{
  "Random drift",
  ",",
  " changing reference points",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Changing reference points"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random drift"],

Cell[TextData[{
  " cumulants and moments",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " describing a distribution",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Describing a distribution"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " equations for the moments",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Equations for the moments"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in a cline",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: drift",
    ButtonData:>{"Allele frequencies: drift", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of genotype frequencies",
  ", ",
  ButtonBox["Recursions: drift",
    ButtonData:>{"Recursions: drift", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population disequilibrium",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population expectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population expectations",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Wright-Fisher sampling",
  ", ",
  ButtonBox["Wright-Fisher sampling",
    ButtonData:>{"Wright-Fisher sampling", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random drift"],

Cell[TextData[{
  "RandomDrift",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: drift",
    ButtonData:>{"Recursions: drift", "RandomDrift"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomDrift"],

Cell[TextData[{
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "RandomDrift"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomDrift"],

Cell[TextData[{
  "RandomFamilies",
  ",",
  " ",
  ButtonBox["Random families",
    ButtonData:>{"Random families", "RandomFamilies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamilies"],

Cell[TextData[{
  "RandomFamily",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "RandomFamily"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamily"],

Cell[TextData[{
  " segregation ratio",
  ", ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamily"],

Cell[TextData[{
  "Random genealogies",
  ",",
  " population bottlenecks",
  ", ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random genealogies"],

Cell[TextData[{
  "RandomGenealogy",
  ",",
  " ",
  ButtonBox["Drawing a genealogy",
    ButtonData:>{"Drawing a genealogy", "RandomGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomGenealogy"],

Cell[TextData[{
  " for ancestral graphs",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", "RandomGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomGenealogy"],

Cell[TextData[{
  "RandomList",
  ",",
  " ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "RandomList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomList"],

Cell[TextData[{
  " sampling without replacement",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomList"],

Cell[TextData[{
  "Random lists",
  ",",
  " compiled",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random lists"],

Cell[TextData[{
  "RandomMating",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "RandomMating"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomMating"],

Cell[TextData[{
  "RandomMultinomial",
  ",",
  " ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", "RandomMultinomial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomMultinomial"],

Cell[TextData[{
  "RandomPreviousFamily",
  ",",
  " ",
  ButtonBox["Random families",
    ButtonData:>{"Random families", "RandomPreviousFamily"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomPreviousFamily"],

Cell[TextData[{
  "Random sampling",
  ",",
  " ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Random sampling"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random sampling"],

Cell[TextData[{
  " example in estimating D",
  ", ",
  ButtonBox["Sampling example",
    ButtonData:>{"Sampling example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of genealogies",
  ", ",
  ButtonBox["Sampling genealogies",
    ButtonData:>{"Sampling genealogies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random sampling"],

Cell[TextData[{
  "RandomSet",
  ",",
  " ",
  ButtonBox["Random sets",
    ButtonData:>{"Random sets", "RandomSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomSet"],

Cell[TextData[{
  "Random union",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Random union"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random union"],

Cell[TextData[{
  " in admixture models",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "RandomUnionObsolete"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random union"],

Cell[TextData[{
  "RandomUnion",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnion"],

Cell[TextData[{
  "RandomUnionMethod",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnionMethod"],

Cell[TextData[{
  "RandomUnionObsolete",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnionObsolete"],

Cell[TextData[{
  "Random walk",
  ",",
  " in estimating D",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random walk"],

Cell[TextData[{
  "RecombinantLineages",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "RecombinantLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinantLineages"],

Cell[TextData[{
  "Recombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Recombination"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Recombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombination"],

Cell[TextData[{
  " across several linked loci",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "NetRecombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " between linked loci",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "LinkedRecombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " context-dependent",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Context-dependent recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotype-dependent",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Genotype-dependent recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in admixture models",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "Recombined"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " no linkage",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "UnlinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombination"],

Cell[TextData[{
  "RecombinationEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "RecombinationEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinationEvents"],

Cell[TextData[{
  "RecombinationRate",
  ",",
  " \[GothicR], \[AliasIndicator]gor\[AliasIndicator]",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinationRate"],

Cell[TextData[{
  "RecombinationSet",
  ",",
  " \[DoubleStruckCapitalR], \[AliasIndicator]dsR\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinationSet"],

Cell[TextData[{
  "Recombined",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "Recombined"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombined"],

Cell[TextData[{
  "RecombineLineage",
  ",",
  " ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "RecombineLineage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombineLineage"],

Cell[TextData[{
  "ReducedData",
  ",",
  " ",
  ButtonBox["Simplifying a dataset",
    ButtonData:>{"Simplifying a dataset", "ReducedData"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReducedData"],

Cell[TextData[{
  "ReferencePoint",
  ",",
  " \[WeierstrassP], \[AliasIndicator]wp\[AliasIndicator]",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePoint"],

Cell[TextData[{
  "ReferencePointMean",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointMean"],

Cell[TextData[{
  " cytoplasmic inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " paternal inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sex-linkage",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointMean"],

Cell[TextData[{
  "ReferencePointSame",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointSame"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointSame"],

Cell[TextData[{
  "ReferencePointZero",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointZero"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointZero"],

Cell[TextData[{
  "References",
  ",",
  " for ancestral graphs",
  ", ",
  ButtonBox["Ancestral graph references",
    ButtonData:>{"Ancestral graph references", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"References"],

Cell[TextData[{
  "Reference values",
  ",",
  " ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Reference values"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reference values"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Reference values"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Describing genotypes and populations"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reference values"],

Cell[TextData[{
  "RemoveTag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "RemoveTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RemoveTag"],

Cell[TextData[{
  "Repeat",
  ",",
  " ",
  ButtonBox["Repeated elements",
    ButtonData:>{"Repeated elements", "Repeat"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Repeat"],

Cell[TextData[{
  "Replace",
  ",",
  " ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Replace"],

Cell[TextData[{
  "ReplaceAllSpecial",
  ",",
  " |.",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReplaceAllSpecial"],

Cell[TextData[{
  "ReplaceRepeatedSpecial",
  ",",
  " ||.",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceRepeatedSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReplaceRepeatedSpecial"],

Cell[TextData[{
  "Representations",
  ",",
  " converting between",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Representations"],

Cell[TextData[{
  "of populations",
  ", ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "Representing the population"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Representations"],

Cell[TextData[{
  "Reproduction",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reproduction"],

Cell[TextData[{
  "Reverse",
  ",",
  " ",
  ButtonBox["Sorting",
    ButtonData:>{"Sorting", "Reverse"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reverse"],

Cell[TextData[{
  "Root",
  ",",
  " of a genealogy",
  ", ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "RootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Root"],

Cell[TextData[{
  "RootedGenealogy",
  ",",
  " ",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "RootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RootedGenealogy"],

Cell[TextData[{
  "RootEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "RootEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RootEvents"],

Cell[TextData[{
  "Rootings",
  ",",
  " of a genealogy, possible",
  ", ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", "PossibleRootings"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Rootings"],

Cell[TextData[{
  "Rules",
  ",",
  " ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Rules"],

Cell[TextData[{
  " non-evaluation of",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Rules"],

Cell[TextData[{
  "SampleCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "SampleCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SampleCovariance"],

Cell[TextData[{
  "SampleIndividuals",
  ",",
  " ",
  ButtonBox["Sampling individuals",
    ButtonData:>{"Sampling individuals", "SampleIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SampleIndividuals"],

Cell[TextData[{
  "SamplePartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SamplePartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SamplePartition"],

Cell[TextData[{
  "Sampling",
  ",",
  " without replacement",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sampling"],

Cell[TextData[{
  "Scripts and faces",
  ",",
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Scripts and faces"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Scripts and faces"],

Cell[TextData[{
  "Segments",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "Segments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Segments"],

Cell[TextData[{
  "SegmentStyle",
  ",",
  " option for PlotSegments",
  ", ",
  ButtonBox["Plotting ancestral graphs",
    ButtonData:>{"Plotting ancestral graphs", "SegmentStyle"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SegmentStyle"],

Cell[TextData[{
  "SegregationRatio",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SegregationRatio"],

Cell[TextData[{
  "SelectContext",
  ",",
  " \[CircleDot], \[AliasIndicator]c.\[AliasIndicator]",
  ", ",
  ButtonBox["Selecting contexts",
    ButtonData:>{"Selecting contexts", "SelectContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectContext"],

Cell[TextData[{
  "SelectIndividuals",
  ",",
  " ",
  ButtonBox["Selecting subsets",
    ButtonData:>{"Selecting subsets", "SelectIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectIndividuals"],

Cell[TextData[{
  "Selection",
  ",",
  " ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Selection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection"],

Cell[TextData[{
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on genotype frequencies",
  ", ",
  ButtonBox["Recursions: fitnesses",
    ButtonData:>{"Recursions: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on multiple alleles",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Technicalities"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " truncation",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "TruncationSelection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with two alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection"],

Cell[TextData[{
  "SelectionCoefficient",
  ",",
  " \[GothicA], \[AliasIndicator]goa\[AliasIndicator]",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionCoefficient"],

Cell[TextData[{
  "Selection coefficients",
  ",",
  " as defined in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Permutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection coefficients"],

Cell[TextData[{
  " making",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with multiple alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection coefficients"],

Cell[TextData[{
  "SelectionExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionExact"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: fitnesses",
    ButtonData:>{"Recursions: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionExact"],

Cell[TextData[{
  "Selection on diploids",
  ",",
  " a method to avoid",
  ", ",
  ButtonBox["A method to avoid",
    ButtonData:>{"A method to avoid", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection on diploids"],

Cell[TextData[{
  " cautionary notes",
  ", ",
  ButtonBox["Cautionary notes",
    ButtonData:>{"Cautionary notes", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete life cycle",
  ", ",
  ButtonBox["Complete life cyle",
    ButtonData:>{"Complete life cyle", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " explaining the rules",
  ", ",
  ButtonBox["Explaining the rules",
    ButtonData:>{"Explaining the rules", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction",
  ", ",
  ButtonBox["Introduction to selection on diploids",
    ButtonData:>{"Introduction to selection on diploids", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " life cycle",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection on diploids"],

Cell[TextData[{
  "SelectionRate",
  ",",
  " \[GothicS],\[AliasIndicator]gos\[AliasIndicator]",
  ", ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SelectionRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionRate"],

Cell[TextData[{
  "SelectLoci",
  ",",
  " ",
  ButtonBox["Selecting subsets",
    ButtonData:>{"Selecting subsets", "SelectLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectLoci"],

Cell[TextData[{
  "Selfing",
  ",",
  " ",
  ButtonBox["Selfing",
    ButtonData:>{"Selfing", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selfing"],

Cell[TextData[{
  "Separate",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Separate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Separate"],

Cell[TextData[{
  "Servedio",
  ",",
  " Maria",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", "Servedio"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Servedio"],

Cell[TextData[{
  "Set",
  ",",
  " of all positions affecting a trait, \[DoubleStruckCapitalZ], \
\[AliasIndicator]dsZ\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set"],

Cell[TextData[{
  " of all positions in genome, \[DoubleStruckCapitalG], \[AliasIndicator]dsG\
\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set"],

Cell[TextData[{
  "Set manipulation",
  ",",
  " overview",
  ", ",
  ButtonBox["Overview of set manipulation",
    ButtonData:>{"Overview of set manipulation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set manipulation"],

Cell[TextData[{
  "SetOfCombinations",
  ",",
  " ",
  ButtonBox["Set combinations",
    ButtonData:>{"Set combinations", "SetOfCombinations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SetOfCombinations"],

Cell[TextData[{
  "SetPartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SetPartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SetPartition"],

Cell[TextData[{
  "Sets of loci",
  ",",
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets of loci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sets of loci"],

Cell[TextData[{
  "Sex",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Sex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex"],

Cell[TextData[{
  "Sex linkage",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex linkage"],

Cell[TextData[{
  " examples of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex linkage"],

Cell[TextData[{
  "SexOfOrigin",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "SexOfOrigin"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SexOfOrigin"],

Cell[TextData[{
  "Sexual selection",
  ",",
  " ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Sexual selection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sexual selection"],

Cell[TextData[{
  " and migration",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Sexual selection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete life cycle",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Complete cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining fitnesses",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Sexual selection by female choice"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "on haploids",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " recombination",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " subtle problem",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "subtle problem"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sexual selection"],

Cell[TextData[{
  "ShortContext",
  ",",
  " ",
  ButtonBox["Abbreviating contexts",
    ButtonData:>{"Abbreviating contexts", "ShortContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ShortContext"],

Cell[TextData[{
  "SigmaMatrix",
  ",",
  " ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "SigmaMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SigmaMatrix"],

Cell[TextData[{
  "SignMask",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "SignMask"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SignMask"],

Cell[TextData[{
  "SimplifyAddUp",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "SimplifyAddUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyAddUp"],

Cell[TextData[{
  "SimplifyAddUpQ",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "SimplifyAddUpQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyAddUpQ"],

Cell[TextData[{
  "SimplifyFamilies",
  ",",
  " ",
  ButtonBox["Probabilities",
    ButtonData:>{"Probabilities", "SimplifyFamilies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyFamilies"],

Cell[TextData[{
  "Simulating individuals",
  ",",
  " recursions",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Simulating individuals"],

Cell[TextData[{
  " representation",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reproduction",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Simulating individuals"],

Cell[TextData[{
  "SizeOfGenealogyPlot",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "SizeOfGenealogyPlot"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SizeOfGenealogyPlot"],

Cell[TextData[{
  "Slatkin & Excoffier 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Slatkin & Excoffier 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Slatkin & Excoffier 1996"],

Cell[TextData[{
  "SlowChange",
  ",",
  " ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SlowChange"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SlowChange"],

Cell[TextData[{
  "SortByClass",
  ",",
  " ",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "SortByClass"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByClass"],

Cell[TextData[{
  " genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "SortByClass"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByClass"],

Cell[TextData[{
  "SortByHead",
  ",",
  " ",
  ButtonBox["Sorting",
    ButtonData:>{"Sorting", "SortByHead"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByHead"],

Cell[TextData[{
  "SpatialCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "SpatialCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SpatialCovariance"],

Cell[TextData[{
  "Spatially varying selection",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Spatially varying selection",
    ButtonData:>{"Spatially varying selection", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Spatially varying selection"],

Cell[TextData[{
  "Special notation",
  ",",
  " ",
  ButtonBox["Special notation",
    ButtonData:>{"Special notation", "Defining notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Special notation"],

Cell[TextData[{
  "SplitSet",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SplitSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SplitSet"],

Cell[TextData[{
  "Stabilising selection",
  ",",
  " change in D",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Change in D"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stabilising selection"],

Cell[TextData[{
  " change in mean",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Change in mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Defining fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", 
      "Natural selection on an additive polygenic trait"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "mean fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Mean fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "New mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "New mean fitness"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stabilising selection"],

Cell[TextData[{
  "Stability",
  ",",
  " of numerical models",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stability"],

Cell[TextData[{
  " of symmetric model",
  ", ",
  ButtonBox["Symmetric stability: outline",
    ButtonData:>{"Symmetric stability: outline", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stability"],

Cell[TextData[{
  "StabilityDirect",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", "StabilityDirect"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityDirect"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", "StabilityDirect"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityDirect"],

Cell[TextData[{
  "StabilityK",
  ",",
  " ",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", "StabilityK"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "StabilityK"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityK"],

Cell[TextData[{
  "StabilityKTable",
  ",",
  " ",
  ButtonBox["Symmetric stability: faster algorithms",
    ButtonData:>{"Symmetric stability: faster algorithms", "StabilityKTable"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityKTable"],

Cell[TextData[{
  "StabilityMatrix",
  ",",
  " ",
  ButtonBox["Making a stability matrix",
    ButtonData:>{"Making a stability matrix", "StabilityMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityMatrix"],

Cell[TextData[{
  "Stage",
  ",",
  " \[Sampi], \[AliasIndicator]sa\[AliasIndicator]",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stage"],

Cell[TextData[{
  "Stages",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stages"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Stages and contexts"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stages"],

Cell[TextData[{
  "StandardPartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StandardPartition"],

Cell[TextData[{
  "StandardPartitionQ",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartitionQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StandardPartitionQ"],

Cell[TextData[{
  "StartingStepSize",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "StartingStepSize"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StartingStepSize"],

Cell[TextData[{
  "Stepping-stone migration",
  ",",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", 
      "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone migration"],

Cell[TextData[{
  "Stepping-stone model",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", 
      "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone model"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "Nearest-neighbour migration"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone model"],

Cell[TextData[{
  "StoreExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreExact"],

Cell[TextData[{
  " for allele frequency clines",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequency clines",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreExact"],

Cell[TextData[{
  "StoreResults",
  ",",
  " option for GameteTable",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreResults"],

Cell[TextData[{
  " option for NewGametes",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " use when compiling",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "StoreResults (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreResults"],

Cell[TextData[{
  "StructuredArray",
  ",",
  " ",
  ButtonBox["Useful functions",
    ButtonData:>{"Useful functions", "StructuredArray"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredArray"],

Cell[TextData[{
  "StructuredInitialParameters",
  ",",
  " ",
  ButtonBox["Initial parameters",
    ButtonData:>{"Initial parameters", "StructuredInitialParameters"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredInitialParameters"],

Cell[TextData[{
  "StructuredLogLikelihood",
  ",",
  " ",
  ButtonBox["Likelihood of a structured model",
    ButtonData:>{"Likelihood of a structured model", 
      "StructuredLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredLogLikelihood"],

Cell[TextData[{
  "StructuredMLE",
  ",",
  " ",
  ButtonBox["Likelihood of a structured model",
    ButtonData:>{"Likelihood of a structured model", "StructuredMLE"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "StructuredMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredMLE"],

Cell[TextData[{
  "StructuredModel",
  ",",
  " ",
  ButtonBox["Useful functions",
    ButtonData:>{"Useful functions", "StructuredModel"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredModel"],

Cell[TextData[{
  "StructuredModelReduce",
  ",",
  " ",
  ButtonBox["Simplifying a model",
    ButtonData:>{"Simplifying a model", "StructuredModelReduce"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredModelReduce"],

Cell[TextData[{
  "Structured models",
  ",",
  " example",
  ", ",
  ButtonBox["Example data",
    ButtonData:>{"Example data", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Structured models"],

Cell[TextData[{
  " hierarchical analysis",
  ", ",
  ButtonBox["Hierarchical analysis",
    ButtonData:>{"Hierarchical analysis", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Structured models"],

Cell[TextData[{
  "StructuredParameter",
  ",",
  " ",
  ButtonBox["Structured parameters",
    ButtonData:>{"Structured parameters", "StructuredParameter"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredParameter"],

Cell[TextData[{
  "StructuredVariance",
  ",",
  " ",
  ButtonBox["Variance components for a structured model",
    ButtonData:>{"Variance components for a structured model", 
      "StructuredVariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredVariance"],

Cell[TextData[{
  "Style sheets",
  ",",
  " bugs with",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Style sheets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Style sheets"],

Cell[TextData[{
  "Subdivide",
  ",",
  " ",
  ButtonBox["Muddling and subdividing sets",
    ButtonData:>{"Muddling and subdividing sets", "Subdivide"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subdivide"],

Cell[TextData[{
  "Subscripts",
  ",",
  " as written in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets in subscripts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subscripts"],

Cell[TextData[{
  "Subsets",
  ",",
  " ",
  ButtonBox["Subsets",
    ButtonData:>{"Subsets", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subsets"],

Cell[TextData[{
  " option for AddUp",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Subsets"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for TimesUp",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subsets"],

Cell[TextData[{
  "Sums",
  ",",
  " multiple",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Multiple sums"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sums"],

Cell[TextData[{
  "SwapStates",
  ",",
  " ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", "SwapStates"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SwapStates"],

Cell[TextData[{
  "Symmetric cline",
  ",",
  " in allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a symmetric cline",
    ButtonData:>{"Allele frequencies: setting up a symmetric cline", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric cline"],

Cell[TextData[{
  " in genotype frequencies",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric cline"],

Cell[TextData[{
  "SymmetricDiploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricDiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricDiploidFrequencies"],

Cell[TextData[{
  "SymmetricHaploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricHaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricHaploidFrequencies"],

Cell[TextData[{
  "Symmetric model",
  ",",
  " adding a neutral marker",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: limitations",
    ButtonData:>{"Symmetric model: limitations", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric model"],

Cell[TextData[{
  " cline example",
  ", ",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: spatially varying selection",
    ButtonData:>{"Symmetric stability: spatially varying selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " limitations",
  ", ",
  ButtonBox["Symmetric model: limitations",
    ButtonData:>{"Symmetric model: limitations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " one deme example",
  ", ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "overview",
  ", ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " references",
  ", ",
  ButtonBox["Symmetric model: references",
    ButtonData:>{"Symmetric model: references", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reproduction",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Symmetric stability: outline",
    ButtonData:>{"Symmetric stability: outline", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric model"],

Cell[TextData[{
  "SymmetricNeutralDiploidFrequencies",
  ",",
  " ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricNeutralDiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricNeutralDiploidFrequencies"],

Cell[TextData[{
  "SymmetricNeutralHaploidFrequencies",
  ",",
  " ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricNeutralHaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricNeutralHaploidFrequencies"],

Cell[TextData[{
  "SymmetricRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "SymmetricRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricRecombination"],

Cell[TextData[{
  "SymmetricRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "SymmetricRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricRepresentations"],

Cell[TextData[{
  "SymmetricSexes",
  ",",
  " ",
  ButtonBox["Symmetric sexes",
    ButtonData:>{"Symmetric sexes", "SymmetricSexes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricSexes"],

Cell[TextData[{
  "Symmetrise",
  ",",
  " ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Symmetrise"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetrise",
    ButtonData:>{"Symmetrise", "Symmetrise"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetrise"],

Cell[TextData[{
  "T",
  ",",
  " time",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "T"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"T"],

Cell[TextData[{
  "Table",
  ",",
  " option for VarianceComponents",
  ", ",
  ButtonBox["Variance components",
    ButtonData:>{"Variance components", "Table"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Table"],

Cell[TextData[{
  "Tag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Tag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tag"],

Cell[TextData[{
  "Tags",
  ",",
  " finding",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Finding tags"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tags"],

Cell[TextData[{
  " setting up hyperlinks to",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Setting up links to a list of tags"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tags"],

Cell[TextData[{
  "TakeAway, \[Backslash], \[AliasIndicator]\[AliasIndicator], ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TakeAway"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TakeAway",
    ButtonData:>{"TakeAway", "TakeAway"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TakeAway"],

Cell[TextData[{
  "TakeOptions",
  ",",
  " ",
  ButtonBox["Manipulating options",
    ButtonData:>{"Manipulating options", "TakeOptions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TakeOptions"],

Cell[TextData[{
  "Time",
  ",",
  " T",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "T"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Time"],

Cell[TextData[{
  "TimesOfEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "TimesOfEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimesOfEvents"],

Cell[TextData[{
  "TimespanOfJunction",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "TimespanOfJunction"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimespanOfJunction"],

Cell[TextData[{
  "TimespanOfLineage",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "TimespanOfLineage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimespanOfLineage"],

Cell[TextData[{
  "TimesUp",
  ",",
  " ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TimesUp"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "TimesUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimesUp"],

Cell[TextData[{
  " multiple products",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Multiple products"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over subsets",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimesUp"],

Cell[TextData[{
  "ToBaake",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "ToBaake"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToBaake"],

Cell[TextData[{
  "ToBennett",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "ToBennett"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToBennett"],

Cell[TextData[{
  "ToBennettExpression",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "ToBennettExpression"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToBennettExpression"],

Cell[TextData[{
  "ToCumulants",
  ",",
  " ",
  ButtonBox["Multilocus cumulants",
    ButtonData:>{"Multilocus cumulants", "ToCumulants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToCumulants"],

Cell[TextData[{
  "ToMoments",
  ",",
  " ",
  ButtonBox["Multilocus cumulants",
    ButtonData:>{"Multilocus cumulants", "ToMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToMoments"],

Cell[TextData[{
  "ToPopulationCumulants",
  ",",
  " ",
  ButtonBox["Random drift: cumulants",
    ButtonData:>{"Random drift: cumulants", "ToPopulationCumulants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToPopulationCumulants"],

Cell[TextData[{
  "ToPopulationMoments",
  ",",
  " ",
  ButtonBox["Random drift: cumulants",
    ButtonData:>{"Random drift: cumulants", "ToPopulationMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToPopulationMoments"],

Cell[TextData[{
  "TotalLength",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "TotalLength"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalLength"],

Cell[TextData[{
  "TotalNumber",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "TotalNumber"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalNumber"],

Cell[TextData[{
  "Trait",
  ",",
  " set of all positions affecting, \[DoubleStruckCapitalZ], \
\[AliasIndicator]dsZ\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Trait"],

Cell[TextData[{
  "TransformedRange",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "TransformedRange"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransformedRange"],

Cell[TextData[{
  "TransformInformation",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "TransformInformation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransformInformation"],

Cell[TextData[{
  "TransmissionRule",
  ",",
  " ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "TransmissionRule"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransmissionRule"],

Cell[TextData[{
  "Transmission rules",
  ",",
  " applying",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "Applying transmission rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Transmission rules"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Transmission rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " distinct from Mathematica rules",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "Transmission vs Mathematica rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Transmission"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Transmission rules"],

Cell[TextData[{
  "TriDiagonalMatrix",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "TriDiagonalMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TriDiagonalMatrix"],

Cell[TextData[{
  "TruncationSelection",
  ",",
  " option for NewGametes",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", 
      "TruncationSelection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TruncationSelection"],

Cell[TextData[{
  "option for SelectionExact",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "TruncationSelection"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TruncationSelection"],

Cell[TextData[{
  "Turelli and Barton 1994",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Turelli and Barton 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Turelli and Barton 1994"],

Cell[TextData[{
  "Turelli & Barton 1994",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Turelli & Barton 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Turelli & Barton 1994"],

Cell[TextData[{
  "Two alleles",
  ",",
  " ",
  ButtonBox["Two alleles",
    ButtonData:>{"Two alleles", "Biallelic"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Two alleles"],

Cell[TextData[{
  " selection coefficients",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Two alleles"],

Cell[TextData[{
  "UMS",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UMS"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UMS"],

Cell[TextData[{
  "UnionOfGametes",
  ",",
  " ",
  ButtonBox["Union of gametes",
    ButtonData:>{"Union of gametes", "UnionOfGametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnionOfGametes"],

Cell[TextData[{
  "UnlinkedRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "UnlinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnlinkedRecombination"],

Cell[TextData[{
  "UnrootedGenealogy",
  ",",
  " ",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "UnrootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnrootedGenealogy"],

Cell[TextData[{
  "UpperOffDiagonal",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "UpperOffDiagonal"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UpperOffDiagonal"],

Cell[TextData[{
  "USM",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"USM"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"USM"],

Cell[TextData[{
  "ValidMatrixQ",
  ",",
  " ",
  ButtonBox["Validity of a mutation matrix",
    ButtonData:>{"Validity of a mutation matrix", "ValidMatrixQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ValidMatrixQ"],

Cell[TextData[{
  "VarianceComponents",
  ",",
  " ",
  ButtonBox["Variance components for a structured model",
    ButtonData:>{"Variance components for a structured model", 
      "VarianceComponents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"VarianceComponents"],

Cell[TextData[{
  " Table option",
  ", ",
  ButtonBox["Variance components",
    ButtonData:>{"Variance components", "Table"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"VarianceComponents"],

Cell[TextData[{
  "Versions",
  ",",
  " of applications packages",
  ", ",
  ButtonBox["Versions",
    ButtonData:>{"Versions", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Versions"],

Cell[TextData[{
  "Wiuf & Hein 1999",
  ",",
  " ",
  ButtonBox["Ancestral graph references",
    ButtonData:>{"Ancestral graph references", "Wiuf & Hein 1999"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Ancestral graphs introduction",
    ButtonData:>{"Ancestral graphs introduction", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Wiuf & Hein 1999"],

Cell[TextData[{
  "WLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"WLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"WLinkedLoci"],

Cell[TextData[{
  "Wright-Fisher sampling",
  ",",
  " ",
  ButtonBox["Wright-Fisher sampling",
    ButtonData:>{"Wright-Fisher sampling", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Wright-Fisher sampling"],

Cell[TextData[{
  "X",
  ",",
  " AllelicState",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicState"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"X"],

Cell[TextData[{
  "XLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"XLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"XLinkedLoci"],

Cell[TextData[{
  "YLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"YLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"YLinkedLoci"],

Cell[TextData[{
  "ZLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ZLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ZLinkedLoci"],

Cell[TextData[{
  "Zygotes",
  ",",
  " \[GothicCapitalZ], \[AliasIndicator]goZ\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Zygotes"],

Cell[TextData[{
  "\[GothicA]",
  ",",
  " \[AliasIndicator]goa\[AliasIndicator], SelectionCoefficient",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicA]"],

Cell[TextData[{
  "\[GothicCapitalA]",
  ",",
  " \[AliasIndicator]goA\[AliasIndicator], adults",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalA]"],

Cell[TextData[{
  "\[GothicCapitalC]",
  ",",
  " \[AliasIndicator]goC\[AliasIndicator], PopulationDisequilibrium",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalC]"],

Cell[TextData[{
  "\[GothicCapitalD]",
  ",",
  " \[AliasIndicator]\[GothicCapitalD]\[AliasIndicator], Disequilibrium",
  ", ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalD]"],

Cell[TextData[{
  "\!\(\(\[GothicCapitalG]\^*\)\)",
  ",",
  " \[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, \
\[GothicCapitalG]new, new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\!\(\(\[GothicCapitalG]\^*\)\)"],

Cell[TextData[{
  "\[GothicCapitalG]",
  ",",
  " \[AliasIndicator]goG\[AliasIndicator], Gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalG]"],

Cell[TextData[{
  "\[GothicCapitalH]",
  ",",
  " \[AliasIndicator]goH\[AliasIndicator], hermaphrodites",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalH]"],

Cell[TextData[{
  "\[GothicCapitalJ]",
  ",",
  " \[AliasIndicator]goJ\[AliasIndicator], juveniles",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalJ]"],

Cell[TextData[{
  "\[GothicK]",
  ",",
  " \[AliasIndicator]gok\[AliasIndicator], CumulantDisequilibrium",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "CumulantDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicK]"],

Cell[TextData[{
  "\[GothicCapitalK]",
  ",",
  " \[AliasIndicator]goK\[AliasIndicator], CumulantPopulationDisequilibrium",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalK]"],

Cell[TextData[{
  "\[GothicM]",
  ",",
  " \[AliasIndicator]gom\[AliasIndicator], MeanContribution",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "MeanContribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicM]"],

Cell[TextData[{
  "\[GothicP]",
  ",",
  " \[AliasIndicator]gop\[AliasIndicator], AlleleFrequencyP",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicP]"],

Cell[TextData[{
  "\[GothicP]\[GothicQ]",
  ",",
  " \[AliasIndicator]gop\[AliasIndicator]\[AliasIndicator]goq\[AliasIndicator]\
, AlleleFrequencyPQ",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyPQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicP]\[GothicQ]"],

Cell[TextData[{
  "\[GothicQ]",
  ",",
  " \[AliasIndicator]goq\[AliasIndicator], AlleleFrequencyQ",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicQ]"],

Cell[TextData[{
  "\[GothicR]",
  ",",
  " \[AliasIndicator]gor\[AliasIndicator], RecombinationRate",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicR]"],

Cell[TextData[{
  "\[GothicS]",
  ",",
  "\[AliasIndicator]gos\[AliasIndicator], SelectionRate",
  ", ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SelectionRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicS]"],

Cell[TextData[{
  "\[GothicCapitalZ]",
  ",",
  " \[AliasIndicator]goZ\[AliasIndicator], Zygotes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalZ]"],

Cell[TextData[{
  "\[DoubleStruckCapitalG]",
  ",",
  " \[AliasIndicator]dsG\[AliasIndicator], set of all positions in genome",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalG]"],

Cell[TextData[{
  "\[DoubleStruckCapitalM]",
  ",",
  " \[AliasIndicator]dsM\[AliasIndicator], MigrationSet",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "MigrationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalM]"],

Cell[TextData[{
  "\[DoubleStruckCapitalR]",
  ",",
  " \[AliasIndicator]dsR\[AliasIndicator], RecombinationSet",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalR]"],

Cell[TextData[{
  "\[DoubleStruckCapitalW]",
  ",",
  " \[AliasIndicator]dsW\[AliasIndicator], FitnessSet",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "FitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalW]"],

Cell[TextData[{
  "\[DoubleStruckCapitalZ]",
  ",",
  " \[AliasIndicator]dsZ\[AliasIndicator], set of all positions affecting a \
trait",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalZ]"],

Cell[TextData[{
  "\[Gamma]",
  ",",
  " \[AliasIndicator]g\[AliasIndicator], ExtractGenes",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Gamma]"],

Cell[TextData[{
  "\[Zeta]",
  ",",
  " \[AliasIndicator]z\[AliasIndicator], AllelicDeviation",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicDeviation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Zeta]"],

Cell[TextData[{
  "\[CapitalMu]",
  ",",
  " \[AliasIndicator]M\[AliasIndicator], MigrationRate",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CapitalMu]"],

Cell[TextData[{
  "\[Chi]",
  ",",
  " \[AliasIndicator]c\[AliasIndicator], ExtractContexts",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Chi]"],

Cell[TextData[{
  "\[Sampi]",
  ",",
  " \[AliasIndicator]sa\[AliasIndicator], Stage",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Sampi]"],

Cell[TextData[{
  "$MetropolisAdjustment",
  ",",
  " ",
  ButtonBox["Metropolis algorithm",
    ButtonData:>{"Metropolis algorithm", "$MetropolisAdjustment"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$MetropolisAdjustment"],

Cell[TextData[{
  "\[WeierstrassP]",
  ",",
  " \[AliasIndicator]wp\[AliasIndicator], ReferencePoint",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[WeierstrassP]"],

Cell[TextData[{
  "\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]",
  ",",
  " \[AliasIndicator]l||\[AliasIndicator] \[AliasIndicator]r||\
\[AliasIndicator], population expectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],

Cell[TextData[{
  "\[CircleDot]",
  ",",
  " \[AliasIndicator]c.\[AliasIndicator], SelectContext",
  ", ",
  ButtonBox["Selecting contexts",
    ButtonData:>{"Selecting contexts", "SelectContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CircleDot]"],

Cell[TextData[{
  "\[Backslash], \[AliasIndicator]\[AliasIndicator], TakeAway, ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TakeAway"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TakeAway",
    ButtonData:>{"TakeAway", "TakeAway"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Backslash]"],

Cell[TextData[{
  "\[Wedge]",
  ",",
  " \[AliasIndicator]^\[AliasIndicator], ExactIntersection",
  ", ",
  ButtonBox["ExactIntersection",
    ButtonData:>{"ExactIntersection", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Wedge]"],

Cell[TextData[{
  "\[CirclePlus]",
  ",",
  " \[AliasIndicator]c+\[AliasIndicator], ChangeContext",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "ChangeContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CirclePlus]"]
}, Closed]],

Cell[CellGroupData[{

Cell[" index may 2002", "Subsubsection"],

Cell[BoxData[
    \(\(Scan[MakeIndexEntry, 
        ProcessIndexMatrix[MasterIndexMatrix]];\)\)], "Input"],

Cell[TextData[{
  "|.",
  ",",
  " ReplaceAllSpecial",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"|."],

Cell[TextData[{
  "\\\\",
  ",",
  " bugs with",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Repeated \\\\"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\\\\"],

Cell[TextData[{
  "<>",
  ",",
  " Expectation",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Expectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"<>"],

Cell[TextData[{
  "||.",
  ",",
  " ReplaceRepeatedSpecial",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"||."],

Cell[TextData[{
  "AddGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddGenealogy"],

Cell[TextData[{
  "Additive models",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "additive models"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive models"],

Cell[TextData[{
  "Additive selection",
  ",",
  " defining fitnesses",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive selection"],

Cell[TextData[{
  " defining rules",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Defining rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new D",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "New D"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "New mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " scaled D",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Scaled D"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive selection"],

Cell[TextData[{
  "AddMutation",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddMutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddMutation"],

Cell[TextData[{
  "AddNode",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddNode"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddNode"],

Cell[TextData[{
  "AddTag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "AddTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddTag"],

Cell[TextData[{
  "AddUp",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "AddUp"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "AddUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddUp"],

Cell[TextData[{
  " multiple sums",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Multiple sums"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over subsets",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Subsets"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Technicalities"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddUp"],

Cell[TextData[{
  "AdmixtureFrequency",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "AdmixtureFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AdmixtureFrequency"],

Cell[TextData[{
  "Admixture models",
  ",",
  " ",
  ButtonBox["Admixture models",
    ButtonData:>{"Admixture models", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview",
    ButtonData:>{"Overview", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Admixture models"],

Cell[TextData[{
  " changing sex",
  ", ",
  ButtonBox["Changing sex",
    ButtonData:>{"Changing sex", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " equilibria",
  ", ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " iteration",
  ", ",
  ButtonBox["Iteration",
    ButtonData:>{"Iteration", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " migration",
  ", ",
  ButtonBox["Migration in admixture models",
    ButtonData:>{"Migration in admixture models", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " recombination",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Admixture models"],

Cell[TextData[{
  "Adults",
  ",",
  " \[GothicCapitalA], \[AliasIndicator]goA\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Adults"],

Cell[TextData[{
  "Allele frequencies",
  ",",
  " definition of fitness",
  ", ",
  ButtonBox["Allele frequencies:fitnesses",
    ButtonData:>{"Allele frequencies:fitnesses", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Allele frequencies"],

Cell[TextData[{
  "AlleleFrequencies",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "AlleleFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencies"],

Cell[TextData[{
  "AlleleFrequencyMean",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyMean"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyMean"],

Cell[TextData[{
  "AlleleFrequencyP",
  ",",
  " \[GothicP], \[AliasIndicator]gop\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyP"],

Cell[TextData[{
  "AlleleFrequencyPermutations",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "AlleleFrequencyPermutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyPermutations"],

Cell[TextData[{
  "AlleleFrequencyPQ",
  ",",
  " \[GothicP]\[GothicQ], \[AliasIndicator]gop\[AliasIndicator]\
\[AliasIndicator]goq\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyPQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyPQ"],

Cell[TextData[{
  "AlleleFrequencyQ",
  ",",
  " \[GothicQ], \[AliasIndicator]goq\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyQ"],

Cell[TextData[{
  "AlleleFrequencyTable",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyTable"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "AlleleFrequencyTable"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyTable"],

Cell[TextData[{
  "AllelicDeviation",
  ",",
  " \[Zeta], \[AliasIndicator]z\[AliasIndicator]",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicDeviation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllelicDeviation"],

Cell[TextData[{
  "AllelicState",
  ",",
  " X",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicState"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllelicState"],

Cell[TextData[{
  "AllSets",
  ",",
  " ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "AllSets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllSets"],

Cell[TextData[{
  "Ancestors",
  ",",
  " determining",
  ", ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "Ancestors"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestors"],

Cell[TextData[{
  "Ancestry",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Ancestry"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestry"],

Cell[TextData[{
  "Arbitrary sets of loci",
  ",",
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Arbitrary sets of loci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Arbitrary sets of loci"],

Cell[TextData[{
  "Arnold 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Arnold 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Arnold 1996"],

Cell[TextData[{
  "Asmussen and Orive 2000",
  ",",
  " ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["References",
    ButtonData:>{"References", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Asmussen and Orive 2000"],

Cell[TextData[{
  "Asmussen et al. 1987",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Asmussen et al 1987"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Asmussen et al. 1987"],

Cell[TextData[{
  "B",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "B"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"B"],

Cell[TextData[{
  "Baake 2001",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Baake"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["References",
    ButtonData:>{"References", "Baake 2001"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Baake 2001"],

Cell[TextData[{
  "Barrier",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", "Barrier"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barrier"],

Cell[TextData[{
  "BarrierStrength",
  ",",
  " ",
  ButtonBox["Describing populations",
    ButtonData:>{"Describing populations", "BarrierStrength"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BarrierStrength"],

Cell[TextData[{
  "Barton 1986",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton 1986"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 1986"],

Cell[TextData[{
  "Barton 1995",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Barton 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 1995"],

Cell[TextData[{
  "Barton 2000",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 2000"],

Cell[TextData[{
  "Barton and Turelli 1991",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Barton and Turelli 1991"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton and Turelli 1991"],

Cell[TextData[{
  "Barton & Gale 1993",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Gale 1993"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Gale 1993"],

Cell[TextData[{
  "Barton & Shpak 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Shpak 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Shpak 1999"],

Cell[TextData[{
  "Barton & Turelli 1991",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Turelli 1991"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Turelli 1991"],

Cell[TextData[{
  "Bennett 1954",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Bennett 1954"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bennett 1954"],

Cell[TextData[{
  "BennettB",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "BennettB"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BennettB"],

Cell[TextData[{
  "BennettC",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "BennettC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BennettC"],

Cell[TextData[{
  "BennettExpansion",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "BennettExpansion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BennettExpansion"],

Cell[TextData[{
  "Biallelic",
  ",",
  " ",
  ButtonBox["Two alleles",
    ButtonData:>{"Two alleles", "Biallelic"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Biallelic"],

Cell[TextData[{
  " selection coefficients",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Biallelic"],

Cell[TextData[{
  "BiallelicMutation",
  ",",
  " ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "BiallelicMutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BiallelicMutation"],

Cell[TextData[{
  " Mutation option",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Mutation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BiallelicMutation"],

Cell[TextData[{
  "Binary integers",
  ",",
  " ",
  ButtonBox["Set combinations",
    ButtonData:>{"Set combinations", "SetOfCombinations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Binary integers"],

Cell[TextData[{
  "Birth",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "Birth"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Birth"],

Cell[TextData[{
  "BirthTime",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "BirthTime"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BirthTime"],

Cell[TextData[{
  "Boundary conditions",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Boundary conditions"],

Cell[TextData[{
  "Box",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Box"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Box"],

Cell[TextData[{
  "Boxes",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Boxes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Boxes"],

Cell[TextData[{
  "Browser categories",
  ",",
  " ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Browser categories"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Browser categories"],

Cell[TextData[{
  "Bugs",
  ",",
  " applying rules",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bugs"],

Cell[TextData[{
  " clashes between packages",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Clashes between packages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " estimating D",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " incompatibilities",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Incompatibilities"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " manipulating notebooks",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Manipulating notebooks"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " multilocus notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Multilocus notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " numerical error with AlleleFrequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Numerical bug"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pasting hyperlinks",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Pasting hyperlinks"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " repeated \\\\",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Repeated \\\\"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " special notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with style sheets",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Style sheets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bugs"],

Cell[TextData[{
  "ChangeContext",
  ",",
  "\[CirclePlus], \[AliasIndicator]c+\[AliasIndicator]",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "ChangeContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ChangeContext"],

Cell[TextData[{
  "ChangeSex",
  ",",
  " ",
  ButtonBox["Changing sex",
    ButtonData:>{"Changing sex", "ChangeSex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ChangeSex"],

Cell[TextData[{
  "ClassToGenotypes",
  ",",
  " ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "ClassToGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClassToGenotypes"],

Cell[TextData[{
  "Cline",
  ",",
  " example of",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cline"],

Cell[TextData[{
  " in allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: spatially varying selection",
    ButtonData:>{"Symmetric stability: spatially varying selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: setting up a symmetric cline",
    ButtonData:>{"Simulating individuals: setting up a symmetric cline", 
      None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: setting up a symmetric cline",
    ButtonData:>{"Symmetric model: setting up a symmetric cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with neutral marker",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", "Cline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cline"],

Cell[TextData[{
  "ClineGradient",
  ",",
  "  for genotype frequencies",
  ", ",
  ButtonBox["ClineGradient: setting up a cline",
    ButtonData:>{"ClineGradient: setting up a cline", "ClineGradient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineGradient"],

Cell[TextData[{
  "ClineWidth",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineWidth"],

Cell[TextData[{
  "  for genotype frequencies",
  ", ",
  ButtonBox["Recursions: setting up a cline",
    ButtonData:>{"Recursions: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineWidth"],

Cell[TextData[{
  "CoalescenceDistribution",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", 
      "CoalescenceDistribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CoalescenceDistribution"],

Cell[TextData[{
  "CollapseGenealogy",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "CollapseGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CollapseGenealogy"],

Cell[TextData[{
  "Combinations",
  ",",
  " set of",
  ", ",
  ButtonBox["Set combinations",
    ButtonData:>{"Set combinations", "SetOfCombinations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Combinations"],

Cell[TextData[{
  "Combine",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Combine"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Combine"],

Cell[TextData[{
  "CompareLogL",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "CompareLogL"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CompareLogL"],

Cell[TextData[{
  "Compiled",
  ",",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Compiled"],

Cell[TextData[{
  "Compiling",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Compiling"],

Cell[TextData[{
  "CondenseGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "CondenseGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CondenseGenealogy"],

Cell[TextData[{
  "CondenseMatrix",
  ",",
  " ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", "CondenseMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CondenseMatrix"],

Cell[TextData[{
  "ConstrainedIntervals",
  ",",
  " ",
  ButtonBox["Constrained intervals",
    ButtonData:>{"Constrained intervals", "ConstrainedIntervals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstrainedIntervals"],

Cell[TextData[{
  "ConstructMutateList",
  ",",
  " ",
  ButtonBox["Allele frequencies: mutation",
    ButtonData:>{"Allele frequencies: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: mutation",
    ButtonData:>{"Simulating individuals: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstructMutateList"],

Cell[TextData[{
  "ConstructMutateMatrix",
  ",",
  " ",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "ConstructMutateMatrix"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "ConstructMutateMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstructMutateMatrix"],

Cell[TextData[{
  "ContextComponentQ",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextComponentQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextComponentQ"],

Cell[TextData[{
  "ContextPosition",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextPosition"],

Cell[TextData[{
  "ContextStageQ",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextStageQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextStageQ"],

Cell[TextData[{
  "ContextStructure",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextStructure"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextStructure"],

Cell[TextData[{
  "Continuous populations",
  ",",
  " estimating covariance",
  ", ",
  ButtonBox["Estimating the covariance",
    ButtonData:>{"Estimating the covariance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Continuous populations"],

Cell[TextData[{
  " example",
  ", ",
  ButtonBox["An example",
    ButtonData:>{"An example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " implementation",
  ", ",
  ButtonBox["Implementation",
    ButtonData:>{"Implementation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving results",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "Saving results"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " the model",
  ", ",
  ButtonBox["The model",
    ButtonData:>{"The model", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Continuous populations"],

Cell[TextData[{
  "ContinuumVariables",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "ContinuumVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContinuumVariables"],

Cell[TextData[{
  "ConvertData",
  ",",
  " ",
  ButtonBox["Converting a dataset",
    ButtonData:>{"Converting a dataset", "ConvertData"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConvertData"],

Cell[TextData[{
  "ConvertHyperlinkToAddOnsLink",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "ConvertHyperlinkToAddOnsLink"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConvertHyperlinkToAddOnsLink"],

Cell[TextData[{
  "Converting",
  ",",
  " between representations",
  ", ",
  ButtonBox["Allele frequencies: converting",
    ButtonData:>{"Allele frequencies: converting", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Converting"],

Cell[TextData[{
  "CountHeterozygotes",
  ",",
  " ",
  ButtonBox["Recursions:manipulation",
    ButtonData:>{"Recursions:manipulation", "CountHeterozygotes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CountHeterozygotes"],

Cell[TextData[{
  "Covariance",
  ",",
  " in continuous populations",
  ", ",
  ButtonBox["Estimating the covariance",
    ButtonData:>{"Estimating the covariance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Covariance"],

Cell[TextData[{
  "CovarianceMidPoints",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "CovarianceMidPoints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CovarianceMidPoints"],

Cell[TextData[{
  "Crow and Kimura 1970",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Crow and Kimura 1970"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Crow and Kimura 1970"],

Cell[TextData[{
  "Cumulant",
  ",",
  " ",
  ButtonBox["Moments and cumulants",
    ButtonData:>{"Moments and cumulants", "Cumulant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cumulant"],

Cell[TextData[{
  "CumulantDisequilibrium",
  ",",
  " \[GothicK], \[AliasIndicator]gok\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "CumulantDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantDisequilibrium"],

Cell[TextData[{
  "CumulantEquilibrium",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "CumulantEquilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantEquilibrium"],

Cell[TextData[{
  "CumulantPopulationDisequilibrium",
  ",",
  " \[GothicCapitalK], \[AliasIndicator]goK\[AliasIndicator]",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantPopulationDisequilibrium"],

Cell[TextData[{
  "CumulantReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "CumulantReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantReduced"],

Cell[TextData[{
  "Cumulants",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "7.2"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Cumulant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cumulants"],

Cell[TextData[{
  "Cytoplasmic inheritance",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cytoplasmic inheritance"],

Cell[TextData[{
  " and migration",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Cytonuclear associations"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " examples of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cytoplasmic inheritance"],

Cell[TextData[{
  "CytoplasmicLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CytoplasmicLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CytoplasmicLoci"],

Cell[TextData[{
  "dAlleleFrequencyPermutations",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "dAlleleFrequencyPermutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"dAlleleFrequencyPermutations"],

Cell[TextData[{
  "Data",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Data"],

Cell[TextData[{
  " missing",
  ", ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Missing data"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notation for",
  ", ",
  ButtonBox["Notation for genetic data",
    ButtonData:>{"Notation for genetic data", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Data"],

Cell[TextData[{
  "Datasets",
  ",",
  " defining",
  ", ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Datasets"],

Cell[TextData[{
  "Dawson 2000",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Bennett"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["References",
    ButtonData:>{"References", "Dawson 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dawson 2000"],

Cell[TextData[{
  "Death",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "Death"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Death"],

Cell[TextData[{
  "DeathTime",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "DeathTime"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeathTime"],

Cell[TextData[{
  "DefineContext",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "DefineContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DefineContext"],

Cell[TextData[{
  "DegreesOfFreedom",
  ",",
  " ",
  ButtonBox["Degrees of freedom",
    ButtonData:>{"Degrees of freedom", "DegreesOfFreedom"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DegreesOfFreedom"],

Cell[TextData[{
  "DeletedMutations",
  ",",
  " ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", "DeletedMutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeletedMutations"],

Cell[TextData[{
  "DeleteGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "DeleteGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeleteGenealogy"],

Cell[TextData[{
  "Deme",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Deme"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Deme"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Deme"],

Cell[TextData[{
  "DemeSize",
  ",",
  " compiling",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "Deme size (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DemeSize"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for MigrateExact",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DemeSize"],

Cell[TextData[{
  "Dempster et al 1977",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Dempster et al 1977"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dempster et al 1977"],

Cell[TextData[{
  "Density",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Density"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Density"],

Cell[TextData[{
  "Descendants",
  ",",
  " ",
  ButtonBox["Ancestors and descendants",
    ButtonData:>{"Ancestors and descendants", "Descendants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Descendants"],

Cell[TextData[{
  " determining",
  ", ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "Descendants"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Descendants"],

Cell[TextData[{
  "Dicytonuclear associations",
  ",",
  " ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dicytonuclear associations"],

Cell[TextData[{
  "Diploid",
  ",",
  " option for MomentFromG",
  ", ",
  ButtonBox["Moments from genotype frequencies",
    ButtonData:>{"Moments from genotype frequencies", "Diploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Diploid"],

Cell[TextData[{
  "DiploidConstraints",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidConstraints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidConstraints"],

Cell[TextData[{
  "DiploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidFrequencies"],

Cell[TextData[{
  "DiploidGenotypeFrequency",
  ",",
  " ",
  ButtonBox["Genotype frequencies from moments",
    ButtonData:>{"Genotype frequencies from moments", 
      "DiploidGenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequency"],

Cell[TextData[{
  "DiploidGenotypeFrequencyList",
  ",",
  " ",
  ButtonBox["Fast calculations",
    ButtonData:>{"Fast calculations", "DiploidGenotypeFrequencyList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyList"],

Cell[TextData[{
  "DiploidGenotypeFrequencyReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyReduced"],

Cell[TextData[{
  "DiploidGenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyTable"],

Cell[TextData[{
  "DiploidIndividuals",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidIndividuals"],

Cell[TextData[{
  "DiploidPhenotype",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidPhenotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidPhenotype"],

Cell[TextData[{
  "DiploidPsi",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidPsi"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "DiploidPsi"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidPsi"],

Cell[TextData[{
  "DiploidRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidRepresentations"],

Cell[TextData[{
  "DiploidSource",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidSource"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "DiploidSource"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidSource"],

Cell[TextData[{
  "DiploidSubsets",
  ",",
  " ",
  ButtonBox["Subsets of loci",
    ButtonData:>{"Subsets of loci", "DiploidSubsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidSubsets"],

Cell[TextData[{
  "DiploidTypes",
  ",",
  " ",
  ButtonBox["Listing genotypes",
    ButtonData:>{"Listing genotypes", "DiploidTypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidTypes"],

Cell[TextData[{
  "Disequilibrium",
  ",",
  " Baake's measure",
  ", ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Baake"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Disequilibrium"],

Cell[TextData[{
  " Bennett's principal components",
  ", ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Bennett"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " \[GothicCapitalD], \[AliasIndicator]\[GothicCapitalD]\[AliasIndicator]",
  ", ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Disequilibrium"],

Cell[TextData[{
  "DisequilibriumMean",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumMean"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumMean"],

Cell[TextData[{
  "DisequilibriumTable",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumTable"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumTable"],

Cell[TextData[{
  "Dispersal",
  ",",
  " in continuum simulations",
  ", ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dispersal"],

Cell[TextData[{
  "DistanceSquared",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "DistanceSquared"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DistanceSquared"],

Cell[TextData[{
  "Distribution",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Distribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Distribution"],

Cell[TextData[{
  "DivideZero",
  ",",
  " ",
  ButtonBox["DivideZero",
    ButtonData:>{"DivideZero", "DivideZero"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DivideZero"],

Cell[TextData[{
  "DoReplicates",
  ",",
  " ",
  ButtonBox["Analysing replicate samples",
    ButtonData:>{"Analysing replicate samples", "DoReplicates"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoReplicates"],

Cell[TextData[{
  "DoubleCline",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a symmetric cline",
    ButtonData:>{"Allele frequencies: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoubleCline"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: setting up a symmetric cline",
    ButtonData:>{"Simulating individuals: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a symmetric cline",
    ButtonData:>{"Symmetric model: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoubleCline"],

Cell[TextData[{
  "DrawSamples",
  ",",
  " ",
  ButtonBox["Setting up replicates",
    ButtonData:>{"Setting up replicates", "DrawSamples"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DrawSamples"],

Cell[TextData[{
  "DropOptions",
  ",",
  " ",
  ButtonBox["Manipulating options",
    ButtonData:>{"Manipulating options", "DropOptions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DropOptions"],

Cell[TextData[{
  "Edwards 1972",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Edwards 1972"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Edwards 1972"],

Cell[TextData[{
  "EmptySets",
  ",",
  "option for PartitionSet",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "EmptySets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EmptySets"],

Cell[TextData[{
  "Epistasis",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Epistasis"],

Cell[TextData[{
  "EquivalentSexes",
  ",",
  " obsolete form of SymmetricSexes",
  ", ",
  ButtonBox["Symmetric sexes",
    ButtonData:>{"Symmetric sexes", "SymmetricSexes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EquivalentSexes"],

Cell[TextData[{
  "ErrorBound",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "ErrorBound"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ErrorBound"],

Cell[TextData[{
  "EstimateFamilyMoments",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "EstimateFamilyMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EstimateFamilyMoments"],

Cell[TextData[{
  "EstimateMoments",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "EstimateMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EstimateMoments"],

Cell[TextData[{
  "Estimating D",
  ",",
  " admixture models",
  ", ",
  ButtonBox["Admixture models",
    ButtonData:>{"Admixture models", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Estimating D"],

Cell[TextData[{
  " alternative methods",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Log-linear models"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction",
  ", ",
  ButtonBox["Introduction to estimating D",
    ButtonData:>{"Introduction to estimating D", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " maximum entropy",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Maximum entropy"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " maximum likelihood, example of",
  ", ",
  ButtonBox["MLE example",
    ButtonData:>{"MLE example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Metropolis random walk",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MLE, cumulants",
  ", ",
  ButtonBox["Finding the MLE",
    ButtonData:>{"Finding the MLE", "Cumulant"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " moments, families",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "Extension to families"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " naive MLE",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Naive MLE"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " obsolete",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pairs of loci",
  ", ",
  ButtonBox["Pairs of loci",
    ButtonData:>{"Pairs of loci", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pairs of loci, example of",
  ", ",
  ButtonBox["Pairwise example",
    ButtonData:>{"Pairwise example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " random sampling, example of",
  ", ",
  ButtonBox["Sampling example",
    ButtonData:>{"Sampling example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " summary",
  ", ",
  ButtonBox["Summary",
    ButtonData:>{"Summary", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " varying divergence",
  ", ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "Varying divergence"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Estimating D"],

Cell[TextData[{
  "ExactEigenvalues",
  ",",
  " ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "ExactEigenvalues"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactEigenvalues"],

Cell[TextData[{
  "ExactIntersection",
  ",",
  " \[Wedge], \[AliasIndicator]^\[AliasIndicator]",
  ", ",
  ButtonBox["ExactIntersection",
    ButtonData:>{"ExactIntersection", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactIntersection"],

Cell[TextData[{
  "ExactProbability",
  ",",
  " ",
  ButtonBox["Exact probability",
    ButtonData:>{"Exact probability", "ExactProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactProbability"],

Cell[TextData[{
  "Expectation",
  ",",
  " <>",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Expectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Expectation"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Expectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population, \[LeftDoubleBracketingBar] \[RightDoubleBracketingBar], \
\[AliasIndicator]l||\[AliasIndicator] \[AliasIndicator]r||\[AliasIndicator]",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Expectation"],

Cell[TextData[{
  "ExponentialF",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExponentialF"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "ExponentialF"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExponentialF"],

Cell[TextData[{
  "ExtantIndividuals",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "ExtantIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtantIndividuals"],

Cell[TextData[{
  "ExtractContexts",
  ",",
  " \[Chi], \[AliasIndicator]c\[AliasIndicator]",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractContexts"],

Cell[TextData[{
  "ExtractExtant",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "ExtractExtant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractExtant"],

Cell[TextData[{
  "ExtractGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "ExtractGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractGenealogy"],

Cell[TextData[{
  "ExtractGenes",
  ",",
  " \[Gamma], \[AliasIndicator]g\[AliasIndicator]",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractGenes"],

Cell[TextData[{
  "ExtractInformation",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "ExtractInformation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractInformation"],

Cell[TextData[{
  "ExtractRepeat",
  ",",
  " ",
  ButtonBox["Repeated elements",
    ButtonData:>{"Repeated elements", "ExtractRepeat"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractRepeat"],

Cell[TextData[{
  "ExtractSubMatrix",
  ",",
  " ",
  ButtonBox["Extracting submatrices",
    ButtonData:>{"Extracting submatrices", "ExtractSubMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractSubMatrix"],

Cell[TextData[{
  "FamilyAlleleFrequencyEstimate",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyAlleleFrequencyEstimate"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyAlleleFrequencyEstimate"],

Cell[TextData[{
  "FamilyEffects",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyEffects"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyEffects"],

Cell[TextData[{
  "FamilyM",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyM"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyM"],

Cell[TextData[{
  "FamilyProbability",
  ",",
  " ",
  ButtonBox["Probabilities",
    ButtonData:>{"Probabilities", "FamilyProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyProbability"],

Cell[TextData[{
  "Family structure",
  ",",
  " set of all",
  ", ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "NewS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Family structure"],

Cell[TextData[{
  "Fecundity",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Fecundity"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fecundity"],

Cell[TextData[{
  "FindHyperlinks",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "FindHyperlinks"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindHyperlinks"],

Cell[TextData[{
  "FindIndexTag",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "FindIndexTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindIndexTag"],

Cell[TextData[{
  "FindMLE",
  ",",
  " ",
  ButtonBox["Finding the MLE",
    ButtonData:>{"Finding the MLE", "FindMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindMLE"],

Cell[TextData[{
  "FindNode",
  ",",
  " ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", "FindNode"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindNode"],

Cell[TextData[{
  "FindPosition",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "FindPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindPosition"],

Cell[TextData[{
  "FindTags",
  ",",
  " ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "FindTags"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindTags"],

Cell[TextData[{
  "Fitness",
  ",",
  " definition for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:fitnesses",
    ButtonData:>{"Allele frequencies:fitnesses", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fitness"],

Cell[TextData[{
  " in individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " problems redefining",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Redefining fitness"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fitness"],

Cell[TextData[{
  "FitnessSet",
  ",",
  " \[DoubleStruckCapitalW], \[AliasIndicator]dsW\[AliasIndicator]",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "FitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessSet"],

Cell[TextData[{
  "FitnessTable",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessTable"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessTable"],

Cell[TextData[{
  "FixedEnds",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FixedEnds"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for MigrateExact",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FixedEnds"],

Cell[TextData[{
  "Flatten",
  ",",
  " ",
  ButtonBox["Flattening lists at specific levels",
    ButtonData:>{"Flattening lists at specific levels", "Flatten"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Flatten"],

Cell[TextData[{
  "FlattenList",
  ",",
  " ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "FlattenList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FlattenList"],

Cell[TextData[{
  " PatternFree",
  ", ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "PatternFree"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FlattenList"],

Cell[TextData[{
  "FourierNormalised",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "FourierNormalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FourierNormalised"],

Cell[TextData[{
  "FourierNormalisedTable",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "FourierNormalisedTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FourierNormalisedTable"],

Cell[TextData[{
  "FrequencyRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "FrequencyRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FrequencyRepresentations"],

Cell[TextData[{
  "FromBaake",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "FromBaake"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FromBaake"],

Cell[TextData[{
  "FromBennett",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "FromBennett"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FromBennett"],

Cell[TextData[{
  "FromBennettExpression",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "FromBennettExpression"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FromBennettExpression"],

Cell[TextData[{
  "FullContext",
  ",",
  " ",
  ButtonBox["Abbreviating contexts",
    ButtonData:>{"Abbreviating contexts", "FullContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullContext"],

Cell[TextData[{
  "FullGenotypeFrequencyReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullGenotypeFrequencyReduced"],

Cell[TextData[{
  "FullGenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullGenotypeFrequencyTable"],

Cell[TextData[{
  "FullOutput",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "FullOutput"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullOutput"],

Cell[TextData[{
  "Function",
  ",",
  " ",
  ButtonBox["Marginal tables",
    ButtonData:>{"Marginal tables", "Function"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Function"],

Cell[TextData[{
  "Gametes",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "Gametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gametes"],

Cell[TextData[{
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new, \!\(\(\[GothicCapitalG]\^*\)\), \
\[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, \[GothicCapitalG]new",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " \[GothicCapitalG], \[AliasIndicator]goG\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gametes"],

Cell[TextData[{
  "GameteTable",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "GameteTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GameteTable"],

Cell[TextData[{
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "GameteTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "GameteTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GameteTable"],

Cell[TextData[{
  "GaussianLogLikelihood",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "GaussianLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GaussianLogLikelihood"],

Cell[TextData[{
  "GaussianMLE",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "GaussianMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GaussianMLE"],

Cell[TextData[{
  "Genealogies",
  ",",
  " exact probability",
  ", ",
  ButtonBox["Exact probability",
    ButtonData:>{"Exact probability", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genealogies"],

Cell[TextData[{
  " family structure",
  ", ",
  ButtonBox["Family structure",
    ButtonData:>{"Family structure", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " generating functions",
  ", ",
  ButtonBox["Deriving recursions for the MGF",
    ButtonData:>{"Deriving recursions for the MGF", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " probability of",
  ", ",
  ButtonBox["Deriving the probability",
    ButtonData:>{"Deriving the probability", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sampling",
  ", ",
  ButtonBox["Sampling genealogies",
    ButtonData:>{"Sampling genealogies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genealogies"],

Cell[TextData[{
  "Genealogy",
  ",",
  " rooting",
  ", ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", "SwapStates"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "RootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genealogy"],

Cell[TextData[{
  "GenealogyToMatrix",
  ",",
  " ",
  ButtonBox["Describing mutation",
    ButtonData:>{"Describing mutation", "GenealogyToMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenealogyToMatrix"],

Cell[TextData[{
  "GeneralizedTransform",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "GeneralizedTransform"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GeneralizedTransform"],

Cell[TextData[{
  "Generating functions",
  ",",
  " examples",
  ", ",
  ButtonBox["Examples of the MGF",
    ButtonData:>{"Examples of the MGF", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Generating functions"],

Cell[TextData[{
  " for cumulants",
  ", ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "GeneralizedTransform"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genealogies",
  ", ",
  ButtonBox["Deriving recursions for the MGF",
    ButtonData:>{"Deriving recursions for the MGF", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Generating functions"],

Cell[TextData[{
  "Genes and contexts",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Genes and contexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genes and contexts"],

Cell[TextData[{
  "Genome",
  ",",
  " set of all positions in, \[DoubleStruckCapitalG], \[AliasIndicator]dsG\
\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genome"],

Cell[TextData[{
  "Genotype",
  ",",
  " in continuum simulations",
  ", ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Genotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype"],

Cell[TextData[{
  " observable",
  ", ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for InitialiseContinuum",
  ", ",
  ButtonBox["Initialisation",
    ButtonData:>{"Initialisation", "Genotype"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype"],

Cell[TextData[{
  "Genotype frequencies",
  ",",
  " recursions",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype frequencies"],

Cell[TextData[{
  "GenotypeFrequencyArguments",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "GenotypeFrequencyArguments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyArguments"],

Cell[TextData[{
  "GenotypeFrequencyConvert",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "GenotypeFrequencyConvert"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyConvert"],

Cell[TextData[{
  "GenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyTable"],

Cell[TextData[{
  "GenotypePosition",
  ",",
  " ",
  ButtonBox["Recursions:manipulation",
    ButtonData:>{"Recursions:manipulation", "GenotypePosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypePosition"],

Cell[TextData[{
  "GenotypeProbability",
  ",",
  " ",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "GenotypeProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeProbability"],

Cell[TextData[{
  " segregation ratio",
  ", ",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeProbability"],

Cell[TextData[{
  "Genotypes",
  ",",
  " notation for",
  ", ",
  ButtonBox["Notation",
    ButtonData:>{"Notation", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotypes"],

Cell[TextData[{
  "GlobalContinuumVariables",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "GlobalContinuumVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GlobalContinuumVariables"],

Cell[TextData[{
  "Gnew",
  ",",
  " \!\(\(\[GothicCapitalG]\^*\)\), \[AliasIndicator]goG\[AliasIndicator]\
\[ControlKey]^*, new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gnew"],

Cell[TextData[{
  "Goodman et al 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Goodman et al 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Goodman et al 1999"],

Cell[TextData[{
  "Griffiths-Tavare",
  ",",
  " ",
  ButtonBox["Exact algorithm",
    ButtonData:>{"Exact algorithm", "GriffithsTavare"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Griffiths-Tavare algorithm",
    ButtonData:>{"Griffiths-Tavare algorithm", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Griffiths-Tavare"],

Cell[TextData[{
  " stochastic algorithm",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "MonteCarloGriffithsTavare"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "Stochastic GT algorithm"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stochastic, comparison with MonteCarloProbability",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", 
      "Comparison with MonteCarloProbability"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stochastic example",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "Small example"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Griffiths-Tavare"],

Cell[TextData[{
  "Guiasu & Shenitzer 1985",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Guiasu & Shenitzer 1985"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Guiasu & Shenitzer 1985"],

Cell[TextData[{
  "HaploidConstraints",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "HaploidConstraints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidConstraints"],

Cell[TextData[{
  "HaploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidFrequencies"],

Cell[TextData[{
  "HaploidGenotypeFrequency",
  ",",
  " ",
  ButtonBox["Genotype frequencies from moments",
    ButtonData:>{"Genotype frequencies from moments", 
      "HaploidGenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidGenotypeFrequency"],

Cell[TextData[{
  "HaploidIndividuals",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidIndividuals"],

Cell[TextData[{
  "HaploidRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidRepresentations"],

Cell[TextData[{
  "Haploids",
  ",",
  " selection on",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Haploids"],

Cell[TextData[{
  "HaploidSource",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "HaploidSource"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "HaploidSource"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidSource"],

Cell[TextData[{
  "HaploidSubsets",
  ",",
  " ",
  ButtonBox["Subsets of loci",
    ButtonData:>{"Subsets of loci", "HaploidSubsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidSubsets"],

Cell[TextData[{
  "HaploidTypes",
  ",",
  " ",
  ButtonBox["Listing genotypes",
    ButtonData:>{"Listing genotypes", "HaploidTypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidTypes"],

Cell[TextData[{
  "Help browser",
  ",",
  " setting up new files",
  ", ",
  ButtonBox["Setting up new help files",
    ButtonData:>{"Setting up new help files", "Setting up new help files"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help browser"],

Cell[TextData[{
  "Help Browser",
  ",",
  " ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "MasterIndexHeading"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help Browser"],

Cell[TextData[{
  " setting up hyperlinks",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up links"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help Browser"],

Cell[TextData[{
  "Hermaphrodites",
  ",",
  " \[GothicCapitalH], \[AliasIndicator]goH\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hermaphrodites"],

Cell[TextData[{
  "HeterozygoteB",
  ",",
  " ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "HeterozygoteB"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HeterozygoteB"],

Cell[TextData[{
  "Hill 1974a",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974a"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974a"],

Cell[TextData[{
  "Hill 1974b",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974b"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974b"],

Cell[TextData[{
  "Hill 1974c",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974c"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974c"],

Cell[TextData[{
  "Hypergeometric model",
  ",",
  " ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hypergeometric model"],

Cell[TextData[{
  "Hyperlinks",
  ",",
  " bugs in pasting",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Pasting hyperlinks"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hyperlinks"],

Cell[TextData[{
  " saving",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Saving the links"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " setting up",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up links"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " to cell tags",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Setting up links to a list of tags"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hyperlinks"],

Cell[TextData[{
  "IncidenceMatrix",
  ",",
  " ",
  ButtonBox["Ordered genealogies",
    ButtonData:>{"Ordered genealogies", "IncidenceMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IncidenceMatrix"],

Cell[TextData[{
  "Index",
  ",",
  " setting up",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up Master Index"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Index"],

Cell[TextData[{
  "Individual",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Individual"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Individual"],

Cell[TextData[{
  "IndividualContinuumVariables",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "IndividualContinuumVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IndividualContinuumVariables"],

Cell[TextData[{
  "IndividualRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "IndividualRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IndividualRepresentations"],

Cell[TextData[{
  "Individuals",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Individuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Individuals"],

Cell[TextData[{
  "Infinite sites mutation",
  ",",
  " ",
  ButtonBox["Describing mutation",
    ButtonData:>{"Describing mutation", "None"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Infinite sites mutation"],

Cell[TextData[{
  "InitialiseContinuum",
  ",",
  " ",
  ButtonBox["Initialisation",
    ButtonData:>{"Initialisation", "InitialiseContinuum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseContinuum"],

Cell[TextData[{
  "InitialiseCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "InitialiseCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseCovariance"],

Cell[TextData[{
  "InitialiseDemes",
  ",",
  " ",
  ButtonBox["Describing the population",
    ButtonData:>{"Describing the population", "InitialiseDemes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Setting up a cline",
    ButtonData:>{"Setting up a cline", "InitialiseDemes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseDemes"],

Cell[TextData[{
  "InitialStep",
  ",",
  " ",
  ButtonBox["Initial step size",
    ButtonData:>{"Initial step size", "InitialStep"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialStep"],

Cell[TextData[{
  "InitialStepReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "InitialStepReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialStepReduced"],

Cell[TextData[{
  "InternalNodes",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "InternalNodes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InternalNodes"],

Cell[TextData[{
  "IntervalCombine",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalCombine"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IntervalCombine"],

Cell[TextData[{
  "IntervalPosition",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IntervalPosition"],

Cell[TextData[{
  "InverseFourierNormalised",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "InverseFourierNormalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InverseFourierNormalised"],

Cell[TextData[{
  "InverseFourierNormalisedTable",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "InverseFourierNormalisedTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InverseFourierNormalisedTable"],

Cell[TextData[{
  "Island model",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Island model"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Island model"],

Cell[TextData[{
  "IterateContinuum",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "IterateContinuum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateContinuum"],

Cell[TextData[{
  "IterateExact",
  ",",
  " example",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateExact"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for allele frequency clines",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "IterateExact"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequency clines",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateExact"],

Cell[TextData[{
  "Join",
  ",",
  " ",
  ButtonBox["Join",
    ButtonData:>{"Join", "Join"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "Join"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Join"],

Cell[TextData[{
  "Juveniles",
  ",",
  " \[GothicCapitalJ], \[AliasIndicator]goJ\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Juveniles"],

Cell[TextData[{
  "Kirkpatrick and Barton 1997",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick and Barton 1997"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick and Barton 1997"],

Cell[TextData[{
  "Kirkpatrick and Servedio 1998",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick and Servedio 1998"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick and Servedio 1998"],

Cell[TextData[{
  "Kirkpatrick et al.",
  ",",
  " ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick et al."},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al."],

Cell[TextData[{
  " arbitrary sets of loci",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Arbitrary sets of loci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Expectation",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Expectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " migration",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " mutation",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " permutations in defining coefficients",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Permutations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Permutations"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " phenotypes",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " position",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Contexts and positions"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "position"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " QLE",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " quasi-linkage equilibrium",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " random drift",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Random drift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference values",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Describing genotypes and populations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Reference values"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " relation with",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Multilocus MS"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " scripts and faces",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Scripts and faces"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " selection",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sets in subscripts",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets in subscripts"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sets of loci",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets of loci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stabilising selection",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", 
      "Natural selection on an additive polygenic trait"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages and contexts",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Stages and contexts"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " transmission rules",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Transmission"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Transmission rules"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al."],

Cell[TextData[{
  "Kirkpatrick et al. 1983",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Kirkpatrick et al 1983"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al. 1983"],

Cell[TextData[{
  "Kruuk 1997",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Kruuk 1997"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kruuk 1997"],

Cell[TextData[{
  "LeafLabels",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "LeafLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LeafLabels"],

Cell[TextData[{
  "LeafOffset",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "LeafOffset"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LeafOffset"],

Cell[TextData[{
  "Leaves",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "Leaves"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Leaves"],

Cell[TextData[{
  "Life cycle",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Life cycle"],

Cell[TextData[{
  " adults",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete",
  ", ",
  ButtonBox["Complete life cycle",
    ButtonData:>{"Complete life cycle", "Complete rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " hermaphrodites",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " juveniles",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages in",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with cytoplasmic inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with sex linkage",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " zygotes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Life cycle"],

Cell[TextData[{
  "Li & Nei 1974",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Li & Nei 1974"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Li & Nei 1974"],

Cell[TextData[{
  "Linkage",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Linkage",
    ButtonData:>{"Linkage", "Linkage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage"],

Cell[TextData[{
  " in numerical models",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Linkage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage"],

Cell[TextData[{
  "Linkage disequilibrium",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage disequilibrium"],

Cell[TextData[{
  "LinkedRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "LinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LinkedRecombination"],

Cell[TextData[{
  "ListToGenealogy",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "ListToGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ListToGenealogy"],

Cell[TextData[{
  "ListToMatrix",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "ListToMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ListToMatrix"],

Cell[TextData[{
  "Location",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Location"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Location"],

Cell[TextData[{
  "Locations",
  ",",
  " ",
  ButtonBox["Locations",
    ButtonData:>{"Locations", "Locations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Locations"],

Cell[TextData[{
  "LocusNames",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "LocusNames"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LocusNames"],

Cell[TextData[{
  "LogLikelihoodDisequilibrium",
  ",",
  " ",
  ButtonBox["Likelihood",
    ButtonData:>{"Likelihood", "LogLikelihoodDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodDisequilibrium"],

Cell[TextData[{
  "LogLikelihoodDisequilibriumReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "LogLikelihoodDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodDisequilibriumReduced"],

Cell[TextData[{
  "LogLikelihoodTest",
  ",",
  " ",
  ButtonBox["Likelihood tests",
    ButtonData:>{"Likelihood tests", "LogLikelihoodTest"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodTest"],

Cell[TextData[{
  "Log-linear models",
  ",",
  " ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Log-linear models"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Log-linear models"],

Cell[TextData[{
  "Long et al 1995",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Long et al 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Long et al 1995"],

Cell[TextData[{
  "LowerOffDiagonal",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "LowerOffDiagonal"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LowerOffDiagonal"],

Cell[TextData[{
  "MacCallum 1994",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "MacCallum 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MacCallum 1994"],

Cell[TextData[{
  "MacCallum et al. 1998",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "MacCallum et al 1998"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MacCallum et al. 1998"],

Cell[TextData[{
  "MakeCline",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeCline"],

Cell[TextData[{
  "  for genotype frequencies",
  ", ",
  ButtonBox["Recursions: setting up a cline",
    ButtonData:>{"Recursions: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeCline"],

Cell[TextData[{
  "MakeDiploid",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDiploid"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDiploid"],

Cell[TextData[{
  "MakeDistanceList",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "MakeDistanceList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDistanceList"],

Cell[TextData[{
  "MakeDistances",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "MakeDistances"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDistances"],

Cell[TextData[{
  "MakeFitnessSet",
  ",",
  " ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "MakeFitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeFitnessSet"],

Cell[TextData[{
  " with multiple alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeFitnessSet"],

Cell[TextData[{
  "MakeGenealogy",
  ",",
  " ",
  ButtonBox["Making a genealogy",
    ButtonData:>{"Making a genealogy", "MakeGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeGenealogy"],

Cell[TextData[{
  "MakeGenealogyPlot",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "MakeGenealogyPlot"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeGenealogyPlot"],

Cell[TextData[{
  "MakeHaploid",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeHaploid"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeHaploid"],

Cell[TextData[{
  "MakeIndividuals",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: converting",
    ButtonData:>{"Allele frequencies: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeIndividuals"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeIndividuals"],

Cell[TextData[{
  "MakeOneWayTable",
  ",",
  " ",
  ButtonBox["Single-locus tables",
    ButtonData:>{"Single-locus tables", "MakeOneWayTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeOneWayTable"],

Cell[TextData[{
  "MakePairwiseTable",
  ",",
  " ",
  ButtonBox["Pairwise tables",
    ButtonData:>{"Pairwise tables", "MakePairwiseTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePairwiseTable"],

Cell[TextData[{
  "MakePopulation",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePopulation"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "MakePopulation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: representation",
    ButtonData:>{"Symmetric model: representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePopulation"],

Cell[TextData[{
  "MakeSelectionCoefficient",
  ",",
  " ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeSelectionCoefficient"],

Cell[TextData[{
  " with multiple alleles",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with two alleles",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeSelectionCoefficient"],

Cell[TextData[{
  "Mangel & Hilborn 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Mangel & Hilborn 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mangel & Hilborn 1996"],

Cell[TextData[{
  "Marginal fitness",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Marginal fitness"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Marginal fitness"],

Cell[TextData[{
  "MarginalTable",
  ",",
  " ",
  ButtonBox["Marginal tables",
    ButtonData:>{"Marginal tables", "MarginalTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalTable"],

Cell[TextData[{
  "MarginalW",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalW"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalW"],

Cell[TextData[{
  "MaternalLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MaternalLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MaternalLoci"],

Cell[TextData[{
  "MatrixGamma",
  ",",
  " ",
  ButtonBox["Fast calculations",
    ButtonData:>{"Fast calculations", "MatrixGamma"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixGamma"],

Cell[TextData[{
  "MatrixToGenealogy",
  ",",
  " ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", "MatrixToGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixToGenealogy"],

Cell[TextData[{
  "MatrixToList",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "MatrixToList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixToList"],

Cell[TextData[{
  "MeanContribution",
  ",",
  " \[GothicM], \[AliasIndicator]gom\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "MeanContribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanContribution"],

Cell[TextData[{
  "Mean fitness",
  ",",
  " ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mean fitness"],

Cell[TextData[{
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mean fitness"],

Cell[TextData[{
  "MeanW",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanW"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanW"],

Cell[TextData[{
  "Meiosis",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Meiosis"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Meiosis"],

Cell[TextData[{
  " in numerical models",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Meiosis"],

Cell[TextData[{
  "MethodC",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MethodC"],

Cell[TextData[{
  "MethodP",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MethodP"],

Cell[TextData[{
  "Metropolis algorithm",
  ",",
  " estimating D",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Metropolis algorithm"],

Cell[TextData[{
  "MetropolisDisequilibrium",
  ",",
  " ",
  ButtonBox["Estimating moments",
    ButtonData:>{"Estimating moments", "MetropolisDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MetropolisDisequilibrium"],

Cell[TextData[{
  "MetropolisDisequilibriumReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MetropolisDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MetropolisDisequilibriumReduced"],

Cell[TextData[{
  "Metropolis et al. 1954",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Metropolis et al 1954"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Metropolis et al. 1954"],

Cell[TextData[{
  "MFromC",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MFromC"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MFromC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MFromC"],

Cell[TextData[{
  "Migrate",
  ",",
  " ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Migrate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migrate"],

Cell[TextData[{
  "MigrateExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrateExact"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrateExact"],

Cell[TextData[{
  "Migration",
  ",",
  " and cytoplasmic inheritance",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Cytonuclear associations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migration"],

Cell[TextData[{
  " and sexual selection",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Sexual selection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " context-dependent",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Context-dependent migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " example of",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotype-dependent",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Genotype-dependent migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of constant numbers",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "Constant numbers"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of haploids",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Haploid migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of juvenile diploids",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Juvenile diploid migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of pollen",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of seeds",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with sindividuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migration"],

Cell[TextData[{
  "MigrationOrder",
  ",",
  "for genotype frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationOrder"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "MigrationOrder"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationOrder"],

Cell[TextData[{
  "MigrationRate",
  ",",
  " \[CapitalMu], \[AliasIndicator]M\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationRate"],

Cell[TextData[{
  "MigrationSet",
  ",",
  " \[DoubleStruckCapitalM], \[AliasIndicator]dsM\[AliasIndicator]",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "MigrationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationSet"],

Cell[TextData[{
  "MissingCombination",
  ",",
  " ",
  ButtonBox["Validity of a mutation matrix",
    ButtonData:>{"Validity of a mutation matrix", "MissingCombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MissingCombination"],

Cell[TextData[{
  "Missing data",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Missing data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Missing data"],

Cell[TextData[{
  "Moment",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Moment"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Moments and cumulants",
    ButtonData:>{"Moments and cumulants", "Moment"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moment"],

Cell[TextData[{
  "MomentAfterMigration",
  ",",
  " ",
  ButtonBox["Migration in admixture models",
    ButtonData:>{"Migration in admixture models", "MomentAfterMigration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentAfterMigration"],

Cell[TextData[{
  "MomentAfterRecombination",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", 
      "MomentAfterRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentAfterRecombination"],

Cell[TextData[{
  "MomentEquilibrium",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "MomentEquilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentEquilibrium"],

Cell[TextData[{
  "MomentGeneratingFunction",
  ",",
  " deriving",
  ", ",
  ButtonBox["Deriving recursions for the MGF",
    ButtonData:>{"Deriving recursions for the MGF", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentGeneratingFunction"],

Cell[TextData[{
  " examples",
  ", ",
  ButtonBox["Examples of the MGF",
    ButtonData:>{"Examples of the MGF", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genealogies",
  ", ",
  ButtonBox["Calculating the MGF",
    ButtonData:>{"Calculating the MGF", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over topologies",
  ", ",
  ButtonBox["Calculating over topologies",
    ButtonData:>{"Calculating over topologies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentGeneratingFunction"],

Cell[TextData[{
  "MomentLimits",
  ",",
  " ",
  ButtonBox["Constraints on moments",
    ButtonData:>{"Constraints on moments", "MomentLimits"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentLimits"],

Cell[TextData[{
  "MomentNew",
  ",",
  " ",
  ButtonBox["Iteration",
    ButtonData:>{"Iteration", "MomentNew"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentNew"],

Cell[TextData[{
  "MomentReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MomentReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentReduced"],

Cell[TextData[{
  "Moments",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "7.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moments"],

Cell[TextData[{
  " estimating the matrix of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "Estimating the matrix"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " extension to description by",
  ", ",
  ButtonBox["References",
    ButtonData:>{"References", "Haber 1984"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " extension to estimation of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "MLE"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " full description by",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " matrix of",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] full matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "ML estimation of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "simple method"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reduced description by",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " simple method for estimating",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "extension to families"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moments"],

Cell[TextData[{
  "MomentsFromG",
  ",",
  " ",
  ButtonBox["Moments from genotype frequencies",
    ButtonData:>{"Moments from genotype frequencies", "MomentsFromG"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentsFromG"],

Cell[TextData[{
  "MomentSimple",
  ",",
  " ",
  ButtonBox["Simplifying the moments",
    ButtonData:>{"Simplifying the moments", "MomentSimple"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentSimple"],

Cell[TextData[{
  "MonteCarloGriffithsTavare",
  ",",
  " ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "MonteCarloGriffithsTavare"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MonteCarloGriffithsTavare"],

Cell[TextData[{
  "MonteCarloProbability",
  ",",
  " ",
  ButtonBox["Estimating the probability",
    ButtonData:>{"Estimating the probability", "MonteCarloProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MonteCarloProbability"],

Cell[TextData[{
  "Mortality",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Mortality"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mortality"],

Cell[TextData[{
  "MostRecentCommonAncestor",
  ",",
  " ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "MostRecentCommonAncestor"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MostRecentCommonAncestor"],

Cell[TextData[{
  "MToC",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MToC"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MToC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MToC"],

Cell[TextData[{
  "MToCEquations",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MToCEquations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MToCEquations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MToCEquations"],

Cell[TextData[{
  "Muddle",
  ",",
  " ",
  ButtonBox["Muddling and subdividing sets",
    ButtonData:>{"Muddling and subdividing sets", "Muddle"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Muddle"],

Cell[TextData[{
  "Multilocus algebra",
  ",",
  " basic notation",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Basic notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus algebra"],

Cell[TextData[{
  " fitness",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction to",
  ", ",
  ButtonBox["Introduction to multilocus algebra",
    ButtonData:>{"Introduction to multilocus algebra", "1.1"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Introduction to multilocus algebra",
    ButtonData:>{"Introduction to multilocus algebra", 
      "Multilocus`Multilocus`"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages in life cycle",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Technicalities"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus algebra"],

Cell[TextData[{
  "Multilocus MS",
  ",",
  " relation with",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Multilocus MS"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus MS"],

Cell[TextData[{
  "Multilocus notation",
  ",",
  " bugs",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Multilocus notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus notation"],

Cell[TextData[{
  "Multinomial sampling",
  ",",
  " without replacement",
  ", ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", 
      "Multinomial sampling wo replacement"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multinomial sampling"],

Cell[TextData[{
  "MultinomialSamplingProbability",
  ",",
  " ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", 
      "MultinomialSamplingProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MultinomialSamplingProbability"],

Cell[TextData[{
  "Multiple alleles",
  ",",
  " and selection coefficients",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple alleles"],

Cell[TextData[{
  " MakeFitnessSet",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " mutation",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " representation of",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " selection on",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple alleles"],

Cell[TextData[{
  "Multiple arguments",
  ",",
  " in PopulationExpectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "multiple arguments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple arguments"],

Cell[TextData[{
  "Multiplicative models",
  ",",
  " in negative binomial",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "multiplicative models"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiplicative models"],

Cell[TextData[{
  "MUS",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MUS"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MUS"],

Cell[TextData[{
  "Mutate",
  ",",
  " allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: mutation",
    ButtonData:>{"Allele frequencies: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutate"],

Cell[TextData[{
  "genotype frequencies",
  ", ",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " individuals",
  ", ",
  ButtonBox["Simulating individuals: mutation",
    ButtonData:>{"Simulating individuals: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric model",
  ", ",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutate"],

Cell[TextData[{
  "MutateCompiled",
  ",",
  " ",
  ButtonBox["Allele frequencies: mutation",
    ButtonData:>{"Allele frequencies: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: mutation",
    ButtonData:>{"Simulating individuals: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutateCompiled"],

Cell[TextData[{
  "Mutation",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Mutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutation"],

Cell[TextData[{
  " Mutations, in multilocus genetics",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for BiallelicMutation",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies: reproduction",
    ButtonData:>{"Allele frequencies: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: reproduction",
    ButtonData:>{"Recursions: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutation"],

Cell[TextData[{
  "MutationInterval",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "MutationInterval"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationInterval"],

Cell[TextData[{
  "MutationLabels",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "MutationLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationLabels"],

Cell[TextData[{
  "MutationOrigin",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "MutationOrigin"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationOrigin"],

Cell[TextData[{
  "MutationRate",
  ",",
  " ",
  ButtonBox["Drawing a genealogy",
    ButtonData:>{"Drawing a genealogy", "MutationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationRate"],

Cell[TextData[{
  "Mutations",
  ",",
  " adding to a genealogy",
  ", ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddMutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutations"],

Cell[TextData[{
  " consistency with a genealogy",
  ", ",
  ButtonBox["Validity of a mutation matrix",
    ButtonData:>{"Validity of a mutation matrix", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " inferring genealogies from",
  ", ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "infinite site",
  ", ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "Mutations"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in genealogies",
  ", ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "Mutations"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutations"],

Cell[TextData[{
  "MVariables",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MVariables"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MVariables"],

Cell[TextData[{
  "Negative binomial",
  ",",
  " c<1",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "c<1"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Negative binomial"],

Cell[TextData[{
  " compiled",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " multiplicative models",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "multiplicative models"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " normalisation",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalisation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " timings",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Timings"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Negative binomial"],

Cell[TextData[{
  "NegativeBinomialLogLikelihood",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", 
      "NegativeBinomialLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeBinomialLogLikelihood"],

Cell[TextData[{
  "NegativeBinomialMLE",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "NegativeBinomialMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeBinomialMLE"],

Cell[TextData[{
  "NegativeHypergeometricDistribution",
  ",",
  " ",
  ButtonBox["Negative hypergeometric distribution",
    ButtonData:>{"Negative hypergeometric distribution", 
      "NegativeHypergeometricDistribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeHypergeometricDistribution"],

Cell[TextData[{
  "NeighbourArray",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "NeighbourArray"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NeighbourArray"],

Cell[TextData[{
  "Neighbours",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Neighbours"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Neighbours"],

Cell[TextData[{
  "NetCovariance",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "NetCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetCovariance"],

Cell[TextData[{
  "NetFecundity",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NetFecundity"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetFecundity"],

Cell[TextData[{
  "NetMortality",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NetMortality"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetMortality"],

Cell[TextData[{
  "NetRecombination",
  ",",
  " ",
  ButtonBox["Linkage",
    ButtonData:>{"Linkage", "NetRecombination"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Linkage in families",
    ButtonData:>{"Linkage in families", "NetRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetRecombination"],

Cell[TextData[{
  " in multilocus genetics",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "NetRecombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "NetRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetRecombination"],

Cell[TextData[{
  "Neutral marker",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Neutral marker"],

Cell[TextData[{
  "NeutralRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "NeutralRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NeutralRepresentations"],

Cell[TextData[{
  "NewGametes",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewGametes"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Mutation option",
  ", ",
  ButtonBox["Allele frequencies: reproduction",
    ButtonData:>{"Allele frequencies: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: reproduction",
    ButtonData:>{"Recursions: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " truncation selection",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", 
      "TruncationSelection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewGametes"],

Cell[TextData[{
  "NewS",
  ",",
  " ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "NewS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewS"],

Cell[TextData[{
  "Node",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "Node"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "Node"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Node"],

Cell[TextData[{
  "NodeFunction",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "NodeFunction"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeFunction"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeFunction"],

Cell[TextData[{
  " option for ExactProbability",
  ", ",
  ButtonBox["Exact probability",
    ButtonData:>{"Exact probability", "NodeFunction"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeFunction"],

Cell[TextData[{
  "NodeLabels",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeLabels"],

Cell[TextData[{
  "NodeOffset",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeOffset"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeOffset"],

Cell[TextData[{
  "Nodes",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "Nodes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Nodes"],

Cell[TextData[{
  "NonMendelian",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonMendelian"],

Cell[TextData[{
  " examples of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonMendelian"],

Cell[TextData[{
  "NonNeutralRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "NonNeutralRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonNeutralRepresentations"],

Cell[TextData[{
  "NonSymmetricRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "NonSymmetricRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonSymmetricRepresentations"],

Cell[TextData[{
  "Normalisation",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalisation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Normalisation"],

Cell[TextData[{
  "Normalised",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Normalised"],

Cell[TextData[{
  "Notation",
  ",",
  " clearing definitions",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "Clearing definitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation"],

Cell[TextData[{
  " data",
  ", ",
  ButtonBox["Notation for genetic data",
    ButtonData:>{"Notation for genetic data", "NotationPackage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining new",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "Defining new notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotypes",
  ", ",
  ButtonBox["Notation",
    ButtonData:>{"Notation", "NotationPackage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation"],

Cell[TextData[{
  "Notation Package",
  ",",
  " ",
  ButtonBox["Notation package",
    ButtonData:>{"Notation package", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation Package"],

Cell[TextData[{
  "NumberedLink",
  ",",
  " ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "NumberedLink"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberedLink"],

Cell[TextData[{
  "Numbering",
  ",",
  " aesthetics",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Aesthetics"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numbering"],

Cell[TextData[{
  " automatic",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "7.2"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notes on",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Notes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving links",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Saving the links"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numbering"],

Cell[TextData[{
  "NumberOfCoalescences",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "NumberOfCoalescences"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfCoalescences"],

Cell[TextData[{
  "NumberOfGenes",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenes"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenes"],

Cell[TextData[{
  "NumberOfGenesTable",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfGenesTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenesTable"],

Cell[TextData[{
  "NumberOfIndividuals",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfIndividuals"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NumberOfIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfIndividuals"],

Cell[TextData[{
  "NumberOfIndividualsTable",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfIndividualsTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfIndividualsTable"],

Cell[TextData[{
  "NumberOfLineages",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "NumberOfLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfLineages"],

Cell[TextData[{
  "NumberOfLoci",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfLoci"],

Cell[TextData[{
  "NumberOfMutations",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "NumberOfMutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfMutations"],

Cell[TextData[{
  "NumberOfPossibleCoalescences",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "NumberOfPossibleCoalescences"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfPossibleCoalescences"],

Cell[TextData[{
  "NumberOfSamplePartitions",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "NumberOfSamplePartitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfSamplePartitions"],

Cell[TextData[{
  "NumberOfSetPartitions",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "NumberOfSetPartitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfSetPartitions"],

Cell[TextData[{
  "NumericalModel",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "NumericalModel"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumericalModel"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "NumericalModel"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumericalModel"],

Cell[TextData[{
  "Numerical models",
  ",",
  " genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numerical models"],

Cell[TextData[{
  " of allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " overview",
  ", ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " problems",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " problems with migration",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "Constant numbers"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric",
  ", ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numerical models"],

Cell[TextData[{
  "Observable genotype",
  ",",
  " ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Observable genotype"],

Cell[TextData[{
  "Obsolete",
  ",",
  " Combine",
  ", ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Separate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Obsolete"],

Cell[TextData[{
  " CumulantReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "CumulantReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidConstraints",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidConstraints"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidGenotypeFrequencyReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidGenotypeFrequencyTable",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Estimating D",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " fitness",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Obsolete notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " FullGenotypeFrequencyReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " FullGenotypeFrequencyTable",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " GenotypeFrequencyArguments",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "GenotypeFrequencyArguments"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " HaploidConstraints",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "HaploidConstraints"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " InitialStepReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "InitialStepReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " IntervalCombine",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalCombine"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " IntervalPosition",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalPosition"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " LogLikelihoodDisequilibriumReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "LogLikelihoodDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MetropolisDisequilibriumReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MetropolisDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MomentReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MomentReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Obsolete"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Separate",
  ", ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Combine"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " SetPartition",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SetPartition"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Obsolete"],

Cell[TextData[{
  "Offspring",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Offspring"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Offspring"],

Cell[TextData[{
  "Ordered",
  ",",
  "option for PartitionSet",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "Ordered"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ordered"],

Cell[TextData[{
  "Orive & Barton 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Orive & Barton 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Orive & Barton 1999"],

Cell[TextData[{
  "OtherSex",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "OtherSex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"OtherSex"],

Cell[TextData[{
  "Packages",
  ",",
  " help",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Packages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Packages"],

Cell[TextData[{
  " overview of",
  ", ",
  ButtonBox["Overview of the packages",
    ButtonData:>{"Overview of the packages", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving using PackageSaver",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " setting up",
  ", ",
  ButtonBox["Setting up the packages",
    ButtonData:>{"Setting up the packages", "Setting up the packages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Special notation",
    ButtonData:>{"Special notation", "Setting up packages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " versions of",
  ", ",
  ButtonBox["Versions",
    ButtonData:>{"Versions", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Packages"],

Cell[TextData[{
  "PackageSaver",
  ",",
  " ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PackageSaver"],

Cell[TextData[{
  "Partitions",
  ",",
  " of sets",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "PartitionSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Partitions"],

Cell[TextData[{
  " standard form",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartition"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " testing for standard form",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartitionQ"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Partitions"],

Cell[TextData[{
  "PartitionSet",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "PartitionSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PartitionSet"],

Cell[TextData[{
  "Paternal inheritance",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Paternal inheritance"],

Cell[TextData[{
  "PaternalLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaternalLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaternalLoci"],

Cell[TextData[{
  "PatternFree",
  ",",
  " ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "PatternFree"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PatternFree"],

Cell[TextData[{
  "Permutations",
  ",",
  "option for PartitionSet",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "Permutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Permutations"],

Cell[TextData[{
  "Permutations in defining coefficients",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Permutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Permutations in defining coefficients"],

Cell[TextData[{
  "Phenotypes",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Phenotypes"],

Cell[TextData[{
  "Phipps & Brill 1995",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Phipps & Brill 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Phipps & Brill 1995"],

Cell[TextData[{
  "Ploidy",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "Ploidy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ploidy"],

Cell[TextData[{
  "PloidyWeightList",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "PloidyWeightList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PloidyWeightList"],

Cell[TextData[{
  "PlotGenealogy",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "PlotGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PlotGenealogy"],

Cell[TextData[{
  "PlotLogL",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "PlotLogL"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PlotLogL"],

Cell[TextData[{
  "PopulationDisequilibrium",
  ",",
  "\[GothicCapitalC], \[AliasIndicator]goC\[AliasIndicator]",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationDisequilibrium"],

Cell[TextData[{
  "PopulationExpectation",
  ",",
  " ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationExpectation"],

Cell[TextData[{
  " multiple arguments",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "multiple arguments"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationExpectation"],

Cell[TextData[{
  "PopulationRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "PopulationRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationRepresentations"],

Cell[TextData[{
  "Position",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "position"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "position"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Position"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "position"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Contexts and positions"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Position"],

Cell[TextData[{
  "PositionsList",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PositionsList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PositionsList"],

Cell[TextData[{
  "PositionsMatrix",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PositionsMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PositionsMatrix"],

Cell[TextData[{
  "PossibleCoalescenceOrder",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "PossibleCoalescenceOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleCoalescenceOrder"],

Cell[TextData[{
  "PossibleDiploidGenotypes",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PossibleDiploidGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleDiploidGenotypes"],

Cell[TextData[{
  "PossibleGenotypes",
  ",",
  " ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "PossibleGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleGenotypes"],

Cell[TextData[{
  "PossibleRootings",
  ",",
  " ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", "PossibleRootings"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleRootings"],

Cell[TextData[{
  "PowerF",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PowerF"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "PowerF"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PowerF"],

Cell[TextData[{
  "PresentOneWayTable",
  ",",
  " ",
  ButtonBox["Single-locus tables",
    ButtonData:>{"Single-locus tables", "PresentOneWayTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentOneWayTable"],

Cell[TextData[{
  "PresentPairwiseTable",
  ",",
  " ",
  ButtonBox["Pairwise tables",
    ButtonData:>{"Pairwise tables", "PresentPairwiseTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentPairwiseTable"],

Cell[TextData[{
  "PresentResults",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "PresentResults"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentResults"],

Cell[TextData[{
  "Principal components",
  ",",
  " Bennett's measure of disequilibrium",
  ", ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Bennett"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Principal components"],

Cell[TextData[{
  "PrintDetails",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "PrintDetails"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PrintDetails"],

Cell[TextData[{
  "Problems",
  ",",
  " avoid integers",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Avoid integers"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Problems"],

Cell[TextData[{
  " redefining fitness",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Allele frequencies"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Redefining fitness"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "StoreResults (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Problems"],

Cell[TextData[{
  "Products",
  ",",
  " multiple",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Multiple products"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Products"],

Cell[TextData[{
  "ProductSum",
  ",",
  " ",
  ButtonBox["ProductSum",
    ButtonData:>{"ProductSum", "ProductSum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ProductSum"],

Cell[TextData[{
  " over sets",
  ", ",
  ButtonBox["ProductSum",
    ButtonData:>{"ProductSum", "ProductSum over sets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ProductSum"],

Cell[TextData[{
  "QLE",
  ",",
  " haploid selection example",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", "QLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"QLE"],

Cell[TextData[{
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"QLE"],

Cell[TextData[{
  "Quasi-linkage equilibrium",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Quasi-linkage equilibrium"],

Cell[TextData[{
  "RandomBottleneckedGenealogy",
  ",",
  " ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", "RandomBottleneckedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomBottleneckedGenealogy"],

Cell[TextData[{
  "RandomCoalescenceOrder",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "RandomCoalescenceOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCoalescenceOrder"],

Cell[TextData[{
  "RandomCoalescenceTimes",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", 
      "RandomCoalescenceTimes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCoalescenceTimes"],

Cell[TextData[{
  "RandomCum",
  ",",
  " ",
  ButtonBox["Sampling from arbitrary distributions",
    ButtonData:>{"Sampling from arbitrary distributions", "RandomCum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCum"],

Cell[TextData[{
  "Random drift",
  ",",
  " changing reference points",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Changing reference points"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random drift"],

Cell[TextData[{
  " cumulants and moments",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " describing a distribution",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Describing a distribution"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " equations for the moments",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Equations for the moments"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in a cline",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: drift",
    ButtonData:>{"Allele frequencies: drift", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of genotype frequencies",
  ", ",
  ButtonBox["Recursions: drift",
    ButtonData:>{"Recursions: drift", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population disequilibrium",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population expectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population expectations",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Wright-Fisher sampling",
  ", ",
  ButtonBox["Wright-Fisher sampling",
    ButtonData:>{"Wright-Fisher sampling", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random drift"],

Cell[TextData[{
  "RandomDrift",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: drift",
    ButtonData:>{"Recursions: drift", "RandomDrift"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomDrift"],

Cell[TextData[{
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "RandomDrift"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomDrift"],

Cell[TextData[{
  "RandomFamilies",
  ",",
  " ",
  ButtonBox["Random families",
    ButtonData:>{"Random families", "RandomFamilies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamilies"],

Cell[TextData[{
  "RandomFamily",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "RandomFamily"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamily"],

Cell[TextData[{
  " segregation ratio",
  ", ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamily"],

Cell[TextData[{
  "Random genealogies",
  ",",
  " population bottlenecks",
  ", ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random genealogies"],

Cell[TextData[{
  "RandomGenealogy",
  ",",
  " ",
  ButtonBox["Drawing a genealogy",
    ButtonData:>{"Drawing a genealogy", "RandomGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomGenealogy"],

Cell[TextData[{
  "RandomList",
  ",",
  " ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "RandomList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomList"],

Cell[TextData[{
  " sampling without replacement",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomList"],

Cell[TextData[{
  "Random lists",
  ",",
  " compiled",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random lists"],

Cell[TextData[{
  "RandomMating",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "RandomMating"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomMating"],

Cell[TextData[{
  "RandomMultinomial",
  ",",
  " ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", "RandomMultinomial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomMultinomial"],

Cell[TextData[{
  "RandomPreviousFamily",
  ",",
  " ",
  ButtonBox["Random families",
    ButtonData:>{"Random families", "RandomPreviousFamily"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomPreviousFamily"],

Cell[TextData[{
  "Random sampling",
  ",",
  " ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Random sampling"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random sampling"],

Cell[TextData[{
  " example in estimating D",
  ", ",
  ButtonBox["Sampling example",
    ButtonData:>{"Sampling example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of genealogies",
  ", ",
  ButtonBox["Sampling genealogies",
    ButtonData:>{"Sampling genealogies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random sampling"],

Cell[TextData[{
  "RandomSet",
  ",",
  " ",
  ButtonBox["Random sets",
    ButtonData:>{"Random sets", "RandomSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomSet"],

Cell[TextData[{
  "Random union",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Random union"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random union"],

Cell[TextData[{
  " in admixture models",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "RandomUnionObsolete"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random union"],

Cell[TextData[{
  "RandomUnion",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnion"],

Cell[TextData[{
  "RandomUnionMethod",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnionMethod"],

Cell[TextData[{
  "RandomUnionObsolete",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnionObsolete"],

Cell[TextData[{
  "Random walk",
  ",",
  " in estimating D",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random walk"],

Cell[TextData[{
  "Recombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Recombination"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Recombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombination"],

Cell[TextData[{
  " across several linked loci",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "NetRecombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " between linked loci",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "LinkedRecombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " context-dependent",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Context-dependent recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotype-dependent",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Genotype-dependent recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in admixture models",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "Recombined"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " no linkage",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "UnlinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombination"],

Cell[TextData[{
  "RecombinationRate",
  ",",
  " \[GothicR], \[AliasIndicator]gor\[AliasIndicator]",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinationRate"],

Cell[TextData[{
  "RecombinationSet",
  ",",
  " \[DoubleStruckCapitalR], \[AliasIndicator]dsR\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinationSet"],

Cell[TextData[{
  "Recombined",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "Recombined"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombined"],

Cell[TextData[{
  "ReducedData",
  ",",
  " ",
  ButtonBox["Simplifying a dataset",
    ButtonData:>{"Simplifying a dataset", "ReducedData"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReducedData"],

Cell[TextData[{
  "ReferencePoint",
  ",",
  " \[WeierstrassP], \[AliasIndicator]wp\[AliasIndicator]",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePoint"],

Cell[TextData[{
  "ReferencePointMean",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointMean"],

Cell[TextData[{
  " cytoplasmic inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " paternal inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sex-linkage",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointMean"],

Cell[TextData[{
  "ReferencePointSame",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointSame"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointSame"],

Cell[TextData[{
  "ReferencePointZero",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointZero"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointZero"],

Cell[TextData[{
  "Reference values",
  ",",
  " ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Reference values"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reference values"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Reference values"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Describing genotypes and populations"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reference values"],

Cell[TextData[{
  "RemoveTag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "RemoveTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RemoveTag"],

Cell[TextData[{
  "Repeat",
  ",",
  " ",
  ButtonBox["Repeated elements",
    ButtonData:>{"Repeated elements", "Repeat"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Repeat"],

Cell[TextData[{
  "Replace",
  ",",
  " ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Replace"],

Cell[TextData[{
  "ReplaceAllSpecial",
  ",",
  " |.",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReplaceAllSpecial"],

Cell[TextData[{
  "ReplaceRepeatedSpecial",
  ",",
  " ||.",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceRepeatedSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReplaceRepeatedSpecial"],

Cell[TextData[{
  "Representations",
  ",",
  " converting between",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Representations"],

Cell[TextData[{
  "of populations",
  ", ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "Representing the population"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Representations"],

Cell[TextData[{
  "Reproduction",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reproduction"],

Cell[TextData[{
  "Reverse",
  ",",
  " ",
  ButtonBox["Sorting",
    ButtonData:>{"Sorting", "Reverse"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reverse"],

Cell[TextData[{
  "Root",
  ",",
  " of a genealogy",
  ", ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "RootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Root"],

Cell[TextData[{
  "RootedGenealogy",
  ",",
  " ",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "RootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RootedGenealogy"],

Cell[TextData[{
  "Rootings",
  ",",
  " of a genealogy, possible",
  ", ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", "PossibleRootings"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Rootings"],

Cell[TextData[{
  "Rules",
  ",",
  " ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Rules"],

Cell[TextData[{
  " non-evaluation of",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Rules"],

Cell[TextData[{
  "SampleCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "SampleCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SampleCovariance"],

Cell[TextData[{
  "SampleIndividuals",
  ",",
  " ",
  ButtonBox["Sampling individuals",
    ButtonData:>{"Sampling individuals", "SampleIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SampleIndividuals"],

Cell[TextData[{
  "SamplePartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SamplePartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SamplePartition"],

Cell[TextData[{
  "Sampling",
  ",",
  " without replacement",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sampling"],

Cell[TextData[{
  "Scripts and faces",
  ",",
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Scripts and faces"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Scripts and faces"],

Cell[TextData[{
  "SegregationRatio",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SegregationRatio"],

Cell[TextData[{
  "SelectContext",
  ",",
  " \[CircleDot], \[AliasIndicator]c.\[AliasIndicator]",
  ", ",
  ButtonBox["Selecting contexts",
    ButtonData:>{"Selecting contexts", "SelectContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectContext"],

Cell[TextData[{
  "SelectIndividuals",
  ",",
  " ",
  ButtonBox["Selecting subsets",
    ButtonData:>{"Selecting subsets", "SelectIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectIndividuals"],

Cell[TextData[{
  "Selection",
  ",",
  " ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Selection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection"],

Cell[TextData[{
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on genotype frequencies",
  ", ",
  ButtonBox["Recursions: fitnesses",
    ButtonData:>{"Recursions: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on multiple alleles",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Technicalities"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " truncation",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "TruncationSelection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with two alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection"],

Cell[TextData[{
  "SelectionCoefficient",
  ",",
  " \[GothicA], \[AliasIndicator]goa\[AliasIndicator]",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionCoefficient"],

Cell[TextData[{
  "Selection coefficients",
  ",",
  " as defined in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Permutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection coefficients"],

Cell[TextData[{
  " making",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with multiple alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection coefficients"],

Cell[TextData[{
  "SelectionExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionExact"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: fitnesses",
    ButtonData:>{"Recursions: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionExact"],

Cell[TextData[{
  "Selection on diploids",
  ",",
  " a method to avoid",
  ", ",
  ButtonBox["A method to avoid",
    ButtonData:>{"A method to avoid", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection on diploids"],

Cell[TextData[{
  " cautionary notes",
  ", ",
  ButtonBox["Cautionary notes",
    ButtonData:>{"Cautionary notes", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete life cycle",
  ", ",
  ButtonBox["Complete life cyle",
    ButtonData:>{"Complete life cyle", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " explaining the rules",
  ", ",
  ButtonBox["Explaining the rules",
    ButtonData:>{"Explaining the rules", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction",
  ", ",
  ButtonBox["Introduction to selection on diploids",
    ButtonData:>{"Introduction to selection on diploids", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " life cycle",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection on diploids"],

Cell[TextData[{
  "SelectionRate",
  ",",
  " \[GothicS],\[AliasIndicator]gos\[AliasIndicator]",
  ", ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SelectionRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionRate"],

Cell[TextData[{
  "SelectLoci",
  ",",
  " ",
  ButtonBox["Selecting subsets",
    ButtonData:>{"Selecting subsets", "SelectLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectLoci"],

Cell[TextData[{
  "Selfing",
  ",",
  " ",
  ButtonBox["Selfing",
    ButtonData:>{"Selfing", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selfing"],

Cell[TextData[{
  "Separate",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Separate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Separate"],

Cell[TextData[{
  "Servedio",
  ",",
  " Maria",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", "Servedio"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Servedio"],

Cell[TextData[{
  "Set",
  ",",
  " of all positions affecting a trait, \[DoubleStruckCapitalZ], \
\[AliasIndicator]dsZ\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set"],

Cell[TextData[{
  " of all positions in genome, \[DoubleStruckCapitalG], \[AliasIndicator]dsG\
\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set"],

Cell[TextData[{
  "Set manipulation",
  ",",
  " overview",
  ", ",
  ButtonBox["Overview of set manipulation",
    ButtonData:>{"Overview of set manipulation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set manipulation"],

Cell[TextData[{
  "SetOfCombinations",
  ",",
  " ",
  ButtonBox["Set combinations",
    ButtonData:>{"Set combinations", "SetOfCombinations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SetOfCombinations"],

Cell[TextData[{
  "SetPartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SetPartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SetPartition"],

Cell[TextData[{
  "Sets of loci",
  ",",
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets of loci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sets of loci"],

Cell[TextData[{
  "Sex",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Sex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex"],

Cell[TextData[{
  "Sex linkage",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex linkage"],

Cell[TextData[{
  " examples of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex linkage"],

Cell[TextData[{
  "SexOfOrigin",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "SexOfOrigin"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SexOfOrigin"],

Cell[TextData[{
  "Sexual selection",
  ",",
  " ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Sexual selection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sexual selection"],

Cell[TextData[{
  " and migration",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Sexual selection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete life cycle",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Complete cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining fitnesses",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Sexual selection by female choice"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "on haploids",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " recombination",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " subtle problem",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "subtle problem"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sexual selection"],

Cell[TextData[{
  "ShortContext",
  ",",
  " ",
  ButtonBox["Abbreviating contexts",
    ButtonData:>{"Abbreviating contexts", "ShortContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ShortContext"],

Cell[TextData[{
  "SigmaMatrix",
  ",",
  " ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "SigmaMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SigmaMatrix"],

Cell[TextData[{
  "SignMask",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "SignMask"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SignMask"],

Cell[TextData[{
  "SimplifyAddUp",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "SimplifyAddUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyAddUp"],

Cell[TextData[{
  "SimplifyAddUpQ",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "SimplifyAddUpQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyAddUpQ"],

Cell[TextData[{
  "SimplifyFamilies",
  ",",
  " ",
  ButtonBox["Probabilities",
    ButtonData:>{"Probabilities", "SimplifyFamilies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyFamilies"],

Cell[TextData[{
  "Simulating individuals",
  ",",
  " recursions",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Simulating individuals"],

Cell[TextData[{
  " representation",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reproduction",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Simulating individuals"],

Cell[TextData[{
  "SizeOfGenealogyPlot",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "SizeOfGenealogyPlot"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SizeOfGenealogyPlot"],

Cell[TextData[{
  "Slatkin & Excoffier 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Slatkin & Excoffier 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Slatkin & Excoffier 1996"],

Cell[TextData[{
  "SlowChange",
  ",",
  " ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SlowChange"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SlowChange"],

Cell[TextData[{
  "SortByClass",
  ",",
  " ",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "SortByClass"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByClass"],

Cell[TextData[{
  " genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "SortByClass"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByClass"],

Cell[TextData[{
  "SortByHead",
  ",",
  " ",
  ButtonBox["Sorting",
    ButtonData:>{"Sorting", "SortByHead"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByHead"],

Cell[TextData[{
  "SpatialCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "SpatialCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SpatialCovariance"],

Cell[TextData[{
  "Spatially varying selection",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Spatially varying selection",
    ButtonData:>{"Spatially varying selection", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Spatially varying selection"],

Cell[TextData[{
  "Special notation",
  ",",
  " ",
  ButtonBox["Special notation",
    ButtonData:>{"Special notation", "Defining notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Special notation"],

Cell[TextData[{
  "SplitSet",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SplitSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SplitSet"],

Cell[TextData[{
  "Stabilising selection",
  ",",
  " change in D",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Change in D"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stabilising selection"],

Cell[TextData[{
  " change in mean",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Change in mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Defining fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", 
      "Natural selection on an additive polygenic trait"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "mean fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Mean fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "New mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "New mean fitness"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stabilising selection"],

Cell[TextData[{
  "Stability",
  ",",
  " of numerical models",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stability"],

Cell[TextData[{
  " of symmetric model",
  ", ",
  ButtonBox["Symmetric stability: outline",
    ButtonData:>{"Symmetric stability: outline", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stability"],

Cell[TextData[{
  "StabilityDirect",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", "StabilityDirect"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityDirect"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", "StabilityDirect"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityDirect"],

Cell[TextData[{
  "StabilityK",
  ",",
  " ",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", "StabilityK"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "StabilityK"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityK"],

Cell[TextData[{
  "StabilityKTable",
  ",",
  " ",
  ButtonBox["Symmetric stability: faster algorithms",
    ButtonData:>{"Symmetric stability: faster algorithms", "StabilityKTable"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityKTable"],

Cell[TextData[{
  "StabilityMatrix",
  ",",
  " ",
  ButtonBox["Making a stability matrix",
    ButtonData:>{"Making a stability matrix", "StabilityMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityMatrix"],

Cell[TextData[{
  "Stage",
  ",",
  " \[Sampi], \[AliasIndicator]sa\[AliasIndicator]",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stage"],

Cell[TextData[{
  "Stages",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stages"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Stages and contexts"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stages"],

Cell[TextData[{
  "StandardPartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StandardPartition"],

Cell[TextData[{
  "StandardPartitionQ",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartitionQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StandardPartitionQ"],

Cell[TextData[{
  "StartingStepSize",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "StartingStepSize"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StartingStepSize"],

Cell[TextData[{
  "Stepping-stone migration",
  ",",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", 
      "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone migration"],

Cell[TextData[{
  "Stepping-stone model",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", 
      "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone model"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "Nearest-neighbour migration"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone model"],

Cell[TextData[{
  "StoreExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreExact"],

Cell[TextData[{
  " for allele frequency clines",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequency clines",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreExact"],

Cell[TextData[{
  "StoreResults",
  ",",
  " option for GameteTable",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreResults"],

Cell[TextData[{
  " option for NewGametes",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " use when compiling",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "StoreResults (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreResults"],

Cell[TextData[{
  "StructuredArray",
  ",",
  " ",
  ButtonBox["Useful functions",
    ButtonData:>{"Useful functions", "StructuredArray"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredArray"],

Cell[TextData[{
  "StructuredInitialParameters",
  ",",
  " ",
  ButtonBox["Initial parameters",
    ButtonData:>{"Initial parameters", "StructuredInitialParameters"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredInitialParameters"],

Cell[TextData[{
  "StructuredLogLikelihood",
  ",",
  " ",
  ButtonBox["Likelihood of a structured model",
    ButtonData:>{"Likelihood of a structured model", 
      "StructuredLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredLogLikelihood"],

Cell[TextData[{
  "StructuredMLE",
  ",",
  " ",
  ButtonBox["Likelihood of a structured model",
    ButtonData:>{"Likelihood of a structured model", "StructuredMLE"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "StructuredMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredMLE"],

Cell[TextData[{
  "StructuredModel",
  ",",
  " ",
  ButtonBox["Useful functions",
    ButtonData:>{"Useful functions", "StructuredModel"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredModel"],

Cell[TextData[{
  "StructuredModelReduce",
  ",",
  " ",
  ButtonBox["Simplifying a model",
    ButtonData:>{"Simplifying a model", "StructuredModelReduce"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredModelReduce"],

Cell[TextData[{
  "Structured models",
  ",",
  " example",
  ", ",
  ButtonBox["Example data",
    ButtonData:>{"Example data", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Structured models"],

Cell[TextData[{
  " hierarchical analysis",
  ", ",
  ButtonBox["Hierarchical analysis",
    ButtonData:>{"Hierarchical analysis", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Structured models"],

Cell[TextData[{
  "StructuredParameter",
  ",",
  " ",
  ButtonBox["Structured parameters",
    ButtonData:>{"Structured parameters", "StructuredParameter"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredParameter"],

Cell[TextData[{
  "StructuredVariance",
  ",",
  " ",
  ButtonBox["Variance components for a structured model",
    ButtonData:>{"Variance components for a structured model", 
      "StructuredVariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredVariance"],

Cell[TextData[{
  "Style sheets",
  ",",
  " bugs with",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Style sheets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Style sheets"],

Cell[TextData[{
  "Subdivide",
  ",",
  " ",
  ButtonBox["Muddling and subdividing sets",
    ButtonData:>{"Muddling and subdividing sets", "Subdivide"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subdivide"],

Cell[TextData[{
  "Subscripts",
  ",",
  " as written in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets in subscripts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subscripts"],

Cell[TextData[{
  "Subsets",
  ",",
  " ",
  ButtonBox["Subsets",
    ButtonData:>{"Subsets", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subsets"],

Cell[TextData[{
  " option for AddUp",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Subsets"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for TimesUp",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subsets"],

Cell[TextData[{
  "Sums",
  ",",
  " multiple",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Multiple sums"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sums"],

Cell[TextData[{
  "SwapStates",
  ",",
  " ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", "SwapStates"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SwapStates"],

Cell[TextData[{
  "Symmetric cline",
  ",",
  " in allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a symmetric cline",
    ButtonData:>{"Allele frequencies: setting up a symmetric cline", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric cline"],

Cell[TextData[{
  " in genotype frequencies",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric cline"],

Cell[TextData[{
  "SymmetricDiploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricDiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricDiploidFrequencies"],

Cell[TextData[{
  "SymmetricHaploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricHaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricHaploidFrequencies"],

Cell[TextData[{
  "Symmetric model",
  ",",
  " adding a neutral marker",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: limitations",
    ButtonData:>{"Symmetric model: limitations", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric model"],

Cell[TextData[{
  " cline example",
  ", ",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: spatially varying selection",
    ButtonData:>{"Symmetric stability: spatially varying selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " limitations",
  ", ",
  ButtonBox["Symmetric model: limitations",
    ButtonData:>{"Symmetric model: limitations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " one deme example",
  ", ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "overview",
  ", ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " references",
  ", ",
  ButtonBox["Symmetric model: references",
    ButtonData:>{"Symmetric model: references", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reproduction",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Symmetric stability: outline",
    ButtonData:>{"Symmetric stability: outline", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric model"],

Cell[TextData[{
  "SymmetricNeutralDiploidFrequencies",
  ",",
  " ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricNeutralDiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricNeutralDiploidFrequencies"],

Cell[TextData[{
  "SymmetricNeutralHaploidFrequencies",
  ",",
  " ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricNeutralHaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricNeutralHaploidFrequencies"],

Cell[TextData[{
  "SymmetricRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "SymmetricRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricRecombination"],

Cell[TextData[{
  "SymmetricRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "SymmetricRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricRepresentations"],

Cell[TextData[{
  "SymmetricSexes",
  ",",
  " ",
  ButtonBox["Symmetric sexes",
    ButtonData:>{"Symmetric sexes", "SymmetricSexes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricSexes"],

Cell[TextData[{
  "Symmetrise",
  ",",
  " ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Symmetrise"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetrise",
    ButtonData:>{"Symmetrise", "Symmetrise"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetrise"],

Cell[TextData[{
  "T",
  ",",
  " time",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "T"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"T"],

Cell[TextData[{
  "Table",
  ",",
  " option for VarianceComponents",
  ", ",
  ButtonBox["Variance components",
    ButtonData:>{"Variance components", "Table"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Table"],

Cell[TextData[{
  "Tag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Tag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tag"],

Cell[TextData[{
  "Tags",
  ",",
  " finding",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Finding tags"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tags"],

Cell[TextData[{
  " setting up hyperlinks to",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Setting up links to a list of tags"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tags"],

Cell[TextData[{
  "TakeAway, \[Backslash], \[AliasIndicator]\[AliasIndicator], ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TakeAway"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TakeAway",
    ButtonData:>{"TakeAway", "TakeAway"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TakeAway"],

Cell[TextData[{
  "TakeOptions",
  ",",
  " ",
  ButtonBox["Manipulating options",
    ButtonData:>{"Manipulating options", "TakeOptions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TakeOptions"],

Cell[TextData[{
  "Time",
  ",",
  " T",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "T"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Time"],

Cell[TextData[{
  "TimesUp",
  ",",
  " ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TimesUp"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "TimesUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimesUp"],

Cell[TextData[{
  " multiple products",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Multiple products"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over subsets",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimesUp"],

Cell[TextData[{
  "ToBaake",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "ToBaake"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToBaake"],

Cell[TextData[{
  "ToBennett",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "ToBennett"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToBennett"],

Cell[TextData[{
  "ToBennettExpression",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "ToBennettExpression"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToBennettExpression"],

Cell[TextData[{
  "ToCumulants",
  ",",
  " ",
  ButtonBox["Multilocus cumulants",
    ButtonData:>{"Multilocus cumulants", "ToCumulants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToCumulants"],

Cell[TextData[{
  "ToMoments",
  ",",
  " ",
  ButtonBox["Multilocus cumulants",
    ButtonData:>{"Multilocus cumulants", "ToMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToMoments"],

Cell[TextData[{
  "ToPopulationCumulants",
  ",",
  " ",
  ButtonBox["Random drift: cumulants",
    ButtonData:>{"Random drift: cumulants", "ToPopulationCumulants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToPopulationCumulants"],

Cell[TextData[{
  "ToPopulationMoments",
  ",",
  " ",
  ButtonBox["Random drift: cumulants",
    ButtonData:>{"Random drift: cumulants", "ToPopulationMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToPopulationMoments"],

Cell[TextData[{
  "TotalLength",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "TotalLength"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalLength"],

Cell[TextData[{
  "TotalNumber",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "TotalNumber"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalNumber"],

Cell[TextData[{
  "Trait",
  ",",
  " set of all positions affecting, \[DoubleStruckCapitalZ], \
\[AliasIndicator]dsZ\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Trait"],

Cell[TextData[{
  "TransformedRange",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "TransformedRange"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransformedRange"],

Cell[TextData[{
  "TransformInformation",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "TransformInformation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransformInformation"],

Cell[TextData[{
  "TransmissionRule",
  ",",
  " ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "TransmissionRule"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransmissionRule"],

Cell[TextData[{
  "Transmission rules",
  ",",
  " applying",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "Applying transmission rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Transmission rules"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Transmission rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " distinct from Mathematica rules",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "Transmission vs Mathematica rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Transmission"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Transmission rules"],

Cell[TextData[{
  "TriDiagonalMatrix",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "TriDiagonalMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TriDiagonalMatrix"],

Cell[TextData[{
  "TruncationSelection",
  ",",
  " option for NewGametes",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", 
      "TruncationSelection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TruncationSelection"],

Cell[TextData[{
  "option for SelectionExact",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "TruncationSelection"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TruncationSelection"],

Cell[TextData[{
  "Turelli and Barton 1994",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Turelli and Barton 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Turelli and Barton 1994"],

Cell[TextData[{
  "Turelli & Barton 1994",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Turelli & Barton 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Turelli & Barton 1994"],

Cell[TextData[{
  "Two alleles",
  ",",
  " ",
  ButtonBox["Two alleles",
    ButtonData:>{"Two alleles", "Biallelic"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Two alleles"],

Cell[TextData[{
  " selection coefficients",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Two alleles"],

Cell[TextData[{
  "UMS",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UMS"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UMS"],

Cell[TextData[{
  "UnionOfGametes",
  ",",
  " ",
  ButtonBox["Union of gametes",
    ButtonData:>{"Union of gametes", "UnionOfGametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnionOfGametes"],

Cell[TextData[{
  "UnlinkedRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "UnlinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnlinkedRecombination"],

Cell[TextData[{
  "UnrootedGenealogy",
  ",",
  " ",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "UnrootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnrootedGenealogy"],

Cell[TextData[{
  "UpperOffDiagonal",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "UpperOffDiagonal"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UpperOffDiagonal"],

Cell[TextData[{
  "USM",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"USM"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"USM"],

Cell[TextData[{
  "ValidMatrixQ",
  ",",
  " ",
  ButtonBox["Validity of a mutation matrix",
    ButtonData:>{"Validity of a mutation matrix", "ValidMatrixQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ValidMatrixQ"],

Cell[TextData[{
  "VarianceComponents",
  ",",
  " ",
  ButtonBox["Variance components for a structured model",
    ButtonData:>{"Variance components for a structured model", 
      "VarianceComponents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"VarianceComponents"],

Cell[TextData[{
  " Table option",
  ", ",
  ButtonBox["Variance components",
    ButtonData:>{"Variance components", "Table"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"VarianceComponents"],

Cell[TextData[{
  "Versions",
  ",",
  " of applications packages",
  ", ",
  ButtonBox["Versions",
    ButtonData:>{"Versions", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Versions"],

Cell[TextData[{
  "WLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"WLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"WLinkedLoci"],

Cell[TextData[{
  "Wright-Fisher sampling",
  ",",
  " ",
  ButtonBox["Wright-Fisher sampling",
    ButtonData:>{"Wright-Fisher sampling", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Wright-Fisher sampling"],

Cell[TextData[{
  "X",
  ",",
  " AllelicState",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicState"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"X"],

Cell[TextData[{
  "XLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"XLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"XLinkedLoci"],

Cell[TextData[{
  "YLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"YLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"YLinkedLoci"],

Cell[TextData[{
  "ZLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ZLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ZLinkedLoci"],

Cell[TextData[{
  "Zygotes",
  ",",
  " \[GothicCapitalZ], \[AliasIndicator]goZ\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Zygotes"],

Cell[TextData[{
  "\[GothicA]",
  ",",
  " \[AliasIndicator]goa\[AliasIndicator], SelectionCoefficient",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicA]"],

Cell[TextData[{
  "\[GothicCapitalA]",
  ",",
  " \[AliasIndicator]goA\[AliasIndicator], adults",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalA]"],

Cell[TextData[{
  "\[GothicCapitalC]",
  ",",
  " \[AliasIndicator]goC\[AliasIndicator], PopulationDisequilibrium",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalC]"],

Cell[TextData[{
  "\[GothicCapitalD]",
  ",",
  " \[AliasIndicator]\[GothicCapitalD]\[AliasIndicator], Disequilibrium",
  ", ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalD]"],

Cell[TextData[{
  "\!\(\(\[GothicCapitalG]\^*\)\)",
  ",",
  " \[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, \
\[GothicCapitalG]new, new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\!\(\(\[GothicCapitalG]\^*\)\)"],

Cell[TextData[{
  "\[GothicCapitalG]",
  ",",
  " \[AliasIndicator]goG\[AliasIndicator], Gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalG]"],

Cell[TextData[{
  "\[GothicCapitalH]",
  ",",
  " \[AliasIndicator]goH\[AliasIndicator], hermaphrodites",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalH]"],

Cell[TextData[{
  "\[GothicCapitalJ]",
  ",",
  " \[AliasIndicator]goJ\[AliasIndicator], juveniles",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalJ]"],

Cell[TextData[{
  "\[GothicK]",
  ",",
  " \[AliasIndicator]gok\[AliasIndicator], CumulantDisequilibrium",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "CumulantDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicK]"],

Cell[TextData[{
  "\[GothicCapitalK]",
  ",",
  " \[AliasIndicator]goK\[AliasIndicator], CumulantPopulationDisequilibrium",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalK]"],

Cell[TextData[{
  "\[GothicM]",
  ",",
  " \[AliasIndicator]gom\[AliasIndicator], MeanContribution",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "MeanContribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicM]"],

Cell[TextData[{
  "\[GothicP]",
  ",",
  " \[AliasIndicator]gop\[AliasIndicator], AlleleFrequencyP",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicP]"],

Cell[TextData[{
  "\[GothicP]\[GothicQ]",
  ",",
  " \[AliasIndicator]gop\[AliasIndicator]\[AliasIndicator]goq\[AliasIndicator]\
, AlleleFrequencyPQ",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyPQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicP]\[GothicQ]"],

Cell[TextData[{
  "\[GothicQ]",
  ",",
  " \[AliasIndicator]goq\[AliasIndicator], AlleleFrequencyQ",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicQ]"],

Cell[TextData[{
  "\[GothicR]",
  ",",
  " \[AliasIndicator]gor\[AliasIndicator], RecombinationRate",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicR]"],

Cell[TextData[{
  "\[GothicS]",
  ",",
  "\[AliasIndicator]gos\[AliasIndicator], SelectionRate",
  ", ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SelectionRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicS]"],

Cell[TextData[{
  "\[GothicCapitalZ]",
  ",",
  " \[AliasIndicator]goZ\[AliasIndicator], Zygotes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalZ]"],

Cell[TextData[{
  "\[DoubleStruckCapitalG]",
  ",",
  " \[AliasIndicator]dsG\[AliasIndicator], set of all positions in genome",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalG]"],

Cell[TextData[{
  "\[DoubleStruckCapitalM]",
  ",",
  " \[AliasIndicator]dsM\[AliasIndicator], MigrationSet",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "MigrationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalM]"],

Cell[TextData[{
  "\[DoubleStruckCapitalR]",
  ",",
  " \[AliasIndicator]dsR\[AliasIndicator], RecombinationSet",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalR]"],

Cell[TextData[{
  "\[DoubleStruckCapitalW]",
  ",",
  " \[AliasIndicator]dsW\[AliasIndicator], FitnessSet",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "FitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalW]"],

Cell[TextData[{
  "\[DoubleStruckCapitalZ]",
  ",",
  " \[AliasIndicator]dsZ\[AliasIndicator], set of all positions affecting a \
trait",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalZ]"],

Cell[TextData[{
  "\[Gamma]",
  ",",
  " \[AliasIndicator]g\[AliasIndicator], ExtractGenes",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Gamma]"],

Cell[TextData[{
  "\[Zeta]",
  ",",
  " \[AliasIndicator]z\[AliasIndicator], AllelicDeviation",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicDeviation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Zeta]"],

Cell[TextData[{
  "\[CapitalMu]",
  ",",
  " \[AliasIndicator]M\[AliasIndicator], MigrationRate",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CapitalMu]"],

Cell[TextData[{
  "\[Chi]",
  ",",
  " \[AliasIndicator]c\[AliasIndicator], ExtractContexts",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Chi]"],

Cell[TextData[{
  "\[Sampi]",
  ",",
  " \[AliasIndicator]sa\[AliasIndicator], Stage",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Sampi]"],

Cell[TextData[{
  "$MetropolisAdjustment",
  ",",
  " ",
  ButtonBox["Metropolis algorithm",
    ButtonData:>{"Metropolis algorithm", "$MetropolisAdjustment"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$MetropolisAdjustment"],

Cell[TextData[{
  "\[WeierstrassP]",
  ",",
  " \[AliasIndicator]wp\[AliasIndicator], ReferencePoint",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[WeierstrassP]"],

Cell[TextData[{
  "\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]",
  ",",
  " \[AliasIndicator]l||\[AliasIndicator] \[AliasIndicator]r||\
\[AliasIndicator], population expectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],

Cell[TextData[{
  "\[CircleDot]",
  ",",
  " \[AliasIndicator]c.\[AliasIndicator], SelectContext",
  ", ",
  ButtonBox["Selecting contexts",
    ButtonData:>{"Selecting contexts", "SelectContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CircleDot]"],

Cell[TextData[{
  "\[Backslash], \[AliasIndicator]\[AliasIndicator], TakeAway, ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TakeAway"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TakeAway",
    ButtonData:>{"TakeAway", "TakeAway"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Backslash]"],

Cell[TextData[{
  "\[Wedge]",
  ",",
  " \[AliasIndicator]^\[AliasIndicator], ExactIntersection",
  ", ",
  ButtonBox["ExactIntersection",
    ButtonData:>{"ExactIntersection", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Wedge]"],

Cell[TextData[{
  "\[CirclePlus]",
  ",",
  " \[AliasIndicator]c+\[AliasIndicator], ChangeContext",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "ChangeContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CirclePlus]"]
}, Closed]],

Cell[CellGroupData[{

Cell["Old index", "Subsubsection"],

Cell[TextData[{
  "|.",
  ",",
  " ReplaceAllSpecial",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"|."],

Cell[TextData[{
  "\\\\",
  ",",
  " bugs with",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Repeated \\\\"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\\\\"],

Cell[TextData[{
  "<>",
  ",",
  " Expectation",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Expectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"<>"],

Cell[TextData[{
  "||.",
  ",",
  " ReplaceRepeatedSpecial",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"||."],

Cell[TextData[{
  "AddGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddGenealogy"],

Cell[TextData[{
  "Additive models",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "additive models"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive models"],

Cell[TextData[{
  "Additive selection",
  ",",
  " defining fitnesses",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive selection"],

Cell[TextData[{
  " defining rules",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Defining rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new D",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "New D"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "New mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " scaled D",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Scaled D"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive selection"],

Cell[TextData[{
  "AddNode",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddNode"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddNode"],

Cell[TextData[{
  "AddTag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "AddTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddTag"],

Cell[TextData[{
  "AddUp",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "AddUp"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "AddUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddUp"],

Cell[TextData[{
  " multiple sums",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Multiple sums"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over subsets",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Subsets"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Technicalities"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddUp"],

Cell[TextData[{
  "AdmixtureFrequency",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "AdmixtureFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AdmixtureFrequency"],

Cell[TextData[{
  "Admixture models",
  ",",
  " ",
  ButtonBox["Admixture models",
    ButtonData:>{"Admixture models", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview",
    ButtonData:>{"Overview", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Admixture models"],

Cell[TextData[{
  " changing sex",
  ", ",
  ButtonBox["Changing sex",
    ButtonData:>{"Changing sex", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " equilibria",
  ", ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " iteration",
  ", ",
  ButtonBox["Iteration",
    ButtonData:>{"Iteration", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " migration",
  ", ",
  ButtonBox["Migration in admixture models",
    ButtonData:>{"Migration in admixture models", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " recombination",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Admixture models"],

Cell[TextData[{
  "Adults",
  ",",
  " \[GothicCapitalA], \[AliasIndicator]goA\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Adults"],

Cell[TextData[{
  "Allele frequencies",
  ",",
  " definition of fitness",
  ", ",
  ButtonBox["Allele frequencies:fitnesses",
    ButtonData:>{"Allele frequencies:fitnesses", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Allele frequencies"],

Cell[TextData[{
  "AlleleFrequencies",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "AlleleFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencies"],

Cell[TextData[{
  "AlleleFrequencyMean",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyMean"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyMean"],

Cell[TextData[{
  "AlleleFrequencyP",
  ",",
  " \[GothicP], \[AliasIndicator]gop\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyP"],

Cell[TextData[{
  "AlleleFrequencyPermutations",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "AlleleFrequencyPermutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyPermutations"],

Cell[TextData[{
  "AlleleFrequencyPQ",
  ",",
  " \[GothicP]\[GothicQ], \[AliasIndicator]gop\[AliasIndicator]\
\[AliasIndicator]goq\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyPQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyPQ"],

Cell[TextData[{
  "AlleleFrequencyQ",
  ",",
  " \[GothicQ], \[AliasIndicator]goq\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyQ"],

Cell[TextData[{
  "AlleleFrequencyTable",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyTable"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "AlleleFrequencyTable"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyTable"],

Cell[TextData[{
  "AllelicDeviation",
  ",",
  " \[Zeta], \[AliasIndicator]z\[AliasIndicator]",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicDeviation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllelicDeviation"],

Cell[TextData[{
  "AllelicState",
  ",",
  " X",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicState"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllelicState"],

Cell[TextData[{
  "AllSets",
  ",",
  " ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "AllSets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllSets"],

Cell[TextData[{
  "Ancestors",
  ",",
  " determining",
  ", ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "Ancestors"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestors"],

Cell[TextData[{
  "Ancestry",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Ancestry"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestry"],

Cell[TextData[{
  "Arbitrary sets of loci",
  ",",
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Arbitrary sets of loci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Arbitrary sets of loci"],

Cell[TextData[{
  "Arnold 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Arnold 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Arnold 1996"],

Cell[TextData[{
  "Asmussen and Orive 2000",
  ",",
  " ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["References",
    ButtonData:>{"References", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Asmussen and Orive 2000"],

Cell[TextData[{
  "Asmussen et al. 1987",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Asmussen et al 1987"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Asmussen et al. 1987"],

Cell[TextData[{
  "B",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "B"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"B"],

Cell[TextData[{
  "Baake 2001",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Baake"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["References",
    ButtonData:>{"References", "Baake 2001"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Baake 2001"],

Cell[TextData[{
  "Barrier",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", "Barrier"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barrier"],

Cell[TextData[{
  "BarrierStrength",
  ",",
  " ",
  ButtonBox["Describing populations",
    ButtonData:>{"Describing populations", "BarrierStrength"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BarrierStrength"],

Cell[TextData[{
  "Barton 1986",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton 1986"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 1986"],

Cell[TextData[{
  "Barton 1995",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Barton 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 1995"],

Cell[TextData[{
  "Barton 2000",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 2000"],

Cell[TextData[{
  "Barton and Turelli 1991",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Barton and Turelli 1991"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton and Turelli 1991"],

Cell[TextData[{
  "Barton & Gale 1993",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Gale 1993"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Gale 1993"],

Cell[TextData[{
  "Barton & Shpak 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Shpak 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Shpak 1999"],

Cell[TextData[{
  "Barton & Turelli 1991",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Turelli 1991"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Turelli 1991"],

Cell[TextData[{
  "Bennett 1954",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Bennett 1954"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bennett 1954"],

Cell[TextData[{
  "BennettB",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "BennettB"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BennettB"],

Cell[TextData[{
  "BennettC",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "BennettC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BennettC"],

Cell[TextData[{
  "BennettExpansion",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "BennettExpansion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BennettExpansion"],

Cell[TextData[{
  "Biallelic",
  ",",
  " ",
  ButtonBox["Two alleles",
    ButtonData:>{"Two alleles", "Biallelic"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Biallelic"],

Cell[TextData[{
  " selection coefficients",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Biallelic"],

Cell[TextData[{
  "BiallelicMutation",
  ",",
  " ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "BiallelicMutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BiallelicMutation"],

Cell[TextData[{
  " Mutation option",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Mutation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BiallelicMutation"],

Cell[TextData[{
  "Birth",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "Birth"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Birth"],

Cell[TextData[{
  "BirthTime",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "BirthTime"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BirthTime"],

Cell[TextData[{
  "Boundary conditions",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Boundary conditions"],

Cell[TextData[{
  "Box",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Box"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Box"],

Cell[TextData[{
  "Boxes",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Boxes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Boxes"],

Cell[TextData[{
  "Browser categories",
  ",",
  " ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Browser categories"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Browser categories"],

Cell[TextData[{
  "Bugs",
  ",",
  " applying rules",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bugs"],

Cell[TextData[{
  " clashes between packages",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Clashes between packages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " estimating D",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " incompatibilities",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Incompatibilities"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " manipulating notebooks",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Manipulating notebooks"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " multilocus notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Multilocus notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " numerical error with AlleleFrequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Numerical bug"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pasting hyperlinks",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Pasting hyperlinks"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " repeated \\\\",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Repeated \\\\"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " special notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with style sheets",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Style sheets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bugs"],

Cell[TextData[{
  "ChangeContext",
  ",",
  "\[CirclePlus], \[AliasIndicator]c+\[AliasIndicator]",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "ChangeContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ChangeContext"],

Cell[TextData[{
  "ChangeSex",
  ",",
  " ",
  ButtonBox["Changing sex",
    ButtonData:>{"Changing sex", "ChangeSex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ChangeSex"],

Cell[TextData[{
  "ClassToGenotypes",
  ",",
  " ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "ClassToGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClassToGenotypes"],

Cell[TextData[{
  "Cline",
  ",",
  " example of",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cline"],

Cell[TextData[{
  " in allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: spatially varying selection",
    ButtonData:>{"Symmetric stability: spatially varying selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: setting up a symmetric cline",
    ButtonData:>{"Simulating individuals: setting up a symmetric cline", 
      None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: setting up a symmetric cline",
    ButtonData:>{"Symmetric model: setting up a symmetric cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with neutral marker",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", "Cline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cline"],

Cell[TextData[{
  "ClineGradient",
  ",",
  "  for genotype frequencies",
  ", ",
  ButtonBox["ClineGradient: setting up a cline",
    ButtonData:>{"ClineGradient: setting up a cline", "ClineGradient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineGradient"],

Cell[TextData[{
  "ClineWidth",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineWidth"],

Cell[TextData[{
  "  for genotype frequencies",
  ", ",
  ButtonBox["Recursions: setting up a cline",
    ButtonData:>{"Recursions: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineWidth"],

Cell[TextData[{
  "CoalescenceDistribution",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", 
      "CoalescenceDistribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CoalescenceDistribution"],

Cell[TextData[{
  "CollapseGenealogy",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "CollapseGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CollapseGenealogy"],

Cell[TextData[{
  "Combine",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Combine"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Combine"],

Cell[TextData[{
  "CompareLogL",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "CompareLogL"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CompareLogL"],

Cell[TextData[{
  "Compiled",
  ",",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Compiled"],

Cell[TextData[{
  "Compiling",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Compiling"],

Cell[TextData[{
  "CondenseGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "CondenseGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CondenseGenealogy"],

Cell[TextData[{
  "ConstrainedIntervals",
  ",",
  " ",
  ButtonBox["Constrained intervals",
    ButtonData:>{"Constrained intervals", "ConstrainedIntervals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstrainedIntervals"],

Cell[TextData[{
  "ConstructMutateList",
  ",",
  " ",
  ButtonBox["Allele frequencies: mutation",
    ButtonData:>{"Allele frequencies: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: mutation",
    ButtonData:>{"Simulating individuals: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstructMutateList"],

Cell[TextData[{
  "ConstructMutateMatrix",
  ",",
  " ",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "ConstructMutateMatrix"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "ConstructMutateMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstructMutateMatrix"],

Cell[TextData[{
  "ContextComponentQ",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextComponentQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextComponentQ"],

Cell[TextData[{
  "ContextPosition",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextPosition"],

Cell[TextData[{
  "ContextStageQ",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextStageQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextStageQ"],

Cell[TextData[{
  "ContextStructure",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextStructure"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextStructure"],

Cell[TextData[{
  "Continuous populations",
  ",",
  " estimating covariance",
  ", ",
  ButtonBox["Estimating the covariance",
    ButtonData:>{"Estimating the covariance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Continuous populations"],

Cell[TextData[{
  " example",
  ", ",
  ButtonBox["An example",
    ButtonData:>{"An example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " implementation",
  ", ",
  ButtonBox["Implementation",
    ButtonData:>{"Implementation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving results",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "Saving results"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " the model",
  ", ",
  ButtonBox["The model",
    ButtonData:>{"The model", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Continuous populations"],

Cell[TextData[{
  "ContinuumVariables",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "ContinuumVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContinuumVariables"],

Cell[TextData[{
  "ConvertData",
  ",",
  " ",
  ButtonBox["Converting a dataset",
    ButtonData:>{"Converting a dataset", "ConvertData"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConvertData"],

Cell[TextData[{
  "ConvertHyperlinkToAddOnsLink",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "ConvertHyperlinkToAddOnsLink"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConvertHyperlinkToAddOnsLink"],

Cell[TextData[{
  "Converting",
  ",",
  " between representations",
  ", ",
  ButtonBox["Allele frequencies: converting",
    ButtonData:>{"Allele frequencies: converting", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Converting"],

Cell[TextData[{
  "CountHeterozygotes",
  ",",
  " ",
  ButtonBox["Recursions:manipulation",
    ButtonData:>{"Recursions:manipulation", "CountHeterozygotes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CountHeterozygotes"],

Cell[TextData[{
  "Covariance",
  ",",
  " in continuous populations",
  ", ",
  ButtonBox["Estimating the covariance",
    ButtonData:>{"Estimating the covariance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Covariance"],

Cell[TextData[{
  "CovarianceMidPoints",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "CovarianceMidPoints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CovarianceMidPoints"],

Cell[TextData[{
  "Crow and Kimura 1970",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Crow and Kimura 1970"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Crow and Kimura 1970"],

Cell[TextData[{
  "Cumulant",
  ",",
  " ",
  ButtonBox["Moments and cumulants",
    ButtonData:>{"Moments and cumulants", "Cumulant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cumulant"],

Cell[TextData[{
  "CumulantDisequilibrium",
  ",",
  " \[GothicK], \[AliasIndicator]gok\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "CumulantDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantDisequilibrium"],

Cell[TextData[{
  "CumulantEquilibrium",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "CumulantEquilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantEquilibrium"],

Cell[TextData[{
  "CumulantPopulationDisequilibrium",
  ",",
  " \[GothicCapitalK], \[AliasIndicator]goK\[AliasIndicator]",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantPopulationDisequilibrium"],

Cell[TextData[{
  "CumulantReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "CumulantReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantReduced"],

Cell[TextData[{
  "Cumulants",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "7.2"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Cumulant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cumulants"],

Cell[TextData[{
  "Cytoplasmic inheritance",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cytoplasmic inheritance"],

Cell[TextData[{
  " and migration",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Cytonuclear associations"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " examples of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cytoplasmic inheritance"],

Cell[TextData[{
  "CytoplasmicLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CytoplasmicLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CytoplasmicLoci"],

Cell[TextData[{
  "dAlleleFrequencyPermutations",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "dAlleleFrequencyPermutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"dAlleleFrequencyPermutations"],

Cell[TextData[{
  "Data",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Data"],

Cell[TextData[{
  " missing",
  ", ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Missing data"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notation for",
  ", ",
  ButtonBox["Notation for genetic data",
    ButtonData:>{"Notation for genetic data", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Data"],

Cell[TextData[{
  "Datasets",
  ",",
  " defining",
  ", ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Datasets"],

Cell[TextData[{
  "Dawson 2000",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Bennett"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["References",
    ButtonData:>{"References", "Dawson 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dawson 2000"],

Cell[TextData[{
  "Death",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "Death"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Death"],

Cell[TextData[{
  "DeathTime",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "DeathTime"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeathTime"],

Cell[TextData[{
  "DefineContext",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "DefineContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DefineContext"],

Cell[TextData[{
  "DegreesOfFreedom",
  ",",
  " ",
  ButtonBox["Degrees of freedom",
    ButtonData:>{"Degrees of freedom", "DegreesOfFreedom"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DegreesOfFreedom"],

Cell[TextData[{
  "DeletedMutations",
  ",",
  " ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", "DeletedMutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeletedMutations"],

Cell[TextData[{
  "DeleteGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "DeleteGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeleteGenealogy"],

Cell[TextData[{
  "Deme",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Deme"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Deme"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Deme"],

Cell[TextData[{
  "DemeSize",
  ",",
  " compiling",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "Deme size (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DemeSize"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for MigrateExact",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DemeSize"],

Cell[TextData[{
  "Dempster et al 1977",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Dempster et al 1977"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dempster et al 1977"],

Cell[TextData[{
  "Density",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Density"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Density"],

Cell[TextData[{
  "Descendants",
  ",",
  " ",
  ButtonBox["Ancestors and descendants",
    ButtonData:>{"Ancestors and descendants", "Descendants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Descendants"],

Cell[TextData[{
  " determining",
  ", ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "Descendants"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Descendants"],

Cell[TextData[{
  "Dicytonuclear associations",
  ",",
  " ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dicytonuclear associations"],

Cell[TextData[{
  "Diploid",
  ",",
  " option for MomentFromG",
  ", ",
  ButtonBox["Moments from genotype frequencies",
    ButtonData:>{"Moments from genotype frequencies", "Diploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Diploid"],

Cell[TextData[{
  "DiploidConstraints",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidConstraints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidConstraints"],

Cell[TextData[{
  "DiploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidFrequencies"],

Cell[TextData[{
  "DiploidGenotypeFrequency",
  ",",
  " ",
  ButtonBox["Genotype frequencies from moments",
    ButtonData:>{"Genotype frequencies from moments", 
      "DiploidGenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequency"],

Cell[TextData[{
  "DiploidGenotypeFrequencyList",
  ",",
  " ",
  ButtonBox["Fast calculations",
    ButtonData:>{"Fast calculations", "DiploidGenotypeFrequencyList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyList"],

Cell[TextData[{
  "DiploidGenotypeFrequencyReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyReduced"],

Cell[TextData[{
  "DiploidGenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyTable"],

Cell[TextData[{
  "DiploidIndividuals",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidIndividuals"],

Cell[TextData[{
  "DiploidPhenotype",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidPhenotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidPhenotype"],

Cell[TextData[{
  "DiploidPsi",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidPsi"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "DiploidPsi"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidPsi"],

Cell[TextData[{
  "DiploidRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidRepresentations"],

Cell[TextData[{
  "DiploidSource",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidSource"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "DiploidSource"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidSource"],

Cell[TextData[{
  "DiploidSubsets",
  ",",
  " ",
  ButtonBox["Subsets of loci",
    ButtonData:>{"Subsets of loci", "DiploidSubsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidSubsets"],

Cell[TextData[{
  "DiploidTypes",
  ",",
  " ",
  ButtonBox["Listing genotypes",
    ButtonData:>{"Listing genotypes", "DiploidTypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidTypes"],

Cell[TextData[{
  "Disequilibrium",
  ",",
  " Baake's measure",
  ", ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Baake"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Disequilibrium"],

Cell[TextData[{
  " Bennett's principal components",
  ", ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Bennett"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " \[GothicCapitalD], \[AliasIndicator]\[GothicCapitalD]\[AliasIndicator]",
  ", ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Disequilibrium"],

Cell[TextData[{
  "DisequilibriumMean",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumMean"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumMean"],

Cell[TextData[{
  "DisequilibriumTable",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumTable"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumTable"],

Cell[TextData[{
  "Dispersal",
  ",",
  " in continuum simulations",
  ", ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dispersal"],

Cell[TextData[{
  "DistanceSquared",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "DistanceSquared"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DistanceSquared"],

Cell[TextData[{
  "Distribution",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Distribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Distribution"],

Cell[TextData[{
  "DivideZero",
  ",",
  " ",
  ButtonBox["DivideZero",
    ButtonData:>{"DivideZero", "DivideZero"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DivideZero"],

Cell[TextData[{
  "DoReplicates",
  ",",
  " ",
  ButtonBox["Analysing replicate samples",
    ButtonData:>{"Analysing replicate samples", "DoReplicates"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoReplicates"],

Cell[TextData[{
  "DoubleCline",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a symmetric cline",
    ButtonData:>{"Allele frequencies: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoubleCline"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: setting up a symmetric cline",
    ButtonData:>{"Simulating individuals: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a symmetric cline",
    ButtonData:>{"Symmetric model: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoubleCline"],

Cell[TextData[{
  "DrawSamples",
  ",",
  " ",
  ButtonBox["Setting up replicates",
    ButtonData:>{"Setting up replicates", "DrawSamples"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DrawSamples"],

Cell[TextData[{
  "DropOptions",
  ",",
  " ",
  ButtonBox["Manipulating options",
    ButtonData:>{"Manipulating options", "DropOptions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DropOptions"],

Cell[TextData[{
  "Edwards 1972",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Edwards 1972"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Edwards 1972"],

Cell[TextData[{
  "EmptySets",
  ",",
  "option for PartitionSet",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "EmptySets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EmptySets"],

Cell[TextData[{
  "Epistasis",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Epistasis"],

Cell[TextData[{
  "EquivalentSexes",
  ",",
  " obsolete form of SymmetricSexes",
  ", ",
  ButtonBox["Symmetric sexes",
    ButtonData:>{"Symmetric sexes", "SymmetricSexes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EquivalentSexes"],

Cell[TextData[{
  "ErrorBound",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "ErrorBound"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ErrorBound"],

Cell[TextData[{
  "EstimateFamilyMoments",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "EstimateFamilyMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EstimateFamilyMoments"],

Cell[TextData[{
  "EstimateMoments",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "EstimateMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EstimateMoments"],

Cell[TextData[{
  "Estimating D",
  ",",
  " admixture models",
  ", ",
  ButtonBox["Admixture models",
    ButtonData:>{"Admixture models", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Estimating D"],

Cell[TextData[{
  " alternative methods",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Log-linear models"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction",
  ", ",
  ButtonBox["Introduction to estimating D",
    ButtonData:>{"Introduction to estimating D", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " maximum entropy",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Maximum entropy"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " maximum likelihood, example of",
  ", ",
  ButtonBox["MLE example",
    ButtonData:>{"MLE example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Metropolis random walk",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MLE, cumulants",
  ", ",
  ButtonBox["Finding the MLE",
    ButtonData:>{"Finding the MLE", "Cumulant"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " moments, families",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "Extension to families"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " naive MLE",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Naive MLE"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " obsolete",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pairs of loci",
  ", ",
  ButtonBox["Pairs of loci",
    ButtonData:>{"Pairs of loci", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pairs of loci, example of",
  ", ",
  ButtonBox["Pairwise example",
    ButtonData:>{"Pairwise example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " random sampling, example of",
  ", ",
  ButtonBox["Sampling example",
    ButtonData:>{"Sampling example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " summary",
  ", ",
  ButtonBox["Summary",
    ButtonData:>{"Summary", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " varying divergence",
  ", ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "Varying divergence"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Estimating D"],

Cell[TextData[{
  "ExactEigenvalues",
  ",",
  " ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "ExactEigenvalues"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactEigenvalues"],

Cell[TextData[{
  "ExactIntersection",
  ",",
  " \[Wedge], \[AliasIndicator]^\[AliasIndicator]",
  ", ",
  ButtonBox["ExactIntersection",
    ButtonData:>{"ExactIntersection", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactIntersection"],

Cell[TextData[{
  "ExactProbability",
  ",",
  " ",
  ButtonBox["Exact probability",
    ButtonData:>{"Exact probability", "ExactProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactProbability"],

Cell[TextData[{
  "Expectation",
  ",",
  " <>",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Expectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Expectation"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Expectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population, \[LeftDoubleBracketingBar] \[RightDoubleBracketingBar], \
\[AliasIndicator]l||\[AliasIndicator] \[AliasIndicator]r||\[AliasIndicator]",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Expectation"],

Cell[TextData[{
  "ExponentialF",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExponentialF"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "ExponentialF"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExponentialF"],

Cell[TextData[{
  "ExtantIndividuals",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "ExtantIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtantIndividuals"],

Cell[TextData[{
  "ExtractContexts",
  ",",
  " \[Chi], \[AliasIndicator]c\[AliasIndicator]",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractContexts"],

Cell[TextData[{
  "ExtractExtant",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "ExtractExtant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractExtant"],

Cell[TextData[{
  "ExtractGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "ExtractGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractGenealogy"],

Cell[TextData[{
  "ExtractGenes",
  ",",
  " \[Gamma], \[AliasIndicator]g\[AliasIndicator]",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractGenes"],

Cell[TextData[{
  "ExtractInformation",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "ExtractInformation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractInformation"],

Cell[TextData[{
  "ExtractRepeat",
  ",",
  " ",
  ButtonBox["Repeated elements",
    ButtonData:>{"Repeated elements", "ExtractRepeat"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractRepeat"],

Cell[TextData[{
  "ExtractSubMatrix",
  ",",
  " ",
  ButtonBox["Extracting submatrices",
    ButtonData:>{"Extracting submatrices", "ExtractSubMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractSubMatrix"],

Cell[TextData[{
  "FamilyAlleleFrequencyEstimate",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyAlleleFrequencyEstimate"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyAlleleFrequencyEstimate"],

Cell[TextData[{
  "FamilyEffects",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyEffects"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyEffects"],

Cell[TextData[{
  "FamilyM",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyM"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyM"],

Cell[TextData[{
  "FamilyProbability",
  ",",
  " ",
  ButtonBox["Probabilities",
    ButtonData:>{"Probabilities", "FamilyProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyProbability"],

Cell[TextData[{
  "Family structure",
  ",",
  " set of all",
  ", ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "NewS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Family structure"],

Cell[TextData[{
  "Fecundity",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Fecundity"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fecundity"],

Cell[TextData[{
  "FindHyperlinks",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "FindHyperlinks"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindHyperlinks"],

Cell[TextData[{
  "FindIndexTag",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "FindIndexTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindIndexTag"],

Cell[TextData[{
  "FindMLE",
  ",",
  " ",
  ButtonBox["Finding the MLE",
    ButtonData:>{"Finding the MLE", "FindMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindMLE"],

Cell[TextData[{
  "FindNode",
  ",",
  " ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", "FindNode"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindNode"],

Cell[TextData[{
  "FindPosition",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "FindPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindPosition"],

Cell[TextData[{
  "FindTags",
  ",",
  " ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "FindTags"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindTags"],

Cell[TextData[{
  "Fitness",
  ",",
  " definition for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:fitnesses",
    ButtonData:>{"Allele frequencies:fitnesses", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fitness"],

Cell[TextData[{
  " in individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " problems redefining",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Redefining fitness"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fitness"],

Cell[TextData[{
  "FitnessSet",
  ",",
  " \[DoubleStruckCapitalW], \[AliasIndicator]dsW\[AliasIndicator]",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "FitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessSet"],

Cell[TextData[{
  "FitnessTable",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessTable"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessTable"],

Cell[TextData[{
  "FixedEnds",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FixedEnds"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for MigrateExact",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FixedEnds"],

Cell[TextData[{
  "Flatten",
  ",",
  " ",
  ButtonBox["Flattening lists at specific levels",
    ButtonData:>{"Flattening lists at specific levels", "Flatten"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Flatten"],

Cell[TextData[{
  "FlattenList",
  ",",
  " ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "FlattenList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FlattenList"],

Cell[TextData[{
  " PatternFree",
  ", ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "PatternFree"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FlattenList"],

Cell[TextData[{
  "FourierNormalised",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "FourierNormalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FourierNormalised"],

Cell[TextData[{
  "FourierNormalisedTable",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "FourierNormalisedTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FourierNormalisedTable"],

Cell[TextData[{
  "FrequencyRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "FrequencyRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FrequencyRepresentations"],

Cell[TextData[{
  "FromBaake",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "FromBaake"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FromBaake"],

Cell[TextData[{
  "FromBennett",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "FromBennett"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FromBennett"],

Cell[TextData[{
  "FromBennettExpression",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "FromBennettExpression"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FromBennettExpression"],

Cell[TextData[{
  "FullContext",
  ",",
  " ",
  ButtonBox["Abbreviating contexts",
    ButtonData:>{"Abbreviating contexts", "FullContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullContext"],

Cell[TextData[{
  "FullGenotypeFrequencyReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullGenotypeFrequencyReduced"],

Cell[TextData[{
  "FullGenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullGenotypeFrequencyTable"],

Cell[TextData[{
  "FullOutput",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "FullOutput"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullOutput"],

Cell[TextData[{
  "Function",
  ",",
  " ",
  ButtonBox["Marginal tables",
    ButtonData:>{"Marginal tables", "Function"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Function"],

Cell[TextData[{
  "Gametes",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "Gametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gametes"],

Cell[TextData[{
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new, \!\(\(\[GothicCapitalG]\^*\)\), \
\[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, \[GothicCapitalG]new",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " \[GothicCapitalG], \[AliasIndicator]goG\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gametes"],

Cell[TextData[{
  "GameteTable",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "GameteTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GameteTable"],

Cell[TextData[{
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "GameteTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "GameteTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GameteTable"],

Cell[TextData[{
  "GaussianLogLikelihood",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "GaussianLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GaussianLogLikelihood"],

Cell[TextData[{
  "GaussianMLE",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "GaussianMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GaussianMLE"],

Cell[TextData[{
  "Genealogies",
  ",",
  " exact probability",
  ", ",
  ButtonBox["Exact probability",
    ButtonData:>{"Exact probability", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genealogies"],

Cell[TextData[{
  " family structure",
  ", ",
  ButtonBox["Family structure",
    ButtonData:>{"Family structure", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " generating functions",
  ", ",
  ButtonBox["Deriving recursions for the MGF",
    ButtonData:>{"Deriving recursions for the MGF", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " probability of",
  ", ",
  ButtonBox["Deriving the probability",
    ButtonData:>{"Deriving the probability", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sampling",
  ", ",
  ButtonBox["Sampling genealogies",
    ButtonData:>{"Sampling genealogies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genealogies"],

Cell[TextData[{
  "GenealogyToMatrix",
  ",",
  " ",
  ButtonBox["Describing mutation",
    ButtonData:>{"Describing mutation", "GenealogyToMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenealogyToMatrix"],

Cell[TextData[{
  "GeneralizedTransform",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "GeneralizedTransform"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GeneralizedTransform"],

Cell[TextData[{
  "Generating functions",
  ",",
  " examples",
  ", ",
  ButtonBox["Examples of the MGF",
    ButtonData:>{"Examples of the MGF", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Generating functions"],

Cell[TextData[{
  " for cumulants",
  ", ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "GeneralizedTransform"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genealogies",
  ", ",
  ButtonBox["Deriving recursions for the MGF",
    ButtonData:>{"Deriving recursions for the MGF", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Generating functions"],

Cell[TextData[{
  "Genes and contexts",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Genes and contexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genes and contexts"],

Cell[TextData[{
  "Genome",
  ",",
  " set of all positions in, \[DoubleStruckCapitalG], \[AliasIndicator]dsG\
\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genome"],

Cell[TextData[{
  "Genotype",
  ",",
  " in continuum simulations",
  ", ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Genotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype"],

Cell[TextData[{
  " observable",
  ", ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for InitialiseContinuum",
  ", ",
  ButtonBox["Initialisation",
    ButtonData:>{"Initialisation", "Genotype"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype"],

Cell[TextData[{
  "Genotype frequencies",
  ",",
  " recursions",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype frequencies"],

Cell[TextData[{
  "GenotypeFrequencyArguments",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "GenotypeFrequencyArguments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyArguments"],

Cell[TextData[{
  "GenotypeFrequencyConvert",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "GenotypeFrequencyConvert"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyConvert"],

Cell[TextData[{
  "GenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyTable"],

Cell[TextData[{
  "GenotypePosition",
  ",",
  " ",
  ButtonBox["Recursions:manipulation",
    ButtonData:>{"Recursions:manipulation", "GenotypePosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypePosition"],

Cell[TextData[{
  "GenotypeProbability",
  ",",
  " ",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "GenotypeProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeProbability"],

Cell[TextData[{
  " segregation ratio",
  ", ",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeProbability"],

Cell[TextData[{
  "Genotypes",
  ",",
  " notation for",
  ", ",
  ButtonBox["Notation",
    ButtonData:>{"Notation", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotypes"],

Cell[TextData[{
  "GlobalContinuumVariables",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "GlobalContinuumVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GlobalContinuumVariables"],

Cell[TextData[{
  "Gnew",
  ",",
  " \!\(\(\[GothicCapitalG]\^*\)\), \[AliasIndicator]goG\[AliasIndicator]\
\[ControlKey]^*, new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gnew"],

Cell[TextData[{
  "Goodman et al 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Goodman et al 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Goodman et al 1999"],

Cell[TextData[{
  "Griffiths-Tavare",
  ",",
  " ",
  ButtonBox["Exact algorithm",
    ButtonData:>{"Exact algorithm", "GriffithsTavare"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Griffiths-Tavare algorithm",
    ButtonData:>{"Griffiths-Tavare algorithm", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Griffiths-Tavare"],

Cell[TextData[{
  " stochastic algorithm",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "MonteCarloGriffithsTavare"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "Stochastic GT algorithm"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stochastic, comparison with MonteCarloProbability",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", 
      "Comparison with MonteCarloProbability"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stochastic example",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "Small example"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Griffiths-Tavare"],

Cell[TextData[{
  "Guiasu & Shenitzer 1985",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Guiasu & Shenitzer 1985"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Guiasu & Shenitzer 1985"],

Cell[TextData[{
  "HaploidConstraints",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "HaploidConstraints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidConstraints"],

Cell[TextData[{
  "HaploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidFrequencies"],

Cell[TextData[{
  "HaploidGenotypeFrequency",
  ",",
  " ",
  ButtonBox["Genotype frequencies from moments",
    ButtonData:>{"Genotype frequencies from moments", 
      "HaploidGenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidGenotypeFrequency"],

Cell[TextData[{
  "HaploidIndividuals",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidIndividuals"],

Cell[TextData[{
  "HaploidRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidRepresentations"],

Cell[TextData[{
  "Haploids",
  ",",
  " selection on",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Haploids"],

Cell[TextData[{
  "HaploidSource",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "HaploidSource"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "HaploidSource"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidSource"],

Cell[TextData[{
  "HaploidSubsets",
  ",",
  " ",
  ButtonBox["Subsets of loci",
    ButtonData:>{"Subsets of loci", "HaploidSubsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidSubsets"],

Cell[TextData[{
  "HaploidTypes",
  ",",
  " ",
  ButtonBox["Listing genotypes",
    ButtonData:>{"Listing genotypes", "HaploidTypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidTypes"],

Cell[TextData[{
  "Help browser",
  ",",
  " setting up new files",
  ", ",
  ButtonBox["Setting up new help files",
    ButtonData:>{"Setting up new help files", "Setting up new help files"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help browser"],

Cell[TextData[{
  "Help Browser",
  ",",
  " ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "MasterIndexHeading"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help Browser"],

Cell[TextData[{
  " setting up hyperlinks",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up links"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help Browser"],

Cell[TextData[{
  "Hermaphrodites",
  ",",
  " \[GothicCapitalH], \[AliasIndicator]goH\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hermaphrodites"],

Cell[TextData[{
  "HeterozygoteB",
  ",",
  " ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "HeterozygoteB"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HeterozygoteB"],

Cell[TextData[{
  "Hill 1974a",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974a"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974a"],

Cell[TextData[{
  "Hill 1974b",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974b"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974b"],

Cell[TextData[{
  "Hill 1974c",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974c"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974c"],

Cell[TextData[{
  "Hypergeometric model",
  ",",
  " ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hypergeometric model"],

Cell[TextData[{
  "Hyperlinks",
  ",",
  " bugs in pasting",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Pasting hyperlinks"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hyperlinks"],

Cell[TextData[{
  " saving",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Saving the links"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " setting up",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up links"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " to cell tags",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Setting up links to a list of tags"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hyperlinks"],

Cell[TextData[{
  "IncidenceMatrix",
  ",",
  " ",
  ButtonBox["Ordered genealogies",
    ButtonData:>{"Ordered genealogies", "IncidenceMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IncidenceMatrix"],

Cell[TextData[{
  "Index",
  ",",
  " setting up",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up Master Index"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Index"],

Cell[TextData[{
  "Individual",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Individual"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Individual"],

Cell[TextData[{
  "IndividualContinuumVariables",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "IndividualContinuumVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IndividualContinuumVariables"],

Cell[TextData[{
  "IndividualRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "IndividualRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IndividualRepresentations"],

Cell[TextData[{
  "Individuals",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Individuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Individuals"],

Cell[TextData[{
  "InitialiseContinuum",
  ",",
  " ",
  ButtonBox["Initialisation",
    ButtonData:>{"Initialisation", "InitialiseContinuum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseContinuum"],

Cell[TextData[{
  "InitialiseCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "InitialiseCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseCovariance"],

Cell[TextData[{
  "InitialiseDemes",
  ",",
  " ",
  ButtonBox["Describing the population",
    ButtonData:>{"Describing the population", "InitialiseDemes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Setting up a cline",
    ButtonData:>{"Setting up a cline", "InitialiseDemes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseDemes"],

Cell[TextData[{
  "InitialStep",
  ",",
  " ",
  ButtonBox["Initial step size",
    ButtonData:>{"Initial step size", "InitialStep"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialStep"],

Cell[TextData[{
  "InitialStepReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "InitialStepReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialStepReduced"],

Cell[TextData[{
  "InternalNodes",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "InternalNodes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InternalNodes"],

Cell[TextData[{
  "IntervalCombine",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalCombine"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IntervalCombine"],

Cell[TextData[{
  "IntervalPosition",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IntervalPosition"],

Cell[TextData[{
  "InverseFourierNormalised",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "InverseFourierNormalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InverseFourierNormalised"],

Cell[TextData[{
  "InverseFourierNormalisedTable",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "InverseFourierNormalisedTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InverseFourierNormalisedTable"],

Cell[TextData[{
  "Island model",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Island model"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Island model"],

Cell[TextData[{
  "IterateContinuum",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "IterateContinuum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateContinuum"],

Cell[TextData[{
  "IterateExact",
  ",",
  " example",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateExact"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for allele frequency clines",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "IterateExact"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequency clines",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateExact"],

Cell[TextData[{
  "Join",
  ",",
  " ",
  ButtonBox["Join",
    ButtonData:>{"Join", "Join"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "Join"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Join"],

Cell[TextData[{
  "Juveniles",
  ",",
  " \[GothicCapitalJ], \[AliasIndicator]goJ\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Juveniles"],

Cell[TextData[{
  "Kirkpatrick and Barton 1997",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick and Barton 1997"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick and Barton 1997"],

Cell[TextData[{
  "Kirkpatrick and Servedio 1998",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick and Servedio 1998"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick and Servedio 1998"],

Cell[TextData[{
  "Kirkpatrick et al.",
  ",",
  " ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick et al."},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al."],

Cell[TextData[{
  " arbitrary sets of loci",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Arbitrary sets of loci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Expectation",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Expectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " migration",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " mutation",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " permutations in defining coefficients",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Permutations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Permutations"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " phenotypes",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " position",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Contexts and positions"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "position"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " QLE",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " quasi-linkage equilibrium",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " random drift",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Random drift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference values",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Describing genotypes and populations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Reference values"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " relation with",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Multilocus MS"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " scripts and faces",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Scripts and faces"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " selection",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sets in subscripts",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets in subscripts"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sets of loci",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets of loci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stabilising selection",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", 
      "Natural selection on an additive polygenic trait"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages and contexts",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Stages and contexts"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " transmission rules",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Transmission"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Transmission rules"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al."],

Cell[TextData[{
  "Kirkpatrick et al. 1983",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Kirkpatrick et al 1983"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al. 1983"],

Cell[TextData[{
  "Kruuk 1997",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Kruuk 1997"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kruuk 1997"],

Cell[TextData[{
  "LeafLabels",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "LeafLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LeafLabels"],

Cell[TextData[{
  "LeafOffset",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "LeafOffset"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LeafOffset"],

Cell[TextData[{
  "Leaves",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "Leaves"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Leaves"],

Cell[TextData[{
  "Life cycle",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Life cycle"],

Cell[TextData[{
  " adults",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete",
  ", ",
  ButtonBox["Complete life cycle",
    ButtonData:>{"Complete life cycle", "Complete rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " hermaphrodites",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " juveniles",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages in",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with cytoplasmic inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with sex linkage",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " zygotes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Life cycle"],

Cell[TextData[{
  "Li & Nei 1974",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Li & Nei 1974"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Li & Nei 1974"],

Cell[TextData[{
  "Linkage",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Linkage",
    ButtonData:>{"Linkage", "Linkage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage"],

Cell[TextData[{
  " in numerical models",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Linkage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage"],

Cell[TextData[{
  "Linkage disequilibrium",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage disequilibrium"],

Cell[TextData[{
  "LinkedRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "LinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LinkedRecombination"],

Cell[TextData[{
  "ListToGenealogy",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "ListToGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ListToGenealogy"],

Cell[TextData[{
  "ListToMatrix",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "ListToMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ListToMatrix"],

Cell[TextData[{
  "Location",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Location"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Location"],

Cell[TextData[{
  "Locations",
  ",",
  " ",
  ButtonBox["Locations",
    ButtonData:>{"Locations", "Locations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Locations"],

Cell[TextData[{
  "LocusNames",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "LocusNames"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LocusNames"],

Cell[TextData[{
  "LogLikelihoodDisequilibrium",
  ",",
  " ",
  ButtonBox["Likelihood",
    ButtonData:>{"Likelihood", "LogLikelihoodDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodDisequilibrium"],

Cell[TextData[{
  "LogLikelihoodDisequilibriumReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "LogLikelihoodDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodDisequilibriumReduced"],

Cell[TextData[{
  "LogLikelihoodTest",
  ",",
  " ",
  ButtonBox["Likelihood tests",
    ButtonData:>{"Likelihood tests", "LogLikelihoodTest"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodTest"],

Cell[TextData[{
  "Log-linear models",
  ",",
  " ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Log-linear models"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Log-linear models"],

Cell[TextData[{
  "Long et al 1995",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Long et al 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Long et al 1995"],

Cell[TextData[{
  "LowerOffDiagonal",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "LowerOffDiagonal"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LowerOffDiagonal"],

Cell[TextData[{
  "MacCallum 1994",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "MacCallum 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MacCallum 1994"],

Cell[TextData[{
  "MacCallum et al. 1998",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "MacCallum et al 1998"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MacCallum et al. 1998"],

Cell[TextData[{
  "MakeCline",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeCline"],

Cell[TextData[{
  "  for genotype frequencies",
  ", ",
  ButtonBox["Recursions: setting up a cline",
    ButtonData:>{"Recursions: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeCline"],

Cell[TextData[{
  "MakeDiploid",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDiploid"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDiploid"],

Cell[TextData[{
  "MakeDistanceList",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "MakeDistanceList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDistanceList"],

Cell[TextData[{
  "MakeDistances",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "MakeDistances"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDistances"],

Cell[TextData[{
  "MakeFitnessSet",
  ",",
  " ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "MakeFitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeFitnessSet"],

Cell[TextData[{
  " with multiple alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeFitnessSet"],

Cell[TextData[{
  "MakeGenealogy",
  ",",
  " ",
  ButtonBox["Making a genealogy",
    ButtonData:>{"Making a genealogy", "MakeGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeGenealogy"],

Cell[TextData[{
  "MakeGenealogyPlot",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "MakeGenealogyPlot"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeGenealogyPlot"],

Cell[TextData[{
  "MakeHaploid",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeHaploid"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeHaploid"],

Cell[TextData[{
  "MakeIndividuals",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: converting",
    ButtonData:>{"Allele frequencies: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeIndividuals"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeIndividuals"],

Cell[TextData[{
  "MakeOneWayTable",
  ",",
  " ",
  ButtonBox["Single-locus tables",
    ButtonData:>{"Single-locus tables", "MakeOneWayTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeOneWayTable"],

Cell[TextData[{
  "MakePairwiseTable",
  ",",
  " ",
  ButtonBox["Pairwise tables",
    ButtonData:>{"Pairwise tables", "MakePairwiseTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePairwiseTable"],

Cell[TextData[{
  "MakePopulation",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePopulation"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "MakePopulation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: representation",
    ButtonData:>{"Symmetric model: representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePopulation"],

Cell[TextData[{
  "MakeSelectionCoefficient",
  ",",
  " ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeSelectionCoefficient"],

Cell[TextData[{
  " with multiple alleles",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with two alleles",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeSelectionCoefficient"],

Cell[TextData[{
  "Mangel & Hilborn 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Mangel & Hilborn 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mangel & Hilborn 1996"],

Cell[TextData[{
  "Marginal fitness",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Marginal fitness"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Marginal fitness"],

Cell[TextData[{
  "MarginalTable",
  ",",
  " ",
  ButtonBox["Marginal tables",
    ButtonData:>{"Marginal tables", "MarginalTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalTable"],

Cell[TextData[{
  "MarginalW",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalW"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalW"],

Cell[TextData[{
  "MaternalLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MaternalLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MaternalLoci"],

Cell[TextData[{
  "MatrixGamma",
  ",",
  " ",
  ButtonBox["Fast calculations",
    ButtonData:>{"Fast calculations", "MatrixGamma"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixGamma"],

Cell[TextData[{
  "MatrixToGenealogy",
  ",",
  " ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", "MatrixToGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixToGenealogy"],

Cell[TextData[{
  "MatrixToList",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "MatrixToList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixToList"],

Cell[TextData[{
  "MeanContribution",
  ",",
  " \[GothicM], \[AliasIndicator]gom\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "MeanContribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanContribution"],

Cell[TextData[{
  "Mean fitness",
  ",",
  " ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mean fitness"],

Cell[TextData[{
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mean fitness"],

Cell[TextData[{
  "MeanW",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanW"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanW"],

Cell[TextData[{
  "Meiosis",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Meiosis"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Meiosis"],

Cell[TextData[{
  " in numerical models",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Meiosis"],

Cell[TextData[{
  "MethodC",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MethodC"],

Cell[TextData[{
  "MethodP",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MethodP"],

Cell[TextData[{
  "Metropolis algorithm",
  ",",
  " estimating D",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Metropolis algorithm"],

Cell[TextData[{
  "MetropolisDisequilibrium",
  ",",
  " ",
  ButtonBox["Estimating moments",
    ButtonData:>{"Estimating moments", "MetropolisDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MetropolisDisequilibrium"],

Cell[TextData[{
  "MetropolisDisequilibriumReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MetropolisDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MetropolisDisequilibriumReduced"],

Cell[TextData[{
  "Metropolis et al. 1954",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Metropolis et al 1954"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Metropolis et al. 1954"],

Cell[TextData[{
  "MFromC",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MFromC"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MFromC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MFromC"],

Cell[TextData[{
  "Migrate",
  ",",
  " ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Migrate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migrate"],

Cell[TextData[{
  "MigrateExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrateExact"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrateExact"],

Cell[TextData[{
  "Migration",
  ",",
  " and cytoplasmic inheritance",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Cytonuclear associations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migration"],

Cell[TextData[{
  " and sexual selection",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Sexual selection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " context-dependent",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Context-dependent migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " example of",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotype-dependent",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Genotype-dependent migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of haploids",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Haploid migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of juvenile diploids",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Juvenile diploid migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of pollen",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of seeds",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with sindividuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migration"],

Cell[TextData[{
  "MigrationOrder",
  ",",
  "for genotype frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationOrder"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "MigrationOrder"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationOrder"],

Cell[TextData[{
  "MigrationRate",
  ",",
  " \[CapitalMu], \[AliasIndicator]M\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationRate"],

Cell[TextData[{
  "MigrationSet",
  ",",
  " \[DoubleStruckCapitalM], \[AliasIndicator]dsM\[AliasIndicator]",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "MigrationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationSet"],

Cell[TextData[{
  "Missing data",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Missing data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Missing data"],

Cell[TextData[{
  "Moment",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Moment"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Moments and cumulants",
    ButtonData:>{"Moments and cumulants", "Moment"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moment"],

Cell[TextData[{
  "MomentAfterMigration",
  ",",
  " ",
  ButtonBox["Migration in admixture models",
    ButtonData:>{"Migration in admixture models", "MomentAfterMigration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentAfterMigration"],

Cell[TextData[{
  "MomentAfterRecombination",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", 
      "MomentAfterRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentAfterRecombination"],

Cell[TextData[{
  "MomentEquilibrium",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "MomentEquilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentEquilibrium"],

Cell[TextData[{
  "MomentGeneratingFunction",
  ",",
  " deriving",
  ", ",
  ButtonBox["Deriving recursions for the MGF",
    ButtonData:>{"Deriving recursions for the MGF", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentGeneratingFunction"],

Cell[TextData[{
  " examples",
  ", ",
  ButtonBox["Examples of the MGF",
    ButtonData:>{"Examples of the MGF", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genealogies",
  ", ",
  ButtonBox["Calculating the MGF",
    ButtonData:>{"Calculating the MGF", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over topologies",
  ", ",
  ButtonBox["Calculating over topologies",
    ButtonData:>{"Calculating over topologies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentGeneratingFunction"],

Cell[TextData[{
  "MomentLimits",
  ",",
  " ",
  ButtonBox["Constraints on moments",
    ButtonData:>{"Constraints on moments", "MomentLimits"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentLimits"],

Cell[TextData[{
  "MomentNew",
  ",",
  " ",
  ButtonBox["Iteration",
    ButtonData:>{"Iteration", "MomentNew"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentNew"],

Cell[TextData[{
  "MomentReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MomentReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentReduced"],

Cell[TextData[{
  "Moments",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "7.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moments"],

Cell[TextData[{
  " estimating the matrix of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "Estimating the matrix"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " extension to description by",
  ", ",
  ButtonBox["References",
    ButtonData:>{"References", "Haber 1984"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " extension to estimation of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "MLE"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " full description by",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " matrix of",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] full matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "ML estimation of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "simple method"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reduced description by",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " simple method for estimating",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "extension to families"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moments"],

Cell[TextData[{
  "MomentsFromG",
  ",",
  " ",
  ButtonBox["Moments from genotype frequencies",
    ButtonData:>{"Moments from genotype frequencies", "MomentsFromG"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentsFromG"],

Cell[TextData[{
  "MomentSimple",
  ",",
  " ",
  ButtonBox["Simplifying the moments",
    ButtonData:>{"Simplifying the moments", "MomentSimple"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentSimple"],

Cell[TextData[{
  "MonteCarloGriffithsTavare",
  ",",
  " ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "MonteCarloGriffithsTavare"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MonteCarloGriffithsTavare"],

Cell[TextData[{
  "MonteCarloProbability",
  ",",
  " ",
  ButtonBox["Estimating the probability",
    ButtonData:>{"Estimating the probability", "MonteCarloProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MonteCarloProbability"],

Cell[TextData[{
  "Mortality",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Mortality"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mortality"],

Cell[TextData[{
  "MostRecentCommonAncestor",
  ",",
  " ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "MostRecentCommonAncestor"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MostRecentCommonAncestor"],

Cell[TextData[{
  "MToC",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MToC"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MToC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MToC"],

Cell[TextData[{
  "MToCEquations",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MToCEquations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MToCEquations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MToCEquations"],

Cell[TextData[{
  "Muddle",
  ",",
  " ",
  ButtonBox["Muddling and subdividing sets",
    ButtonData:>{"Muddling and subdividing sets", "Muddle"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Muddle"],

Cell[TextData[{
  "Multilocus algebra",
  ",",
  " basic notation",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Basic notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus algebra"],

Cell[TextData[{
  " fitness",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction to",
  ", ",
  ButtonBox["Introduction to multilocus algebra",
    ButtonData:>{"Introduction to multilocus algebra", "1.1"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Introduction to multilocus algebra",
    ButtonData:>{"Introduction to multilocus algebra", 
      "Multilocus`Multilocus`"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages in life cycle",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Technicalities"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus algebra"],

Cell[TextData[{
  "Multilocus MS",
  ",",
  " relation with",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Multilocus MS"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus MS"],

Cell[TextData[{
  "Multilocus notation",
  ",",
  " bugs",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Multilocus notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus notation"],

Cell[TextData[{
  "Multinomial sampling",
  ",",
  " without replacement",
  ", ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", 
      "Multinomial sampling wo replacement"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multinomial sampling"],

Cell[TextData[{
  "MultinomialSamplingProbability",
  ",",
  " ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", 
      "MultinomialSamplingProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MultinomialSamplingProbability"],

Cell[TextData[{
  "Multiple alleles",
  ",",
  " and selection coefficients",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple alleles"],

Cell[TextData[{
  " MakeFitnessSet",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " mutation",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " representation of",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " selection on",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple alleles"],

Cell[TextData[{
  "Multiple arguments",
  ",",
  " in PopulationExpectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "multiple arguments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple arguments"],

Cell[TextData[{
  "Multiplicative models",
  ",",
  " in negative binomial",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "multiplicative models"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiplicative models"],

Cell[TextData[{
  "MUS",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MUS"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MUS"],

Cell[TextData[{
  "Mutate",
  ",",
  " allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: mutation",
    ButtonData:>{"Allele frequencies: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutate"],

Cell[TextData[{
  "genotype frequencies",
  ", ",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " individuals",
  ", ",
  ButtonBox["Simulating individuals: mutation",
    ButtonData:>{"Simulating individuals: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric model",
  ", ",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutate"],

Cell[TextData[{
  "MutateCompiled",
  ",",
  " ",
  ButtonBox["Allele frequencies: mutation",
    ButtonData:>{"Allele frequencies: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: mutation",
    ButtonData:>{"Simulating individuals: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutateCompiled"],

Cell[TextData[{
  "Mutation",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Mutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutation"],

Cell[TextData[{
  " Mutations, in multilocus genetics",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for BiallelicMutation",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies: reproduction",
    ButtonData:>{"Allele frequencies: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: reproduction",
    ButtonData:>{"Recursions: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutation"],

Cell[TextData[{
  "MutationInterval",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "MutationInterval"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationInterval"],

Cell[TextData[{
  "MutationLabels",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "MutationLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationLabels"],

Cell[TextData[{
  "MutationOrigin",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "MutationOrigin"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationOrigin"],

Cell[TextData[{
  "MutationRate",
  ",",
  " ",
  ButtonBox["Drawing a genealogy",
    ButtonData:>{"Drawing a genealogy", "MutationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationRate"],

Cell[TextData[{
  "Mutations",
  ",",
  " in genealogies",
  ", ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "Mutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutations"],

Cell[TextData[{
  "MVariables",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MVariables"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MVariables"],

Cell[TextData[{
  "Negative binomial",
  ",",
  " c<1",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "c<1"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Negative binomial"],

Cell[TextData[{
  " compiled",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " multiplicative models",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "multiplicative models"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " normalisation",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalisation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " timings",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Timings"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Negative binomial"],

Cell[TextData[{
  "NegativeBinomialLogLikelihood",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", 
      "NegativeBinomialLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeBinomialLogLikelihood"],

Cell[TextData[{
  "NegativeBinomialMLE",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "NegativeBinomialMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeBinomialMLE"],

Cell[TextData[{
  "NegativeHypergeometricDistribution",
  ",",
  " ",
  ButtonBox["Negative hypergeometric distribution",
    ButtonData:>{"Negative hypergeometric distribution", 
      "NegativeHypergeometricDistribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeHypergeometricDistribution"],

Cell[TextData[{
  "NeighbourArray",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "NeighbourArray"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NeighbourArray"],

Cell[TextData[{
  "Neighbours",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Neighbours"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Neighbours"],

Cell[TextData[{
  "NetCovariance",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "NetCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetCovariance"],

Cell[TextData[{
  "NetFecundity",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NetFecundity"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetFecundity"],

Cell[TextData[{
  "NetMortality",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NetMortality"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetMortality"],

Cell[TextData[{
  "NetRecombination",
  ",",
  " ",
  ButtonBox["Linkage",
    ButtonData:>{"Linkage", "NetRecombination"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Linkage in families",
    ButtonData:>{"Linkage in families", "NetRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetRecombination"],

Cell[TextData[{
  " in multilocus genetics",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "NetRecombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "NetRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetRecombination"],

Cell[TextData[{
  "Neutral marker",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Neutral marker"],

Cell[TextData[{
  "NeutralRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "NeutralRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NeutralRepresentations"],

Cell[TextData[{
  "NewGametes",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewGametes"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Mutation option",
  ", ",
  ButtonBox["Allele frequencies: reproduction",
    ButtonData:>{"Allele frequencies: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: reproduction",
    ButtonData:>{"Recursions: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " truncation selection",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", 
      "TruncationSelection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewGametes"],

Cell[TextData[{
  "NewS",
  ",",
  " ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "NewS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewS"],

Cell[TextData[{
  "Node",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "Node"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "Node"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Node"],

Cell[TextData[{
  "NodeFunction",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "NodeFunction"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeFunction"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeFunction"],

Cell[TextData[{
  " option for ExactProbability",
  ", ",
  ButtonBox["Exact probability",
    ButtonData:>{"Exact probability", "NodeFunction"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeFunction"],

Cell[TextData[{
  "NodeLabels",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeLabels"],

Cell[TextData[{
  "NodeOffset",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeOffset"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeOffset"],

Cell[TextData[{
  "Nodes",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "Nodes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Nodes"],

Cell[TextData[{
  "NonMendelian",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonMendelian"],

Cell[TextData[{
  " examples of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonMendelian"],

Cell[TextData[{
  "NonNeutralRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "NonNeutralRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonNeutralRepresentations"],

Cell[TextData[{
  "NonSymmetricRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "NonSymmetricRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonSymmetricRepresentations"],

Cell[TextData[{
  "Normalisation",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalisation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Normalisation"],

Cell[TextData[{
  "Normalised",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Normalised"],

Cell[TextData[{
  "Notation",
  ",",
  " clearing definitions",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "Clearing definitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation"],

Cell[TextData[{
  " data",
  ", ",
  ButtonBox["Notation for genetic data",
    ButtonData:>{"Notation for genetic data", "NotationPackage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining new",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "Defining new notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotypes",
  ", ",
  ButtonBox["Notation",
    ButtonData:>{"Notation", "NotationPackage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation"],

Cell[TextData[{
  "Notation Package",
  ",",
  " ",
  ButtonBox["Notation package",
    ButtonData:>{"Notation package", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation Package"],

Cell[TextData[{
  "NumberedLink",
  ",",
  " ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "NumberedLink"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberedLink"],

Cell[TextData[{
  "Numbering",
  ",",
  " aesthetics",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Aesthetics"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numbering"],

Cell[TextData[{
  " automatic",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "7.2"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notes on",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Notes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving links",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Saving the links"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numbering"],

Cell[TextData[{
  "NumberOfCoalescences",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "NumberOfCoalescences"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfCoalescences"],

Cell[TextData[{
  "NumberOfGenes",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenes"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenes"],

Cell[TextData[{
  "NumberOfGenesTable",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfGenesTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenesTable"],

Cell[TextData[{
  "NumberOfIndividuals",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfIndividuals"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NumberOfIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfIndividuals"],

Cell[TextData[{
  "NumberOfIndividualsTable",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfIndividualsTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfIndividualsTable"],

Cell[TextData[{
  "NumberOfLineages",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "NumberOfLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfLineages"],

Cell[TextData[{
  "NumberOfLoci",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfLoci"],

Cell[TextData[{
  "NumberOfMutations",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "NumberOfMutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfMutations"],

Cell[TextData[{
  "NumberOfPossibleCoalescences",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "NumberOfPossibleCoalescences"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfPossibleCoalescences"],

Cell[TextData[{
  "NumberOfSamplePartitions",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "NumberOfSamplePartitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfSamplePartitions"],

Cell[TextData[{
  "NumberOfSetPartitions",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "NumberOfSetPartitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfSetPartitions"],

Cell[TextData[{
  "NumericalModel",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "NumericalModel"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumericalModel"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "NumericalModel"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumericalModel"],

Cell[TextData[{
  "Numerical models",
  ",",
  " genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numerical models"],

Cell[TextData[{
  " of allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " overview",
  ", ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " problems",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric",
  ", ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numerical models"],

Cell[TextData[{
  "Observable genotype",
  ",",
  " ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Observable genotype"],

Cell[TextData[{
  "Obsolete",
  ",",
  " Combine",
  ", ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Separate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Obsolete"],

Cell[TextData[{
  " CumulantReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "CumulantReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidConstraints",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidConstraints"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidGenotypeFrequencyReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidGenotypeFrequencyTable",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Estimating D",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " fitness",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Obsolete notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " FullGenotypeFrequencyReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " FullGenotypeFrequencyTable",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " GenotypeFrequencyArguments",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "GenotypeFrequencyArguments"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " HaploidConstraints",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "HaploidConstraints"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " InitialStepReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "InitialStepReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " IntervalCombine",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalCombine"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " IntervalPosition",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalPosition"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " LogLikelihoodDisequilibriumReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "LogLikelihoodDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MetropolisDisequilibriumReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MetropolisDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MomentReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MomentReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Obsolete"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Separate",
  ", ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Combine"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " SetPartition",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SetPartition"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Obsolete"],

Cell[TextData[{
  "Offspring",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Offspring"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Offspring"],

Cell[TextData[{
  "Ordered",
  ",",
  "option for PartitionSet",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "Ordered"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ordered"],

Cell[TextData[{
  "Orive & Barton 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Orive & Barton 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Orive & Barton 1999"],

Cell[TextData[{
  "OtherSex",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "OtherSex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"OtherSex"],

Cell[TextData[{
  "Packages",
  ",",
  " help",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Packages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Packages"],

Cell[TextData[{
  " overview of",
  ", ",
  ButtonBox["Overview of the packages",
    ButtonData:>{"Overview of the packages", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving using PackageSaver",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " setting up",
  ", ",
  ButtonBox["Setting up the packages",
    ButtonData:>{"Setting up the packages", "Setting up the packages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Special notation",
    ButtonData:>{"Special notation", "Setting up packages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " versions of",
  ", ",
  ButtonBox["Versions",
    ButtonData:>{"Versions", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Packages"],

Cell[TextData[{
  "PackageSaver",
  ",",
  " ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PackageSaver"],

Cell[TextData[{
  "Partitions",
  ",",
  " of sets",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "PartitionSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Partitions"],

Cell[TextData[{
  " standard form",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartition"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " testing for standard form",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartitionQ"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Partitions"],

Cell[TextData[{
  "PartitionSet",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "PartitionSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PartitionSet"],

Cell[TextData[{
  "Paternal inheritance",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Paternal inheritance"],

Cell[TextData[{
  "PaternalLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaternalLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaternalLoci"],

Cell[TextData[{
  "PatternFree",
  ",",
  " ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "PatternFree"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PatternFree"],

Cell[TextData[{
  "Permutations",
  ",",
  "option for PartitionSet",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "Permutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Permutations"],

Cell[TextData[{
  "Permutations in defining coefficients",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Permutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Permutations in defining coefficients"],

Cell[TextData[{
  "Phenotypes",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Phenotypes"],

Cell[TextData[{
  "Phipps & Brill 1995",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Phipps & Brill 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Phipps & Brill 1995"],

Cell[TextData[{
  "Ploidy",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "Ploidy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ploidy"],

Cell[TextData[{
  "PloidyWeightList",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "PloidyWeightList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PloidyWeightList"],

Cell[TextData[{
  "PlotGenealogy",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "PlotGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PlotGenealogy"],

Cell[TextData[{
  "PlotLogL",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "PlotLogL"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PlotLogL"],

Cell[TextData[{
  "PopulationDisequilibrium",
  ",",
  "\[GothicCapitalC], \[AliasIndicator]goC\[AliasIndicator]",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationDisequilibrium"],

Cell[TextData[{
  "PopulationExpectation",
  ",",
  " ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationExpectation"],

Cell[TextData[{
  " multiple arguments",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "multiple arguments"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationExpectation"],

Cell[TextData[{
  "PopulationRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "PopulationRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationRepresentations"],

Cell[TextData[{
  "Position",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "position"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "position"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Position"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "position"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Contexts and positions"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Position"],

Cell[TextData[{
  "PositionsList",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PositionsList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PositionsList"],

Cell[TextData[{
  "PositionsMatrix",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PositionsMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PositionsMatrix"],

Cell[TextData[{
  "PossibleCoalescenceOrder",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "PossibleCoalescenceOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleCoalescenceOrder"],

Cell[TextData[{
  "PossibleDiploidGenotypes",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PossibleDiploidGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleDiploidGenotypes"],

Cell[TextData[{
  "PossibleGenotypes",
  ",",
  " ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "PossibleGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleGenotypes"],

Cell[TextData[{
  "PowerF",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PowerF"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "PowerF"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PowerF"],

Cell[TextData[{
  "PresentOneWayTable",
  ",",
  " ",
  ButtonBox["Single-locus tables",
    ButtonData:>{"Single-locus tables", "PresentOneWayTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentOneWayTable"],

Cell[TextData[{
  "PresentPairwiseTable",
  ",",
  " ",
  ButtonBox["Pairwise tables",
    ButtonData:>{"Pairwise tables", "PresentPairwiseTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentPairwiseTable"],

Cell[TextData[{
  "PresentResults",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "PresentResults"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentResults"],

Cell[TextData[{
  "Principal components",
  ",",
  " Bennett's measure of disequilibrium",
  ", ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Bennett"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Principal components"],

Cell[TextData[{
  "PrintDetails",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "PrintDetails"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PrintDetails"],

Cell[TextData[{
  "Problems",
  ",",
  " avoid integers",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Avoid integers"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Problems"],

Cell[TextData[{
  " redefining fitness",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Allele frequencies"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Redefining fitness"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "StoreResults (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Problems"],

Cell[TextData[{
  "Products",
  ",",
  " multiple",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Multiple products"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Products"],

Cell[TextData[{
  "ProductSum",
  ",",
  " ",
  ButtonBox["ProductSum",
    ButtonData:>{"ProductSum", "ProductSum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ProductSum"],

Cell[TextData[{
  " over sets",
  ", ",
  ButtonBox["ProductSum",
    ButtonData:>{"ProductSum", "ProductSum over sets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ProductSum"],

Cell[TextData[{
  "QLE",
  ",",
  " haploid selection example",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", "QLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"QLE"],

Cell[TextData[{
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"QLE"],

Cell[TextData[{
  "Quasi-linkage equilibrium",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Quasi-linkage equilibrium"],

Cell[TextData[{
  "RandomBottleneckedGenealogy",
  ",",
  " ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", "RandomBottleneckedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomBottleneckedGenealogy"],

Cell[TextData[{
  "RandomCoalescenceOrder",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "RandomCoalescenceOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCoalescenceOrder"],

Cell[TextData[{
  "RandomCoalescenceTimes",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", 
      "RandomCoalescenceTimes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCoalescenceTimes"],

Cell[TextData[{
  "RandomCum",
  ",",
  " ",
  ButtonBox["Sampling from arbitrary distributions",
    ButtonData:>{"Sampling from arbitrary distributions", "RandomCum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCum"],

Cell[TextData[{
  "Random drift",
  ",",
  " changing reference points",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Changing reference points"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random drift"],

Cell[TextData[{
  " cumulants and moments",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " describing a distribution",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Describing a distribution"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " equations for the moments",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Equations for the moments"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in a cline",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: drift",
    ButtonData:>{"Allele frequencies: drift", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of genotype frequencies",
  ", ",
  ButtonBox["Recursions: drift",
    ButtonData:>{"Recursions: drift", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population disequilibrium",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population expectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population expectations",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Wright-Fisher sampling",
  ", ",
  ButtonBox["Wright-Fisher sampling",
    ButtonData:>{"Wright-Fisher sampling", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random drift"],

Cell[TextData[{
  "RandomDrift",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: drift",
    ButtonData:>{"Recursions: drift", "RandomDrift"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomDrift"],

Cell[TextData[{
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "RandomDrift"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomDrift"],

Cell[TextData[{
  "RandomFamilies",
  ",",
  " ",
  ButtonBox["Random families",
    ButtonData:>{"Random families", "RandomFamilies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamilies"],

Cell[TextData[{
  "RandomFamily",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "RandomFamily"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamily"],

Cell[TextData[{
  " segregation ratio",
  ", ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamily"],

Cell[TextData[{
  "Random genealogies",
  ",",
  " population bottlenecks",
  ", ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random genealogies"],

Cell[TextData[{
  "RandomGenealogy",
  ",",
  " ",
  ButtonBox["Drawing a genealogy",
    ButtonData:>{"Drawing a genealogy", "RandomGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomGenealogy"],

Cell[TextData[{
  "RandomList",
  ",",
  " ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "RandomList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomList"],

Cell[TextData[{
  " sampling without replacement",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomList"],

Cell[TextData[{
  "Random lists",
  ",",
  " compiled",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random lists"],

Cell[TextData[{
  "RandomMating",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "RandomMating"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomMating"],

Cell[TextData[{
  "RandomMultinomial",
  ",",
  " ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", "RandomMultinomial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomMultinomial"],

Cell[TextData[{
  "RandomPreviousFamily",
  ",",
  " ",
  ButtonBox["Random families",
    ButtonData:>{"Random families", "RandomPreviousFamily"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomPreviousFamily"],

Cell[TextData[{
  "Random sampling",
  ",",
  " ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Random sampling"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random sampling"],

Cell[TextData[{
  " example in estimating D",
  ", ",
  ButtonBox["Sampling example",
    ButtonData:>{"Sampling example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of genealogies",
  ", ",
  ButtonBox["Sampling genealogies",
    ButtonData:>{"Sampling genealogies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random sampling"],

Cell[TextData[{
  "RandomSet",
  ",",
  " ",
  ButtonBox["Random sets",
    ButtonData:>{"Random sets", "RandomSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomSet"],

Cell[TextData[{
  "Random union",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Random union"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random union"],

Cell[TextData[{
  " in admixture models",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "RandomUnionObsolete"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random union"],

Cell[TextData[{
  "RandomUnion",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnion"],

Cell[TextData[{
  "RandomUnionMethod",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnionMethod"],

Cell[TextData[{
  "RandomUnionObsolete",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnionObsolete"],

Cell[TextData[{
  "Random walk",
  ",",
  " in estimating D",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random walk"],

Cell[TextData[{
  "Recombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Recombination"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Recombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombination"],

Cell[TextData[{
  " across several linked loci",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "NetRecombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " between linked loci",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "LinkedRecombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " context-dependent",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Context-dependent recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotype-dependent",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Genotype-dependent recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in admixture models",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "Recombined"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " no linkage",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "UnlinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombination"],

Cell[TextData[{
  "RecombinationRate",
  ",",
  " \[GothicR], \[AliasIndicator]gor\[AliasIndicator]",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinationRate"],

Cell[TextData[{
  "RecombinationSet",
  ",",
  " \[DoubleStruckCapitalR], \[AliasIndicator]dsR\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinationSet"],

Cell[TextData[{
  "Recombined",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "Recombined"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombined"],

Cell[TextData[{
  "ReducedData",
  ",",
  " ",
  ButtonBox["Simplifying a dataset",
    ButtonData:>{"Simplifying a dataset", "ReducedData"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReducedData"],

Cell[TextData[{
  "ReferencePoint",
  ",",
  " \[WeierstrassP], \[AliasIndicator]wp\[AliasIndicator]",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePoint"],

Cell[TextData[{
  "ReferencePointMean",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointMean"],

Cell[TextData[{
  " cytoplasmic inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " paternal inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sex-linkage",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointMean"],

Cell[TextData[{
  "ReferencePointSame",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointSame"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointSame"],

Cell[TextData[{
  "ReferencePointZero",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointZero"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointZero"],

Cell[TextData[{
  "Reference values",
  ",",
  " ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Reference values"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reference values"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Reference values"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Describing genotypes and populations"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reference values"],

Cell[TextData[{
  "RemoveTag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "RemoveTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RemoveTag"],

Cell[TextData[{
  "Repeat",
  ",",
  " ",
  ButtonBox["Repeated elements",
    ButtonData:>{"Repeated elements", "Repeat"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Repeat"],

Cell[TextData[{
  "Replace",
  ",",
  " ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Replace"],

Cell[TextData[{
  "ReplaceAllSpecial",
  ",",
  " |.",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReplaceAllSpecial"],

Cell[TextData[{
  "ReplaceRepeatedSpecial",
  ",",
  " ||.",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceRepeatedSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReplaceRepeatedSpecial"],

Cell[TextData[{
  "Representations",
  ",",
  " converting between",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Representations"],

Cell[TextData[{
  "of populations",
  ", ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "Representing the population"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Representations"],

Cell[TextData[{
  "Reproduction",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reproduction"],

Cell[TextData[{
  "Reverse",
  ",",
  " ",
  ButtonBox["Sorting",
    ButtonData:>{"Sorting", "Reverse"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reverse"],

Cell[TextData[{
  "RootedGenealogy",
  ",",
  " ",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "RootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RootedGenealogy"],

Cell[TextData[{
  "Rules",
  ",",
  " ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Rules"],

Cell[TextData[{
  " non-evaluation of",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Rules"],

Cell[TextData[{
  "SampleCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "SampleCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SampleCovariance"],

Cell[TextData[{
  "SampleIndividuals",
  ",",
  " ",
  ButtonBox["Sampling individuals",
    ButtonData:>{"Sampling individuals", "SampleIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SampleIndividuals"],

Cell[TextData[{
  "SamplePartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SamplePartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SamplePartition"],

Cell[TextData[{
  "Sampling",
  ",",
  " without replacement",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sampling"],

Cell[TextData[{
  "Scripts and faces",
  ",",
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Scripts and faces"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Scripts and faces"],

Cell[TextData[{
  "SegregationRatio",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SegregationRatio"],

Cell[TextData[{
  "SelectContext",
  ",",
  " \[CircleDot], \[AliasIndicator]c.\[AliasIndicator]",
  ", ",
  ButtonBox["Selecting contexts",
    ButtonData:>{"Selecting contexts", "SelectContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectContext"],

Cell[TextData[{
  "SelectIndividuals",
  ",",
  " ",
  ButtonBox["Selecting subsets",
    ButtonData:>{"Selecting subsets", "SelectIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectIndividuals"],

Cell[TextData[{
  "Selection",
  ",",
  " ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Selection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection"],

Cell[TextData[{
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on genotype frequencies",
  ", ",
  ButtonBox["Recursions: fitnesses",
    ButtonData:>{"Recursions: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on multiple alleles",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Technicalities"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " truncation",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "TruncationSelection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with two alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection"],

Cell[TextData[{
  "SelectionCoefficient",
  ",",
  " \[GothicA], \[AliasIndicator]goa\[AliasIndicator]",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionCoefficient"],

Cell[TextData[{
  "Selection coefficients",
  ",",
  " as defined in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Permutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection coefficients"],

Cell[TextData[{
  " making",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with multiple alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection coefficients"],

Cell[TextData[{
  "SelectionExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionExact"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: fitnesses",
    ButtonData:>{"Recursions: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionExact"],

Cell[TextData[{
  "Selection on diploids",
  ",",
  " a method to avoid",
  ", ",
  ButtonBox["A method to avoid",
    ButtonData:>{"A method to avoid", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection on diploids"],

Cell[TextData[{
  " cautionary notes",
  ", ",
  ButtonBox["Cautionary notes",
    ButtonData:>{"Cautionary notes", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete life cycle",
  ", ",
  ButtonBox["Complete life cyle",
    ButtonData:>{"Complete life cyle", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " explaining the rules",
  ", ",
  ButtonBox["Explaining the rules",
    ButtonData:>{"Explaining the rules", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction",
  ", ",
  ButtonBox["Introduction to selection on diploids",
    ButtonData:>{"Introduction to selection on diploids", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " life cycle",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection on diploids"],

Cell[TextData[{
  "SelectionRate",
  ",",
  " \[GothicS],\[AliasIndicator]gos\[AliasIndicator]",
  ", ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SelectionRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionRate"],

Cell[TextData[{
  "SelectLoci",
  ",",
  " ",
  ButtonBox["Selecting subsets",
    ButtonData:>{"Selecting subsets", "SelectLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectLoci"],

Cell[TextData[{
  "Selfing",
  ",",
  " ",
  ButtonBox["Selfing",
    ButtonData:>{"Selfing", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selfing"],

Cell[TextData[{
  "Separate",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Separate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Separate"],

Cell[TextData[{
  "Servedio",
  ",",
  " Maria",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", "Servedio"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Servedio"],

Cell[TextData[{
  "Set",
  ",",
  " of all positions affecting a trait, \[DoubleStruckCapitalZ], \
\[AliasIndicator]dsZ\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set"],

Cell[TextData[{
  " of all positions in genome, \[DoubleStruckCapitalG], \[AliasIndicator]dsG\
\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set"],

Cell[TextData[{
  "Set manipulation",
  ",",
  " overview",
  ", ",
  ButtonBox["Overview of set manipulation",
    ButtonData:>{"Overview of set manipulation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set manipulation"],

Cell[TextData[{
  "SetPartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SetPartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SetPartition"],

Cell[TextData[{
  "Sets of loci",
  ",",
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets of loci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sets of loci"],

Cell[TextData[{
  "Sex",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Sex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex"],

Cell[TextData[{
  "Sex linkage",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex linkage"],

Cell[TextData[{
  " examples of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex linkage"],

Cell[TextData[{
  "SexOfOrigin",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "SexOfOrigin"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SexOfOrigin"],

Cell[TextData[{
  "Sexual selection",
  ",",
  " ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Sexual selection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sexual selection"],

Cell[TextData[{
  " and migration",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Sexual selection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete life cycle",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Complete cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining fitnesses",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Sexual selection by female choice"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "on haploids",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " recombination",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " subtle problem",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "subtle problem"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sexual selection"],

Cell[TextData[{
  "ShortContext",
  ",",
  " ",
  ButtonBox["Abbreviating contexts",
    ButtonData:>{"Abbreviating contexts", "ShortContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ShortContext"],

Cell[TextData[{
  "SigmaMatrix",
  ",",
  " ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "SigmaMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SigmaMatrix"],

Cell[TextData[{
  "SignMask",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "SignMask"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SignMask"],

Cell[TextData[{
  "SimplifyAddUp",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "SimplifyAddUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyAddUp"],

Cell[TextData[{
  "SimplifyAddUpQ",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "SimplifyAddUpQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyAddUpQ"],

Cell[TextData[{
  "SimplifyFamilies",
  ",",
  " ",
  ButtonBox["Probabilities",
    ButtonData:>{"Probabilities", "SimplifyFamilies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyFamilies"],

Cell[TextData[{
  "Simulating individuals",
  ",",
  " recursions",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Simulating individuals"],

Cell[TextData[{
  " representation",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reproduction",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Simulating individuals"],

Cell[TextData[{
  "SizeOfGenealogyPlot",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "SizeOfGenealogyPlot"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SizeOfGenealogyPlot"],

Cell[TextData[{
  "Slatkin & Excoffier 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Slatkin & Excoffier 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Slatkin & Excoffier 1996"],

Cell[TextData[{
  "SlowChange",
  ",",
  " ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SlowChange"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SlowChange"],

Cell[TextData[{
  "SortByClass",
  ",",
  " ",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "SortByClass"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByClass"],

Cell[TextData[{
  " genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "SortByClass"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByClass"],

Cell[TextData[{
  "SortByHead",
  ",",
  " ",
  ButtonBox["Sorting",
    ButtonData:>{"Sorting", "SortByHead"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByHead"],

Cell[TextData[{
  "SpatialCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "SpatialCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SpatialCovariance"],

Cell[TextData[{
  "Spatially varying selection",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Spatially varying selection",
    ButtonData:>{"Spatially varying selection", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Spatially varying selection"],

Cell[TextData[{
  "Special notation",
  ",",
  " ",
  ButtonBox["Special notation",
    ButtonData:>{"Special notation", "Defining notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Special notation"],

Cell[TextData[{
  "SplitSet",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SplitSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SplitSet"],

Cell[TextData[{
  "Stabilising selection",
  ",",
  " change in D",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Change in D"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stabilising selection"],

Cell[TextData[{
  " change in mean",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Change in mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Defining fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", 
      "Natural selection on an additive polygenic trait"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "mean fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Mean fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "New mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "New mean fitness"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stabilising selection"],

Cell[TextData[{
  "Stability",
  ",",
  " of numerical models",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stability"],

Cell[TextData[{
  " of symmetric model",
  ", ",
  ButtonBox["Symmetric stability: outline",
    ButtonData:>{"Symmetric stability: outline", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stability"],

Cell[TextData[{
  "StabilityDirect",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", "StabilityDirect"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityDirect"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", "StabilityDirect"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityDirect"],

Cell[TextData[{
  "StabilityK",
  ",",
  " ",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", "StabilityK"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "StabilityK"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityK"],

Cell[TextData[{
  "StabilityKTable",
  ",",
  " ",
  ButtonBox["Symmetric stability: faster algorithms",
    ButtonData:>{"Symmetric stability: faster algorithms", "StabilityKTable"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityKTable"],

Cell[TextData[{
  "StabilityMatrix",
  ",",
  " ",
  ButtonBox["Making a stability matrix",
    ButtonData:>{"Making a stability matrix", "StabilityMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityMatrix"],

Cell[TextData[{
  "Stage",
  ",",
  " \[Sampi], \[AliasIndicator]sa\[AliasIndicator]",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stage"],

Cell[TextData[{
  "Stages",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stages"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Stages and contexts"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stages"],

Cell[TextData[{
  "StandardPartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StandardPartition"],

Cell[TextData[{
  "StandardPartitionQ",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartitionQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StandardPartitionQ"],

Cell[TextData[{
  "StartingStepSize",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "StartingStepSize"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StartingStepSize"],

Cell[TextData[{
  "Stepping-stone migration",
  ",",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", 
      "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone migration"],

Cell[TextData[{
  "Stepping-stone model",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", 
      "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone model"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "Nearest-neighbour migration"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone model"],

Cell[TextData[{
  "StoreExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreExact"],

Cell[TextData[{
  " for allele frequency clines",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequency clines",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreExact"],

Cell[TextData[{
  "StoreResults",
  ",",
  " option for GameteTable",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreResults"],

Cell[TextData[{
  " option for NewGametes",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " use when compiling",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "StoreResults (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreResults"],

Cell[TextData[{
  "StructuredArray",
  ",",
  " ",
  ButtonBox["Useful functions",
    ButtonData:>{"Useful functions", "StructuredArray"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredArray"],

Cell[TextData[{
  "StructuredInitialParameters",
  ",",
  " ",
  ButtonBox["Initial parameters",
    ButtonData:>{"Initial parameters", "StructuredInitialParameters"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredInitialParameters"],

Cell[TextData[{
  "StructuredLogLikelihood",
  ",",
  " ",
  ButtonBox["Likelihood of a structured model",
    ButtonData:>{"Likelihood of a structured model", 
      "StructuredLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredLogLikelihood"],

Cell[TextData[{
  "StructuredMLE",
  ",",
  " ",
  ButtonBox["Likelihood of a structured model",
    ButtonData:>{"Likelihood of a structured model", "StructuredMLE"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "StructuredMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredMLE"],

Cell[TextData[{
  "StructuredModel",
  ",",
  " ",
  ButtonBox["Useful functions",
    ButtonData:>{"Useful functions", "StructuredModel"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredModel"],

Cell[TextData[{
  "StructuredModelReduce",
  ",",
  " ",
  ButtonBox["Simplifying a model",
    ButtonData:>{"Simplifying a model", "StructuredModelReduce"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredModelReduce"],

Cell[TextData[{
  "Structured models",
  ",",
  " example",
  ", ",
  ButtonBox["Example data",
    ButtonData:>{"Example data", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Structured models"],

Cell[TextData[{
  " hierarchical analysis",
  ", ",
  ButtonBox["Hierarchical analysis",
    ButtonData:>{"Hierarchical analysis", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Structured models"],

Cell[TextData[{
  "StructuredParameter",
  ",",
  " ",
  ButtonBox["Structured parameters",
    ButtonData:>{"Structured parameters", "StructuredParameter"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredParameter"],

Cell[TextData[{
  "StructuredVariance",
  ",",
  " ",
  ButtonBox["Variance components for a structured model",
    ButtonData:>{"Variance components for a structured model", 
      "StructuredVariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredVariance"],

Cell[TextData[{
  "Style sheets",
  ",",
  " bugs with",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Style sheets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Style sheets"],

Cell[TextData[{
  "Subdivide",
  ",",
  " ",
  ButtonBox["Muddling and subdividing sets",
    ButtonData:>{"Muddling and subdividing sets", "Subdivide"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subdivide"],

Cell[TextData[{
  "Subscripts",
  ",",
  " as written in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets in subscripts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subscripts"],

Cell[TextData[{
  "Subsets",
  ",",
  " ",
  ButtonBox["Subsets",
    ButtonData:>{"Subsets", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subsets"],

Cell[TextData[{
  " option for AddUp",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Subsets"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for TimesUp",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subsets"],

Cell[TextData[{
  "Sums",
  ",",
  " multiple",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Multiple sums"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sums"],

Cell[TextData[{
  "Symmetric cline",
  ",",
  " in allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a symmetric cline",
    ButtonData:>{"Allele frequencies: setting up a symmetric cline", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric cline"],

Cell[TextData[{
  " in genotype frequencies",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric cline"],

Cell[TextData[{
  "SymmetricDiploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricDiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricDiploidFrequencies"],

Cell[TextData[{
  "SymmetricHaploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricHaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricHaploidFrequencies"],

Cell[TextData[{
  "Symmetric model",
  ",",
  " adding a neutral marker",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: limitations",
    ButtonData:>{"Symmetric model: limitations", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric model"],

Cell[TextData[{
  " cline example",
  ", ",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: spatially varying selection",
    ButtonData:>{"Symmetric stability: spatially varying selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " limitations",
  ", ",
  ButtonBox["Symmetric model: limitations",
    ButtonData:>{"Symmetric model: limitations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " one deme example",
  ", ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "overview",
  ", ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " references",
  ", ",
  ButtonBox["Symmetric model: references",
    ButtonData:>{"Symmetric model: references", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reproduction",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Symmetric stability: outline",
    ButtonData:>{"Symmetric stability: outline", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric model"],

Cell[TextData[{
  "SymmetricNeutralDiploidFrequencies",
  ",",
  " ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricNeutralDiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricNeutralDiploidFrequencies"],

Cell[TextData[{
  "SymmetricNeutralHaploidFrequencies",
  ",",
  " ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricNeutralHaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricNeutralHaploidFrequencies"],

Cell[TextData[{
  "SymmetricRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "SymmetricRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricRecombination"],

Cell[TextData[{
  "SymmetricRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "SymmetricRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricRepresentations"],

Cell[TextData[{
  "SymmetricSexes",
  ",",
  " ",
  ButtonBox["Symmetric sexes",
    ButtonData:>{"Symmetric sexes", "SymmetricSexes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricSexes"],

Cell[TextData[{
  "Symmetrise",
  ",",
  " ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Symmetrise"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetrise",
    ButtonData:>{"Symmetrise", "Symmetrise"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetrise"],

Cell[TextData[{
  "T",
  ",",
  " time",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "T"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"T"],

Cell[TextData[{
  "Table",
  ",",
  " option for VarianceComponents",
  ", ",
  ButtonBox["Variance components",
    ButtonData:>{"Variance components", "Table"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Table"],

Cell[TextData[{
  "Tag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Tag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tag"],

Cell[TextData[{
  "Tags",
  ",",
  " finding",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Finding tags"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tags"],

Cell[TextData[{
  " setting up hyperlinks to",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Setting up links to a list of tags"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tags"],

Cell[TextData[{
  "TakeAway, \[Backslash], \[AliasIndicator]\[AliasIndicator], ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TakeAway"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TakeAway",
    ButtonData:>{"TakeAway", "TakeAway"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TakeAway"],

Cell[TextData[{
  "TakeOptions",
  ",",
  " ",
  ButtonBox["Manipulating options",
    ButtonData:>{"Manipulating options", "TakeOptions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TakeOptions"],

Cell[TextData[{
  "Time",
  ",",
  " T",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "T"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Time"],

Cell[TextData[{
  "TimesUp",
  ",",
  " ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TimesUp"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "TimesUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimesUp"],

Cell[TextData[{
  " multiple products",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Multiple products"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over subsets",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimesUp"],

Cell[TextData[{
  "ToBaake",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "ToBaake"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToBaake"],

Cell[TextData[{
  "ToBennett",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "ToBennett"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToBennett"],

Cell[TextData[{
  "ToBennettExpression",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "ToBennettExpression"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToBennettExpression"],

Cell[TextData[{
  "ToCumulants",
  ",",
  " ",
  ButtonBox["Multilocus cumulants",
    ButtonData:>{"Multilocus cumulants", "ToCumulants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToCumulants"],

Cell[TextData[{
  "ToMoments",
  ",",
  " ",
  ButtonBox["Multilocus cumulants",
    ButtonData:>{"Multilocus cumulants", "ToMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToMoments"],

Cell[TextData[{
  "ToPopulationCumulants",
  ",",
  " ",
  ButtonBox["Random drift: cumulants",
    ButtonData:>{"Random drift: cumulants", "ToPopulationCumulants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToPopulationCumulants"],

Cell[TextData[{
  "ToPopulationMoments",
  ",",
  " ",
  ButtonBox["Random drift: cumulants",
    ButtonData:>{"Random drift: cumulants", "ToPopulationMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToPopulationMoments"],

Cell[TextData[{
  "TotalLength",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "TotalLength"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalLength"],

Cell[TextData[{
  "TotalNumber",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "TotalNumber"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalNumber"],

Cell[TextData[{
  "Trait",
  ",",
  " set of all positions affecting, \[DoubleStruckCapitalZ], \
\[AliasIndicator]dsZ\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Trait"],

Cell[TextData[{
  "TransformedRange",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "TransformedRange"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransformedRange"],

Cell[TextData[{
  "TransformInformation",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "TransformInformation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransformInformation"],

Cell[TextData[{
  "TransmissionRule",
  ",",
  " ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "TransmissionRule"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransmissionRule"],

Cell[TextData[{
  "Transmission rules",
  ",",
  " applying",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "Applying transmission rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Transmission rules"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Transmission rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " distinct from Mathematica rules",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "Transmission vs Mathematica rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Transmission"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Transmission rules"],

Cell[TextData[{
  "TriDiagonalMatrix",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "TriDiagonalMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TriDiagonalMatrix"],

Cell[TextData[{
  "TruncationSelection",
  ",",
  " option for NewGametes",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", 
      "TruncationSelection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TruncationSelection"],

Cell[TextData[{
  "option for SelectionExact",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "TruncationSelection"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TruncationSelection"],

Cell[TextData[{
  "Turelli and Barton 1994",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Turelli and Barton 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Turelli and Barton 1994"],

Cell[TextData[{
  "Turelli & Barton 1994",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Turelli & Barton 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Turelli & Barton 1994"],

Cell[TextData[{
  "Two alleles",
  ",",
  " ",
  ButtonBox["Two alleles",
    ButtonData:>{"Two alleles", "Biallelic"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Two alleles"],

Cell[TextData[{
  " selection coefficients",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Two alleles"],

Cell[TextData[{
  "UMS",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UMS"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UMS"],

Cell[TextData[{
  "UnionOfGametes",
  ",",
  " ",
  ButtonBox["Union of gametes",
    ButtonData:>{"Union of gametes", "UnionOfGametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnionOfGametes"],

Cell[TextData[{
  "UnlinkedRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "UnlinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnlinkedRecombination"],

Cell[TextData[{
  "UnrootedGenealogy",
  ",",
  " ",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "UnrootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnrootedGenealogy"],

Cell[TextData[{
  "UpperOffDiagonal",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "UpperOffDiagonal"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UpperOffDiagonal"],

Cell[TextData[{
  "USM",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"USM"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"USM"],

Cell[TextData[{
  "VarianceComponents",
  ",",
  " ",
  ButtonBox["Variance components for a structured model",
    ButtonData:>{"Variance components for a structured model", 
      "VarianceComponents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"VarianceComponents"],

Cell[TextData[{
  " Table option",
  ", ",
  ButtonBox["Variance components",
    ButtonData:>{"Variance components", "Table"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"VarianceComponents"],

Cell[TextData[{
  "Versions",
  ",",
  " of applications packages",
  ", ",
  ButtonBox["Versions",
    ButtonData:>{"Versions", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Versions"],

Cell[TextData[{
  "WLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"WLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"WLinkedLoci"],

Cell[TextData[{
  "Wright-Fisher sampling",
  ",",
  " ",
  ButtonBox["Wright-Fisher sampling",
    ButtonData:>{"Wright-Fisher sampling", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Wright-Fisher sampling"],

Cell[TextData[{
  "X",
  ",",
  " AllelicState",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicState"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"X"],

Cell[TextData[{
  "XLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"XLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"XLinkedLoci"],

Cell[TextData[{
  "YLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"YLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"YLinkedLoci"],

Cell[TextData[{
  "ZLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ZLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ZLinkedLoci"],

Cell[TextData[{
  "Zygotes",
  ",",
  " \[GothicCapitalZ], \[AliasIndicator]goZ\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Zygotes"],

Cell[TextData[{
  "\[GothicA]",
  ",",
  " \[AliasIndicator]goa\[AliasIndicator], SelectionCoefficient",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicA]"],

Cell[TextData[{
  "\[GothicCapitalA]",
  ",",
  " \[AliasIndicator]goA\[AliasIndicator], adults",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalA]"],

Cell[TextData[{
  "\[GothicCapitalC]",
  ",",
  " \[AliasIndicator]goC\[AliasIndicator], PopulationDisequilibrium",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalC]"],

Cell[TextData[{
  "\[GothicCapitalD]",
  ",",
  " \[AliasIndicator]\[GothicCapitalD]\[AliasIndicator], Disequilibrium",
  ", ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalD]"],

Cell[TextData[{
  "\!\(\(\[GothicCapitalG]\^*\)\)",
  ",",
  " \[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, \
\[GothicCapitalG]new, new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\!\(\(\[GothicCapitalG]\^*\)\)"],

Cell[TextData[{
  "\[GothicCapitalG]",
  ",",
  " \[AliasIndicator]goG\[AliasIndicator], Gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalG]"],

Cell[TextData[{
  "\[GothicCapitalH]",
  ",",
  " \[AliasIndicator]goH\[AliasIndicator], hermaphrodites",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalH]"],

Cell[TextData[{
  "\[GothicCapitalJ]",
  ",",
  " \[AliasIndicator]goJ\[AliasIndicator], juveniles",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalJ]"],

Cell[TextData[{
  "\[GothicK]",
  ",",
  " \[AliasIndicator]gok\[AliasIndicator], CumulantDisequilibrium",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "CumulantDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicK]"],

Cell[TextData[{
  "\[GothicCapitalK]",
  ",",
  " \[AliasIndicator]goK\[AliasIndicator], CumulantPopulationDisequilibrium",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalK]"],

Cell[TextData[{
  "\[GothicM]",
  ",",
  " \[AliasIndicator]gom\[AliasIndicator], MeanContribution",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "MeanContribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicM]"],

Cell[TextData[{
  "\[GothicP]",
  ",",
  " \[AliasIndicator]gop\[AliasIndicator], AlleleFrequencyP",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicP]"],

Cell[TextData[{
  "\[GothicP]\[GothicQ]",
  ",",
  " \[AliasIndicator]gop\[AliasIndicator]\[AliasIndicator]goq\[AliasIndicator]\
, AlleleFrequencyPQ",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyPQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicP]\[GothicQ]"],

Cell[TextData[{
  "\[GothicQ]",
  ",",
  " \[AliasIndicator]goq\[AliasIndicator], AlleleFrequencyQ",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicQ]"],

Cell[TextData[{
  "\[GothicR]",
  ",",
  " \[AliasIndicator]gor\[AliasIndicator], RecombinationRate",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicR]"],

Cell[TextData[{
  "\[GothicS]",
  ",",
  "\[AliasIndicator]gos\[AliasIndicator], SelectionRate",
  ", ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SelectionRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicS]"],

Cell[TextData[{
  "\[GothicCapitalZ]",
  ",",
  " \[AliasIndicator]goZ\[AliasIndicator], Zygotes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalZ]"],

Cell[TextData[{
  "\[DoubleStruckCapitalG]",
  ",",
  " \[AliasIndicator]dsG\[AliasIndicator], set of all positions in genome",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalG]"],

Cell[TextData[{
  "\[DoubleStruckCapitalM]",
  ",",
  " \[AliasIndicator]dsM\[AliasIndicator], MigrationSet",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "MigrationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalM]"],

Cell[TextData[{
  "\[DoubleStruckCapitalR]",
  ",",
  " \[AliasIndicator]dsR\[AliasIndicator], RecombinationSet",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalR]"],

Cell[TextData[{
  "\[DoubleStruckCapitalW]",
  ",",
  " \[AliasIndicator]dsW\[AliasIndicator], FitnessSet",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "FitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalW]"],

Cell[TextData[{
  "\[DoubleStruckCapitalZ]",
  ",",
  " \[AliasIndicator]dsZ\[AliasIndicator], set of all positions affecting a \
trait",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalZ]"],

Cell[TextData[{
  "\[Gamma]",
  ",",
  " \[AliasIndicator]g\[AliasIndicator], ExtractGenes",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Gamma]"],

Cell[TextData[{
  "\[Zeta]",
  ",",
  " \[AliasIndicator]z\[AliasIndicator], AllelicDeviation",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicDeviation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Zeta]"],

Cell[TextData[{
  "\[CapitalMu]",
  ",",
  " \[AliasIndicator]M\[AliasIndicator], MigrationRate",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CapitalMu]"],

Cell[TextData[{
  "\[Chi]",
  ",",
  " \[AliasIndicator]c\[AliasIndicator], ExtractContexts",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Chi]"],

Cell[TextData[{
  "\[Sampi]",
  ",",
  " \[AliasIndicator]sa\[AliasIndicator], Stage",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Sampi]"],

Cell[TextData[{
  "$MetropolisAdjustment",
  ",",
  " ",
  ButtonBox["Metropolis algorithm",
    ButtonData:>{"Metropolis algorithm", "$MetropolisAdjustment"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$MetropolisAdjustment"],

Cell[TextData[{
  "\[WeierstrassP]",
  ",",
  " \[AliasIndicator]wp\[AliasIndicator], ReferencePoint",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[WeierstrassP]"],

Cell[TextData[{
  "\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]",
  ",",
  " \[AliasIndicator]l||\[AliasIndicator] \[AliasIndicator]r||\
\[AliasIndicator], population expectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],

Cell[TextData[{
  "\[CircleDot]",
  ",",
  " \[AliasIndicator]c.\[AliasIndicator], SelectContext",
  ", ",
  ButtonBox["Selecting contexts",
    ButtonData:>{"Selecting contexts", "SelectContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CircleDot]"],

Cell[TextData[{
  "\[Backslash], \[AliasIndicator]\[AliasIndicator], TakeAway, ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TakeAway"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TakeAway",
    ButtonData:>{"TakeAway", "TakeAway"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Backslash]"],

Cell[TextData[{
  "\[Wedge]",
  ",",
  " \[AliasIndicator]^\[AliasIndicator], ExactIntersection",
  ", ",
  ButtonBox["ExactIntersection",
    ButtonData:>{"ExactIntersection", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Wedge]"],

Cell[TextData[{
  "\[CirclePlus]",
  ",",
  " \[AliasIndicator]c+\[AliasIndicator], ChangeContext",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "ChangeContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CirclePlus]"]
}, Closed]],

Cell[CellGroupData[{

Cell["oldish index", "Subsubsection"],

Cell[TextData[{
  "|.",
  ",",
  " ReplaceAllSpecial",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"|."],

Cell[TextData[{
  "\\\\",
  ",",
  " bugs with",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Repeated \\\\"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\\\\"],

Cell[TextData[{
  "<>",
  ",",
  " Expectation",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Expectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"<>"],

Cell[TextData[{
  "||.",
  ",",
  " ReplaceRepeatedSpecial",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"||."],

Cell[TextData[{
  "AddGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddGenealogy"],

Cell[TextData[{
  "Additive models",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "additive models"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive models"],

Cell[TextData[{
  "Additive selection",
  ",",
  " defining fitnesses",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive selection"],

Cell[TextData[{
  " defining rules",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Defining rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new D",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "New D"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "New mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " scaled D",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Scaled D"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive selection"],

Cell[TextData[{
  "AddNode",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddNode"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddNode"],

Cell[TextData[{
  "AddTag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "AddTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddTag"],

Cell[TextData[{
  "AddUp",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "AddUp"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "AddUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddUp"],

Cell[TextData[{
  " multiple sums",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Multiple sums"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over subsets",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Subsets"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Technicalities"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddUp"],

Cell[TextData[{
  "AdmixtureFrequency",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "AdmixtureFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AdmixtureFrequency"],

Cell[TextData[{
  "Admixture models",
  ",",
  " ",
  ButtonBox["Admixture models",
    ButtonData:>{"Admixture models", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview",
    ButtonData:>{"Overview", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Admixture models"],

Cell[TextData[{
  " changing sex",
  ", ",
  ButtonBox["Changing sex",
    ButtonData:>{"Changing sex", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " equilibria",
  ", ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " iteration",
  ", ",
  ButtonBox["Iteration",
    ButtonData:>{"Iteration", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " migration",
  ", ",
  ButtonBox["Migration in admixture models",
    ButtonData:>{"Migration in admixture models", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " recombination",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Admixture models"],

Cell[TextData[{
  "Adults",
  ",",
  " \[GothicCapitalA], \[AliasIndicator]goA\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Adults"],

Cell[TextData[{
  "Allele frequencies",
  ",",
  " definition of fitness",
  ", ",
  ButtonBox["Allele frequencies:fitnesses",
    ButtonData:>{"Allele frequencies:fitnesses", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Allele frequencies"],

Cell[TextData[{
  "AlleleFrequencies",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "AlleleFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencies"],

Cell[TextData[{
  "AlleleFrequencyMean",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyMean"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyMean"],

Cell[TextData[{
  "AlleleFrequencyP",
  ",",
  " \[GothicP], \[AliasIndicator]gop\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyP"],

Cell[TextData[{
  "AlleleFrequencyPermutations",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "AlleleFrequencyPermutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyPermutations"],

Cell[TextData[{
  "AlleleFrequencyPQ",
  ",",
  " \[GothicP]\[GothicQ], \[AliasIndicator]gop\[AliasIndicator]\
\[AliasIndicator]goq\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyPQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyPQ"],

Cell[TextData[{
  "AlleleFrequencyQ",
  ",",
  " \[GothicQ], \[AliasIndicator]goq\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyQ"],

Cell[TextData[{
  "AlleleFrequencyTable",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyTable"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "AlleleFrequencyTable"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyTable"],

Cell[TextData[{
  "AllelicDeviation",
  ",",
  " \[Zeta], \[AliasIndicator]z\[AliasIndicator]",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicDeviation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllelicDeviation"],

Cell[TextData[{
  "AllelicState",
  ",",
  " X",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicState"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllelicState"],

Cell[TextData[{
  "AllSets",
  ",",
  " ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "AllSets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllSets"],

Cell[TextData[{
  "Ancestors",
  ",",
  " determining",
  ", ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "Ancestors"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestors"],

Cell[TextData[{
  "Ancestry",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Ancestry"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestry"],

Cell[TextData[{
  "Arbitrary sets of loci",
  ",",
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Arbitrary sets of loci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Arbitrary sets of loci"],

Cell[TextData[{
  "Arnold 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Arnold 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Arnold 1996"],

Cell[TextData[{
  "Asmussen and Orive 2000",
  ",",
  " ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["References",
    ButtonData:>{"References", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Asmussen and Orive 2000"],

Cell[TextData[{
  "Asmussen et al. 1987",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Asmussen et al 1987"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Asmussen et al. 1987"],

Cell[TextData[{
  "B",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "B"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"B"],

Cell[TextData[{
  "Barrier",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", "Barrier"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barrier"],

Cell[TextData[{
  "BarrierStrength",
  ",",
  " ",
  ButtonBox["Describing populations",
    ButtonData:>{"Describing populations", "BarrierStrength"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BarrierStrength"],

Cell[TextData[{
  "Barton 1986",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton 1986"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 1986"],

Cell[TextData[{
  "Barton 1995",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Barton 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 1995"],

Cell[TextData[{
  "Barton 2000",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 2000"],

Cell[TextData[{
  "Barton and Turelli 1991",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Barton and Turelli 1991"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton and Turelli 1991"],

Cell[TextData[{
  "Barton & Gale 1993",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Gale 1993"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Gale 1993"],

Cell[TextData[{
  "Barton & Shpak 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Shpak 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Shpak 1999"],

Cell[TextData[{
  "Barton & Turelli 1991",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Turelli 1991"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Turelli 1991"],

Cell[TextData[{
  "Biallelic",
  ",",
  " ",
  ButtonBox["Two alleles",
    ButtonData:>{"Two alleles", "Biallelic"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Biallelic"],

Cell[TextData[{
  " selection coefficients",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Biallelic"],

Cell[TextData[{
  "Birth",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "Birth"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Birth"],

Cell[TextData[{
  "BirthTime",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "BirthTime"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BirthTime"],

Cell[TextData[{
  "Boundary conditions",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Boundary conditions"],

Cell[TextData[{
  "Box",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Box"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Box"],

Cell[TextData[{
  "Boxes",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Boxes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Boxes"],

Cell[TextData[{
  "Browser categories",
  ",",
  " ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Browser categories"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Browser categories"],

Cell[TextData[{
  "Bugs",
  ",",
  " applying rules",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bugs"],

Cell[TextData[{
  " clashes between packages",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Clashes between packages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " estimating D",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " incompatibilities",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Incompatibilities"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " manipulating notebooks",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Manipulating notebooks"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " multilocus notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Multilocus notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " numerical error with AlleleFrequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Numerical bug"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pasting hyperlinks",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Pasting hyperlinks"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " repeated \\\\",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Repeated \\\\"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " special notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with style sheets",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Style sheets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bugs"],

Cell[TextData[{
  "ChangeContext",
  ",",
  "\[CirclePlus], \[AliasIndicator]c+\[AliasIndicator]",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "ChangeContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ChangeContext"],

Cell[TextData[{
  "ChangeSex",
  ",",
  " ",
  ButtonBox["Changing sex",
    ButtonData:>{"Changing sex", "ChangeSex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ChangeSex"],

Cell[TextData[{
  "ClassToGenotypes",
  ",",
  " ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "ClassToGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClassToGenotypes"],

Cell[TextData[{
  "Cline",
  ",",
  " example of",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cline"],

Cell[TextData[{
  " in allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: spatially varying selection",
    ButtonData:>{"Symmetric stability: spatially varying selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: setting up a symmetric cline",
    ButtonData:>{"Simulating individuals: setting up a symmetric cline", 
      None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: setting up a symmetric cline",
    ButtonData:>{"Symmetric model: setting up a symmetric cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with neutral marker",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", "Cline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cline"],

Cell[TextData[{
  "ClineGradient",
  ",",
  "  for genotype frequencies",
  ", ",
  ButtonBox["ClineGradient: setting up a cline",
    ButtonData:>{"ClineGradient: setting up a cline", "ClineGradient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineGradient"],

Cell[TextData[{
  "ClineWidth",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineWidth"],

Cell[TextData[{
  "  for genotype frequencies",
  ", ",
  ButtonBox["Recursions: setting up a cline",
    ButtonData:>{"Recursions: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineWidth"],

Cell[TextData[{
  "CoalescenceDistribution",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", 
      "CoalescenceDistribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CoalescenceDistribution"],

Cell[TextData[{
  "CollapseGenealogy",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "CollapseGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CollapseGenealogy"],

Cell[TextData[{
  "Combine",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Combine"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Combine"],

Cell[TextData[{
  "CompareLogL",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "CompareLogL"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CompareLogL"],

Cell[TextData[{
  "Compiled",
  ",",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Compiled"],

Cell[TextData[{
  "Compiling",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Compiling"],

Cell[TextData[{
  "CondenseGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "CondenseGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CondenseGenealogy"],

Cell[TextData[{
  "ConstrainedIntervals",
  ",",
  " ",
  ButtonBox["Constrained intervals",
    ButtonData:>{"Constrained intervals", "ConstrainedIntervals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstrainedIntervals"],

Cell[TextData[{
  "ConstructMutateList",
  ",",
  " ",
  ButtonBox["Allele frequencies: mutation",
    ButtonData:>{"Allele frequencies: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: mutation",
    ButtonData:>{"Simulating individuals: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstructMutateList"],

Cell[TextData[{
  "ConstructMutateMatrix",
  ",",
  " ",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "ConstructMutateMatrix"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "ConstructMutateMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstructMutateMatrix"],

Cell[TextData[{
  "ContextComponentQ",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextComponentQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextComponentQ"],

Cell[TextData[{
  "ContextPosition",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextPosition"],

Cell[TextData[{
  "ContextStageQ",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextStageQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextStageQ"],

Cell[TextData[{
  "ContextStructure",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextStructure"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextStructure"],

Cell[TextData[{
  "Continuous populations",
  ",",
  " estimating covariance",
  ", ",
  ButtonBox["Estimating the covariance",
    ButtonData:>{"Estimating the covariance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Continuous populations"],

Cell[TextData[{
  " example",
  ", ",
  ButtonBox["An example",
    ButtonData:>{"An example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " implementation",
  ", ",
  ButtonBox["Implementation",
    ButtonData:>{"Implementation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " the model",
  ", ",
  ButtonBox["The model",
    ButtonData:>{"The model", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Continuous populations"],

Cell[TextData[{
  "ConvertData",
  ",",
  " ",
  ButtonBox["Converting a dataset",
    ButtonData:>{"Converting a dataset", "ConvertData"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConvertData"],

Cell[TextData[{
  "ConvertHyperlinkToAddOnsLink",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "ConvertHyperlinkToAddOnsLink"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConvertHyperlinkToAddOnsLink"],

Cell[TextData[{
  "Converting",
  ",",
  " between representations",
  ", ",
  ButtonBox["Allele frequencies: converting",
    ButtonData:>{"Allele frequencies: converting", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Converting"],

Cell[TextData[{
  "CountHeterozygotes",
  ",",
  " ",
  ButtonBox["Recursions:manipulation",
    ButtonData:>{"Recursions:manipulation", "CountHeterozygotes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CountHeterozygotes"],

Cell[TextData[{
  "Covariance",
  ",",
  " in continuous populations",
  ", ",
  ButtonBox["Estimating the covariance",
    ButtonData:>{"Estimating the covariance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Covariance"],

Cell[TextData[{
  "CovarianceMidPoints",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "CovarianceMidPoints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CovarianceMidPoints"],

Cell[TextData[{
  "Crow and Kimura 1970",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Crow and Kimura 1970"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Crow and Kimura 1970"],

Cell[TextData[{
  "Cumulant",
  ",",
  " ",
  ButtonBox["Moments and cumulants",
    ButtonData:>{"Moments and cumulants", "Cumulant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cumulant"],

Cell[TextData[{
  "CumulantDisequilibrium",
  ",",
  " \[GothicK], \[AliasIndicator]gok\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "CumulantDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantDisequilibrium"],

Cell[TextData[{
  "CumulantEquilibrium",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "CumulantEquilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantEquilibrium"],

Cell[TextData[{
  "CumulantPopulationDisequilibrium",
  ",",
  " \[GothicCapitalK], \[AliasIndicator]goK\[AliasIndicator]",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantPopulationDisequilibrium"],

Cell[TextData[{
  "CumulantReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "CumulantReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantReduced"],

Cell[TextData[{
  "Cumulants",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "7.2"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Cumulant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cumulants"],

Cell[TextData[{
  "Cytoplasmic inheritance",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cytoplasmic inheritance"],

Cell[TextData[{
  " and migration",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Cytonuclear associations"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " examples of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cytoplasmic inheritance"],

Cell[TextData[{
  "CytoplasmicLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CytoplasmicLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CytoplasmicLoci"],

Cell[TextData[{
  "dAlleleFrequencyPermutations",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "dAlleleFrequencyPermutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"dAlleleFrequencyPermutations"],

Cell[TextData[{
  "Data",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Data"],

Cell[TextData[{
  " missing",
  ", ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Missing data"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notation for",
  ", ",
  ButtonBox["Notation for genetic data",
    ButtonData:>{"Notation for genetic data", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Data"],

Cell[TextData[{
  "Datasets",
  ",",
  " defining",
  ", ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Datasets"],

Cell[TextData[{
  "Death",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "Death"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Death"],

Cell[TextData[{
  "DeathTime",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "DeathTime"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeathTime"],

Cell[TextData[{
  "DefineContext",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "DefineContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DefineContext"],

Cell[TextData[{
  "DegreesOfFreedom",
  ",",
  " ",
  ButtonBox["Degrees of freedom",
    ButtonData:>{"Degrees of freedom", "DegreesOfFreedom"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DegreesOfFreedom"],

Cell[TextData[{
  "DeletedMutations",
  ",",
  " ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", "DeletedMutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeletedMutations"],

Cell[TextData[{
  "DeleteGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "DeleteGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeleteGenealogy"],

Cell[TextData[{
  "Deme",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Deme"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Deme"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Deme"],

Cell[TextData[{
  "DemeSize",
  ",",
  " compiling",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "Deme size (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DemeSize"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for MigrateExact",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DemeSize"],

Cell[TextData[{
  "Dempster et al 1977",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Dempster et al 1977"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dempster et al 1977"],

Cell[TextData[{
  "Density",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Density"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Density"],

Cell[TextData[{
  "Descendants",
  ",",
  " ",
  ButtonBox["Ancestors and descendants",
    ButtonData:>{"Ancestors and descendants", "Descendants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Descendants"],

Cell[TextData[{
  " determining",
  ", ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "Descendants"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Descendants"],

Cell[TextData[{
  "Dicytonuclear associations",
  ",",
  " ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dicytonuclear associations"],

Cell[TextData[{
  "Diploid",
  ",",
  " option for MomentFromG",
  ", ",
  ButtonBox["Moments from genotype frequencies",
    ButtonData:>{"Moments from genotype frequencies", "Diploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Diploid"],

Cell[TextData[{
  "DiploidConstraints",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidConstraints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidConstraints"],

Cell[TextData[{
  "DiploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidFrequencies"],

Cell[TextData[{
  "DiploidGenotypeFrequency",
  ",",
  " ",
  ButtonBox["Genotype frequencies from moments",
    ButtonData:>{"Genotype frequencies from moments", 
      "DiploidGenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequency"],

Cell[TextData[{
  "DiploidGenotypeFrequencyList",
  ",",
  " ",
  ButtonBox["Fast calculations",
    ButtonData:>{"Fast calculations", "DiploidGenotypeFrequencyList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyList"],

Cell[TextData[{
  "DiploidGenotypeFrequencyReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyReduced"],

Cell[TextData[{
  "DiploidGenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyTable"],

Cell[TextData[{
  "DiploidIndividuals",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidIndividuals"],

Cell[TextData[{
  "DiploidPhenotype",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidPhenotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidPhenotype"],

Cell[TextData[{
  "DiploidPsi",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidPsi"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "DiploidPsi"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidPsi"],

Cell[TextData[{
  "DiploidRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidRepresentations"],

Cell[TextData[{
  "DiploidSource",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidSource"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "DiploidSource"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidSource"],

Cell[TextData[{
  "DiploidSubsets",
  ",",
  " ",
  ButtonBox["Subsets of loci",
    ButtonData:>{"Subsets of loci", "DiploidSubsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidSubsets"],

Cell[TextData[{
  "DiploidTypes",
  ",",
  " ",
  ButtonBox["Listing genotypes",
    ButtonData:>{"Listing genotypes", "DiploidTypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidTypes"],

Cell[TextData[{
  "Disequilibrium",
  ",",
  " population",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Disequilibrium"],

Cell[TextData[{
  " \[GothicCapitalD], \[AliasIndicator]\[GothicCapitalD]\[AliasIndicator]",
  ", ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Disequilibrium"],

Cell[TextData[{
  "DisequilibriumMean",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumMean"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumMean"],

Cell[TextData[{
  "DisequilibriumTable",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumTable"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumTable"],

Cell[TextData[{
  "DistanceSquared",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "DistanceSquared"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DistanceSquared"],

Cell[TextData[{
  "Distribution",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Distribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Distribution"],

Cell[TextData[{
  "DivideZero",
  ",",
  " ",
  ButtonBox["DivideZero",
    ButtonData:>{"DivideZero", "DivideZero"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DivideZero"],

Cell[TextData[{
  "DoReplicates",
  ",",
  " ",
  ButtonBox["Analysing replicate samples",
    ButtonData:>{"Analysing replicate samples", "DoReplicates"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoReplicates"],

Cell[TextData[{
  "DoubleCline",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a symmetric cline",
    ButtonData:>{"Allele frequencies: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoubleCline"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: setting up a symmetric cline",
    ButtonData:>{"Simulating individuals: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a symmetric cline",
    ButtonData:>{"Symmetric model: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoubleCline"],

Cell[TextData[{
  "DrawSamples",
  ",",
  " ",
  ButtonBox["Setting up replicates",
    ButtonData:>{"Setting up replicates", "DrawSamples"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DrawSamples"],

Cell[TextData[{
  "DropOptions",
  ",",
  " ",
  ButtonBox["Manipulating options",
    ButtonData:>{"Manipulating options", "DropOptions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DropOptions"],

Cell[TextData[{
  "Edwards 1972",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Edwards 1972"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Edwards 1972"],

Cell[TextData[{
  "Epistasis",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Epistasis"],

Cell[TextData[{
  "EquivalentSexes",
  ",",
  " obsolete form of SymmetricSexes",
  ", ",
  ButtonBox["Symmetric sexes",
    ButtonData:>{"Symmetric sexes", "SymmetricSexes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EquivalentSexes"],

Cell[TextData[{
  "ErrorBound",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "ErrorBound"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ErrorBound"],

Cell[TextData[{
  "EstimateFamilyMoments",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "EstimateFamilyMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EstimateFamilyMoments"],

Cell[TextData[{
  "EstimateMoments",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "EstimateMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EstimateMoments"],

Cell[TextData[{
  "Estimating D",
  ",",
  " admixture models",
  ", ",
  ButtonBox["Admixture models",
    ButtonData:>{"Admixture models", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Estimating D"],

Cell[TextData[{
  " alternative methods",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Log-linear models"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction",
  ", ",
  ButtonBox["Introduction to estimating D",
    ButtonData:>{"Introduction to estimating D", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " maximum entropy",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Maximum entropy"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " maximum likelihood, example of",
  ", ",
  ButtonBox["MLE example",
    ButtonData:>{"MLE example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Metropolis random walk",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MLE, cumulants",
  ", ",
  ButtonBox["Finding the MLE",
    ButtonData:>{"Finding the MLE", "Cumulant"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " moments, families",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "Extension to families"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " naive MLE",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Naive MLE"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " obsolete",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pairs of loci",
  ", ",
  ButtonBox["Pairs of loci",
    ButtonData:>{"Pairs of loci", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pairs of loci, example of",
  ", ",
  ButtonBox["Pairwise example",
    ButtonData:>{"Pairwise example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " random sampling, example of",
  ", ",
  ButtonBox["Sampling example",
    ButtonData:>{"Sampling example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " summary",
  ", ",
  ButtonBox["Summary",
    ButtonData:>{"Summary", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " varying divergence",
  ", ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "Varying divergence"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Estimating D"],

Cell[TextData[{
  "ExactEigenvalues",
  ",",
  " ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "ExactEigenvalues"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactEigenvalues"],

Cell[TextData[{
  "ExactIntersection",
  ",",
  " \[Wedge], \[AliasIndicator]^\[AliasIndicator]",
  ", ",
  ButtonBox["ExactIntersection",
    ButtonData:>{"ExactIntersection", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactIntersection"],

Cell[TextData[{
  "ExactProbability",
  ",",
  " ",
  ButtonBox["Exact probability",
    ButtonData:>{"Exact probability", "ExactProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactProbability"],

Cell[TextData[{
  "Expectation",
  ",",
  " <>",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Expectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Expectation"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Expectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population, \[LeftDoubleBracketingBar] \[RightDoubleBracketingBar], \
\[AliasIndicator]l||\[AliasIndicator] \[AliasIndicator]r||\[AliasIndicator]",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Expectation"],

Cell[TextData[{
  "ExponentialF",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExponentialF"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "ExponentialF"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExponentialF"],

Cell[TextData[{
  "ExtantIndividuals",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "ExtantIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtantIndividuals"],

Cell[TextData[{
  "ExtractContexts",
  ",",
  " \[Chi], \[AliasIndicator]c\[AliasIndicator]",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractContexts"],

Cell[TextData[{
  "ExtractExtant",
  ",",
  " ",
  ButtonBox["Initialisation",
    ButtonData:>{"Initialisation", "ExtractExtant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractExtant"],

Cell[TextData[{
  "ExtractGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "ExtractGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractGenealogy"],

Cell[TextData[{
  "ExtractGenes",
  ",",
  " \[Gamma], \[AliasIndicator]g\[AliasIndicator]",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractGenes"],

Cell[TextData[{
  "ExtractInformation",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "ExtractInformation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractInformation"],

Cell[TextData[{
  "ExtractRepeat",
  ",",
  " ",
  ButtonBox["Repeated elements",
    ButtonData:>{"Repeated elements", "ExtractRepeat"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractRepeat"],

Cell[TextData[{
  "ExtractSubMatrix",
  ",",
  " ",
  ButtonBox["Extracting submatrices",
    ButtonData:>{"Extracting submatrices", "ExtractSubMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractSubMatrix"],

Cell[TextData[{
  "FamilyAlleleFrequencyEstimate",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyAlleleFrequencyEstimate"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyAlleleFrequencyEstimate"],

Cell[TextData[{
  "FamilyEffects",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyEffects"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyEffects"],

Cell[TextData[{
  "FamilyM",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyM"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyM"],

Cell[TextData[{
  "FamilyProbability",
  ",",
  " ",
  ButtonBox["Probabilities",
    ButtonData:>{"Probabilities", "FamilyProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyProbability"],

Cell[TextData[{
  "Family structure",
  ",",
  " set of all",
  ", ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "NewS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Family structure"],

Cell[TextData[{
  "Fecundity",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Fecundity"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fecundity"],

Cell[TextData[{
  "FindHyperlinks",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "FindHyperlinks"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindHyperlinks"],

Cell[TextData[{
  "FindIndexTag",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "FindIndexTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindIndexTag"],

Cell[TextData[{
  "FindMLE",
  ",",
  " ",
  ButtonBox["Finding the MLE",
    ButtonData:>{"Finding the MLE", "FindMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindMLE"],

Cell[TextData[{
  "FindNode",
  ",",
  " ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", "FindNode"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindNode"],

Cell[TextData[{
  "FindPosition",
  ",",
  " ",
  ButtonBox["Initialisation",
    ButtonData:>{"Initialisation", "FindPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindPosition"],

Cell[TextData[{
  "FindTags",
  ",",
  " ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "FindTags"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindTags"],

Cell[TextData[{
  "Fitness",
  ",",
  " definition for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:fitnesses",
    ButtonData:>{"Allele frequencies:fitnesses", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fitness"],

Cell[TextData[{
  " in individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " problems redefining",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Redefining fitness"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fitness"],

Cell[TextData[{
  "FitnessSet",
  ",",
  " \[DoubleStruckCapitalW], \[AliasIndicator]dsW\[AliasIndicator]",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "FitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessSet"],

Cell[TextData[{
  "FitnessTable",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessTable"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessTable"],

Cell[TextData[{
  "FixedEnds",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FixedEnds"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for MigrateExact",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FixedEnds"],

Cell[TextData[{
  "Flatten",
  ",",
  " ",
  ButtonBox["Flattening lists at specific levels",
    ButtonData:>{"Flattening lists at specific levels", "Flatten"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Flatten"],

Cell[TextData[{
  "FlattenList",
  ",",
  " ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "FlattenList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FlattenList"],

Cell[TextData[{
  " PatternFree",
  ", ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "PatternFree"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FlattenList"],

Cell[TextData[{
  "FourierNormalised",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "FourierNormalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FourierNormalised"],

Cell[TextData[{
  "FourierNormalisedTable",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "FourierNormalisedTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FourierNormalisedTable"],

Cell[TextData[{
  "FrequencyRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "FrequencyRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FrequencyRepresentations"],

Cell[TextData[{
  "FullContext",
  ",",
  " ",
  ButtonBox["Abbreviating contexts",
    ButtonData:>{"Abbreviating contexts", "FullContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullContext"],

Cell[TextData[{
  "FullGenotypeFrequencyReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullGenotypeFrequencyReduced"],

Cell[TextData[{
  "FullGenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullGenotypeFrequencyTable"],

Cell[TextData[{
  "FullOutput",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "FullOutput"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullOutput"],

Cell[TextData[{
  "Function",
  ",",
  " ",
  ButtonBox["Marginal tables",
    ButtonData:>{"Marginal tables", "Function"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Function"],

Cell[TextData[{
  "Gametes",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "Gametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gametes"],

Cell[TextData[{
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new, \!\(\(\[GothicCapitalG]\^*\)\), \
\[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, \[GothicCapitalG]new",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " \[GothicCapitalG], \[AliasIndicator]goG\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gametes"],

Cell[TextData[{
  "GameteTable",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "GameteTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GameteTable"],

Cell[TextData[{
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "GameteTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "GameteTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GameteTable"],

Cell[TextData[{
  "GaussianLogLikelihood",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "GaussianLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GaussianLogLikelihood"],

Cell[TextData[{
  "GaussianMLE",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "GaussianMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GaussianMLE"],

Cell[TextData[{
  "Genealogies",
  ",",
  " exact probability",
  ", ",
  ButtonBox["Exact probability",
    ButtonData:>{"Exact probability", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genealogies"],

Cell[TextData[{
  " family structure",
  ", ",
  ButtonBox["Family structure",
    ButtonData:>{"Family structure", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " generating functions",
  ", ",
  ButtonBox["Deriving recursions for the MGF",
    ButtonData:>{"Deriving recursions for the MGF", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " probability of",
  ", ",
  ButtonBox["Deriving the probability",
    ButtonData:>{"Deriving the probability", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sampling",
  ", ",
  ButtonBox["Sampling genealogies",
    ButtonData:>{"Sampling genealogies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genealogies"],

Cell[TextData[{
  "GenealogyToMatrix",
  ",",
  " ",
  ButtonBox["Describing mutation",
    ButtonData:>{"Describing mutation", "GenealogyToMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenealogyToMatrix"],

Cell[TextData[{
  "GeneralizedTransform",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "GeneralizedTransform"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GeneralizedTransform"],

Cell[TextData[{
  "Generating functions",
  ",",
  " examples",
  ", ",
  ButtonBox["Examples of the MGF",
    ButtonData:>{"Examples of the MGF", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Generating functions"],

Cell[TextData[{
  " for cumulants",
  ", ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "GeneralizedTransform"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genealogies",
  ", ",
  ButtonBox["Deriving recursions for the MGF",
    ButtonData:>{"Deriving recursions for the MGF", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Generating functions"],

Cell[TextData[{
  "Genes and contexts",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Genes and contexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genes and contexts"],

Cell[TextData[{
  "Genome",
  ",",
  " set of all positions in, \[DoubleStruckCapitalG], \[AliasIndicator]dsG\
\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genome"],

Cell[TextData[{
  "Genotype",
  ",",
  " observable",
  ", ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype"],

Cell[TextData[{
  "Genotype frequencies",
  ",",
  " recursions",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype frequencies"],

Cell[TextData[{
  "GenotypeFrequencyArguments",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "GenotypeFrequencyArguments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyArguments"],

Cell[TextData[{
  "GenotypeFrequencyConvert",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "GenotypeFrequencyConvert"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyConvert"],

Cell[TextData[{
  "GenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyTable"],

Cell[TextData[{
  "GenotypePosition",
  ",",
  " ",
  ButtonBox["Recursions:manipulation",
    ButtonData:>{"Recursions:manipulation", "GenotypePosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypePosition"],

Cell[TextData[{
  "GenotypeProbability",
  ",",
  " ",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "GenotypeProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeProbability"],

Cell[TextData[{
  " segregation ratio",
  ", ",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeProbability"],

Cell[TextData[{
  "Genotypes",
  ",",
  " notation for",
  ", ",
  ButtonBox["Notation",
    ButtonData:>{"Notation", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotypes"],

Cell[TextData[{
  "Gnew",
  ",",
  " \!\(\(\[GothicCapitalG]\^*\)\), \[AliasIndicator]goG\[AliasIndicator]\
\[ControlKey]^*, new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gnew"],

Cell[TextData[{
  "Goodman et al 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Goodman et al 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Goodman et al 1999"],

Cell[TextData[{
  "Griffiths-Tavare",
  ",",
  " ",
  ButtonBox["Exact algorithm",
    ButtonData:>{"Exact algorithm", "GriffithsTavare"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Griffiths-Tavare algorithm",
    ButtonData:>{"Griffiths-Tavare algorithm", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Griffiths-Tavare"],

Cell[TextData[{
  " stochastic algorithm",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "MonteCarloGriffithsTavare"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "Stochastic GT algorithm"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stochastic, comparison with MonteCarloProbability",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", 
      "Comparison with MonteCarloProbability"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stochastic example",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "Small example"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Griffiths-Tavare"],

Cell[TextData[{
  "Guiasu & Shenitzer 1985",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Guiasu & Shenitzer 1985"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Guiasu & Shenitzer 1985"],

Cell[TextData[{
  "HaploidConstraints",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "HaploidConstraints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidConstraints"],

Cell[TextData[{
  "HaploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidFrequencies"],

Cell[TextData[{
  "HaploidGenotypeFrequency",
  ",",
  " ",
  ButtonBox["Genotype frequencies from moments",
    ButtonData:>{"Genotype frequencies from moments", 
      "HaploidGenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidGenotypeFrequency"],

Cell[TextData[{
  "HaploidIndividuals",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidIndividuals"],

Cell[TextData[{
  "HaploidRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidRepresentations"],

Cell[TextData[{
  "Haploids",
  ",",
  " selection on",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Haploids"],

Cell[TextData[{
  "HaploidSource",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "HaploidSource"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "HaploidSource"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidSource"],

Cell[TextData[{
  "HaploidSubsets",
  ",",
  " ",
  ButtonBox["Subsets of loci",
    ButtonData:>{"Subsets of loci", "HaploidSubsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidSubsets"],

Cell[TextData[{
  "HaploidTypes",
  ",",
  " ",
  ButtonBox["Listing genotypes",
    ButtonData:>{"Listing genotypes", "HaploidTypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidTypes"],

Cell[TextData[{
  "Help browser",
  ",",
  " setting up new files",
  ", ",
  ButtonBox["Setting up new help files",
    ButtonData:>{"Setting up new help files", "Setting up new help files"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help browser"],

Cell[TextData[{
  "Help Browser",
  ",",
  " ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "MasterIndexHeading"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help Browser"],

Cell[TextData[{
  " setting up hyperlinks",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up links"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help Browser"],

Cell[TextData[{
  "Hermaphrodites",
  ",",
  " \[GothicCapitalH], \[AliasIndicator]goH\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hermaphrodites"],

Cell[TextData[{
  "HeterozygoteB",
  ",",
  " ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "HeterozygoteB"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HeterozygoteB"],

Cell[TextData[{
  "Hill 1974a",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974a"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974a"],

Cell[TextData[{
  "Hill 1974b",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974b"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974b"],

Cell[TextData[{
  "Hill 1974c",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974c"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974c"],

Cell[TextData[{
  "Hypergeometric model",
  ",",
  " ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hypergeometric model"],

Cell[TextData[{
  "Hyperlinks",
  ",",
  " bugs in pasting",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Pasting hyperlinks"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hyperlinks"],

Cell[TextData[{
  " saving",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Saving the links"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " setting up",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up links"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " to cell tags",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Setting up links to a list of tags"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hyperlinks"],

Cell[TextData[{
  "IncidenceMatrix",
  ",",
  " ",
  ButtonBox["Ordered genealogies",
    ButtonData:>{"Ordered genealogies", "IncidenceMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IncidenceMatrix"],

Cell[TextData[{
  "Index",
  ",",
  " setting up",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up Master Index"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Index"],

Cell[TextData[{
  "Individual",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Individual"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Individual"],

Cell[TextData[{
  "IndividualRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "IndividualRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IndividualRepresentations"],

Cell[TextData[{
  "Individuals",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Individuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Individuals"],

Cell[TextData[{
  "InitialiseContinuum",
  ",",
  " ",
  ButtonBox["Initialisation",
    ButtonData:>{"Initialisation", "InitialiseContinuum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseContinuum"],

Cell[TextData[{
  "InitialiseCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "InitialiseCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseCovariance"],

Cell[TextData[{
  "InitialiseDemes",
  ",",
  " ",
  ButtonBox["Describing the population",
    ButtonData:>{"Describing the population", "InitialiseDemes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Setting up a cline",
    ButtonData:>{"Setting up a cline", "InitialiseDemes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseDemes"],

Cell[TextData[{
  "InitialStep",
  ",",
  " ",
  ButtonBox["Initial step size",
    ButtonData:>{"Initial step size", "InitialStep"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialStep"],

Cell[TextData[{
  "InitialStepReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "InitialStepReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialStepReduced"],

Cell[TextData[{
  "InternalNodes",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "InternalNodes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InternalNodes"],

Cell[TextData[{
  "IntervalCombine",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalCombine"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IntervalCombine"],

Cell[TextData[{
  "IntervalPosition",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IntervalPosition"],

Cell[TextData[{
  "InverseFourierNormalised",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "InverseFourierNormalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InverseFourierNormalised"],

Cell[TextData[{
  "InverseFourierNormalisedTable",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "InverseFourierNormalisedTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InverseFourierNormalisedTable"],

Cell[TextData[{
  "Island model",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Island model"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Island model"],

Cell[TextData[{
  "IterateContinuum",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "IterateContinuum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateContinuum"],

Cell[TextData[{
  "IterateExact",
  ",",
  " example",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateExact"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for allele frequency clines",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "IterateExact"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequency clines",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateExact"],

Cell[TextData[{
  "Join",
  ",",
  " ",
  ButtonBox["Join",
    ButtonData:>{"Join", "Join"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "Join"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Join"],

Cell[TextData[{
  "Juveniles",
  ",",
  " \[GothicCapitalJ], \[AliasIndicator]goJ\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Juveniles"],

Cell[TextData[{
  "Kirkpatrick and Barton 1997",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick and Barton 1997"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick and Barton 1997"],

Cell[TextData[{
  "Kirkpatrick and Servedio 1998",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick and Servedio 1998"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick and Servedio 1998"],

Cell[TextData[{
  "Kirkpatrick et al.",
  ",",
  " ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick et al."},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al."],

Cell[TextData[{
  " arbitrary sets of loci",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Arbitrary sets of loci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Expectation",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Expectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " migration",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " mutation",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " permutations in defining coefficients",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Permutations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Permutations"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " phenotypes",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " position",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Contexts and positions"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "position"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " QLE",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " quasi-linkage equilibrium",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " random drift",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Random drift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference values",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Describing genotypes and populations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Reference values"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " relation with",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Multilocus MS"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " scripts and faces",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Scripts and faces"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " selection",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sets in subscripts",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets in subscripts"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sets of loci",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets of loci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stabilising selection",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", 
      "Natural selection on an additive polygenic trait"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages and contexts",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Stages and contexts"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " transmission rules",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Transmission"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Transmission rules"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al."],

Cell[TextData[{
  "Kirkpatrick et al. 1983",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Kirkpatrick et al 1983"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al. 1983"],

Cell[TextData[{
  "Kruuk 1997",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Kruuk 1997"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kruuk 1997"],

Cell[TextData[{
  "LeafLabels",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "LeafLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LeafLabels"],

Cell[TextData[{
  "LeafOffset",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "LeafOffset"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LeafOffset"],

Cell[TextData[{
  "Leaves",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "Leaves"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Leaves"],

Cell[TextData[{
  "Life cycle",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Life cycle"],

Cell[TextData[{
  " adults",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete",
  ", ",
  ButtonBox["Complete life cycle",
    ButtonData:>{"Complete life cycle", "Complete rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " hermaphrodites",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " juveniles",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages in",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with cytoplasmic inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with sex linkage",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " zygotes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Life cycle"],

Cell[TextData[{
  "Li & Nei 1974",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Li & Nei 1974"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Li & Nei 1974"],

Cell[TextData[{
  "Linkage",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Linkage",
    ButtonData:>{"Linkage", "Linkage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage"],

Cell[TextData[{
  " in numerical models",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Linkage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage"],

Cell[TextData[{
  "Linkage disequilibrium",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage disequilibrium"],

Cell[TextData[{
  "ListToGenealogy",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "ListToGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ListToGenealogy"],

Cell[TextData[{
  "ListToMatrix",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "ListToMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ListToMatrix"],

Cell[TextData[{
  "Location",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Location"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Location"],

Cell[TextData[{
  "Locations",
  ",",
  " ",
  ButtonBox["Locations",
    ButtonData:>{"Locations", "Locations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Locations"],

Cell[TextData[{
  "LocusNames",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "LocusNames"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LocusNames"],

Cell[TextData[{
  "LogLikelihoodDisequilibrium",
  ",",
  " ",
  ButtonBox["Likelihood",
    ButtonData:>{"Likelihood", "LogLikelihoodDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodDisequilibrium"],

Cell[TextData[{
  "LogLikelihoodDisequilibriumReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "LogLikelihoodDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodDisequilibriumReduced"],

Cell[TextData[{
  "LogLikelihoodTest",
  ",",
  " ",
  ButtonBox["Likelihood tests",
    ButtonData:>{"Likelihood tests", "LogLikelihoodTest"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodTest"],

Cell[TextData[{
  "Log-linear models",
  ",",
  " ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Log-linear models"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Log-linear models"],

Cell[TextData[{
  "Long et al 1995",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Long et al 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Long et al 1995"],

Cell[TextData[{
  "LowerOffDiagonal",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "LowerOffDiagonal"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LowerOffDiagonal"],

Cell[TextData[{
  "MacCallum 1994",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "MacCallum 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MacCallum 1994"],

Cell[TextData[{
  "MacCallum et al. 1998",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "MacCallum et al 1998"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MacCallum et al. 1998"],

Cell[TextData[{
  "MakeCline",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeCline"],

Cell[TextData[{
  "  for genotype frequencies",
  ", ",
  ButtonBox["Recursions: setting up a cline",
    ButtonData:>{"Recursions: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeCline"],

Cell[TextData[{
  "MakeDiploid",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDiploid"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDiploid"],

Cell[TextData[{
  "MakeDistanceList",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "MakeDistanceList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDistanceList"],

Cell[TextData[{
  "MakeDistances",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "MakeDistances"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDistances"],

Cell[TextData[{
  "MakeFitnessSet",
  ",",
  " ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "MakeFitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeFitnessSet"],

Cell[TextData[{
  " with multiple alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeFitnessSet"],

Cell[TextData[{
  "MakeGenealogy",
  ",",
  " ",
  ButtonBox["Making a genealogy",
    ButtonData:>{"Making a genealogy", "MakeGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeGenealogy"],

Cell[TextData[{
  "MakeGenealogyPlot",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "MakeGenealogyPlot"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeGenealogyPlot"],

Cell[TextData[{
  "MakeHaploid",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeHaploid"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeHaploid"],

Cell[TextData[{
  "MakeIndividuals",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: converting",
    ButtonData:>{"Allele frequencies: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeIndividuals"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeIndividuals"],

Cell[TextData[{
  "MakeOneWayTable",
  ",",
  " ",
  ButtonBox["Single-locus tables",
    ButtonData:>{"Single-locus tables", "MakeOneWayTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeOneWayTable"],

Cell[TextData[{
  "MakePairwiseTable",
  ",",
  " ",
  ButtonBox["Pairwise tables",
    ButtonData:>{"Pairwise tables", "MakePairwiseTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePairwiseTable"],

Cell[TextData[{
  "MakePopulation",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePopulation"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "MakePopulation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: representation",
    ButtonData:>{"Symmetric model: representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePopulation"],

Cell[TextData[{
  "MakeSelectionCoefficient",
  ",",
  " ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeSelectionCoefficient"],

Cell[TextData[{
  " with multiple alleles",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with two alleles",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeSelectionCoefficient"],

Cell[TextData[{
  "Mangel & Hilborn 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Mangel & Hilborn 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mangel & Hilborn 1996"],

Cell[TextData[{
  "Marginal fitness",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Marginal fitness"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Marginal fitness"],

Cell[TextData[{
  "MarginalTable",
  ",",
  " ",
  ButtonBox["Marginal tables",
    ButtonData:>{"Marginal tables", "MarginalTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalTable"],

Cell[TextData[{
  "MarginalW",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalW"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalW"],

Cell[TextData[{
  "MaternalLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MaternalLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MaternalLoci"],

Cell[TextData[{
  "MatrixGamma",
  ",",
  " ",
  ButtonBox["Fast calculations",
    ButtonData:>{"Fast calculations", "MatrixGamma"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixGamma"],

Cell[TextData[{
  "MatrixToGenealogy",
  ",",
  " ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", "MatrixToGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixToGenealogy"],

Cell[TextData[{
  "MatrixToList",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "MatrixToList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixToList"],

Cell[TextData[{
  "MeanContribution",
  ",",
  " \[GothicM], \[AliasIndicator]gom\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "MeanContribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanContribution"],

Cell[TextData[{
  "Mean fitness",
  ",",
  " ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mean fitness"],

Cell[TextData[{
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mean fitness"],

Cell[TextData[{
  "MeanW",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanW"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanW"],

Cell[TextData[{
  "Meiosis",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Meiosis"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Meiosis"],

Cell[TextData[{
  " in numerical models",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Meiosis"],

Cell[TextData[{
  "MethodC",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MethodC"],

Cell[TextData[{
  "MethodP",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MethodP"],

Cell[TextData[{
  "Metropolis algorithm",
  ",",
  " estimating D",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Metropolis algorithm"],

Cell[TextData[{
  "MetropolisDisequilibrium",
  ",",
  " ",
  ButtonBox["Estimating moments",
    ButtonData:>{"Estimating moments", "MetropolisDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MetropolisDisequilibrium"],

Cell[TextData[{
  "MetropolisDisequilibriumReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MetropolisDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MetropolisDisequilibriumReduced"],

Cell[TextData[{
  "Metropolis et al. 1954",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Metropolis et al 1954"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Metropolis et al. 1954"],

Cell[TextData[{
  "MFromC",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MFromC"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MFromC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MFromC"],

Cell[TextData[{
  "Migrate",
  ",",
  " ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Migrate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migrate"],

Cell[TextData[{
  "MigrateExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrateExact"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrateExact"],

Cell[TextData[{
  "Migration",
  ",",
  " and cytoplasmic inheritance",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Cytonuclear associations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migration"],

Cell[TextData[{
  " and sexual selection",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Sexual selection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " context-dependent",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Context-dependent migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " example of",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotype-dependent",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Genotype-dependent migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of haploids",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Haploid migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of juvenile diploids",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Juvenile diploid migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of pollen",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of seeds",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with sindividuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migration"],

Cell[TextData[{
  "MigrationOrder",
  ",",
  "for genotype frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationOrder"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "MigrationOrder"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationOrder"],

Cell[TextData[{
  "MigrationRate",
  ",",
  " \[CapitalMu], \[AliasIndicator]M\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationRate"],

Cell[TextData[{
  "MigrationSet",
  ",",
  " \[DoubleStruckCapitalM], \[AliasIndicator]dsM\[AliasIndicator]",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "MigrationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationSet"],

Cell[TextData[{
  "Missing data",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Missing data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Missing data"],

Cell[TextData[{
  "Moment",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Moment"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Moments and cumulants",
    ButtonData:>{"Moments and cumulants", "Moment"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moment"],

Cell[TextData[{
  "MomentAfterMigration",
  ",",
  " ",
  ButtonBox["Migration in admixture models",
    ButtonData:>{"Migration in admixture models", "MomentAfterMigration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentAfterMigration"],

Cell[TextData[{
  "MomentAfterRecombination",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", 
      "MomentAfterRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentAfterRecombination"],

Cell[TextData[{
  "MomentEquilibrium",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "MomentEquilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentEquilibrium"],

Cell[TextData[{
  "MomentGeneratingFunction",
  ",",
  " deriving",
  ", ",
  ButtonBox["Deriving recursions for the MGF",
    ButtonData:>{"Deriving recursions for the MGF", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentGeneratingFunction"],

Cell[TextData[{
  " examples",
  ", ",
  ButtonBox["Examples of the MGF",
    ButtonData:>{"Examples of the MGF", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genealogies",
  ", ",
  ButtonBox["Calculating the MGF",
    ButtonData:>{"Calculating the MGF", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over topologies",
  ", ",
  ButtonBox["Calculating over topologies",
    ButtonData:>{"Calculating over topologies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentGeneratingFunction"],

Cell[TextData[{
  "MomentLimits",
  ",",
  " ",
  ButtonBox["Constraints on moments",
    ButtonData:>{"Constraints on moments", "MomentLimits"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentLimits"],

Cell[TextData[{
  "MomentNew",
  ",",
  " ",
  ButtonBox["Iteration",
    ButtonData:>{"Iteration", "MomentNew"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentNew"],

Cell[TextData[{
  "MomentReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MomentReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentReduced"],

Cell[TextData[{
  "Moments",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "7.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moments"],

Cell[TextData[{
  " estimating the matrix of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "Estimating the matrix"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " extension to description by",
  ", ",
  ButtonBox["References",
    ButtonData:>{"References", "Haber 1984"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " extension to estimation of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "MLE"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " full description by",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " matrix of",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] full matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "ML estimation of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "simple method"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reduced description by",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " simple method for estimating",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "extension to families"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moments"],

Cell[TextData[{
  "MomentsFromG",
  ",",
  " ",
  ButtonBox["Moments from genotype frequencies",
    ButtonData:>{"Moments from genotype frequencies", "MomentsFromG"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentsFromG"],

Cell[TextData[{
  "MomentSimple",
  ",",
  " ",
  ButtonBox["Simplifying the moments",
    ButtonData:>{"Simplifying the moments", "MomentSimple"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentSimple"],

Cell[TextData[{
  "MonteCarloGriffithsTavare",
  ",",
  " ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "MonteCarloGriffithsTavare"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MonteCarloGriffithsTavare"],

Cell[TextData[{
  "MonteCarloProbability",
  ",",
  " ",
  ButtonBox["Estimating the probability",
    ButtonData:>{"Estimating the probability", "MonteCarloProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MonteCarloProbability"],

Cell[TextData[{
  "Mortality",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Mortality"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mortality"],

Cell[TextData[{
  "MostRecentCommonAncestor",
  ",",
  " ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "MostRecentCommonAncestor"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MostRecentCommonAncestor"],

Cell[TextData[{
  "MToC",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MToC"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MToC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MToC"],

Cell[TextData[{
  "MToCEquations",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MToCEquations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MToCEquations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MToCEquations"],

Cell[TextData[{
  "Muddle",
  ",",
  " ",
  ButtonBox["Muddling and subdividing sets",
    ButtonData:>{"Muddling and subdividing sets", "Muddle"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Muddle"],

Cell[TextData[{
  "Multilocus algebra",
  ",",
  " basic notation",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Basic notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus algebra"],

Cell[TextData[{
  " fitness",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction to",
  ", ",
  ButtonBox["Introduction to multilocus algebra",
    ButtonData:>{"Introduction to multilocus algebra", "1.1"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Introduction to multilocus algebra",
    ButtonData:>{"Introduction to multilocus algebra", 
      "Multilocus`Multilocus`"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages in life cycle",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Technicalities"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus algebra"],

Cell[TextData[{
  "Multilocus MS",
  ",",
  " relation with",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Multilocus MS"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus MS"],

Cell[TextData[{
  "Multilocus notation",
  ",",
  " bugs",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Multilocus notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus notation"],

Cell[TextData[{
  "Multinomial sampling",
  ",",
  " without replacement",
  ", ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", 
      "Multinomial sampling wo replacement"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multinomial sampling"],

Cell[TextData[{
  "MultinomialSamplingProbability",
  ",",
  " ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", 
      "MultinomialSamplingProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MultinomialSamplingProbability"],

Cell[TextData[{
  "Multiple alleles",
  ",",
  " and selection coefficients",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple alleles"],

Cell[TextData[{
  " MakeFitnessSet",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " representation of",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " selection on",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple alleles"],

Cell[TextData[{
  "Multiple arguments",
  ",",
  " in PopulationExpectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "multiple arguments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple arguments"],

Cell[TextData[{
  "Multiplicative models",
  ",",
  " in negative binomial",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "multiplicative models"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiplicative models"],

Cell[TextData[{
  "MUS",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MUS"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MUS"],

Cell[TextData[{
  "Mutate",
  ",",
  " allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: mutation",
    ButtonData:>{"Allele frequencies: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutate"],

Cell[TextData[{
  "genotype frequencies",
  ", ",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " individuals",
  ", ",
  ButtonBox["Simulating individuals: mutation",
    ButtonData:>{"Simulating individuals: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric model",
  ", ",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutate"],

Cell[TextData[{
  "MutateCompiled",
  ",",
  " ",
  ButtonBox["Allele frequencies: mutation",
    ButtonData:>{"Allele frequencies: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: mutation",
    ButtonData:>{"Simulating individuals: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutateCompiled"],

Cell[TextData[{
  "Mutation",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Mutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutation"],

Cell[TextData[{
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies: reproduction",
    ButtonData:>{"Allele frequencies: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: reproduction",
    ButtonData:>{"Recursions: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutation"],

Cell[TextData[{
  "MutationInterval",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "MutationInterval"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationInterval"],

Cell[TextData[{
  "MutationLabels",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "MutationLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationLabels"],

Cell[TextData[{
  "MutationOrigin",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "MutationOrigin"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationOrigin"],

Cell[TextData[{
  "MutationRate",
  ",",
  " ",
  ButtonBox["Drawing a genealogy",
    ButtonData:>{"Drawing a genealogy", "MutationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationRate"],

Cell[TextData[{
  "Mutations",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "Mutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutations"],

Cell[TextData[{
  "MVariables",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MVariables"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MVariables"],

Cell[TextData[{
  "Negative binomial",
  ",",
  " c<1",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "c<1"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Negative binomial"],

Cell[TextData[{
  " compiled",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " multiplicative models",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "multiplicative models"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " normalisation",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalisation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " timings",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Timings"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Negative binomial"],

Cell[TextData[{
  "NegativeBinomialLogLikelihood",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", 
      "NegativeBinomialLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeBinomialLogLikelihood"],

Cell[TextData[{
  "NegativeBinomialMLE",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "NegativeBinomialMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeBinomialMLE"],

Cell[TextData[{
  "NegativeHypergeometricDistribution",
  ",",
  " ",
  ButtonBox["Negative hypergeometric distribution",
    ButtonData:>{"Negative hypergeometric distribution", 
      "NegativeHypergeometricDistribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeHypergeometricDistribution"],

Cell[TextData[{
  "NeighbourArray",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "NeighbourArray"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NeighbourArray"],

Cell[TextData[{
  "Neighbours",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Neighbours"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Neighbours"],

Cell[TextData[{
  "NetCovariance",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "NetCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetCovariance"],

Cell[TextData[{
  "NetFecundity",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NetFecundity"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetFecundity"],

Cell[TextData[{
  "NetMortality",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NetMortality"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetMortality"],

Cell[TextData[{
  "NetRecombination",
  ",",
  " ",
  ButtonBox["Linkage",
    ButtonData:>{"Linkage", "NetRecombination"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Linkage in families",
    ButtonData:>{"Linkage in families", "NetRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetRecombination"],

Cell[TextData[{
  " in numerical models",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "NetRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetRecombination"],

Cell[TextData[{
  "Neutral marker",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Neutral marker"],

Cell[TextData[{
  "NeutralRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "NeutralRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NeutralRepresentations"],

Cell[TextData[{
  "NewGametes",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewGametes"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Mutation option",
  ", ",
  ButtonBox["Allele frequencies: reproduction",
    ButtonData:>{"Allele frequencies: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: reproduction",
    ButtonData:>{"Recursions: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " truncation selection",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", 
      "TruncationSelection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewGametes"],

Cell[TextData[{
  "NewS",
  ",",
  " ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "NewS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewS"],

Cell[TextData[{
  "Node",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "Node"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "Node"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Node"],

Cell[TextData[{
  "NodeFunction",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "NodeFunction"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeFunction"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeFunction"],

Cell[TextData[{
  " option for ExactProbability",
  ", ",
  ButtonBox["Exact probability",
    ButtonData:>{"Exact probability", "NodeFunction"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeFunction"],

Cell[TextData[{
  "NodeLabels",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeLabels"],

Cell[TextData[{
  "NodeOffset",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeOffset"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeOffset"],

Cell[TextData[{
  "Nodes",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "Nodes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Nodes"],

Cell[TextData[{
  "NonMendelian",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonMendelian"],

Cell[TextData[{
  " examples of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonMendelian"],

Cell[TextData[{
  "NonNeutralRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "NonNeutralRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonNeutralRepresentations"],

Cell[TextData[{
  "NonSymmetricRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "NonSymmetricRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonSymmetricRepresentations"],

Cell[TextData[{
  "Normalisation",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalisation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Normalisation"],

Cell[TextData[{
  "Normalised",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Normalised"],

Cell[TextData[{
  "Notation",
  ",",
  " clearing definitions",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "Clearing definitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation"],

Cell[TextData[{
  " data",
  ", ",
  ButtonBox["Notation for genetic data",
    ButtonData:>{"Notation for genetic data", "NotationPackage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining new",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "Defining new notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotypes",
  ", ",
  ButtonBox["Notation",
    ButtonData:>{"Notation", "NotationPackage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation"],

Cell[TextData[{
  "Notation Package",
  ",",
  " ",
  ButtonBox["Notation package",
    ButtonData:>{"Notation package", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation Package"],

Cell[TextData[{
  "NumberedLink",
  ",",
  " ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "NumberedLink"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberedLink"],

Cell[TextData[{
  "Numbering",
  ",",
  " aesthetics",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Aesthetics"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numbering"],

Cell[TextData[{
  " automatic",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "7.2"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notes on",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Notes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving links",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Saving the links"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numbering"],

Cell[TextData[{
  "NumberOfCoalescences",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "NumberOfCoalescences"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfCoalescences"],

Cell[TextData[{
  "NumberOfGenes",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenes"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenes"],

Cell[TextData[{
  "NumberOfGenesTable",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfGenesTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenesTable"],

Cell[TextData[{
  "NumberOfIndividuals",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfIndividuals"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NumberOfIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfIndividuals"],

Cell[TextData[{
  "NumberOfIndividualsTable",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfIndividualsTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfIndividualsTable"],

Cell[TextData[{
  "NumberOfLineages",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "NumberOfLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfLineages"],

Cell[TextData[{
  "NumberOfLoci",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfLoci"],

Cell[TextData[{
  "NumberOfMutations",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "NumberOfMutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfMutations"],

Cell[TextData[{
  "NumberOfPossibleCoalescences",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "NumberOfPossibleCoalescences"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfPossibleCoalescences"],

Cell[TextData[{
  "NumberOfSamplePartitions",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "NumberOfSamplePartitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfSamplePartitions"],

Cell[TextData[{
  "NumberOfSetPartitions",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "NumberOfSetPartitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfSetPartitions"],

Cell[TextData[{
  "NumericalModel",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "NumericalModel"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumericalModel"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "NumericalModel"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumericalModel"],

Cell[TextData[{
  "Numerical models",
  ",",
  " genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numerical models"],

Cell[TextData[{
  " of allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " overview",
  ", ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " problems",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric",
  ", ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numerical models"],

Cell[TextData[{
  "Observable genotype",
  ",",
  " ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Observable genotype"],

Cell[TextData[{
  "Obsolete",
  ",",
  " Combine",
  ", ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Separate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Obsolete"],

Cell[TextData[{
  " CumulantReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "CumulantReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidConstraints",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidConstraints"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidGenotypeFrequencyReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidGenotypeFrequencyTable",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Estimating D",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " fitness",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Obsolete notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " FullGenotypeFrequencyReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " FullGenotypeFrequencyTable",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " GenotypeFrequencyArguments",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "GenotypeFrequencyArguments"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " HaploidConstraints",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "HaploidConstraints"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " InitialStepReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "InitialStepReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " IntervalCombine",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalCombine"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " IntervalPosition",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalPosition"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " LogLikelihoodDisequilibriumReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "LogLikelihoodDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MetropolisDisequilibriumReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MetropolisDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MomentReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MomentReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Obsolete"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Separate",
  ", ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Combine"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Obsolete"],

Cell[TextData[{
  "Offspring",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Offspring"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Offspring"],

Cell[TextData[{
  "Orive & Barton 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Orive & Barton 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Orive & Barton 1999"],

Cell[TextData[{
  "OtherSex",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "OtherSex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"OtherSex"],

Cell[TextData[{
  "Packages",
  ",",
  " help",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Packages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Packages"],

Cell[TextData[{
  " overview of",
  ", ",
  ButtonBox["Overview of the packages",
    ButtonData:>{"Overview of the packages", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving using PackageSaver",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " setting up",
  ", ",
  ButtonBox["Setting up the packages",
    ButtonData:>{"Setting up the packages", "Setting up the packages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Special notation",
    ButtonData:>{"Special notation", "Setting up packages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " versions of",
  ", ",
  ButtonBox["Versions",
    ButtonData:>{"Versions", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Packages"],

Cell[TextData[{
  "PackageSaver",
  ",",
  " ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PackageSaver"],

Cell[TextData[{
  "Paternal inheritance",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Paternal inheritance"],

Cell[TextData[{
  "PaternalLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaternalLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaternalLoci"],

Cell[TextData[{
  "PatternFree",
  ",",
  " ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "PatternFree"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PatternFree"],

Cell[TextData[{
  "Permutations in defining coefficients",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Permutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Permutations in defining coefficients"],

Cell[TextData[{
  "Phenotypes",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Phenotypes"],

Cell[TextData[{
  "Phipps & Brill 1995",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Phipps & Brill 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Phipps & Brill 1995"],

Cell[TextData[{
  "Ploidy",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "Ploidy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ploidy"],

Cell[TextData[{
  "PloidyWeightList",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "PloidyWeightList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PloidyWeightList"],

Cell[TextData[{
  "PlotGenealogy",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "PlotGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PlotGenealogy"],

Cell[TextData[{
  "PlotLogL",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "PlotLogL"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PlotLogL"],

Cell[TextData[{
  "PopulationDisequilibrium",
  ",",
  "\[GothicCapitalC], \[AliasIndicator]goC\[AliasIndicator]",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationDisequilibrium"],

Cell[TextData[{
  "PopulationExpectation",
  ",",
  " ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationExpectation"],

Cell[TextData[{
  " multiple arguments",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "multiple arguments"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationExpectation"],

Cell[TextData[{
  "PopulationRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "PopulationRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationRepresentations"],

Cell[TextData[{
  "Position",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "position"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "position"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Position"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "position"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Contexts and positions"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Position"],

Cell[TextData[{
  "PositionsList",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PositionsList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PositionsList"],

Cell[TextData[{
  "PositionsMatrix",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PositionsMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PositionsMatrix"],

Cell[TextData[{
  "PossibleCoalescenceOrder",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "PossibleCoalescenceOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleCoalescenceOrder"],

Cell[TextData[{
  "PossibleDiploidGenotypes",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PossibleDiploidGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleDiploidGenotypes"],

Cell[TextData[{
  "PossibleGenotypes",
  ",",
  " ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "PossibleGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleGenotypes"],

Cell[TextData[{
  "PowerF",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PowerF"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "PowerF"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PowerF"],

Cell[TextData[{
  "PresentOneWayTable",
  ",",
  " ",
  ButtonBox["Single-locus tables",
    ButtonData:>{"Single-locus tables", "PresentOneWayTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentOneWayTable"],

Cell[TextData[{
  "PresentPairwiseTable",
  ",",
  " ",
  ButtonBox["Pairwise tables",
    ButtonData:>{"Pairwise tables", "PresentPairwiseTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentPairwiseTable"],

Cell[TextData[{
  "PresentResults",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "PresentResults"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentResults"],

Cell[TextData[{
  "PrintDetails",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "PrintDetails"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PrintDetails"],

Cell[TextData[{
  "Problems",
  ",",
  " avoid integers",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Avoid integers"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Problems"],

Cell[TextData[{
  " redefining fitness",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Allele frequencies"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Redefining fitness"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "StoreResults (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Problems"],

Cell[TextData[{
  "Products",
  ",",
  " multiple",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Multiple products"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Products"],

Cell[TextData[{
  "ProductSum",
  ",",
  " ",
  ButtonBox["ProductSum",
    ButtonData:>{"ProductSum", "ProductSum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ProductSum"],

Cell[TextData[{
  " over sets",
  ", ",
  ButtonBox["ProductSum",
    ButtonData:>{"ProductSum", "ProductSum over sets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ProductSum"],

Cell[TextData[{
  "QLE",
  ",",
  " haploid selection example",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", "QLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"QLE"],

Cell[TextData[{
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"QLE"],

Cell[TextData[{
  "Quasi-linkage equilibrium",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Quasi-linkage equilibrium"],

Cell[TextData[{
  "RandomBottleneckedGenealogy",
  ",",
  " ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", "RandomBottleneckedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomBottleneckedGenealogy"],

Cell[TextData[{
  "RandomCoalescenceOrder",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "RandomCoalescenceOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCoalescenceOrder"],

Cell[TextData[{
  "RandomCoalescenceTimes",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", 
      "RandomCoalescenceTimes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCoalescenceTimes"],

Cell[TextData[{
  "RandomCum",
  ",",
  " ",
  ButtonBox["Sampling from arbitrary distributions",
    ButtonData:>{"Sampling from arbitrary distributions", "RandomCum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCum"],

Cell[TextData[{
  "Random drift",
  ",",
  " changing reference points",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Changing reference points"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random drift"],

Cell[TextData[{
  " cumulants and moments",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " describing a distribution",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Describing a distribution"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " equations for the moments",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Equations for the moments"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in a cline",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: drift",
    ButtonData:>{"Allele frequencies: drift", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of genotype frequencies",
  ", ",
  ButtonBox["Recursions: drift",
    ButtonData:>{"Recursions: drift", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population disequilibrium",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population expectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population expectations",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Wright-Fisher sampling",
  ", ",
  ButtonBox["Wright-Fisher sampling",
    ButtonData:>{"Wright-Fisher sampling", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random drift"],

Cell[TextData[{
  "RandomDrift",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: drift",
    ButtonData:>{"Recursions: drift", "RandomDrift"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomDrift"],

Cell[TextData[{
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "RandomDrift"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomDrift"],

Cell[TextData[{
  "RandomFamilies",
  ",",
  " ",
  ButtonBox["Random families",
    ButtonData:>{"Random families", "RandomFamilies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamilies"],

Cell[TextData[{
  "RandomFamily",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "RandomFamily"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamily"],

Cell[TextData[{
  " segregation ratio",
  ", ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamily"],

Cell[TextData[{
  "Random genealogies",
  ",",
  " population bottlenecks",
  ", ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random genealogies"],

Cell[TextData[{
  "RandomGenealogy",
  ",",
  " ",
  ButtonBox["Drawing a genealogy",
    ButtonData:>{"Drawing a genealogy", "RandomGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomGenealogy"],

Cell[TextData[{
  "RandomList",
  ",",
  " ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "RandomList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomList"],

Cell[TextData[{
  " sampling without replacement",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomList"],

Cell[TextData[{
  "Random lists",
  ",",
  " compiled",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random lists"],

Cell[TextData[{
  "RandomMating",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "RandomMating"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomMating"],

Cell[TextData[{
  "RandomMultinomial",
  ",",
  " ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", "RandomMultinomial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomMultinomial"],

Cell[TextData[{
  "RandomPreviousFamily",
  ",",
  " ",
  ButtonBox["Random families",
    ButtonData:>{"Random families", "RandomPreviousFamily"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomPreviousFamily"],

Cell[TextData[{
  "Random sampling",
  ",",
  " ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Random sampling"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random sampling"],

Cell[TextData[{
  " example in estimating D",
  ", ",
  ButtonBox["Sampling example",
    ButtonData:>{"Sampling example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of genealogies",
  ", ",
  ButtonBox["Sampling genealogies",
    ButtonData:>{"Sampling genealogies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random sampling"],

Cell[TextData[{
  "RandomSet",
  ",",
  " ",
  ButtonBox["Random sets",
    ButtonData:>{"Random sets", "RandomSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomSet"],

Cell[TextData[{
  "Random union",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Random union"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random union"],

Cell[TextData[{
  " in admixture models",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "RandomUnionObsolete"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random union"],

Cell[TextData[{
  "RandomUnion",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnion"],

Cell[TextData[{
  "RandomUnionMethod",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnionMethod"],

Cell[TextData[{
  "RandomUnionObsolete",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnionObsolete"],

Cell[TextData[{
  "Random walk",
  ",",
  " in estimating D",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random walk"],

Cell[TextData[{
  "Recombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Recombination"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Recombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombination"],

Cell[TextData[{
  " context-dependent",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Context-dependent recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotype-dependent",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Genotype-dependent recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in admixture models",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "Recombined"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " no linkage",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "UnlinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombination"],

Cell[TextData[{
  "RecombinationRate",
  ",",
  " \[GothicR], \[AliasIndicator]gor\[AliasIndicator]",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinationRate"],

Cell[TextData[{
  "RecombinationSet",
  ",",
  " \[DoubleStruckCapitalR], \[AliasIndicator]dsR\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinationSet"],

Cell[TextData[{
  "Recombined",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "Recombined"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombined"],

Cell[TextData[{
  "ReducedData",
  ",",
  " ",
  ButtonBox["Simplifying a dataset",
    ButtonData:>{"Simplifying a dataset", "ReducedData"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReducedData"],

Cell[TextData[{
  "ReferencePoint",
  ",",
  " \[WeierstrassP], \[AliasIndicator]wp\[AliasIndicator]",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePoint"],

Cell[TextData[{
  "ReferencePointMean",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointMean"],

Cell[TextData[{
  " cytoplasmic inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " paternal inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sex-linkage",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointMean"],

Cell[TextData[{
  "ReferencePointSame",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointSame"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointSame"],

Cell[TextData[{
  "ReferencePointZero",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointZero"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointZero"],

Cell[TextData[{
  "Reference values",
  ",",
  " ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Reference values"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reference values"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Reference values"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Describing genotypes and populations"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reference values"],

Cell[TextData[{
  "RemoveTag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "RemoveTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RemoveTag"],

Cell[TextData[{
  "Repeat",
  ",",
  " ",
  ButtonBox["Repeated elements",
    ButtonData:>{"Repeated elements", "Repeat"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Repeat"],

Cell[TextData[{
  "Replace",
  ",",
  " ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Replace"],

Cell[TextData[{
  "ReplaceAllSpecial",
  ",",
  " |.",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReplaceAllSpecial"],

Cell[TextData[{
  "ReplaceRepeatedSpecial",
  ",",
  " ||.",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceRepeatedSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReplaceRepeatedSpecial"],

Cell[TextData[{
  "Representations",
  ",",
  " converting between",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Representations"],

Cell[TextData[{
  "of populations",
  ", ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "Representing the population"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Representations"],

Cell[TextData[{
  "Reproduction",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reproduction"],

Cell[TextData[{
  "Reverse",
  ",",
  " ",
  ButtonBox["Sorting",
    ButtonData:>{"Sorting", "Reverse"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reverse"],

Cell[TextData[{
  "RootedGenealogy",
  ",",
  " ",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "RootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RootedGenealogy"],

Cell[TextData[{
  "Rules",
  ",",
  " ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Rules"],

Cell[TextData[{
  " non-evaluation of",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Rules"],

Cell[TextData[{
  "SampleCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "SampleCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SampleCovariance"],

Cell[TextData[{
  "SampleIndividuals",
  ",",
  " ",
  ButtonBox["Sampling individuals",
    ButtonData:>{"Sampling individuals", "SampleIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SampleIndividuals"],

Cell[TextData[{
  "SamplePartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SamplePartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SamplePartition"],

Cell[TextData[{
  "Sampling",
  ",",
  " without replacement",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sampling"],

Cell[TextData[{
  "Scripts and faces",
  ",",
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Scripts and faces"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Scripts and faces"],

Cell[TextData[{
  "SegregationRatio",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SegregationRatio"],

Cell[TextData[{
  "SelectContext",
  ",",
  " \[CircleDot], \[AliasIndicator]c.\[AliasIndicator]",
  ", ",
  ButtonBox["Selecting contexts",
    ButtonData:>{"Selecting contexts", "SelectContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectContext"],

Cell[TextData[{
  "SelectIndividuals",
  ",",
  " ",
  ButtonBox["Selecting subsets",
    ButtonData:>{"Selecting subsets", "SelectIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectIndividuals"],

Cell[TextData[{
  "Selection",
  ",",
  " ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Selection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection"],

Cell[TextData[{
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on genotype frequencies",
  ", ",
  ButtonBox["Recursions: fitnesses",
    ButtonData:>{"Recursions: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on multiple alleles",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Technicalities"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " truncation",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "TruncationSelection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with two alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection"],

Cell[TextData[{
  "SelectionCoefficient",
  ",",
  " \[GothicA], \[AliasIndicator]goa\[AliasIndicator]",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionCoefficient"],

Cell[TextData[{
  "Selection coefficients",
  ",",
  " as defined in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Permutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection coefficients"],

Cell[TextData[{
  " making",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with multiple alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection coefficients"],

Cell[TextData[{
  "SelectionExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionExact"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: fitnesses",
    ButtonData:>{"Recursions: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionExact"],

Cell[TextData[{
  "Selection on diploids",
  ",",
  " a method to avoid",
  ", ",
  ButtonBox["A method to avoid",
    ButtonData:>{"A method to avoid", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection on diploids"],

Cell[TextData[{
  " cautionary notes",
  ", ",
  ButtonBox["Cautionary notes",
    ButtonData:>{"Cautionary notes", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete life cycle",
  ", ",
  ButtonBox["Complete life cyle",
    ButtonData:>{"Complete life cyle", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " explaining the rules",
  ", ",
  ButtonBox["Explaining the rules",
    ButtonData:>{"Explaining the rules", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction",
  ", ",
  ButtonBox["Introduction to selection on diploids",
    ButtonData:>{"Introduction to selection on diploids", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " life cycle",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection on diploids"],

Cell[TextData[{
  "SelectionRate",
  ",",
  " \[GothicS],\[AliasIndicator]gos\[AliasIndicator]",
  ", ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SelectionRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionRate"],

Cell[TextData[{
  "SelectLoci",
  ",",
  " ",
  ButtonBox["Selecting subsets",
    ButtonData:>{"Selecting subsets", "SelectLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectLoci"],

Cell[TextData[{
  "Selfing",
  ",",
  " ",
  ButtonBox["Selfing",
    ButtonData:>{"Selfing", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selfing"],

Cell[TextData[{
  "Separate",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Separate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Separate"],

Cell[TextData[{
  "Servedio",
  ",",
  " Maria",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", "Servedio"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Servedio"],

Cell[TextData[{
  "Set",
  ",",
  " of all positions affecting a trait, \[DoubleStruckCapitalZ], \
\[AliasIndicator]dsZ\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set"],

Cell[TextData[{
  " of all positions in genome, \[DoubleStruckCapitalG], \[AliasIndicator]dsG\
\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set"],

Cell[TextData[{
  "Set manipulation",
  ",",
  " overview",
  ", ",
  ButtonBox["Overview of set manipulation",
    ButtonData:>{"Overview of set manipulation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set manipulation"],

Cell[TextData[{
  "SetPartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SetPartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SetPartition"],

Cell[TextData[{
  "Sets of loci",
  ",",
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets of loci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sets of loci"],

Cell[TextData[{
  "Sex",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Sex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex"],

Cell[TextData[{
  "Sex linkage",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex linkage"],

Cell[TextData[{
  " examples of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex linkage"],

Cell[TextData[{
  "SexOfOrigin",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "SexOfOrigin"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SexOfOrigin"],

Cell[TextData[{
  "Sexual selection",
  ",",
  " ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Sexual selection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sexual selection"],

Cell[TextData[{
  " and migration",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Sexual selection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete life cycle",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Complete cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining fitnesses",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Sexual selection by female choice"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "on haploids",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " recombination",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " subtle problem",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "subtle problem"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sexual selection"],

Cell[TextData[{
  "ShortContext",
  ",",
  " ",
  ButtonBox["Abbreviating contexts",
    ButtonData:>{"Abbreviating contexts", "ShortContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ShortContext"],

Cell[TextData[{
  "SigmaMatrix",
  ",",
  " ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "SigmaMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SigmaMatrix"],

Cell[TextData[{
  "SignMask",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "SignMask"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SignMask"],

Cell[TextData[{
  "SimplifyAddUp",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "SimplifyAddUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyAddUp"],

Cell[TextData[{
  "SimplifyAddUpQ",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "SimplifyAddUpQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyAddUpQ"],

Cell[TextData[{
  "SimplifyFamilies",
  ",",
  " ",
  ButtonBox["Probabilities",
    ButtonData:>{"Probabilities", "SimplifyFamilies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyFamilies"],

Cell[TextData[{
  "Simulating individuals",
  ",",
  " recursions",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Simulating individuals"],

Cell[TextData[{
  " representation",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reproduction",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Simulating individuals"],

Cell[TextData[{
  "SizeOfGenealogyPlot",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "SizeOfGenealogyPlot"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SizeOfGenealogyPlot"],

Cell[TextData[{
  "Slatkin & Excoffier 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Slatkin & Excoffier 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Slatkin & Excoffier 1996"],

Cell[TextData[{
  "SlowChange",
  ",",
  " ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SlowChange"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SlowChange"],

Cell[TextData[{
  "SortByClass",
  ",",
  " ",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "SortByClass"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByClass"],

Cell[TextData[{
  " genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "SortByClass"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByClass"],

Cell[TextData[{
  "SortByHead",
  ",",
  " ",
  ButtonBox["Sorting",
    ButtonData:>{"Sorting", "SortByHead"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByHead"],

Cell[TextData[{
  "SpatialCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "SpatialCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SpatialCovariance"],

Cell[TextData[{
  "Spatially varying selection",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Spatially varying selection",
    ButtonData:>{"Spatially varying selection", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Spatially varying selection"],

Cell[TextData[{
  "Special notation",
  ",",
  " ",
  ButtonBox["Special notation",
    ButtonData:>{"Special notation", "Defining notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Special notation"],

Cell[TextData[{
  "Stabilising selection",
  ",",
  " change in D",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Change in D"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stabilising selection"],

Cell[TextData[{
  " change in mean",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Change in mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Defining fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", 
      "Natural selection on an additive polygenic trait"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "mean fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Mean fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "New mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "New mean fitness"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stabilising selection"],

Cell[TextData[{
  "Stability",
  ",",
  " of numerical models",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stability"],

Cell[TextData[{
  " of symmetric model",
  ", ",
  ButtonBox["Symmetric stability: outline",
    ButtonData:>{"Symmetric stability: outline", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stability"],

Cell[TextData[{
  "StabilityDirect",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", "StabilityDirect"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityDirect"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", "StabilityDirect"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityDirect"],

Cell[TextData[{
  "StabilityK",
  ",",
  " ",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", "StabilityK"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "StabilityK"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityK"],

Cell[TextData[{
  "StabilityKTable",
  ",",
  " ",
  ButtonBox["Symmetric stability: faster algorithms",
    ButtonData:>{"Symmetric stability: faster algorithms", "StabilityKTable"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityKTable"],

Cell[TextData[{
  "StabilityMatrix",
  ",",
  " ",
  ButtonBox["Making a stability matrix",
    ButtonData:>{"Making a stability matrix", "StabilityMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityMatrix"],

Cell[TextData[{
  "Stage",
  ",",
  " \[Sampi], \[AliasIndicator]sa\[AliasIndicator]",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stage"],

Cell[TextData[{
  "Stages",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stages"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Stages and contexts"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stages"],

Cell[TextData[{
  "StartingStepSize",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "StartingStepSize"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StartingStepSize"],

Cell[TextData[{
  "Stepping-stone migration",
  ",",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", 
      "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone migration"],

Cell[TextData[{
  "Stepping-stone model",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", 
      "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone model"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "Nearest-neighbour migration"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone model"],

Cell[TextData[{
  "StoreExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreExact"],

Cell[TextData[{
  " for allele frequency clines",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequency clines",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreExact"],

Cell[TextData[{
  "StoreResults",
  ",",
  " option for GameteTable",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreResults"],

Cell[TextData[{
  " option for NewGametes",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " use when compiling",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "StoreResults (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreResults"],

Cell[TextData[{
  "StructuredArray",
  ",",
  " ",
  ButtonBox["Useful functions",
    ButtonData:>{"Useful functions", "StructuredArray"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredArray"],

Cell[TextData[{
  "StructuredInitialParameters",
  ",",
  " ",
  ButtonBox["Initial parameters",
    ButtonData:>{"Initial parameters", "StructuredInitialParameters"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredInitialParameters"],

Cell[TextData[{
  "StructuredLogLikelihood",
  ",",
  " ",
  ButtonBox["Likelihood of a structured model",
    ButtonData:>{"Likelihood of a structured model", 
      "StructuredLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredLogLikelihood"],

Cell[TextData[{
  "StructuredMLE",
  ",",
  " ",
  ButtonBox["Likelihood of a structured model",
    ButtonData:>{"Likelihood of a structured model", "StructuredMLE"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "StructuredMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredMLE"],

Cell[TextData[{
  "StructuredModel",
  ",",
  " ",
  ButtonBox["Useful functions",
    ButtonData:>{"Useful functions", "StructuredModel"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredModel"],

Cell[TextData[{
  "StructuredModelReduce",
  ",",
  " ",
  ButtonBox["Simplifying a model",
    ButtonData:>{"Simplifying a model", "StructuredModelReduce"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredModelReduce"],

Cell[TextData[{
  "Structured models",
  ",",
  " example",
  ", ",
  ButtonBox["Example data",
    ButtonData:>{"Example data", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Structured models"],

Cell[TextData[{
  " hierarchical analysis",
  ", ",
  ButtonBox["Hierarchical analysis",
    ButtonData:>{"Hierarchical analysis", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Structured models"],

Cell[TextData[{
  "StructuredParameter",
  ",",
  " ",
  ButtonBox["Structured parameters",
    ButtonData:>{"Structured parameters", "StructuredParameter"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredParameter"],

Cell[TextData[{
  "StructuredVariance",
  ",",
  " ",
  ButtonBox["Variance components for a structured model",
    ButtonData:>{"Variance components for a structured model", 
      "StructuredVariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredVariance"],

Cell[TextData[{
  "Style sheets",
  ",",
  " bugs with",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Style sheets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Style sheets"],

Cell[TextData[{
  "Subdivide",
  ",",
  " ",
  ButtonBox["Muddling and subdividing sets",
    ButtonData:>{"Muddling and subdividing sets", "Subdivide"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subdivide"],

Cell[TextData[{
  "Subscripts",
  ",",
  " as written in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets in subscripts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subscripts"],

Cell[TextData[{
  "Subsets",
  ",",
  " ",
  ButtonBox["Subsets",
    ButtonData:>{"Subsets", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subsets"],

Cell[TextData[{
  " option for AddUp",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Subsets"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for TimesUp",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subsets"],

Cell[TextData[{
  "Sums",
  ",",
  " multiple",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Multiple sums"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sums"],

Cell[TextData[{
  "Symmetric cline",
  ",",
  " in allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a symmetric cline",
    ButtonData:>{"Allele frequencies: setting up a symmetric cline", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric cline"],

Cell[TextData[{
  " in genotype frequencies",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric cline"],

Cell[TextData[{
  "SymmetricDiploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricDiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricDiploidFrequencies"],

Cell[TextData[{
  "SymmetricHaploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricHaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricHaploidFrequencies"],

Cell[TextData[{
  "Symmetric model",
  ",",
  " adding a neutral marker",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: limitations",
    ButtonData:>{"Symmetric model: limitations", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric model"],

Cell[TextData[{
  " cline example",
  ", ",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: spatially varying selection",
    ButtonData:>{"Symmetric stability: spatially varying selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " limitations",
  ", ",
  ButtonBox["Symmetric model: limitations",
    ButtonData:>{"Symmetric model: limitations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " one deme example",
  ", ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "overview",
  ", ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " references",
  ", ",
  ButtonBox["Symmetric model: references",
    ButtonData:>{"Symmetric model: references", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reproduction",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Symmetric stability: outline",
    ButtonData:>{"Symmetric stability: outline", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric model"],

Cell[TextData[{
  "SymmetricNeutralDiploidFrequencies",
  ",",
  " ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricNeutralDiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricNeutralDiploidFrequencies"],

Cell[TextData[{
  "SymmetricNeutralHaploidFrequencies",
  ",",
  " ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricNeutralHaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricNeutralHaploidFrequencies"],

Cell[TextData[{
  "SymmetricRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "SymmetricRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricRecombination"],

Cell[TextData[{
  "SymmetricRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "SymmetricRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricRepresentations"],

Cell[TextData[{
  "SymmetricSexes",
  ",",
  " ",
  ButtonBox["Symmetric sexes",
    ButtonData:>{"Symmetric sexes", "SymmetricSexes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricSexes"],

Cell[TextData[{
  "Symmetrise",
  ",",
  " ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Symmetrise"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetrise",
    ButtonData:>{"Symmetrise", "Symmetrise"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetrise"],

Cell[TextData[{
  "T",
  ",",
  " time",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "T"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"T"],

Cell[TextData[{
  "Table",
  ",",
  " option for VarianceComponents",
  ", ",
  ButtonBox["Variance components",
    ButtonData:>{"Variance components", "Table"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Table"],

Cell[TextData[{
  "Tag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Tag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tag"],

Cell[TextData[{
  "Tags",
  ",",
  " finding",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Finding tags"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tags"],

Cell[TextData[{
  " setting up hyperlinks to",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Setting up links to a list of tags"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tags"],

Cell[TextData[{
  "TakeAway, \[Backslash], \[AliasIndicator]\[AliasIndicator], ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TakeAway"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TakeAway",
    ButtonData:>{"TakeAway", "TakeAway"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TakeAway"],

Cell[TextData[{
  "TakeOptions",
  ",",
  " ",
  ButtonBox["Manipulating options",
    ButtonData:>{"Manipulating options", "TakeOptions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TakeOptions"],

Cell[TextData[{
  "Time",
  ",",
  " T",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "T"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Time"],

Cell[TextData[{
  "TimesUp",
  ",",
  " ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TimesUp"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "TimesUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimesUp"],

Cell[TextData[{
  " multiple products",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Multiple products"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over subsets",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimesUp"],

Cell[TextData[{
  "ToCumulants",
  ",",
  " ",
  ButtonBox["Multilocus cumulants",
    ButtonData:>{"Multilocus cumulants", "ToCumulants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToCumulants"],

Cell[TextData[{
  "ToMoments",
  ",",
  " ",
  ButtonBox["Multilocus cumulants",
    ButtonData:>{"Multilocus cumulants", "ToMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToMoments"],

Cell[TextData[{
  "ToPopulationCumulants",
  ",",
  " ",
  ButtonBox["Random drift: cumulants",
    ButtonData:>{"Random drift: cumulants", "ToPopulationCumulants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToPopulationCumulants"],

Cell[TextData[{
  "ToPopulationMoments",
  ",",
  " ",
  ButtonBox["Random drift: cumulants",
    ButtonData:>{"Random drift: cumulants", "ToPopulationMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToPopulationMoments"],

Cell[TextData[{
  "TotalLength",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "TotalLength"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalLength"],

Cell[TextData[{
  "TotalNumber",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "TotalNumber"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalNumber"],

Cell[TextData[{
  "Trait",
  ",",
  " set of all positions affecting, \[DoubleStruckCapitalZ], \
\[AliasIndicator]dsZ\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Trait"],

Cell[TextData[{
  "TransformedRange",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "TransformedRange"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransformedRange"],

Cell[TextData[{
  "TransformInformation",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "TransformInformation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransformInformation"],

Cell[TextData[{
  "TransmissionRule",
  ",",
  " ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "TransmissionRule"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransmissionRule"],

Cell[TextData[{
  "Transmission rules",
  ",",
  " applying",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "Applying transmission rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Transmission rules"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Transmission rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " distinct from Mathematica rules",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "Transmission vs Mathematica rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Transmission"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Transmission rules"],

Cell[TextData[{
  "TriDiagonalMatrix",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "TriDiagonalMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TriDiagonalMatrix"],

Cell[TextData[{
  "TruncationSelection",
  ",",
  " option for NewGametes",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", 
      "TruncationSelection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TruncationSelection"],

Cell[TextData[{
  "option for SelectionExact",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "TruncationSelection"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TruncationSelection"],

Cell[TextData[{
  "Turelli and Barton 1994",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Turelli and Barton 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Turelli and Barton 1994"],

Cell[TextData[{
  "Turelli & Barton 1994",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Turelli & Barton 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Turelli & Barton 1994"],

Cell[TextData[{
  "Two alleles",
  ",",
  " ",
  ButtonBox["Two alleles",
    ButtonData:>{"Two alleles", "Biallelic"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Two alleles"],

Cell[TextData[{
  " selection coefficients",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Two alleles"],

Cell[TextData[{
  "UMS",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UMS"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UMS"],

Cell[TextData[{
  "UnionOfGametes",
  ",",
  " ",
  ButtonBox["Union of gametes",
    ButtonData:>{"Union of gametes", "UnionOfGametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnionOfGametes"],

Cell[TextData[{
  "UnlinkedRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "UnlinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnlinkedRecombination"],

Cell[TextData[{
  "UnrootedGenealogy",
  ",",
  " ",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "UnrootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnrootedGenealogy"],

Cell[TextData[{
  "UpperOffDiagonal",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "UpperOffDiagonal"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UpperOffDiagonal"],

Cell[TextData[{
  "USM",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"USM"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"USM"],

Cell[TextData[{
  "VarianceComponents",
  ",",
  " ",
  ButtonBox["Variance components for a structured model",
    ButtonData:>{"Variance components for a structured model", 
      "VarianceComponents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"VarianceComponents"],

Cell[TextData[{
  " Table option",
  ", ",
  ButtonBox["Variance components",
    ButtonData:>{"Variance components", "Table"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"VarianceComponents"],

Cell[TextData[{
  "Versions",
  ",",
  " of applications packages",
  ", ",
  ButtonBox["Versions",
    ButtonData:>{"Versions", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Versions"],

Cell[TextData[{
  "WLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"WLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"WLinkedLoci"],

Cell[TextData[{
  "Wright-Fisher sampling",
  ",",
  " ",
  ButtonBox["Wright-Fisher sampling",
    ButtonData:>{"Wright-Fisher sampling", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Wright-Fisher sampling"],

Cell[TextData[{
  "X",
  ",",
  " AllelicState",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicState"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"X"],

Cell[TextData[{
  "XLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"XLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"XLinkedLoci"],

Cell[TextData[{
  "YLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"YLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"YLinkedLoci"],

Cell[TextData[{
  "ZLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ZLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ZLinkedLoci"],

Cell[TextData[{
  "Zygotes",
  ",",
  " \[GothicCapitalZ], \[AliasIndicator]goZ\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Zygotes"],

Cell[TextData[{
  "\[GothicA]",
  ",",
  " \[AliasIndicator]goa\[AliasIndicator], SelectionCoefficient",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicA]"],

Cell[TextData[{
  "\[GothicCapitalA]",
  ",",
  " \[AliasIndicator]goA\[AliasIndicator], adults",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalA]"],

Cell[TextData[{
  "\[GothicCapitalC]",
  ",",
  " \[AliasIndicator]goC\[AliasIndicator], PopulationDisequilibrium",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalC]"],

Cell[TextData[{
  "\[GothicCapitalD]",
  ",",
  " \[AliasIndicator]\[GothicCapitalD]\[AliasIndicator], Disequilibrium",
  ", ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalD]"],

Cell[TextData[{
  "\!\(\(\[GothicCapitalG]\^*\)\)",
  ",",
  " \[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, \
\[GothicCapitalG]new, new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\!\(\(\[GothicCapitalG]\^*\)\)"],

Cell[TextData[{
  "\[GothicCapitalG]",
  ",",
  " \[AliasIndicator]goG\[AliasIndicator], Gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalG]"],

Cell[TextData[{
  "\[GothicCapitalH]",
  ",",
  " \[AliasIndicator]goH\[AliasIndicator], hermaphrodites",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalH]"],

Cell[TextData[{
  "\[GothicCapitalJ]",
  ",",
  " \[AliasIndicator]goJ\[AliasIndicator], juveniles",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalJ]"],

Cell[TextData[{
  "\[GothicK]",
  ",",
  " \[AliasIndicator]gok\[AliasIndicator], CumulantDisequilibrium",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "CumulantDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicK]"],

Cell[TextData[{
  "\[GothicCapitalK]",
  ",",
  " \[AliasIndicator]goK\[AliasIndicator], CumulantPopulationDisequilibrium",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalK]"],

Cell[TextData[{
  "\[GothicM]",
  ",",
  " \[AliasIndicator]gom\[AliasIndicator], MeanContribution",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "MeanContribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicM]"],

Cell[TextData[{
  "\[GothicP]",
  ",",
  " \[AliasIndicator]gop\[AliasIndicator], AlleleFrequencyP",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicP]"],

Cell[TextData[{
  "\[GothicP]\[GothicQ]",
  ",",
  " \[AliasIndicator]gop\[AliasIndicator]\[AliasIndicator]goq\[AliasIndicator]\
, AlleleFrequencyPQ",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyPQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicP]\[GothicQ]"],

Cell[TextData[{
  "\[GothicQ]",
  ",",
  " \[AliasIndicator]goq\[AliasIndicator], AlleleFrequencyQ",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicQ]"],

Cell[TextData[{
  "\[GothicR]",
  ",",
  " \[AliasIndicator]gor\[AliasIndicator], RecombinationRate",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicR]"],

Cell[TextData[{
  "\[GothicS]",
  ",",
  "\[AliasIndicator]gos\[AliasIndicator], SelectionRate",
  ", ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SelectionRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicS]"],

Cell[TextData[{
  "\[GothicCapitalZ]",
  ",",
  " \[AliasIndicator]goZ\[AliasIndicator], Zygotes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalZ]"],

Cell[TextData[{
  "\[DoubleStruckCapitalG]",
  ",",
  " \[AliasIndicator]dsG\[AliasIndicator], set of all positions in genome",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalG]"],

Cell[TextData[{
  "\[DoubleStruckCapitalM]",
  ",",
  " \[AliasIndicator]dsM\[AliasIndicator], MigrationSet",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "MigrationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalM]"],

Cell[TextData[{
  "\[DoubleStruckCapitalR]",
  ",",
  " \[AliasIndicator]dsR\[AliasIndicator], RecombinationSet",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalR]"],

Cell[TextData[{
  "\[DoubleStruckCapitalW]",
  ",",
  " \[AliasIndicator]dsW\[AliasIndicator], FitnessSet",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "FitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalW]"],

Cell[TextData[{
  "\[DoubleStruckCapitalZ]",
  ",",
  " \[AliasIndicator]dsZ\[AliasIndicator], set of all positions affecting a \
trait",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalZ]"],

Cell[TextData[{
  "\[Gamma]",
  ",",
  " \[AliasIndicator]g\[AliasIndicator], ExtractGenes",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Gamma]"],

Cell[TextData[{
  "\[Zeta]",
  ",",
  " \[AliasIndicator]z\[AliasIndicator], AllelicDeviation",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicDeviation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Zeta]"],

Cell[TextData[{
  "\[CapitalMu]",
  ",",
  " \[AliasIndicator]M\[AliasIndicator], MigrationRate",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CapitalMu]"],

Cell[TextData[{
  "\[Chi]",
  ",",
  " \[AliasIndicator]c\[AliasIndicator], ExtractContexts",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Chi]"],

Cell[TextData[{
  "\[Sampi]",
  ",",
  " \[AliasIndicator]sa\[AliasIndicator], Stage",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Sampi]"],

Cell[TextData[{
  "$MetropolisAdjustment",
  ",",
  " ",
  ButtonBox["Metropolis algorithm",
    ButtonData:>{"Metropolis algorithm", "$MetropolisAdjustment"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$MetropolisAdjustment"],

Cell[TextData[{
  "\[WeierstrassP]",
  ",",
  " \[AliasIndicator]wp\[AliasIndicator], ReferencePoint",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[WeierstrassP]"],

Cell[TextData[{
  "\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]",
  ",",
  " \[AliasIndicator]l||\[AliasIndicator] \[AliasIndicator]r||\
\[AliasIndicator], population expectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],

Cell[TextData[{
  "\[CircleDot]",
  ",",
  " \[AliasIndicator]c.\[AliasIndicator], SelectContext",
  ", ",
  ButtonBox["Selecting contexts",
    ButtonData:>{"Selecting contexts", "SelectContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CircleDot]"],

Cell[TextData[{
  "\[Backslash], \[AliasIndicator]\[AliasIndicator], TakeAway, ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TakeAway"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TakeAway",
    ButtonData:>{"TakeAway", "TakeAway"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Backslash]"],

Cell[TextData[{
  "\[Wedge]",
  ",",
  " \[AliasIndicator]^\[AliasIndicator], ExactIntersection",
  ", ",
  ButtonBox["ExactIntersection",
    ButtonData:>{"ExactIntersection", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Wedge]"],

Cell[TextData[{
  "\[CirclePlus]",
  ",",
  " \[AliasIndicator]c+\[AliasIndicator], ChangeContext",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "ChangeContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CirclePlus]"]
}, Closed]],

Cell[CellGroupData[{

Cell["old index", "Subsubsection"],

Cell[BoxData[
    \(\(Scan[MakeIndexEntry, 
        ProcessIndexMatrix[MasterIndexMatrix]];\)\)], "Input"],

Cell[TextData[{
  "|.",
  ",",
  " ReplaceAllSpecial",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"|."],

Cell[TextData[{
  "\\\\",
  ",",
  " bugs with",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Repeated \\\\"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\\\\"],

Cell[TextData[{
  "<>",
  ",",
  " Expectation",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Expectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"<>"],

Cell[TextData[{
  "||.",
  ",",
  " ReplaceRepeatedSpecial",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"||."],

Cell[TextData[{
  "AddGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddGenealogy"],

Cell[TextData[{
  "Additive models",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "additive models"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive models"],

Cell[TextData[{
  "Additive selection",
  ",",
  " defining fitnesses",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive selection"],

Cell[TextData[{
  " defining rules",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Defining rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new D",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "New D"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "New mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " scaled D",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Scaled D"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive selection"],

Cell[TextData[{
  "AddNode",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddNode"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddNode"],

Cell[TextData[{
  "AddTag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "AddTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddTag"],

Cell[TextData[{
  "AddUp",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "AddUp"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "AddUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddUp"],

Cell[TextData[{
  " multiple sums",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Multiple sums"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over subsets",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Subsets"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Technicalities"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddUp"],

Cell[TextData[{
  "AdmixtureFrequency",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "AdmixtureFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AdmixtureFrequency"],

Cell[TextData[{
  "Admixture models",
  ",",
  " ",
  ButtonBox["Admixture models",
    ButtonData:>{"Admixture models", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview",
    ButtonData:>{"Overview", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Admixture models"],

Cell[TextData[{
  " changing sex",
  ", ",
  ButtonBox["Changing sex",
    ButtonData:>{"Changing sex", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " equilibria",
  ", ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " iteration",
  ", ",
  ButtonBox["Iteration",
    ButtonData:>{"Iteration", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " migration",
  ", ",
  ButtonBox["Migration in admixture models",
    ButtonData:>{"Migration in admixture models", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " recombination",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Admixture models"],

Cell[TextData[{
  "Adults",
  ",",
  " \[GothicCapitalA], \[AliasIndicator]goA\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Adults"],

Cell[TextData[{
  "Allele frequencies",
  ",",
  " definition of fitness",
  ", ",
  ButtonBox["Allele frequencies:fitnesses",
    ButtonData:>{"Allele frequencies:fitnesses", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Allele frequencies"],

Cell[TextData[{
  "AlleleFrequencies",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "AlleleFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencies"],

Cell[TextData[{
  "AlleleFrequencyMean",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyMean"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyMean"],

Cell[TextData[{
  "AlleleFrequencyP",
  ",",
  " \[GothicP], \[AliasIndicator]gop\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyP"],

Cell[TextData[{
  "AlleleFrequencyPermutations",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "AlleleFrequencyPermutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyPermutations"],

Cell[TextData[{
  "AlleleFrequencyPQ",
  ",",
  " \[GothicP]\[GothicQ], \[AliasIndicator]gop\[AliasIndicator]\
\[AliasIndicator]goq\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyPQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyPQ"],

Cell[TextData[{
  "AlleleFrequencyQ",
  ",",
  " \[GothicQ], \[AliasIndicator]goq\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyQ"],

Cell[TextData[{
  "AlleleFrequencyTable",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyTable"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "AlleleFrequencyTable"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyTable"],

Cell[TextData[{
  "AllelicDeviation",
  ",",
  " \[Zeta], \[AliasIndicator]z\[AliasIndicator]",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicDeviation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllelicDeviation"],

Cell[TextData[{
  "AllelicState",
  ",",
  " X",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicState"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllelicState"],

Cell[TextData[{
  "AllSets",
  ",",
  " ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "AllSets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllSets"],

Cell[TextData[{
  "Ancestors",
  ",",
  " determining",
  ", ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "Ancestors"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestors"],

Cell[TextData[{
  "Ancestry",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Ancestry"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestry"],

Cell[TextData[{
  "Arbitrary sets of loci",
  ",",
  " as used in Johnson et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Arbitrary sets of loci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Arbitrary sets of loci"],

Cell[TextData[{
  "Arnold 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Arnold 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Arnold 1996"],

Cell[TextData[{
  "Asmussen and Orive 2000",
  ",",
  " ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["References",
    ButtonData:>{"References", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Asmussen and Orive 2000"],

Cell[TextData[{
  "Asmussen et al. 1987",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Asmussen et al 1987"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Asmussen et al. 1987"],

Cell[TextData[{
  "B",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "B"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"B"],

Cell[TextData[{
  "Barrier",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", "Barrier"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barrier"],

Cell[TextData[{
  "BarrierStrength",
  ",",
  " ",
  ButtonBox["Describing populations",
    ButtonData:>{"Describing populations", "BarrierStrength"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BarrierStrength"],

Cell[TextData[{
  "Barton 1986",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton 1986"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 1986"],

Cell[TextData[{
  "Barton 1995",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Barton 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 1995"],

Cell[TextData[{
  "Barton 2000",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 2000"],

Cell[TextData[{
  "Barton and Turelli 1991",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Barton and Turelli 1991"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton and Turelli 1991"],

Cell[TextData[{
  "Barton & Gale 1993",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Gale 1993"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Gale 1993"],

Cell[TextData[{
  "Barton & Shpak 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Shpak 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Shpak 1999"],

Cell[TextData[{
  "Barton & Turelli 1991",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Turelli 1991"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Turelli 1991"],

Cell[TextData[{
  "Biallelic",
  ",",
  " ",
  ButtonBox["Two alleles",
    ButtonData:>{"Two alleles", "Biallelic"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Biallelic"],

Cell[TextData[{
  " selection coefficients",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Biallelic"],

Cell[TextData[{
  "Birth",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "Birth"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Birth"],

Cell[TextData[{
  "BirthTime",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "BirthTime"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BirthTime"],

Cell[TextData[{
  "Boundary conditions",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Boundary conditions"],

Cell[TextData[{
  "Box",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Box"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Box"],

Cell[TextData[{
  "Boxes",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Boxes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Boxes"],

Cell[TextData[{
  "Browser categories",
  ",",
  " ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Browser categories"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Browser categories"],

Cell[TextData[{
  "Bugs",
  ",",
  " applying rules",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bugs"],

Cell[TextData[{
  " clashes between packages",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Clashes between packages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " estimating D",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " incompatibilities",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Incompatibilities"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " manipulating notebooks",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Manipulating notebooks"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " multilocus notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Multilocus notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " numerical error with AlleleFrequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Numerical bug"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pasting hyperlinks",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Pasting hyperlinks"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " repeated \\\\",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Repeated \\\\"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " special notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bugs"],

Cell[TextData[{
  "ChangeContext",
  ",",
  "\[CirclePlus], \[AliasIndicator]c+\[AliasIndicator]",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "ChangeContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ChangeContext"],

Cell[TextData[{
  "ChangeSex",
  ",",
  " ",
  ButtonBox["Changing sex",
    ButtonData:>{"Changing sex", "ChangeSex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ChangeSex"],

Cell[TextData[{
  "ClassToGenotypes",
  ",",
  " ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "ClassToGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClassToGenotypes"],

Cell[TextData[{
  "Cline",
  ",",
  " example of",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cline"],

Cell[TextData[{
  " in allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: spatially varying selection",
    ButtonData:>{"Symmetric stability: spatially varying selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: setting up a symmetric cline",
    ButtonData:>{"Simulating individuals: setting up a symmetric cline", 
      None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: setting up a symmetric cline",
    ButtonData:>{"Symmetric model: setting up a symmetric cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with neutral marker",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", "Cline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cline"],

Cell[TextData[{
  "ClineGradient",
  ",",
  "  for genotype frequencies",
  ", ",
  ButtonBox["ClineGradient: setting up a cline",
    ButtonData:>{"ClineGradient: setting up a cline", "ClineGradient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineGradient"],

Cell[TextData[{
  "ClineWidth",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineWidth"],

Cell[TextData[{
  "  for genotype frequencies",
  ", ",
  ButtonBox["Recursions: setting up a cline",
    ButtonData:>{"Recursions: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineWidth"],

Cell[TextData[{
  "CoalescenceDistribution",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", 
      "CoalescenceDistribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CoalescenceDistribution"],

Cell[TextData[{
  "CollapseGenealogy",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "CollapseGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CollapseGenealogy"],

Cell[TextData[{
  "Combine",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Combine"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Combine"],

Cell[TextData[{
  "CompareLogL",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "CompareLogL"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CompareLogL"],

Cell[TextData[{
  "Compiled",
  ",",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Compiled"],

Cell[TextData[{
  "Compiling",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Compiling"],

Cell[TextData[{
  "CondenseGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "CondenseGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CondenseGenealogy"],

Cell[TextData[{
  "ConstrainedIntervals",
  ",",
  " ",
  ButtonBox["Constrained intervals",
    ButtonData:>{"Constrained intervals", "ConstrainedIntervals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstrainedIntervals"],

Cell[TextData[{
  "ContextComponentQ",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextComponentQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextComponentQ"],

Cell[TextData[{
  "ContextPosition",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextPosition"],

Cell[TextData[{
  "ContextStageQ",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextStageQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextStageQ"],

Cell[TextData[{
  "ContextStructure",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextStructure"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextStructure"],

Cell[TextData[{
  "Continuous populations",
  ",",
  " estimating covariance",
  ", ",
  ButtonBox["Estimating the covariance",
    ButtonData:>{"Estimating the covariance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Continuous populations"],

Cell[TextData[{
  " example",
  ", ",
  ButtonBox["An example",
    ButtonData:>{"An example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " implementation",
  ", ",
  ButtonBox["Implementation",
    ButtonData:>{"Implementation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " the model",
  ", ",
  ButtonBox["The model",
    ButtonData:>{"The model", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Continuous populations"],

Cell[TextData[{
  "ConvertData",
  ",",
  " ",
  ButtonBox["Converting a dataset",
    ButtonData:>{"Converting a dataset", "ConvertData"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConvertData"],

Cell[TextData[{
  "ConvertHyperlinkToAddOnsLink",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "ConvertHyperlinkToAddOnsLink"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConvertHyperlinkToAddOnsLink"],

Cell[TextData[{
  "Converting",
  ",",
  " between representations",
  ", ",
  ButtonBox["Allele frequencies: converting",
    ButtonData:>{"Allele frequencies: converting", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Converting"],

Cell[TextData[{
  "CountHeterozygotes",
  ",",
  " ",
  ButtonBox["Recursions:manipulation",
    ButtonData:>{"Recursions:manipulation", "CountHeterozygotes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CountHeterozygotes"],

Cell[TextData[{
  "Covariance",
  ",",
  " in continuous populations",
  ", ",
  ButtonBox["Estimating the covariance",
    ButtonData:>{"Estimating the covariance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Covariance"],

Cell[TextData[{
  "CovarianceMidPoints",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "CovarianceMidPoints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CovarianceMidPoints"],

Cell[TextData[{
  "Crow and Kimura 1970",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Crow and Kimura 1970"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Crow and Kimura 1970"],

Cell[TextData[{
  "Cumulant",
  ",",
  " ",
  ButtonBox["Moments and cumulants",
    ButtonData:>{"Moments and cumulants", "Cumulant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cumulant"],

Cell[TextData[{
  "CumulantDisequilibrium",
  ",",
  " \[GothicK], \[AliasIndicator]gok\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "CumulantDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantDisequilibrium"],

Cell[TextData[{
  "CumulantEquilibrium",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "CumulantEquilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantEquilibrium"],

Cell[TextData[{
  "CumulantPopulationDisequilibrium",
  ",",
  " \[GothicCapitalK], \[AliasIndicator]goK\[AliasIndicator]",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantPopulationDisequilibrium"],

Cell[TextData[{
  "CumulantReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "CumulantReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantReduced"],

Cell[TextData[{
  "Cumulants",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "7.2"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Cumulant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cumulants"],

Cell[TextData[{
  "Cytoplasmic inheritance",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cytoplasmic inheritance"],

Cell[TextData[{
  " and migration",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Cytonuclear associations"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " examples of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cytoplasmic inheritance"],

Cell[TextData[{
  "CytoplasmicLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CytoplasmicLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CytoplasmicLoci"],

Cell[TextData[{
  "dAlleleFrequencyPermutations",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "dAlleleFrequencyPermutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"dAlleleFrequencyPermutations"],

Cell[TextData[{
  "Data",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Data"],

Cell[TextData[{
  " missing",
  ", ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Missing data"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notation for",
  ", ",
  ButtonBox["Notation for genetic data",
    ButtonData:>{"Notation for genetic data", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Data"],

Cell[TextData[{
  "Datasets",
  ",",
  " defining",
  ", ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Datasets"],

Cell[TextData[{
  "Death",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "Death"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Death"],

Cell[TextData[{
  "DeathTime",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "DeathTime"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeathTime"],

Cell[TextData[{
  "DefineContext",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "DefineContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DefineContext"],

Cell[TextData[{
  "DegreesOfFreedom",
  ",",
  " ",
  ButtonBox["Degrees of freedom",
    ButtonData:>{"Degrees of freedom", "DegreesOfFreedom"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DegreesOfFreedom"],

Cell[TextData[{
  "DeletedMutations",
  ",",
  " ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", "DeletedMutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeletedMutations"],

Cell[TextData[{
  "DeleteGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "DeleteGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeleteGenealogy"],

Cell[TextData[{
  "Deme",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Deme"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Deme"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Deme"],

Cell[TextData[{
  "DemeSize",
  ",",
  " compiling",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "Deme size (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DemeSize"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for MigrateExact",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DemeSize"],

Cell[TextData[{
  "Dempster et al 1977",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Dempster et al 1977"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dempster et al 1977"],

Cell[TextData[{
  "Density",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Density"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Density"],

Cell[TextData[{
  "Descendants",
  ",",
  " ",
  ButtonBox["Ancestors and descendants",
    ButtonData:>{"Ancestors and descendants", "Descendants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Descendants"],

Cell[TextData[{
  " determining",
  ", ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "Descendants"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Descendants"],

Cell[TextData[{
  "Dicytonuclear associations",
  ",",
  " ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dicytonuclear associations"],

Cell[TextData[{
  "Diploid",
  ",",
  " option for MomentFromG",
  ", ",
  ButtonBox["Moments from genotype frequencies",
    ButtonData:>{"Moments from genotype frequencies", "Diploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Diploid"],

Cell[TextData[{
  "DiploidConstraints",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidConstraints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidConstraints"],

Cell[TextData[{
  "DiploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidFrequencies"],

Cell[TextData[{
  "DiploidGenotypeFrequency",
  ",",
  " ",
  ButtonBox["Genotype frequencies from moments",
    ButtonData:>{"Genotype frequencies from moments", 
      "DiploidGenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequency"],

Cell[TextData[{
  "DiploidGenotypeFrequencyList",
  ",",
  " ",
  ButtonBox["Fast calculations",
    ButtonData:>{"Fast calculations", "DiploidGenotypeFrequencyList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyList"],

Cell[TextData[{
  "DiploidGenotypeFrequencyReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyReduced"],

Cell[TextData[{
  "DiploidGenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyTable"],

Cell[TextData[{
  "DiploidIndividuals",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidIndividuals"],

Cell[TextData[{
  "DiploidPhenotype",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidPhenotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidPhenotype"],

Cell[TextData[{
  "DiploidPsi",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidPsi"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "DiploidPsi"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidPsi"],

Cell[TextData[{
  "DiploidRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidRepresentations"],

Cell[TextData[{
  "DiploidSource",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidSource"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "DiploidSource"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidSource"],

Cell[TextData[{
  "DiploidSubsets",
  ",",
  " ",
  ButtonBox["Subsets of loci",
    ButtonData:>{"Subsets of loci", "DiploidSubsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidSubsets"],

Cell[TextData[{
  "DiploidTypes",
  ",",
  " ",
  ButtonBox["Listing genotypes",
    ButtonData:>{"Listing genotypes", "DiploidTypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidTypes"],

Cell[TextData[{
  "Disequilibrium",
  ",",
  " population",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Disequilibrium"],

Cell[TextData[{
  " \[GothicCapitalD], \[AliasIndicator]\[GothicCapitalD]\[AliasIndicator]",
  ", ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Disequilibrium"],

Cell[TextData[{
  "DisequilibriumMean",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumMean"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumMean"],

Cell[TextData[{
  "DisequilibriumTable",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumTable"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumTable"],

Cell[TextData[{
  "DistanceSquared",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "DistanceSquared"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DistanceSquared"],

Cell[TextData[{
  "Distribution",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Distribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Distribution"],

Cell[TextData[{
  "DivideZero",
  ",",
  " ",
  ButtonBox["DivideZero",
    ButtonData:>{"DivideZero", "DivideZero"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DivideZero"],

Cell[TextData[{
  "DoReplicates",
  ",",
  " ",
  ButtonBox["Analysing replicate samples",
    ButtonData:>{"Analysing replicate samples", "DoReplicates"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoReplicates"],

Cell[TextData[{
  "DoubleCline",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a symmetric cline",
    ButtonData:>{"Allele frequencies: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoubleCline"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: setting up a symmetric cline",
    ButtonData:>{"Simulating individuals: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a symmetric cline",
    ButtonData:>{"Symmetric model: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoubleCline"],

Cell[TextData[{
  "DrawSamples",
  ",",
  " ",
  ButtonBox["Setting up replicates",
    ButtonData:>{"Setting up replicates", "DrawSamples"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DrawSamples"],

Cell[TextData[{
  "DropOptions",
  ",",
  " ",
  ButtonBox["Manipulating options",
    ButtonData:>{"Manipulating options", "DropOptions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DropOptions"],

Cell[TextData[{
  "Edwards 1972",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Edwards 1972"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Edwards 1972"],

Cell[TextData[{
  "Epistasis",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Epistasis"],

Cell[TextData[{
  "EquivalentSexes",
  ",",
  " obsolete form of SymmetricSexes",
  ", ",
  ButtonBox["Symmetric sexes",
    ButtonData:>{"Symmetric sexes", "SymmetricSexes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EquivalentSexes"],

Cell[TextData[{
  "ErrorBound",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "ErrorBound"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ErrorBound"],

Cell[TextData[{
  "EstimateFamilyMoments",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "EstimateFamilyMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EstimateFamilyMoments"],

Cell[TextData[{
  "EstimateMoments",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "EstimateMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EstimateMoments"],

Cell[TextData[{
  "Estimating D",
  ",",
  " admixture models",
  ", ",
  ButtonBox["Admixture models",
    ButtonData:>{"Admixture models", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Estimating D"],

Cell[TextData[{
  " alternative methods",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Log-linear models"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction",
  ", ",
  ButtonBox["Introduction to estimating D",
    ButtonData:>{"Introduction to estimating D", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " maximum entropy",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Maximum entropy"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " maximum likelihood, example of",
  ", ",
  ButtonBox["MLE example",
    ButtonData:>{"MLE example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Metropolis random walk",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MLE, cumulants",
  ", ",
  ButtonBox["Finding the MLE",
    ButtonData:>{"Finding the MLE", "Cumulant"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " moments, families",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "Extension to families"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " naive MLE",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Naive MLE"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " obsolete",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pairs of loci",
  ", ",
  ButtonBox["Pairs of loci",
    ButtonData:>{"Pairs of loci", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pairs of loci, example of",
  ", ",
  ButtonBox["Pairwise example",
    ButtonData:>{"Pairwise example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " random sampling, example of",
  ", ",
  ButtonBox["Sampling example",
    ButtonData:>{"Sampling example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " summary",
  ", ",
  ButtonBox["Summary",
    ButtonData:>{"Summary", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " varying divergence",
  ", ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "Varying divergence"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Estimating D"],

Cell[TextData[{
  "ExactEigenvalues",
  ",",
  " ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "ExactEigenvalues"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactEigenvalues"],

Cell[TextData[{
  "ExactIntersection",
  ",",
  " \[Wedge], \[AliasIndicator]^\[AliasIndicator]",
  ", ",
  ButtonBox["ExactIntersection",
    ButtonData:>{"ExactIntersection", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactIntersection"],

Cell[TextData[{
  "Expectation",
  ",",
  " <>",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Expectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Expectation"],

Cell[TextData[{
  " as used in Johnson et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Expectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population, \[LeftDoubleBracketingBar] \[RightDoubleBracketingBar], \
\[AliasIndicator]l||\[AliasIndicator] \[AliasIndicator]r||\[AliasIndicator]",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Expectation"],

Cell[TextData[{
  "ExponentialF",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExponentialF"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "ExponentialF"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExponentialF"],

Cell[TextData[{
  "ExtantIndividuals",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "ExtantIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtantIndividuals"],

Cell[TextData[{
  "ExtractContexts",
  ",",
  " \[Chi], \[AliasIndicator]c\[AliasIndicator]",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractContexts"],

Cell[TextData[{
  "ExtractExtant",
  ",",
  " ",
  ButtonBox["Initialisation",
    ButtonData:>{"Initialisation", "ExtractExtant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractExtant"],

Cell[TextData[{
  "ExtractGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "ExtractGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractGenealogy"],

Cell[TextData[{
  "ExtractGenes",
  ",",
  " conflict with Johnson et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "gamma"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractGenes"],

Cell[TextData[{
  " \[Gamma], \[AliasIndicator]g\[AliasIndicator]",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractGenes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractGenes"],

Cell[TextData[{
  "ExtractInformation",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "ExtractInformation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractInformation"],

Cell[TextData[{
  "ExtractRepeat",
  ",",
  " ",
  ButtonBox["Repeated elements",
    ButtonData:>{"Repeated elements", "ExtractRepeat"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractRepeat"],

Cell[TextData[{
  "ExtractSubMatrix",
  ",",
  " ",
  ButtonBox["Extracting submatrices",
    ButtonData:>{"Extracting submatrices", "ExtractSubMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractSubMatrix"],

Cell[TextData[{
  "FamilyAlleleFrequencyEstimate",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyAlleleFrequencyEstimate"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyAlleleFrequencyEstimate"],

Cell[TextData[{
  "FamilyEffects",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyEffects"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyEffects"],

Cell[TextData[{
  "FamilyM",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyM"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyM"],

Cell[TextData[{
  "FamilyProbability",
  ",",
  " ",
  ButtonBox["Probabilities",
    ButtonData:>{"Probabilities", "FamilyProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyProbability"],

Cell[TextData[{
  "Family structure",
  ",",
  " set of all",
  ", ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "NewS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Family structure"],

Cell[TextData[{
  "Fecundity",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Fecundity"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fecundity"],

Cell[TextData[{
  "FindHyperlinks",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "FindHyperlinks"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindHyperlinks"],

Cell[TextData[{
  "FindIndexTag",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "FindIndexTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindIndexTag"],

Cell[TextData[{
  "FindMLE",
  ",",
  " ",
  ButtonBox["Finding the MLE",
    ButtonData:>{"Finding the MLE", "FindMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindMLE"],

Cell[TextData[{
  "FindNode",
  ",",
  " ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", "FindNode"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindNode"],

Cell[TextData[{
  "FindPosition",
  ",",
  " ",
  ButtonBox["Initialisation",
    ButtonData:>{"Initialisation", "FindPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindPosition"],

Cell[TextData[{
  "FindTags",
  ",",
  " ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "FindTags"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindTags"],

Cell[TextData[{
  "Fitness",
  ",",
  " definition for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:fitnesses",
    ButtonData:>{"Allele frequencies:fitnesses", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fitness"],

Cell[TextData[{
  " in individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " problems redefining",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Redefining fitness"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fitness"],

Cell[TextData[{
  "FitnessSet",
  ",",
  " \[DoubleStruckCapitalW], \[AliasIndicator]dsW\[AliasIndicator]",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "FitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessSet"],

Cell[TextData[{
  "FitnessTable",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessTable"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessTable"],

Cell[TextData[{
  "FixedEnds",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FixedEnds"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for MigrateExact",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FixedEnds"],

Cell[TextData[{
  "Flatten",
  ",",
  " ",
  ButtonBox["Flattening lists at specific levels",
    ButtonData:>{"Flattening lists at specific levels", "Flatten"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Flatten"],

Cell[TextData[{
  "FlattenList",
  ",",
  " ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "FlattenList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FlattenList"],

Cell[TextData[{
  " PatternFree",
  ", ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "PatternFree"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FlattenList"],

Cell[TextData[{
  "FourierNormalised",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "FourierNormalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FourierNormalised"],

Cell[TextData[{
  "FourierNormalisedTable",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "FourierNormalisedTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FourierNormalisedTable"],

Cell[TextData[{
  "FrequencyRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "FrequencyRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FrequencyRepresentations"],

Cell[TextData[{
  "FullContext",
  ",",
  " ",
  ButtonBox["Abbreviating contexts",
    ButtonData:>{"Abbreviating contexts", "FullContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullContext"],

Cell[TextData[{
  "FullGenotypeFrequencyReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullGenotypeFrequencyReduced"],

Cell[TextData[{
  "FullGenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullGenotypeFrequencyTable"],

Cell[TextData[{
  "FullOutput",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "FullOutput"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullOutput"],

Cell[TextData[{
  "Function",
  ",",
  " ",
  ButtonBox["Marginal tables",
    ButtonData:>{"Marginal tables", "Function"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Function"],

Cell[TextData[{
  "Gametes",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "Gametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gametes"],

Cell[TextData[{
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new, \!\(\(\[GothicCapitalG]\^*\)\), \
\[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, \[GothicCapitalG]new",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " \[GothicCapitalG], \[AliasIndicator]goG\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gametes"],

Cell[TextData[{
  "GameteTable",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "GameteTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GameteTable"],

Cell[TextData[{
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "GameteTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "GameteTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GameteTable"],

Cell[TextData[{
  "GaussianLogLikelihood",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "GaussianLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GaussianLogLikelihood"],

Cell[TextData[{
  "GaussianMLE",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "GaussianMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GaussianMLE"],

Cell[TextData[{
  "Genealogies",
  ",",
  " family structure",
  ", ",
  ButtonBox["Family structure",
    ButtonData:>{"Family structure", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genealogies"],

Cell[TextData[{
  " probability of",
  ", ",
  ButtonBox["Deriving the probability",
    ButtonData:>{"Deriving the probability", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sampling",
  ", ",
  ButtonBox["Sampling genealogies",
    ButtonData:>{"Sampling genealogies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genealogies"],

Cell[TextData[{
  "GenealogyToMatrix",
  ",",
  " ",
  ButtonBox["Describing mutation",
    ButtonData:>{"Describing mutation", "GenealogyToMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenealogyToMatrix"],

Cell[TextData[{
  "GeneralizedTransform",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "GeneralizedTransform"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GeneralizedTransform"],

Cell[TextData[{
  "Genes and contexts",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Genes and contexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genes and contexts"],

Cell[TextData[{
  "Genome",
  ",",
  " set of all positions in, \[DoubleStruckCapitalG], \[AliasIndicator]dsG\
\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genome"],

Cell[TextData[{
  "Genotype",
  ",",
  " observable",
  ", ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype"],

Cell[TextData[{
  "Genotype frequencies",
  ",",
  " recursions",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype frequencies"],

Cell[TextData[{
  "GenotypeFrequencyArguments",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "GenotypeFrequencyArguments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyArguments"],

Cell[TextData[{
  "GenotypeFrequencyConvert",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "GenotypeFrequencyConvert"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyConvert"],

Cell[TextData[{
  "GenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyTable"],

Cell[TextData[{
  "GenotypePosition",
  ",",
  " ",
  ButtonBox["Recursions:manipulation",
    ButtonData:>{"Recursions:manipulation", "GenotypePosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypePosition"],

Cell[TextData[{
  "GenotypeProbability",
  ",",
  " ",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "GenotypeProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeProbability"],

Cell[TextData[{
  " segregation ratio",
  ", ",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeProbability"],

Cell[TextData[{
  "Genotypes",
  ",",
  " notation for",
  ", ",
  ButtonBox["Notation",
    ButtonData:>{"Notation", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotypes"],

Cell[TextData[{
  "Gnew",
  ",",
  " \!\(\(\[GothicCapitalG]\^*\)\), \[AliasIndicator]goG\[AliasIndicator]\
\[ControlKey]^*, new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gnew"],

Cell[TextData[{
  "Goodman et al 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Goodman et al 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Goodman et al 1999"],

Cell[TextData[{
  "Griffiths-Tavare",
  ",",
  " ",
  ButtonBox["Exact algorithm",
    ButtonData:>{"Exact algorithm", "GriffithsTavare"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Griffiths-Tavare algorithm",
    ButtonData:>{"Griffiths-Tavare algorithm", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Griffiths-Tavare"],

Cell[TextData[{
  " stochastic algorithm",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "MonteCarloGriffithsTavare"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "Stochastic GT algorithm"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stochastic, comparison with MonteCarloProbability",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", 
      "Comparison with MonteCarloProbability"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stochastic example",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "Small example"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Griffiths-Tavare"],

Cell[TextData[{
  "Guiasu & Shenitzer 1985",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Guiasu & Shenitzer 1985"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Guiasu & Shenitzer 1985"],

Cell[TextData[{
  "HaploidConstraints",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "HaploidConstraints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidConstraints"],

Cell[TextData[{
  "HaploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidFrequencies"],

Cell[TextData[{
  "HaploidGenotypeFrequency",
  ",",
  " ",
  ButtonBox["Genotype frequencies from moments",
    ButtonData:>{"Genotype frequencies from moments", 
      "HaploidGenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidGenotypeFrequency"],

Cell[TextData[{
  "HaploidIndividuals",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidIndividuals"],

Cell[TextData[{
  "HaploidRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidRepresentations"],

Cell[TextData[{
  "HaploidSource",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "HaploidSource"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "HaploidSource"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidSource"],

Cell[TextData[{
  "HaploidSubsets",
  ",",
  " ",
  ButtonBox["Subsets of loci",
    ButtonData:>{"Subsets of loci", "HaploidSubsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidSubsets"],

Cell[TextData[{
  "HaploidTypes",
  ",",
  " ",
  ButtonBox["Listing genotypes",
    ButtonData:>{"Listing genotypes", "HaploidTypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidTypes"],

Cell[TextData[{
  "Help browser",
  ",",
  " setting up new files",
  ", ",
  ButtonBox["Setting up new help files",
    ButtonData:>{"Setting up new help files", "Setting up new help files"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help browser"],

Cell[TextData[{
  "Help Browser",
  ",",
  " ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "MasterIndexHeading"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help Browser"],

Cell[TextData[{
  " setting up hyperlinks",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up links"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help Browser"],

Cell[TextData[{
  "Hermaphrodites",
  ",",
  " \[GothicCapitalH], \[AliasIndicator]goH\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hermaphrodites"],

Cell[TextData[{
  "HeterozygoteB",
  ",",
  " ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "HeterozygoteB"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HeterozygoteB"],

Cell[TextData[{
  "Hill 1974a",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974a"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974a"],

Cell[TextData[{
  "Hill 1974b",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974b"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974b"],

Cell[TextData[{
  "Hill 1974c",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974c"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974c"],

Cell[TextData[{
  "Hypergeometric model",
  ",",
  " ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hypergeometric model"],

Cell[TextData[{
  "Hyperlinks",
  ",",
  " bugs in pasting",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Pasting hyperlinks"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hyperlinks"],

Cell[TextData[{
  " saving",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Saving the links"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " setting up",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up links"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " to cell tags",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Setting up links to a list of tags"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hyperlinks"],

Cell[TextData[{
  "IncidenceMatrix",
  ",",
  " ",
  ButtonBox["Ordered genealogies",
    ButtonData:>{"Ordered genealogies", "IncidenceMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IncidenceMatrix"],

Cell[TextData[{
  "Index",
  ",",
  " setting up",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up Master Index"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Index"],

Cell[TextData[{
  "Individual",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Individual"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Individual"],

Cell[TextData[{
  "IndividualRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "IndividualRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IndividualRepresentations"],

Cell[TextData[{
  "Individuals",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Individuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Individuals"],

Cell[TextData[{
  "InitialiseContinuum",
  ",",
  " ",
  ButtonBox["Initialisation",
    ButtonData:>{"Initialisation", "InitialiseContinuum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseContinuum"],

Cell[TextData[{
  "InitialiseCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "InitialiseCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseCovariance"],

Cell[TextData[{
  "InitialiseDemes",
  ",",
  " ",
  ButtonBox["Describing the population",
    ButtonData:>{"Describing the population", "InitialiseDemes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Setting up a cline",
    ButtonData:>{"Setting up a cline", "InitialiseDemes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseDemes"],

Cell[TextData[{
  "InitialStep",
  ",",
  " ",
  ButtonBox["Initial step size",
    ButtonData:>{"Initial step size", "InitialStep"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialStep"],

Cell[TextData[{
  "InitialStepReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "InitialStepReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialStepReduced"],

Cell[TextData[{
  "InternalNodes",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "InternalNodes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InternalNodes"],

Cell[TextData[{
  "IntervalCombine",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalCombine"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IntervalCombine"],

Cell[TextData[{
  "IntervalPosition",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IntervalPosition"],

Cell[TextData[{
  "InverseFourierNormalised",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "InverseFourierNormalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InverseFourierNormalised"],

Cell[TextData[{
  "InverseFourierNormalisedTable",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "InverseFourierNormalisedTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InverseFourierNormalisedTable"],

Cell[TextData[{
  "Island model",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Island model"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Island model"],

Cell[TextData[{
  "IterateContinuum",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "IterateContinuum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateContinuum"],

Cell[TextData[{
  "IterateExact",
  ",",
  " example",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateExact"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for allele frequency clines",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "IterateExact"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequency clines",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateExact"],

Cell[TextData[{
  "Johnson et al.",
  ",",
  " ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Johnson et al."},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Johnson et al."],

Cell[TextData[{
  " arbitrary sets of loci",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Arbitrary sets of loci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Expectation",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Expectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " permutations in defining coefficients",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Permutations"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " position",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "position"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " random drift",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Random drift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference values",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Reference values"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " relation with",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Multilocus MS"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " scripts and faces",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Scripts and faces"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sets in subscripts",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Sets in subscripts"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sets of loci",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Sets of loci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages and contexts",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Stages and contexts"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " transmission rules",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Transmission rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " \[Gamma], ambiguous use of",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "gamma"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Johnson et al."],

Cell[TextData[{
  "Join",
  ",",
  " ",
  ButtonBox["Join",
    ButtonData:>{"Join", "Join"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "Join"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Join"],

Cell[TextData[{
  "Juveniles",
  ",",
  " \[GothicCapitalJ], \[AliasIndicator]goJ\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Juveniles"],

Cell[TextData[{
  "Kirkpatrick and Barton 1997",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick and Barton 1997"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick and Barton 1997"],

Cell[TextData[{
  "Kirkpatrick and Servedio 1998",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick and Servedio 1998"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick and Servedio 1998"],

Cell[TextData[{
  "Kirkpatrick et al. 1983",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Kirkpatrick et al 1983"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al. 1983"],

Cell[TextData[{
  "Kruuk 1997",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Kruuk 1997"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kruuk 1997"],

Cell[TextData[{
  "LeafLabels",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "LeafLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LeafLabels"],

Cell[TextData[{
  "LeafOffset",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "LeafOffset"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LeafOffset"],

Cell[TextData[{
  "Leaves",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "Leaves"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Leaves"],

Cell[TextData[{
  "Life cycle",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Life cycle"],

Cell[TextData[{
  " adults",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete",
  ", ",
  ButtonBox["Complete life cycle",
    ButtonData:>{"Complete life cycle", "Complete rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " hermaphrodites",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " juveniles",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages in",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with cytoplasmic inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with sex linkage",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " zygotes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Life cycle"],

Cell[TextData[{
  "Li & Nei 1974",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Li & Nei 1974"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Li & Nei 1974"],

Cell[TextData[{
  "Linkage",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Linkage",
    ButtonData:>{"Linkage", "Linkage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage"],

Cell[TextData[{
  " in numerical models",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Linkage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage"],

Cell[TextData[{
  "Linkage disequilibrium",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage disequilibrium"],

Cell[TextData[{
  "ListToGenealogy",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "ListToGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ListToGenealogy"],

Cell[TextData[{
  "ListToMatrix",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "ListToMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ListToMatrix"],

Cell[TextData[{
  "Location",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Location"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Location"],

Cell[TextData[{
  "Locations",
  ",",
  " ",
  ButtonBox["Locations",
    ButtonData:>{"Locations", "Locations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Locations"],

Cell[TextData[{
  "LocusNames",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "LocusNames"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LocusNames"],

Cell[TextData[{
  "LogLikelihoodDisequilibrium",
  ",",
  " ",
  ButtonBox["Likelihood",
    ButtonData:>{"Likelihood", "LogLikelihoodDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodDisequilibrium"],

Cell[TextData[{
  "LogLikelihoodDisequilibriumReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "LogLikelihoodDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodDisequilibriumReduced"],

Cell[TextData[{
  "LogLikelihoodTest",
  ",",
  " ",
  ButtonBox["Likelihood tests",
    ButtonData:>{"Likelihood tests", "LogLikelihoodTest"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodTest"],

Cell[TextData[{
  "Log-linear models",
  ",",
  " ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Log-linear models"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Log-linear models"],

Cell[TextData[{
  "Long et al 1995",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Long et al 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Long et al 1995"],

Cell[TextData[{
  "LowerOffDiagonal",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "LowerOffDiagonal"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LowerOffDiagonal"],

Cell[TextData[{
  "MacCallum 1994",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "MacCallum 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MacCallum 1994"],

Cell[TextData[{
  "MacCallum et al. 1998",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "MacCallum et al 1998"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MacCallum et al. 1998"],

Cell[TextData[{
  "MakeCline",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeCline"],

Cell[TextData[{
  "  for genotype frequencies",
  ", ",
  ButtonBox["Recursions: setting up a cline",
    ButtonData:>{"Recursions: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeCline"],

Cell[TextData[{
  "MakeDiploid",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDiploid"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDiploid"],

Cell[TextData[{
  "MakeDistanceList",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "MakeDistanceList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDistanceList"],

Cell[TextData[{
  "MakeDistances",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "MakeDistances"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDistances"],

Cell[TextData[{
  "MakeFitnessSet",
  ",",
  " ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "MakeFitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeFitnessSet"],

Cell[TextData[{
  " with multiple alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeFitnessSet"],

Cell[TextData[{
  "MakeGenealogy",
  ",",
  " ",
  ButtonBox["Making a genealogy",
    ButtonData:>{"Making a genealogy", "MakeGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeGenealogy"],

Cell[TextData[{
  "MakeGenealogyPlot",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "MakeGenealogyPlot"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeGenealogyPlot"],

Cell[TextData[{
  "MakeHaploid",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeHaploid"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeHaploid"],

Cell[TextData[{
  "MakeIndividuals",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: converting",
    ButtonData:>{"Allele frequencies: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeIndividuals"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeIndividuals"],

Cell[TextData[{
  "MakeOneWayTable",
  ",",
  " ",
  ButtonBox["Single-locus tables",
    ButtonData:>{"Single-locus tables", "MakeOneWayTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeOneWayTable"],

Cell[TextData[{
  "MakePairwiseTable",
  ",",
  " ",
  ButtonBox["Pairwise tables",
    ButtonData:>{"Pairwise tables", "MakePairwiseTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePairwiseTable"],

Cell[TextData[{
  "MakePopulation",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePopulation"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "MakePopulation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: representation",
    ButtonData:>{"Symmetric model: representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePopulation"],

Cell[TextData[{
  "MakeSelectionCoefficient",
  ",",
  " ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeSelectionCoefficient"],

Cell[TextData[{
  " with multiple alleles",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with two alleles",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeSelectionCoefficient"],

Cell[TextData[{
  "Mangel & Hilborn 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Mangel & Hilborn 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mangel & Hilborn 1996"],

Cell[TextData[{
  "Marginal fitness",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Marginal fitness"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Marginal fitness"],

Cell[TextData[{
  "MarginalTable",
  ",",
  " ",
  ButtonBox["Marginal tables",
    ButtonData:>{"Marginal tables", "MarginalTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalTable"],

Cell[TextData[{
  "MarginalW",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalW"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalW"],

Cell[TextData[{
  "MatrixGamma",
  ",",
  " ",
  ButtonBox["Fast calculations",
    ButtonData:>{"Fast calculations", "MatrixGamma"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixGamma"],

Cell[TextData[{
  "MatrixToGenealogy",
  ",",
  " ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", "MatrixToGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixToGenealogy"],

Cell[TextData[{
  "MatrixToList",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "MatrixToList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixToList"],

Cell[TextData[{
  "MeanContribution",
  ",",
  " \[GothicM], \[AliasIndicator]gom\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "MeanContribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanContribution"],

Cell[TextData[{
  "Mean fitness",
  ",",
  " ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mean fitness"],

Cell[TextData[{
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mean fitness"],

Cell[TextData[{
  "MeanW",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanW"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanW"],

Cell[TextData[{
  "Meiosis",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Meiosis"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Meiosis"],

Cell[TextData[{
  " in numerical models",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Meiosis"],

Cell[TextData[{
  "MethodC",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MethodC"],

Cell[TextData[{
  "MethodP",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MethodP"],

Cell[TextData[{
  "Metropolis algorithm",
  ",",
  " estimating D",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Metropolis algorithm"],

Cell[TextData[{
  "MetropolisDisequilibrium",
  ",",
  " ",
  ButtonBox["Estimating moments",
    ButtonData:>{"Estimating moments", "MetropolisDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MetropolisDisequilibrium"],

Cell[TextData[{
  "MetropolisDisequilibriumReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MetropolisDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MetropolisDisequilibriumReduced"],

Cell[TextData[{
  "Metropolis et al. 1954",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Metropolis et al 1954"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Metropolis et al. 1954"],

Cell[TextData[{
  "MFromC",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MFromC"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MFromC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MFromC"],

Cell[TextData[{
  "Migrate",
  ",",
  " ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Migrate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migrate"],

Cell[TextData[{
  "MigrateExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrateExact"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrateExact"],

Cell[TextData[{
  "Migration",
  ",",
  " and cytoplasmic inheritance",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Cytonuclear associations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migration"],

Cell[TextData[{
  " and sexual selection",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Sexual selection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " context-dependent",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Context-dependent migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " example of",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotype-dependent",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Genotype-dependent migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of haploids",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Haploid migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of juvenile diploids",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Juvenile diploid migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of pollen",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of seeds",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with sindividuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migration"],

Cell[TextData[{
  "MigrationOrder",
  ",",
  "for genotype frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationOrder"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "MigrationOrder"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationOrder"],

Cell[TextData[{
  "MigrationRate",
  ",",
  " \[CapitalMu], \[AliasIndicator]M\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationRate"],

Cell[TextData[{
  "MigrationSet",
  ",",
  " \[DoubleStruckCapitalM], \[AliasIndicator]dsM\[AliasIndicator]",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "MigrationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationSet"],

Cell[TextData[{
  "Missing data",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Missing data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Missing data"],

Cell[TextData[{
  "Moment",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Moment"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Moments and cumulants",
    ButtonData:>{"Moments and cumulants", "Moment"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moment"],

Cell[TextData[{
  "MomentAfterMigration",
  ",",
  " ",
  ButtonBox["Migration in admixture models",
    ButtonData:>{"Migration in admixture models", "MomentAfterMigration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentAfterMigration"],

Cell[TextData[{
  "MomentAfterRecombination",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", 
      "MomentAfterRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentAfterRecombination"],

Cell[TextData[{
  "MomentEquilibrium",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "MomentEquilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentEquilibrium"],

Cell[TextData[{
  "MomentLimits",
  ",",
  " ",
  ButtonBox["Constraints on moments",
    ButtonData:>{"Constraints on moments", "MomentLimits"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentLimits"],

Cell[TextData[{
  "MomentNew",
  ",",
  " ",
  ButtonBox["Iteration",
    ButtonData:>{"Iteration", "MomentNew"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentNew"],

Cell[TextData[{
  "MomentReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MomentReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentReduced"],

Cell[TextData[{
  "Moments",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "7.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moments"],

Cell[TextData[{
  " estimating the matrix of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "Estimating the matrix"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " extension to description by",
  ", ",
  ButtonBox["References",
    ButtonData:>{"References", "Haber 1984"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " extension to estimation of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "MLE"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " full description by",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " matrix of",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] full matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "ML estimation of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "simple method"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reduced description by",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " simple method for estimating",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "extension to families"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moments"],

Cell[TextData[{
  "MomentsFromG",
  ",",
  " ",
  ButtonBox["Moments from genotype frequencies",
    ButtonData:>{"Moments from genotype frequencies", "MomentsFromG"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentsFromG"],

Cell[TextData[{
  "MomentSimple",
  ",",
  " ",
  ButtonBox["Simplifying the moments",
    ButtonData:>{"Simplifying the moments", "MomentSimple"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentSimple"],

Cell[TextData[{
  "MonteCarloGriffithsTavare",
  ",",
  " ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "MonteCarloGriffithsTavare"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MonteCarloGriffithsTavare"],

Cell[TextData[{
  "MonteCarloProbability",
  ",",
  " ",
  ButtonBox["Estimating the probability",
    ButtonData:>{"Estimating the probability", "MonteCarloProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MonteCarloProbability"],

Cell[TextData[{
  "Mortality",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Mortality"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mortality"],

Cell[TextData[{
  "MostRecentCommonAncestor",
  ",",
  " ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "MostRecentCommonAncestor"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MostRecentCommonAncestor"],

Cell[TextData[{
  "MToC",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MToC"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MToC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MToC"],

Cell[TextData[{
  "MToCEquations",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MToCEquations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MToCEquations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MToCEquations"],

Cell[TextData[{
  "Muddle",
  ",",
  " ",
  ButtonBox["Muddling and subdividing sets",
    ButtonData:>{"Muddling and subdividing sets", "Muddle"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Muddle"],

Cell[TextData[{
  "Multilocus algebra",
  ",",
  " basic notation",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Basic notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus algebra"],

Cell[TextData[{
  " fitness",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction to",
  ", ",
  ButtonBox["Introduction to multilocus algebra",
    ButtonData:>{"Introduction to multilocus algebra", "1.1"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Introduction to multilocus algebra",
    ButtonData:>{"Introduction to multilocus algebra", 
      "Multilocus`Multilocus`"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages in life cycle",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Technicalities"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus algebra"],

Cell[TextData[{
  "Multilocus MS",
  ",",
  " relation with",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Multilocus MS"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus MS"],

Cell[TextData[{
  "Multilocus notation",
  ",",
  " bugs",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Multilocus notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus notation"],

Cell[TextData[{
  "Multinomial sampling",
  ",",
  " without replacement",
  ", ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", 
      "Multinomial sampling wo replacement"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multinomial sampling"],

Cell[TextData[{
  "MultinomialSamplingProbability",
  ",",
  " ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", 
      "MultinomialSamplingProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MultinomialSamplingProbability"],

Cell[TextData[{
  "Multiple alleles",
  ",",
  " and selection coefficients",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple alleles"],

Cell[TextData[{
  " MakeFitnessSet",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " representation of",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " selection on",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple alleles"],

Cell[TextData[{
  "Multiple arguments",
  ",",
  " in PopulationExpectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "multiple arguments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple arguments"],

Cell[TextData[{
  "Multiplicative models",
  ",",
  " in negative binomial",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "multiplicative models"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiplicative models"],

Cell[TextData[{
  "MUS",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MUS"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MUS"],

Cell[TextData[{
  "MutationInterval",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "MutationInterval"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationInterval"],

Cell[TextData[{
  "MutationLabels",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "MutationLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationLabels"],

Cell[TextData[{
  "MutationOrigin",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "MutationOrigin"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationOrigin"],

Cell[TextData[{
  "MutationRate",
  ",",
  " ",
  ButtonBox["Drawing a genealogy",
    ButtonData:>{"Drawing a genealogy", "MutationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationRate"],

Cell[TextData[{
  "Mutations",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "Mutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutations"],

Cell[TextData[{
  "MVariables",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MVariables"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MVariables"],

Cell[TextData[{
  "Negative binomial",
  ",",
  " c<1",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "c<1"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Negative binomial"],

Cell[TextData[{
  " compiled",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " multiplicative models",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "multiplicative models"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " normalisation",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalisation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " timings",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Timings"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Negative binomial"],

Cell[TextData[{
  "NegativeBinomialLogLikelihood",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", 
      "NegativeBinomialLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeBinomialLogLikelihood"],

Cell[TextData[{
  "NegativeBinomialMLE",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "NegativeBinomialMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeBinomialMLE"],

Cell[TextData[{
  "NegativeHypergeometricDistribution",
  ",",
  " ",
  ButtonBox["Negative hypergeometric distribution",
    ButtonData:>{"Negative hypergeometric distribution", 
      "NegativeHypergeometricDistribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeHypergeometricDistribution"],

Cell[TextData[{
  "NeighbourArray",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "NeighbourArray"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NeighbourArray"],

Cell[TextData[{
  "Neighbours",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Neighbours"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Neighbours"],

Cell[TextData[{
  "NetCovariance",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "NetCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetCovariance"],

Cell[TextData[{
  "NetFecundity",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NetFecundity"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetFecundity"],

Cell[TextData[{
  "NetMortality",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NetMortality"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetMortality"],

Cell[TextData[{
  "NetRecombination",
  ",",
  " ",
  ButtonBox["Linkage",
    ButtonData:>{"Linkage", "NetRecombination"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Linkage in families",
    ButtonData:>{"Linkage in families", "NetRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetRecombination"],

Cell[TextData[{
  " in numerical models",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "NetRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetRecombination"],

Cell[TextData[{
  "Neutral marker",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Neutral marker"],

Cell[TextData[{
  "NeutralRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "NeutralRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NeutralRepresentations"],

Cell[TextData[{
  "NewGametes",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewGametes"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewGametes"],

Cell[TextData[{
  "NewS",
  ",",
  " ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "NewS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewS"],

Cell[TextData[{
  "Node",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "Node"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "Node"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Node"],

Cell[TextData[{
  "NodeFunction",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "NodeFunction"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeFunction"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeFunction"],

Cell[TextData[{
  "NodeLabels",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeLabels"],

Cell[TextData[{
  "NodeOffset",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeOffset"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeOffset"],

Cell[TextData[{
  "Nodes",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "Nodes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Nodes"],

Cell[TextData[{
  "NonMendelian",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonMendelian"],

Cell[TextData[{
  " examples of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonMendelian"],

Cell[TextData[{
  "NonNeutralRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "NonNeutralRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonNeutralRepresentations"],

Cell[TextData[{
  "NonSymmetricRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "NonSymmetricRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonSymmetricRepresentations"],

Cell[TextData[{
  "Normalisation",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalisation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Normalisation"],

Cell[TextData[{
  "Normalised",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Normalised"],

Cell[TextData[{
  "Notation",
  ",",
  " data",
  ", ",
  ButtonBox["Notation for genetic data",
    ButtonData:>{"Notation for genetic data", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation"],

Cell[TextData[{
  " genotypes",
  ", ",
  ButtonBox["Notation",
    ButtonData:>{"Notation", "NotationPackage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation"],

Cell[TextData[{
  "Notation package",
  ",",
  " ",
  ButtonBox["Notation package",
    ButtonData:>{"Notation package", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation package"],

Cell[TextData[{
  "NumberedLink",
  ",",
  " ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "NumberedLink"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberedLink"],

Cell[TextData[{
  "Numbering",
  ",",
  " aesthetics",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Aesthetics"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numbering"],

Cell[TextData[{
  " automatic",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "7.2"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notes on",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Notes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving links",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Saving the links"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numbering"],

Cell[TextData[{
  "NumberOfCoalescences",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "NumberOfCoalescences"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfCoalescences"],

Cell[TextData[{
  "NumberOfGenes",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenes"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenes"],

Cell[TextData[{
  "NumberOfGenesTable",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfGenesTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenesTable"],

Cell[TextData[{
  "NumberOfIndividuals",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfIndividuals"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NumberOfIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfIndividuals"],

Cell[TextData[{
  "NumberOfIndividualsTable",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfIndividualsTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfIndividualsTable"],

Cell[TextData[{
  "NumberOfLineages",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "NumberOfLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfLineages"],

Cell[TextData[{
  "NumberOfLoci",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfLoci"],

Cell[TextData[{
  "NumberOfMutations",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "NumberOfMutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfMutations"],

Cell[TextData[{
  "NumberOfPossibleCoalescences",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "NumberOfPossibleCoalescences"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfPossibleCoalescences"],

Cell[TextData[{
  "NumberOfSamplePartitions",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "NumberOfSamplePartitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfSamplePartitions"],

Cell[TextData[{
  "NumberOfSetPartitions",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "NumberOfSetPartitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfSetPartitions"],

Cell[TextData[{
  "NumericalModel",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", "NumericalModel"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumericalModel"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "NumericalModel"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumericalModel"],

Cell[TextData[{
  "Numerical models",
  ",",
  " genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numerical models"],

Cell[TextData[{
  " of allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:representation",
    ButtonData:>{"Allele frequencies:representation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " overview",
  ", ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " problems",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric",
  ", ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numerical models"],

Cell[TextData[{
  "Observable genotype",
  ",",
  " ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Observable genotype"],

Cell[TextData[{
  "Obsolete",
  ",",
  " Combine",
  ", ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Separate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Obsolete"],

Cell[TextData[{
  " CumulantReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "CumulantReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidConstraints",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidConstraints"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidGenotypeFrequencyReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidGenotypeFrequencyTable",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Estimating D",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " fitness",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Obsolete notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " FullGenotypeFrequencyReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " FullGenotypeFrequencyTable",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " GenotypeFrequencyArguments",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "GenotypeFrequencyArguments"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " HaploidConstraints",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "HaploidConstraints"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " InitialStepReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "InitialStepReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " IntervalCombine",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalCombine"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " IntervalPosition",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalPosition"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " LogLikelihoodDisequilibriumReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "LogLikelihoodDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MetropolisDisequilibriumReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MetropolisDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MomentReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MomentReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Obsolete"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Separate",
  ", ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Combine"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Obsolete"],

Cell[TextData[{
  "Offspring",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Offspring"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Offspring"],

Cell[TextData[{
  "Orive & Barton 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Orive & Barton 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Orive & Barton 1999"],

Cell[TextData[{
  "OtherSex",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "OtherSex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"OtherSex"],

Cell[TextData[{
  "Packages",
  ",",
  " help",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Packages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Packages"],

Cell[TextData[{
  " overview of",
  ", ",
  ButtonBox["Overview of the packages",
    ButtonData:>{"Overview of the packages", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving using PackageSaver",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " setting up",
  ", ",
  ButtonBox["Setting up the packages",
    ButtonData:>{"Setting up the packages", "Setting up the packages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Special notation",
    ButtonData:>{"Special notation", "Setting up packages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " versions of",
  ", ",
  ButtonBox["Versions",
    ButtonData:>{"Versions", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Packages"],

Cell[TextData[{
  "PackageSaver",
  ",",
  " ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PackageSaver"],

Cell[TextData[{
  "PatternFree",
  ",",
  " ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "PatternFree"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PatternFree"],

Cell[TextData[{
  "Phipps & Brill 1995",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Phipps & Brill 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Phipps & Brill 1995"],

Cell[TextData[{
  "Ploidy",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "Ploidy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ploidy"],

Cell[TextData[{
  "PloidyWeightList",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "PloidyWeightList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PloidyWeightList"],

Cell[TextData[{
  "PlotGenealogy",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "PlotGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PlotGenealogy"],

Cell[TextData[{
  "PlotLogL",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "PlotLogL"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PlotLogL"],

Cell[TextData[{
  "PopulationDisequilibrium",
  ",",
  "\[GothicCapitalC], \[AliasIndicator]goC\[AliasIndicator]",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationDisequilibrium"],

Cell[TextData[{
  "PopulationExpectation",
  ",",
  " ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationExpectation"],

Cell[TextData[{
  " multiple arguments",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "multiple arguments"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationExpectation"],

Cell[TextData[{
  "PopulationRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "PopulationRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationRepresentations"],

Cell[TextData[{
  "Position",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "position"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "position"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Position"],

Cell[TextData[{
  " as used in Johnson et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "position"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Position"],

Cell[TextData[{
  "PositionsList",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PositionsList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PositionsList"],

Cell[TextData[{
  "PositionsMatrix",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PositionsMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PositionsMatrix"],

Cell[TextData[{
  "PossibleCoalescenceOrder",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "PossibleCoalescenceOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleCoalescenceOrder"],

Cell[TextData[{
  "PossibleDiploidGenotypes",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PossibleDiploidGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleDiploidGenotypes"],

Cell[TextData[{
  "PossibleGenotypes",
  ",",
  " ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "PossibleGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleGenotypes"],

Cell[TextData[{
  "PowerF",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PowerF"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "PowerF"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PowerF"],

Cell[TextData[{
  "PresentOneWayTable",
  ",",
  " ",
  ButtonBox["Single-locus tables",
    ButtonData:>{"Single-locus tables", "PresentOneWayTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentOneWayTable"],

Cell[TextData[{
  "PresentPairwiseTable",
  ",",
  " ",
  ButtonBox["Pairwise tables",
    ButtonData:>{"Pairwise tables", "PresentPairwiseTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentPairwiseTable"],

Cell[TextData[{
  "PresentResults",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "PresentResults"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentResults"],

Cell[TextData[{
  "PrintDetails",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "PrintDetails"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PrintDetails"],

Cell[TextData[{
  "Problems",
  ",",
  " avoid integers",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Avoid integers"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Problems"],

Cell[TextData[{
  " redefining fitness",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Allele frequencies"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Redefining fitness"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "StoreResults (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Problems"],

Cell[TextData[{
  "Products",
  ",",
  " multiple",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Multiple products"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Products"],

Cell[TextData[{
  "ProductSum",
  ",",
  " ",
  ButtonBox["ProductSum",
    ButtonData:>{"ProductSum", "ProductSum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ProductSum"],

Cell[TextData[{
  "ProductSum over sets",
  ",",
  " ",
  ButtonBox["ProductSum",
    ButtonData:>{"ProductSum", "ProductSum over sets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ProductSum over sets"],

Cell[TextData[{
  "RandomBottleneckedGenealogy",
  ",",
  " ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", "RandomBottleneckedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomBottleneckedGenealogy"],

Cell[TextData[{
  "RandomCoalescenceOrder",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "RandomCoalescenceOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCoalescenceOrder"],

Cell[TextData[{
  "RandomCoalescenceTimes",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", 
      "RandomCoalescenceTimes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCoalescenceTimes"],

Cell[TextData[{
  "RandomCum",
  ",",
  " ",
  ButtonBox["Sampling from arbitrary distributions",
    ButtonData:>{"Sampling from arbitrary distributions", "RandomCum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCum"],

Cell[TextData[{
  "Random drift",
  ",",
  " changing reference points",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Changing reference points"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random drift"],

Cell[TextData[{
  " cumulants and moments",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " describing a distribution",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Describing a distribution"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " equations for the moments",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Equations for the moments"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in a cline",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: drift",
    ButtonData:>{"Allele frequencies: drift", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of genotype frequencies",
  ", ",
  ButtonBox["Recursions: drift",
    ButtonData:>{"Recursions: drift", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population disequilibrium",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population expectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population expectations",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Wright-Fisher sampling",
  ", ",
  ButtonBox["Wright-Fisher sampling",
    ButtonData:>{"Wright-Fisher sampling", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random drift"],

Cell[TextData[{
  "RandomDrift",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: drift",
    ButtonData:>{"Recursions: drift", "RandomDrift"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomDrift"],

Cell[TextData[{
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "RandomDrift"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomDrift"],

Cell[TextData[{
  "RandomFamilies",
  ",",
  " ",
  ButtonBox["Random families",
    ButtonData:>{"Random families", "RandomFamilies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamilies"],

Cell[TextData[{
  "RandomFamily",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "RandomFamily"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamily"],

Cell[TextData[{
  " segregation ratio",
  ", ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamily"],

Cell[TextData[{
  "Random genealogies",
  ",",
  " population bottlenecks",
  ", ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random genealogies"],

Cell[TextData[{
  "RandomGenealogy",
  ",",
  " ",
  ButtonBox["Drawing a genealogy",
    ButtonData:>{"Drawing a genealogy", "RandomGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomGenealogy"],

Cell[TextData[{
  "RandomList",
  ",",
  " ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "RandomList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomList"],

Cell[TextData[{
  " sampling without replacement",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomList"],

Cell[TextData[{
  "Random lists",
  ",",
  " compiled",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random lists"],

Cell[TextData[{
  "RandomMating",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "RandomMating"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomMating"],

Cell[TextData[{
  "RandomMultinomial",
  ",",
  " ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", "RandomMultinomial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomMultinomial"],

Cell[TextData[{
  "RandomPreviousFamily",
  ",",
  " ",
  ButtonBox["Random families",
    ButtonData:>{"Random families", "RandomPreviousFamily"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomPreviousFamily"],

Cell[TextData[{
  "Random sampling",
  ",",
  " ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Random sampling"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random sampling"],

Cell[TextData[{
  " example in estimating D",
  ", ",
  ButtonBox["Sampling example",
    ButtonData:>{"Sampling example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of genealogies",
  ", ",
  ButtonBox["Sampling genealogies",
    ButtonData:>{"Sampling genealogies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random sampling"],

Cell[TextData[{
  "RandomSet",
  ",",
  " ",
  ButtonBox["Random sets",
    ButtonData:>{"Random sets", "RandomSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomSet"],

Cell[TextData[{
  "Random union",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Random union"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random union"],

Cell[TextData[{
  " in admixture models",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "RandomUnionObsolete"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random union"],

Cell[TextData[{
  "RandomUnion",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnion"],

Cell[TextData[{
  "RandomUnionMethod",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnionMethod"],

Cell[TextData[{
  "RandomUnionObsolete",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnionObsolete"],

Cell[TextData[{
  "Random walk",
  ",",
  " in estimating D",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random walk"],

Cell[TextData[{
  "Recombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Recombination"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Recombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombination"],

Cell[TextData[{
  " context-dependent",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Context-dependent recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotype-dependent",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Genotype-dependent recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in admixture models",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "Recombined"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " no linkage",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "UnlinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombination"],

Cell[TextData[{
  "RecombinationRate",
  ",",
  " \[GothicR], \[AliasIndicator]gor\[AliasIndicator]",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinationRate"],

Cell[TextData[{
  "RecombinationSet",
  ",",
  " \[DoubleStruckCapitalR], \[AliasIndicator]dsR\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinationSet"],

Cell[TextData[{
  "Recombined",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "Recombined"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombined"],

Cell[TextData[{
  "ReducedData",
  ",",
  " ",
  ButtonBox["Simplifying a dataset",
    ButtonData:>{"Simplifying a dataset", "ReducedData"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReducedData"],

Cell[TextData[{
  "ReferencePoint",
  ",",
  " \[WeierstrassP], \[AliasIndicator]wp\[AliasIndicator]",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePoint"],

Cell[TextData[{
  "ReferencePointMean",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointMean"],

Cell[TextData[{
  " cytoplasmic inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sex-linkage",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointMean"],

Cell[TextData[{
  "ReferencePointSame",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointSame"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointSame"],

Cell[TextData[{
  "ReferencePointZero",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointZero"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointZero"],

Cell[TextData[{
  "Reference values",
  ",",
  " ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Reference values"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reference values"],

Cell[TextData[{
  " as used in Johnson et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Reference values"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reference values"],

Cell[TextData[{
  "RemoveTag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "RemoveTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RemoveTag"],

Cell[TextData[{
  "Repeat",
  ",",
  " ",
  ButtonBox["Repeated elements",
    ButtonData:>{"Repeated elements", "Repeat"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Repeat"],

Cell[TextData[{
  "Replace",
  ",",
  " ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Replace"],

Cell[TextData[{
  "ReplaceAllSpecial",
  ",",
  " |.",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReplaceAllSpecial"],

Cell[TextData[{
  "ReplaceRepeatedSpecial",
  ",",
  " ||.",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceRepeatedSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReplaceRepeatedSpecial"],

Cell[TextData[{
  "Representations",
  ",",
  " converting between",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Representations"],

Cell[TextData[{
  "of populations",
  ", ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "Representing the population"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Representations"],

Cell[TextData[{
  "Reproduction",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reproduction"],

Cell[TextData[{
  "Reverse",
  ",",
  " ",
  ButtonBox["Sorting",
    ButtonData:>{"Sorting", "Reverse"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reverse"],

Cell[TextData[{
  "RootedGenealogy",
  ",",
  " ",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "RootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RootedGenealogy"],

Cell[TextData[{
  "Rules",
  ",",
  " ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Rules"],

Cell[TextData[{
  " non-evaluation of",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Rules"],

Cell[TextData[{
  "SampleCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "SampleCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SampleCovariance"],

Cell[TextData[{
  "SampleIndividuals",
  ",",
  " ",
  ButtonBox["Sampling individuals",
    ButtonData:>{"Sampling individuals", "SampleIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SampleIndividuals"],

Cell[TextData[{
  "SamplePartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SamplePartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SamplePartition"],

Cell[TextData[{
  "Sampling",
  ",",
  " without replacement",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sampling"],

Cell[TextData[{
  "Scripts and faces",
  ",",
  " as used in Johnson et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Scripts and faces"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Scripts and faces"],

Cell[TextData[{
  "SegregationRatio",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SegregationRatio"],

Cell[TextData[{
  "SelectContext",
  ",",
  " \[CircleDot], \[AliasIndicator]c.\[AliasIndicator]",
  ", ",
  ButtonBox["Selecting contexts",
    ButtonData:>{"Selecting contexts", "SelectContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectContext"],

Cell[TextData[{
  "SelectIndividuals",
  ",",
  " ",
  ButtonBox["Selecting subsets",
    ButtonData:>{"Selecting subsets", "SelectIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectIndividuals"],

Cell[TextData[{
  "Selection",
  ",",
  " ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Selection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection"],

Cell[TextData[{
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on genotype frequencies",
  ", ",
  ButtonBox["Recursions: fitnesses",
    ButtonData:>{"Recursions: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on multiple alleles",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Technicalities"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with two alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection"],

Cell[TextData[{
  "SelectionCoefficient",
  ",",
  " \[GothicA], \[AliasIndicator]goa\[AliasIndicator]",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionCoefficient"],

Cell[TextData[{
  "Selection coefficients",
  ",",
  " as defined in Johnson et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Permutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection coefficients"],

Cell[TextData[{
  " making",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with multiple alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection coefficients"],

Cell[TextData[{
  "SelectionExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionExact"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: fitnesses",
    ButtonData:>{"Recursions: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionExact"],

Cell[TextData[{
  "Selection on diploids",
  ",",
  " a method to avoid",
  ", ",
  ButtonBox["A method to avoid",
    ButtonData:>{"A method to avoid", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection on diploids"],

Cell[TextData[{
  " cautionary notes",
  ", ",
  ButtonBox["Cautionary notes",
    ButtonData:>{"Cautionary notes", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete life cycle",
  ", ",
  ButtonBox["Complete life cyle",
    ButtonData:>{"Complete life cyle", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " explaining the rules",
  ", ",
  ButtonBox["Explaining the rules",
    ButtonData:>{"Explaining the rules", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction",
  ", ",
  ButtonBox["Introduction to selection on diploids",
    ButtonData:>{"Introduction to selection on diploids", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " life cycle",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection on diploids"],

Cell[TextData[{
  "SelectionRate",
  ",",
  " \[GothicS],\[AliasIndicator]gos\[AliasIndicator]",
  ", ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SelectionRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionRate"],

Cell[TextData[{
  "SelectLoci",
  ",",
  " ",
  ButtonBox["Selecting subsets",
    ButtonData:>{"Selecting subsets", "SelectLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectLoci"],

Cell[TextData[{
  "Selfing",
  ",",
  " ",
  ButtonBox["Selfing",
    ButtonData:>{"Selfing", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selfing"],

Cell[TextData[{
  "Separate",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Separate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Separate"],

Cell[TextData[{
  "Set",
  ",",
  " of all positions affecting a trait, \[DoubleStruckCapitalZ], \
\[AliasIndicator]dsZ\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set"],

Cell[TextData[{
  " of all positions in genome, \[DoubleStruckCapitalG], \[AliasIndicator]dsG\
\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set"],

Cell[TextData[{
  "Set manipulation",
  ",",
  " overview",
  ", ",
  ButtonBox["Overview of set manipulation",
    ButtonData:>{"Overview of set manipulation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set manipulation"],

Cell[TextData[{
  "SetPartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SetPartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SetPartition"],

Cell[TextData[{
  "Sets of loci",
  ",",
  " as used in Johnson et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Sets of loci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sets of loci"],

Cell[TextData[{
  "Sex",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Sex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex"],

Cell[TextData[{
  "Sex linkage",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex linkage"],

Cell[TextData[{
  " examples of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex linkage"],

Cell[TextData[{
  "SexOfOrigin",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "SexOfOrigin"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SexOfOrigin"],

Cell[TextData[{
  "Sexual selection",
  ",",
  " ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Sexual selection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sexual selection"],

Cell[TextData[{
  " and migration",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Sexual selection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete life cycle",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Complete cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining fitnesses",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " recombination",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " subtle problem",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "subtle problem"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sexual selection"],

Cell[TextData[{
  "ShortContext",
  ",",
  " ",
  ButtonBox["Abbreviating contexts",
    ButtonData:>{"Abbreviating contexts", "ShortContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ShortContext"],

Cell[TextData[{
  "SigmaMatrix",
  ",",
  " ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "SigmaMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SigmaMatrix"],

Cell[TextData[{
  "SignMask",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "SignMask"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SignMask"],

Cell[TextData[{
  "SimplifyAddUp",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "SimplifyAddUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyAddUp"],

Cell[TextData[{
  "SimplifyAddUpQ",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "SimplifyAddUpQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyAddUpQ"],

Cell[TextData[{
  "SimplifyFamilies",
  ",",
  " ",
  ButtonBox["Probabilities",
    ButtonData:>{"Probabilities", "SimplifyFamilies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyFamilies"],

Cell[TextData[{
  "Simulating individuals",
  ",",
  " recursions",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Simulating individuals"],

Cell[TextData[{
  " representation",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reproduction",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Simulating individuals"],

Cell[TextData[{
  "SizeOfGenealogyPlot",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "SizeOfGenealogyPlot"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SizeOfGenealogyPlot"],

Cell[TextData[{
  "Slatkin & Excoffier 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Slatkin & Excoffier 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Slatkin & Excoffier 1996"],

Cell[TextData[{
  "SlowChange",
  ",",
  " ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SlowChange"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SlowChange"],

Cell[TextData[{
  "SortByClass",
  ",",
  " ",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "SortByClass"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByClass"],

Cell[TextData[{
  " genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "SortByClass"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByClass"],

Cell[TextData[{
  "SortByHead",
  ",",
  " ",
  ButtonBox["Sorting",
    ButtonData:>{"Sorting", "SortByHead"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByHead"],

Cell[TextData[{
  "SpatialCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "SpatialCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SpatialCovariance"],

Cell[TextData[{
  "Spatially varying selection",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Spatially varying selection",
    ButtonData:>{"Spatially varying selection", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Spatially varying selection"],

Cell[TextData[{
  "Special notation",
  ",",
  " ",
  ButtonBox["Special notation",
    ButtonData:>{"Special notation", "Defining notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Special notation"],

Cell[TextData[{
  "Stabilising selection",
  ",",
  " change in D",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Change in D"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stabilising selection"],

Cell[TextData[{
  " change in mean",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Change in mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Defining fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "mean fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Mean fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "New mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "New mean fitness"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stabilising selection"],

Cell[TextData[{
  "Stability",
  ",",
  " of numerical models",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stability"],

Cell[TextData[{
  " of symmetric model",
  ", ",
  ButtonBox["Symmetric stability: outline",
    ButtonData:>{"Symmetric stability: outline", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stability"],

Cell[TextData[{
  "StabilityDirect",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", "StabilityDirect"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityDirect"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", "StabilityDirect"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityDirect"],

Cell[TextData[{
  "StabilityK",
  ",",
  " ",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", "StabilityK"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "StabilityK"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityK"],

Cell[TextData[{
  "StabilityKTable",
  ",",
  " ",
  ButtonBox["Symmetric stability: faster algorithms",
    ButtonData:>{"Symmetric stability: faster algorithms", "StabilityKTable"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityKTable"],

Cell[TextData[{
  "StabilityMatrix",
  ",",
  " ",
  ButtonBox["Making a stability matrix",
    ButtonData:>{"Making a stability matrix", "StabilityMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityMatrix"],

Cell[TextData[{
  "Stage",
  ",",
  " \[Sampi], \[AliasIndicator]sa\[AliasIndicator]",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stage"],

Cell[TextData[{
  "Stages",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stages"],

Cell[TextData[{
  " as used in Johnson et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Stages and contexts"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stages"],

Cell[TextData[{
  "StartingStepSize",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "StartingStepSize"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StartingStepSize"],

Cell[TextData[{
  "Stepping-stone migration",
  ",",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", 
      "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone migration"],

Cell[TextData[{
  "Stepping-stone model",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", 
      "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone model"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "Nearest-neighbour migration"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone model"],

Cell[TextData[{
  "StoreExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreExact"],

Cell[TextData[{
  " for allele frequency clines",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequency clines",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreExact"],

Cell[TextData[{
  "StoreResults",
  ",",
  " option for GameteTable",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreResults"],

Cell[TextData[{
  " option for NewGametes",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " use when compiling",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "StoreResults (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreResults"],

Cell[TextData[{
  "StructuredArray",
  ",",
  " ",
  ButtonBox["Useful functions",
    ButtonData:>{"Useful functions", "StructuredArray"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredArray"],

Cell[TextData[{
  "StructuredInitialParameters",
  ",",
  " ",
  ButtonBox["Initial parameters",
    ButtonData:>{"Initial parameters", "StructuredInitialParameters"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredInitialParameters"],

Cell[TextData[{
  "StructuredLogLikelihood",
  ",",
  " ",
  ButtonBox["Likelihood of a structured model",
    ButtonData:>{"Likelihood of a structured model", 
      "StructuredLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredLogLikelihood"],

Cell[TextData[{
  "StructuredMLE",
  ",",
  " ",
  ButtonBox["Likelihood of a structured model",
    ButtonData:>{"Likelihood of a structured model", "StructuredMLE"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "StructuredMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredMLE"],

Cell[TextData[{
  "StructuredModel",
  ",",
  " ",
  ButtonBox["Useful functions",
    ButtonData:>{"Useful functions", "StructuredModel"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredModel"],

Cell[TextData[{
  "StructuredModelReduce",
  ",",
  " ",
  ButtonBox["Simplifying a model",
    ButtonData:>{"Simplifying a model", "StructuredModelReduce"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredModelReduce"],

Cell[TextData[{
  "Structured models",
  ",",
  " example",
  ", ",
  ButtonBox["Example data",
    ButtonData:>{"Example data", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Structured models"],

Cell[TextData[{
  " hierarchical analysis",
  ", ",
  ButtonBox["Hierarchical analysis",
    ButtonData:>{"Hierarchical analysis", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Structured models"],

Cell[TextData[{
  "StructuredParameter",
  ",",
  " ",
  ButtonBox["Structured parameters",
    ButtonData:>{"Structured parameters", "StructuredParameter"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredParameter"],

Cell[TextData[{
  "StructuredVariance",
  ",",
  " ",
  ButtonBox["Variance components for a structured model",
    ButtonData:>{"Variance components for a structured model", 
      "StructuredVariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredVariance"],

Cell[TextData[{
  "Subdivide",
  ",",
  " ",
  ButtonBox["Muddling and subdividing sets",
    ButtonData:>{"Muddling and subdividing sets", "Subdivide"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subdivide"],

Cell[TextData[{
  "Subscripts",
  ",",
  " as written in Johnson et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Sets in subscripts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subscripts"],

Cell[TextData[{
  "Subsets",
  ",",
  " ",
  ButtonBox["Subsets",
    ButtonData:>{"Subsets", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subsets"],

Cell[TextData[{
  " option for AddUp",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Subsets"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for TimesUp",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subsets"],

Cell[TextData[{
  "Sums",
  ",",
  " multiple",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Multiple sums"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sums"],

Cell[TextData[{
  "Symmetric cline",
  ",",
  " in allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a symmetric cline",
    ButtonData:>{"Allele frequencies: setting up a symmetric cline", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric cline"],

Cell[TextData[{
  " in genotype frequencies",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric cline"],

Cell[TextData[{
  "SymmetricDiploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricDiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricDiploidFrequencies"],

Cell[TextData[{
  "SymmetricHaploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricHaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricHaploidFrequencies"],

Cell[TextData[{
  "Symmetric model",
  ",",
  " adding a neutral marker",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: limitations",
    ButtonData:>{"Symmetric model: limitations", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric model"],

Cell[TextData[{
  " cline example",
  ", ",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: spatially varying selection",
    ButtonData:>{"Symmetric stability: spatially varying selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " limitations",
  ", ",
  ButtonBox["Symmetric model: limitations",
    ButtonData:>{"Symmetric model: limitations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " one deme example",
  ", ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "overview",
  ", ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " references",
  ", ",
  ButtonBox["Symmetric model: references",
    ButtonData:>{"Symmetric model: references", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reproduction",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Symmetric stability: outline",
    ButtonData:>{"Symmetric stability: outline", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric model"],

Cell[TextData[{
  "SymmetricNeutralDiploidFrequencies",
  ",",
  " ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricNeutralDiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricNeutralDiploidFrequencies"],

Cell[TextData[{
  "SymmetricNeutralHaploidFrequencies",
  ",",
  " ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricNeutralHaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricNeutralHaploidFrequencies"],

Cell[TextData[{
  "SymmetricRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "SymmetricRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricRecombination"],

Cell[TextData[{
  "SymmetricRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "SymmetricRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricRepresentations"],

Cell[TextData[{
  "SymmetricSexes",
  ",",
  " ",
  ButtonBox["Symmetric sexes",
    ButtonData:>{"Symmetric sexes", "SymmetricSexes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricSexes"],

Cell[TextData[{
  "Symmetrise",
  ",",
  " ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Symmetrise"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetrise",
    ButtonData:>{"Symmetrise", "Symmetrise"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetrise"],

Cell[TextData[{
  "T",
  ",",
  " time",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "T"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"T"],

Cell[TextData[{
  "Table",
  ",",
  " option for VarianceComponents",
  ", ",
  ButtonBox["Variance components",
    ButtonData:>{"Variance components", "Table"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Table"],

Cell[TextData[{
  "Tag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Tag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tag"],

Cell[TextData[{
  "Tags",
  ",",
  " finding",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Finding tags"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tags"],

Cell[TextData[{
  " setting up hyperlinks to",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Setting up links to a list of tags"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tags"],

Cell[TextData[{
  "TakeAway, \[Backslash], \[AliasIndicator]\[AliasIndicator], ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TakeAway"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TakeAway",
    ButtonData:>{"TakeAway", "TakeAway"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TakeAway"],

Cell[TextData[{
  "TakeOptions",
  ",",
  " ",
  ButtonBox["Manipulating options",
    ButtonData:>{"Manipulating options", "TakeOptions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TakeOptions"],

Cell[TextData[{
  "Time",
  ",",
  " T",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "T"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Time"],

Cell[TextData[{
  "TimesUp",
  ",",
  " ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TimesUp"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "TimesUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimesUp"],

Cell[TextData[{
  " multiple products",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Multiple products"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over subsets",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimesUp"],

Cell[TextData[{
  "ToCumulants",
  ",",
  " ",
  ButtonBox["Multilocus cumulants",
    ButtonData:>{"Multilocus cumulants", "ToCumulants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToCumulants"],

Cell[TextData[{
  "ToMoments",
  ",",
  " ",
  ButtonBox["Multilocus cumulants",
    ButtonData:>{"Multilocus cumulants", "ToMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToMoments"],

Cell[TextData[{
  "ToPopulationCumulants",
  ",",
  " ",
  ButtonBox["Random drift: cumulants",
    ButtonData:>{"Random drift: cumulants", "ToPopulationCumulants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToPopulationCumulants"],

Cell[TextData[{
  "ToPopulationMoments",
  ",",
  " ",
  ButtonBox["Random drift: cumulants",
    ButtonData:>{"Random drift: cumulants", "ToPopulationMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToPopulationMoments"],

Cell[TextData[{
  "TotalLength",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "TotalLength"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalLength"],

Cell[TextData[{
  "TotalNumber",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "TotalNumber"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalNumber"],

Cell[TextData[{
  "Trait",
  ",",
  " set of all positions affecting, \[DoubleStruckCapitalZ], \
\[AliasIndicator]dsZ\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Trait"],

Cell[TextData[{
  "TransformedRange",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "TransformedRange"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransformedRange"],

Cell[TextData[{
  "TransformInformation",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "TransformInformation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransformInformation"],

Cell[TextData[{
  "TransmissionRule",
  ",",
  " ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "TransmissionRule"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransmissionRule"],

Cell[TextData[{
  "Transmission rules",
  ",",
  " applying",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "Applying transmission rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Transmission rules"],

Cell[TextData[{
  " as used in Johnson et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Transmission rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " distinct from Mathematica rules",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "Transmission vs Mathematica rules"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Transmission rules"],

Cell[TextData[{
  "TriDiagonalMatrix",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "TriDiagonalMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TriDiagonalMatrix"],

Cell[TextData[{
  "Turelli and Barton 1994",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Turelli and Barton 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Turelli and Barton 1994"],

Cell[TextData[{
  "Turelli & Barton 1994",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Turelli & Barton 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Turelli & Barton 1994"],

Cell[TextData[{
  "Two alleles",
  ",",
  " ",
  ButtonBox["Two alleles",
    ButtonData:>{"Two alleles", "Biallelic"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Two alleles"],

Cell[TextData[{
  " selection coefficients",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Two alleles"],

Cell[TextData[{
  "UMS",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UMS"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UMS"],

Cell[TextData[{
  "UnionOfGametes",
  ",",
  " ",
  ButtonBox["Union of gametes",
    ButtonData:>{"Union of gametes", "UnionOfGametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnionOfGametes"],

Cell[TextData[{
  "UnlinkedRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "UnlinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnlinkedRecombination"],

Cell[TextData[{
  "UnrootedGenealogy",
  ",",
  " ",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "UnrootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnrootedGenealogy"],

Cell[TextData[{
  "UpperOffDiagonal",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "UpperOffDiagonal"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UpperOffDiagonal"],

Cell[TextData[{
  "USM",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"USM"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"USM"],

Cell[TextData[{
  "VarianceComponents",
  ",",
  " ",
  ButtonBox["Variance components for a structured model",
    ButtonData:>{"Variance components for a structured model", 
      "VarianceComponents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"VarianceComponents"],

Cell[TextData[{
  " Table option",
  ", ",
  ButtonBox["Variance components",
    ButtonData:>{"Variance components", "Table"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"VarianceComponents"],

Cell[TextData[{
  "Versions",
  ",",
  " of applications packages",
  ", ",
  ButtonBox["Versions",
    ButtonData:>{"Versions", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Versions"],

Cell[TextData[{
  "WLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"WLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"WLinkedLoci"],

Cell[TextData[{
  "Wright-Fisher sampling",
  ",",
  " ",
  ButtonBox["Wright-Fisher sampling",
    ButtonData:>{"Wright-Fisher sampling", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Wright-Fisher sampling"],

Cell[TextData[{
  "X",
  ",",
  " AllelicState",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicState"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"X"],

Cell[TextData[{
  "XLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"XLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"XLinkedLoci"],

Cell[TextData[{
  "YLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"YLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"YLinkedLoci"],

Cell[TextData[{
  "ZLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ZLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ZLinkedLoci"],

Cell[TextData[{
  "Zygotes",
  ",",
  " \[GothicCapitalZ], \[AliasIndicator]goZ\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Zygotes"],

Cell[TextData[{
  "\[GothicA]",
  ",",
  " \[AliasIndicator]goa\[AliasIndicator], SelectionCoefficient",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicA]"],

Cell[TextData[{
  "\[GothicCapitalA]",
  ",",
  " \[AliasIndicator]goA\[AliasIndicator], adults",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalA]"],

Cell[TextData[{
  "\[GothicCapitalC]",
  ",",
  " \[AliasIndicator]goC\[AliasIndicator], PopulationDisequilibrium",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalC]"],

Cell[TextData[{
  "\[GothicCapitalD]",
  ",",
  " \[AliasIndicator]\[GothicCapitalD]\[AliasIndicator], Disequilibrium",
  ", ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalD]"],

Cell[TextData[{
  "\!\(\(\[GothicCapitalG]\^*\)\)",
  ",",
  " \[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, \
\[GothicCapitalG]new, new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\!\(\(\[GothicCapitalG]\^*\)\)"],

Cell[TextData[{
  "\[GothicCapitalG]",
  ",",
  " \[AliasIndicator]goG\[AliasIndicator], Gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalG]"],

Cell[TextData[{
  "\[GothicCapitalH]",
  ",",
  " \[AliasIndicator]goH\[AliasIndicator], hermaphrodites",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalH]"],

Cell[TextData[{
  "\[GothicCapitalJ]",
  ",",
  " \[AliasIndicator]goJ\[AliasIndicator], juveniles",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalJ]"],

Cell[TextData[{
  "\[GothicK]",
  ",",
  " \[AliasIndicator]gok\[AliasIndicator], CumulantDisequilibrium",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "CumulantDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicK]"],

Cell[TextData[{
  "\[GothicCapitalK]",
  ",",
  " \[AliasIndicator]goK\[AliasIndicator], CumulantPopulationDisequilibrium",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalK]"],

Cell[TextData[{
  "\[GothicM]",
  ",",
  " \[AliasIndicator]gom\[AliasIndicator], MeanContribution",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "MeanContribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicM]"],

Cell[TextData[{
  "\[GothicP]",
  ",",
  " \[AliasIndicator]gop\[AliasIndicator], AlleleFrequencyP",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicP]"],

Cell[TextData[{
  "\[GothicP]\[GothicQ]",
  ",",
  " \[AliasIndicator]gop\[AliasIndicator]\[AliasIndicator]goq\[AliasIndicator]\
, AlleleFrequencyPQ",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyPQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicP]\[GothicQ]"],

Cell[TextData[{
  "\[GothicQ]",
  ",",
  " \[AliasIndicator]goq\[AliasIndicator], AlleleFrequencyQ",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicQ]"],

Cell[TextData[{
  "\[GothicR]",
  ",",
  " \[AliasIndicator]gor\[AliasIndicator], RecombinationRate",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicR]"],

Cell[TextData[{
  "\[GothicS]",
  ",",
  "\[AliasIndicator]gos\[AliasIndicator], SelectionRate",
  ", ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SelectionRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicS]"],

Cell[TextData[{
  "\[GothicCapitalZ]",
  ",",
  " \[AliasIndicator]goZ\[AliasIndicator], Zygotes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalZ]"],

Cell[TextData[{
  "\[DoubleStruckCapitalG]",
  ",",
  " \[AliasIndicator]dsG\[AliasIndicator], set of all positions in genome",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalG]"],

Cell[TextData[{
  "\[DoubleStruckCapitalM]",
  ",",
  " \[AliasIndicator]dsM\[AliasIndicator], MigrationSet",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "MigrationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalM]"],

Cell[TextData[{
  "\[DoubleStruckCapitalR]",
  ",",
  " \[AliasIndicator]dsR\[AliasIndicator], RecombinationSet",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalR]"],

Cell[TextData[{
  "\[DoubleStruckCapitalW]",
  ",",
  " \[AliasIndicator]dsW\[AliasIndicator], FitnessSet",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "FitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalW]"],

Cell[TextData[{
  "\[DoubleStruckCapitalZ]",
  ",",
  " \[AliasIndicator]dsZ\[AliasIndicator], set of all positions affecting a \
trait",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalZ]"],

Cell[TextData[{
  "\[Gamma]",
  ",",
  " conflict with Johnson et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "gamma"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Gamma]"],

Cell[TextData[{
  " \[AliasIndicator]g\[AliasIndicator], ExtractGenes",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractGenes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Gamma]"],

Cell[TextData[{
  "\[Zeta]",
  ",",
  " \[AliasIndicator]z\[AliasIndicator], AllelicDeviation",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicDeviation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Zeta]"],

Cell[TextData[{
  "\[CapitalMu]",
  ",",
  " \[AliasIndicator]M\[AliasIndicator], MigrationRate",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CapitalMu]"],

Cell[TextData[{
  "\[Chi]",
  ",",
  " \[AliasIndicator]c\[AliasIndicator], ExtractContexts",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Chi]"],

Cell[TextData[{
  "\[Sampi]",
  ",",
  " \[AliasIndicator]sa\[AliasIndicator], Stage",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Sampi]"],

Cell[TextData[{
  "$MetropolisAdjustment",
  ",",
  " ",
  ButtonBox["Metropolis algorithm",
    ButtonData:>{"Metropolis algorithm", "$MetropolisAdjustment"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$MetropolisAdjustment"],

Cell[TextData[{
  "\[WeierstrassP]",
  ",",
  " \[AliasIndicator]wp\[AliasIndicator], ReferencePoint",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[WeierstrassP]"],

Cell[TextData[{
  "\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]",
  ",",
  " \[AliasIndicator]l||\[AliasIndicator] \[AliasIndicator]r||\
\[AliasIndicator], population expectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],

Cell[TextData[{
  "\[CircleDot]",
  ",",
  " \[AliasIndicator]c.\[AliasIndicator], SelectContext",
  ", ",
  ButtonBox["Selecting contexts",
    ButtonData:>{"Selecting contexts", "SelectContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CircleDot]"],

Cell[TextData[{
  "\[Backslash], \[AliasIndicator]\[AliasIndicator], TakeAway, ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TakeAway"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TakeAway",
    ButtonData:>{"TakeAway", "TakeAway"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Backslash]"],

Cell[TextData[{
  "\[Wedge]",
  ",",
  " \[AliasIndicator]^\[AliasIndicator], ExactIntersection",
  ", ",
  ButtonBox["ExactIntersection",
    ButtonData:>{"ExactIntersection", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Wedge]"],

Cell[TextData[{
  "\[CirclePlus]",
  ",",
  " \[AliasIndicator]c+\[AliasIndicator], ChangeContext",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "ChangeContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CirclePlus]"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definitions", "Section"],

Cell[BoxData[{
    \(\(<< Utilities`SetManipulation`;\)\), "\n", 
    \(\(<< Utilities`Hyperlinks`;\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(packageSet = {"\<:Genealogies\>", "\<:Multilocus\>", "\<:Using \
packages\>", "\<:Utilities\>"};\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
FindBrowserCategories[':Multilocus'] finds the name of the \
corresponding BrowserCategories.m file\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(FindBrowserCategories::usage = \
"\<FindBrowserCategories[':Multilocus'] finds the name of the corresponding \
BrowserCategories.m file\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FindBrowserCategories::noBrowserCategories = "\<Error in finding \
BrowserCategories.m: `1` \>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FindBrowserCategories[pn_String] := 
        Module[{fn}, \[IndentingNewLine]fn = 
            FileNames["\<BrowserCategories.m\>", \
{ToFileName[{"\<:AddOns:Applications\>", 
                    pn, "\<:Documentation:English\>"}]}]; \
\[IndentingNewLine]If[
            Length[fn] \[NotEqual] 1, \[IndentingNewLine]Message[
              FindBrowserCategories::noBrowserCategories, 
              fn], \[IndentingNewLine]fn = First[fn]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
FindTagList[':Multilocus'] lists all the headings of items in the \
help files for Multilocus\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(FindTagList::usage = "\<FindTagList[':Multilocus'] lists all the \
headings of items in the help files for Multilocus.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FindTagList[pn_String] := 
        Module[{fn = FindBrowserCategories[pn], nb, ps, 
            expr}, \[IndentingNewLine]nb = 
            NotebookOpen[fn]; \[IndentingNewLine]SelectionMove[nb, \ All, \ 
            Notebook]; \[IndentingNewLine]expr = 
            ToExpression[
              First[NotebookRead[nb]]]; \[IndentingNewLine]NotebookClose[
            nb]; \[IndentingNewLine]ps = \(Drop[#, \(-1\)] &\) /@ 
              Position[expr, 
                CopyTag \[Rule] 
                  None]; \[IndentingNewLine]\((\(Extract[expr, \ #] &\) /@ 
                ps)\) /. Item[a_, __] \[Rule] a];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
InsertIndexTags[':Multilocus'] creates a new notebook that replaces \
Item[tag,file,CopyTag->None] by Item[tag,file,IndexTag->tag,CopyTag->None].  \
It is important that no tags be repeated.\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(InsertIndexTags::usage = "\<InsertIndexTags[':Multilocus'] creates a \
new notebook that replaces Item[tag,file,CopyTag->None] by \
Item[tag,file,IndexTag->tag,CopyTag->None].  It is important that no tags be \
repeated.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(InsertIndexTags::repeatedTags = "\<Repeated tags for `1`\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(InsertIndexTags[pn_String] := 
        Module[{fn = FindBrowserCategories[pn], nb, ps, expr, ee, 
            tl = FindTagList[pn]}, \[IndentingNewLine]If[
            Length[Union[tl]] \[NotEqual] 
              Length[tl], \[IndentingNewLine]Print[
              ExtractRepeat[tl] // TableForm]; 
            Message[InsertIndexTags::repeatedTags, 
              tl], \[IndentingNewLine]nb = 
              NotebookOpen[fn]; \[IndentingNewLine]SelectionMove[nb, \ All, \ 
              Notebook]; \[IndentingNewLine]expr = 
              NotebookRead[nb]; \[IndentingNewLine]NotebookClose[
              nb]; \[IndentingNewLine]ee = 
              ToExpression[expr\[LeftDoubleBracket]1\[RightDoubleBracket]] /. 
                Item[a_, f_, CopyTag \[Rule] None] -> 
                  Item[a, f, IndexTag \[Rule] a, 
                    CopyTag \[Rule] None]; \[IndentingNewLine]NotebookPut[
              Notebook[{ToString[ee]}]]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ConvertFormattedFiles", "Subsubsection"],

Cell[BoxData[
    \(\(ConvertFormattedFiles::usage = "\<ConvertFormattedFiles[filename] \
converts a notebook saved as a formatted expression to unformatted \
form.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ConvertFormattedFiles[fn_] := 
        Module[{nb, expr}, \[IndentingNewLine]nb = 
            NotebookOpen[fn]; \[IndentingNewLine]expr = NotebookGet[nb]; 
          NotebookClose[nb]; \[IndentingNewLine]exprNew = 
            expr //. {RowBox[{s___String}] \[RuleDelayed] StringJoin[s], 
                BoxData[s_String] \[Rule] s}; \[IndentingNewLine]NotebookPut[
            exprNew];];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
FindNamedFiles[\":Multilocus\"] lists the files named in \
BrowserCategories.m\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(FindNamedFiles::usage = "\<FindNamedFiles[\":Multilocus\"] lists the \
files named in BrowserCategories.m\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FindNamedFiles[pn_] := 
        Module[{nb, expr}, \[IndentingNewLine]nb = 
            NotebookOpen[
              FindBrowserCategories[pn]]; \[IndentingNewLine]expr = 
            ToExpression[\(NotebookGet[nb]\)\[LeftDoubleBracket]1, 1, 
                1\[RightDoubleBracket]]; \[IndentingNewLine]NotebookClose[
            nb]; \[IndentingNewLine]FlattenList[
              expr /. BrowserCategory \[Rule] List, Item[__]] /. 
            Item[_, f_, _, _] \[RuleDelayed] f];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["FileNameOnly[fn] strips the directory name away", "Subsubsection"],

Cell[BoxData[
    \(\(FileNameOnly::usage = "\<FileNameOnly[fn] strips the directory name \
away\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FileNameOnly[fn_String] := 
        StringDrop[fn, \ StringLength[DirectoryName[fn]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ExtractCellTags[] lists all the cell tags found in the selected \
notebook\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(ExtractCellTags::usage = "\<ExtractCellTags[] lists all the cell tags \
found in the selected notebook. ExtractCellTags[filename] extracts tags from \
the named file.  Tags from the same cell are grouped - for example, \
{a,{b1,b2},c} gives four tags from three cells.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractCellTags[] := 
        Module[{expr = NotebookGet[SelectedNotebook[]], 
            ps}, \[IndentingNewLine]ps = 
            Position[expr, 
              CellTags]; \[IndentingNewLine]Union[\(\((Extract[expr, 
                      Drop[#, \(-1\)]] // Last)\) &\) /@ ps]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractCellTags[fn_String] := 
        Module[{nb, ct, expr, ps}, \[IndentingNewLine]nb = 
            NotebookOpen[fn, 
              Visible \[Rule] False]; \[IndentingNewLine]expr = 
            NotebookGet[nb]; \[IndentingNewLine]ps = 
            Position[expr, CellTags]; \[IndentingNewLine]ct = 
            Union[\(\((Extract[expr, Drop[#, \(-1\)]] // Last)\) &\) /@ 
                ps]; \[IndentingNewLine]NotebookClose[nb]; ct];\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SplitString[\"string\[Ellipsis],next string\[Ellipsis]\"] returns \
the string, split at the first comma: {\"string...\",\"next string\[Ellipsis]\
\"}\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(SplitString::usage = "\<SplitString[\"string\[Ellipsis],next string\
\[Ellipsis]\"] returns the string, split at the first comma: \
{\"string...\",\"next string\[Ellipsis]\"}.  If there is no comma, returns \
{\"string\",\"\"}\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SplitString[s_String] := 
        Module[{ps = StringPosition[s, "\<,\>"]}, \[IndentingNewLine]If[
            ps \[Equal] {}, {s, "\<\>"}, {StringTake[s, 
                ps\[LeftDoubleBracket]1, 1\[RightDoubleBracket] - 1], 
              StringDrop[s, 
                ps\[LeftDoubleBracket]1, 
                  1\[RightDoubleBracket]]}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MakeButtonBoxes[{subname,{{indextag1,celltag1},\[Ellipsis]}}] \
yields {ButtonBox[],\",\",\[Ellipsis]}\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(MakeButtonBoxes::usage = \
"\<MakeButtonBoxes[{subname,{{indextag1,celltag1},\[Ellipsis]}}] yields \
{ButtonBox[],\",\",...}.\>";\)\(\ \ \ \)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MakeButtonBoxes[{sn_, ll : {{_, _} .. }}] := 
        Module[{buttons, 
            ch}, \[IndentingNewLine]buttons = \({"\<,\>", 
                  ButtonBox[#\[LeftDoubleBracket]1\[RightDoubleBracket], 
                    ButtonData \[RuleDelayed] #, 
                    ButtonStyle \[Rule] "\<AddOnsLink\>"]} &\) /@ 
              ll; \[IndentingNewLine]buttons = 
            Drop[buttons // Flatten, 1]; \[IndentingNewLine]ch = 
            If[sn == "\<\>", {"\< \>"}, {sn, "\<, \>"}]; \
\[IndentingNewLine]ch~Join~buttons];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MakeIndexEntry[{name,{{subname1,{{indextag11,celltag11},\[Ellipsis]}\
},\[Ellipsis]}}] prints a cell in the style \"Index\", and tagged with the \
name of the entry.  The main entry has the form name, subname1, link1, link2\
\[Ellipsis]; subsequent entries are all printed in a second cell in style \
\"IndexSubentry\", also tagged with the name of the main entry\
\>", \
"Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(MakeIndexEntry::usage = \
"\<MakeIndexEntry[{name,{{subname1,{{indextag11,celltag11},\[Ellipsis]}},\
\[Ellipsis]}}] prints a cell in the style \"Index\", and tagged with the name \
of the entry.  The main entry has the form name, subname1, link1, link2\
\[Ellipsis]; subsequent entries are all printed in a second cell in style \
\"IndexSubentry\", also tagged with the name of the main entry.\>";\)\(\ \ \ \
\)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MakeIndexEntry[{n_, {{sn_, 
                ll : {{_, _} .. }}}}] := \[IndentingNewLine]CellPrint[
          Cell[TextData[{n, "\<,\>"}~Join~
                MakeButtonBoxes[{sn, ll}]], "\<Index\>", 
            CellTags \[Rule] {n}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MakeIndexEntry[{n_, {{sn1_, ll1 : {{_, _} .. }}, 
              snl : {_, {{_, _} .. }} .. }}] := \((MakeIndexEntry[{n, {{sn1, 
                  ll1}}}]; \[IndentingNewLine]CellPrint[
            Cell[TextData[
                Drop[Flatten[\(\(({"\<\n\>"}~Join~
                            MakeButtonBoxes[#])\) &\) /@ {snl}], 
                  1]], "\<IndexSubentry\>", 
              CellTags \[Rule] {n}]])\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ProcessIndexMatrix[MasterIndexMatrix] generates a matrix which has \
the right structure to generate an index.  Each row consists of a name, \
followed by a list of subentries.  When passed to MakeIndexEntry, this \
generates a main entry cell, possibly followed by a cell containing \
subentries.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(ProcessIndexMatrix::usage = "\<ProcessIndexMatrix[MasterIndexMatrix] \
generates a matrix which has the right structure to generate an index.  Each \
row consists of a name, followed by a list of subentries.  When passed to \
MakeIndexEntry, this generates a main entry cell, possibly followed by a cell \
containing subentries.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ProcessIndexMatrix::wrongNumber = "\<Processed index matrix has the \
wrong number of entries: `1`/`2` entries of the form {{_,_},{_,_}}.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ProcessIndexMatrix[wtl2_] := 
        Module[{wtl3, wtl4, nameset, chk}, \[IndentingNewLine]wtl3 = 
            Sort[Union[wtl2]] /. {n_String, it_String, 
                  ct_} \[RuleDelayed] {SplitString[n], {it, 
                    ct}}; \[IndentingNewLine]chk = 
            Cases[wtl3, \ {{_, _}, {_, _}}]; \[IndentingNewLine]If[
            Length[chk] != Length[wtl3], \[IndentingNewLine]Message[
              ProcessIndexMatrix::wrongNumber, Length[chk], Length[wtl3]]; 
            wtl3, \[IndentingNewLine]nameset = 
              Sort[Union[\(\((#\[LeftDoubleBracket]1, 
                          1\[RightDoubleBracket])\) &\) /@ 
                    wtl3]]; \[IndentingNewLine]wtl4 = \(\(({#, 
                      Cases[wtl3, \ {{#, _}, {_, _}}] /. {{#, sn_}, {it_, 
                              ct_}} \[RuleDelayed] {sn, {it, ct}}})\) &\) /@ 
                nameset; \[IndentingNewLine]\(\(({#\[LeftDoubleBracket]1\
\[RightDoubleBracket], \(#\[LeftDoubleBracket]2\[RightDoubleBracket] /. \
{x_String, y_} \[RuleDelayed] {x, {y}}\) //. {a___List, {x_String, y_List}, 
                          b___List, {x_String, z_List}, 
                          c___List} \[RuleDelayed] {a, {x, Join[y, z]}, b, 
                          c}})\) &\) /@ wtl4]];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["MasterIndexMatrix", "Section",
  CellTags->"MasterIndexMatrix"],

Cell[CellGroupData[{

Cell["\<\
MasterIndexMatrix is a matrix of the form {{\"name\", \"index \
tag\", \"cell tag\"}\[Ellipsis]}.  It can be edited to generate a new \
index.\
\>", "Subsubsection",
  CellTags->"MasterIndexMatrix"],

Cell[BoxData[
    \(\(MasterIndexMatrix::usage = "\<MasterIndexMatrix is a matrix of the \
form {{\"name\", \"index tag\", \"cell tag\"}\[Ellipsis]}.  It can be edited \
to generate a new index.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"MasterIndexMatrix", "=", " ", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"\"\<AddAncestors, to ancestral graphs\>\"", 
                  "\"\<Ancestors & descendants\>\"", "\"\<AddAncestors\>\""},
                {"\"\<AddCoalescentLineage, to ancestral graph\>\"", 
                  "\"\<Coalescence and recombination\>\"", 
                  "\"\<AddCoalescentLineage\>\""},
                {"\"\<AddDescendants, to ancestral graphs\>\"", 
                  "\"\<Ancestors & descendants\>\"", 
                  "\"\<AddDescendants\>\""},
                {"\"\<AddGenealogy\>\"", "\"\<Manipulating genealogies\>\"", 
                  "\"\<AddGenealogy\>\""},
                {"\"\<Additive models\>\"", "\"\<Gaussian likelihoods\>\"", 
                  "\"\<additive models\>\""},
                {"\"\<Additive selection, defining fitnesses\>\"", 
                  "\"\<Additive selection\>\"", 
                  "\"\<Defining fitnesses\>\""},
                {"\"\<Additive selection, defining rules\>\"", 
                  "\"\<Additive selection\>\"", "\"\<Defining rules\>\""},
                {"\"\<Additive selection, new D\>\"", 
                  "\"\<Additive selection\>\"", "\"\<New D\>\""},
                {"\"\<Additive selection, new mean\>\"", 
                  "\"\<Additive selection\>\"", "\"\<New mean\>\""},
                {"\"\<Additive selection, scaled D\>\"", 
                  "\"\<Additive selection\>\"", "\"\<Scaled D\>\""},
                {"\"\<AddMutation\>\"", "\"\<Manipulating genealogies\>\"", 
                  "\"\<AddMutation\>\""},
                {"\"\<AddNode\>\"", "\"\<Manipulating genealogies\>\"", 
                  "\"\<AddNode\>\""},
                {"\"\<AddRecombinantLineages, to ancestral graph\>\"", 
                  "\"\<Coalescence and recombination\>\"", 
                  "\"\<AddRecombinantLineages\>\""},
                {"\"\<AddTag\>\"", "\"\<Tagging sets\>\"", "\"\<AddTag\>\""},
                {"\"\<AddUp\>\"", "\"\<AddUp\>\"", "\"\<AddUp\>\""},
                {"\"\<AddUp\>\"", "\"\<Operations on sets\>\"", 
                  "\"\<AddUp\>\""},
                {"\"\<AddUp, multiple sums\>\"", "\"\<AddUp\>\"", 
                  "\"\<Multiple sums\>\""},
                {"\"\<AddUp, over subsets\>\"", "\"\<AddUp\>\"", 
                  "\"\<Subsets\>\""},
                {"\"\<AddUp, technicalities\>\"", "\"\<AddUp\>\"", 
                  "\"\<Technicalities\>\""},
                {"\"\<AdmixtureFrequency\>\"", "\"\<Equilibria\>\"", 
                  "\"\<AdmixtureFrequency\>\""},
                {"\"\<Admixture models\>\"", "\"\<Admixture models\>\"", 
                  "None"},
                {"\"\<Admixture models\>\"", "\"\<Overview\>\"", "None"},
                {"\"\<Admixture models, changing sex\>\"", 
                  "\"\<Changing sex\>\"", "None"},
                {"\"\<Admixture models, equilibria\>\"", "\"\<Equilibria\>\"",
                   "None"},
                {"\"\<Admixture models, iteration\>\"", "\"\<Iteration\>\"", 
                  "None"},
                {"\"\<Admixture models, migration\>\"", 
                  "\"\<Migration in admixture models\>\"", "None"},
                {"\"\<Admixture models, recombination\>\"", 
                  "\"\<Recombination in admixture models\>\"", "None"},
                {
                  "\"\<Adults, \[GothicCapitalA], \[AliasIndicator]goA\
\[AliasIndicator]\>\"", "\"\<Life cycle\>\"", "\"\<Adults\>\""},
                {
                  "\"\<Adults, \[GothicCapitalA], \[AliasIndicator]goA\
\[AliasIndicator]\>\"", "\"\<Notation reference\>\"", "None"},
                {"\"\<Allele frequencies, definition of fitness\>\"", 
                  "\"\<Allele frequencies:fitnesses\>\"", 
                  "\"\<Defining fitnesses\>\""},
                {"\"\<AlleleFrequencies, in numerical models\>\"", 
                  "\"\<Allele frequencies: representation\>\"", "None"},
                {"\"\<AlleleFrequencies, in numerical models\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<AlleleFrequencies\>\""},
                {"\"\<Allele frequencies, extracting\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<AlleleFrequency\>\""},
                {"\"\<AlleleFrequency\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<AlleleFrequency\>\""},
                {"\"\<AlleleFrequencyMean\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<AlleleFrequencyMean\>\""},
                {"\"\<AlleleFrequencyMean, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: representation\>\"", 
                  "\"\<AlleleFrequencyMean\>\""},
                {"\"\<AlleleFrequencyMean, for genotype frequencies\>\"", 
                  "\"\<Recursions: description\>\"", 
                  "\"\<AlleleFrequencyMean\>\""},
                {"\"\<AlleleFrequencyMean, for individuals\>\"", 
                  "\"\<Simulating individuals: Describing populations\>\"", 
                  "\"\<AlleleFrequencyMean\>\""},
                {"\"\<AlleleFrequencyMean, for symmetric model\>\"", 
                  "\"\<Symmetric model: Describing populations\>\"", 
                  "\"\<AlleleFrequencyMean\>\""},
                {"\"\<AlleleFrequencyPermutations\>\"", 
                  "\"\<Internal functions\>\"", 
                  "\"\<AlleleFrequencyPermutations\>\""},
                {
                  "\"\<AlleleFrequencyPQ, \[GothicP]\[GothicQ], \
\[AliasIndicator]gop\[AliasIndicator]\[AliasIndicator]goq\[AliasIndicator]\>\"\
", "\"\<Populations\>\"", "\"\<AlleleFrequencyPQ\>\""},
                {
                  "\"\<AlleleFrequencyP, \[GothicP], \[AliasIndicator]gop\
\[AliasIndicator]\>\"", "\"\<Populations\>\"", "\"\<AlleleFrequencyP\>\""},
                {
                  "\"\<AlleleFrequencyQ, \[GothicQ], \[AliasIndicator]goq\
\[AliasIndicator]\>\"", "\"\<Populations\>\"", "\"\<AlleleFrequencyQ\>\""},
                {"\"\<AlleleFrequencyTable\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<AlleleFrequencyTable\>\""},
                {"\"\<AlleleFrequencyTable, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: representation\>\"", 
                  "\"\<AlleleFrequencyTable\>\""},
                {"\"\<AlleleFrequencyTable, with null alleles\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<NulAllele\>\""},
                {"\"\<AlleleFrequencyTable, for genotype frequencies\>\"", 
                  "\"\<Recursions: description\>\"", 
                  "\"\<AlleleFrequencyTable\>\""},
                {"\"\<AlleleFrequencyTable, for individuals\>\"", 
                  "\"\<Simulating individuals: Describing populations\>\"", 
                  "\"\<AlleleFrequencyTable\>\""},
                {"\"\<AlleleFrequencyTable, for symmetric model\>\"", 
                  "\"\<Symmetric model: Describing populations\>\"", 
                  "\"\<AlleleFrequencyTable\>\""},
                {
                  "\"\<AllelicDeviation, \[Zeta], \[AliasIndicator]z\
\[AliasIndicator]\>\"", "\"\<Allelic state\>\"", "\"\<AllelicDeviation\>\""},
                {"\"\<AllelicState, X\>\"", "\"\<Allelic state\>\"", 
                  "\"\<AllelicState\>\""},
                {"\"\<AllEvents, in ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<AllEvents\>\""},
                {"\"\<AllSets\>\"", "\"\<The set of all structures\>\"", 
                  "\"\<AllSets\>\""},
                {"\"\<Ancestors, determining\>\"", 
                  "\"\<Determining ancestry\>\"", "\"\<Ancestors\>\""},
                {"\"\<Ancestors, in ancestral graphs\>\"", 
                  "\"\<Ancestors & descendants\>\"", "\"\<Ancestors\>\""},
                {"\"\<AncestralGraphPattern\>\"", 
                  "\"\<Representing ancestral graphs\>\"", 
                  "\"\<AncestralGraphPattern\>\""},
                {"\"\<Ancestral graphs, describing\>\"", 
                  "\"\<Describing ancestral graphs\>\"", "None"},
                {"\"\<Ancestral graphs, genealogies in\>\"", 
                  "\"\<Extracting genealogies\>\"", 
                  "\"\<ExtractGenealogy\>\""},
                {"\"\<Ancestral graphs, introduction\>\"", 
                  "\"\<Ancestral graphs introduction\>\"", "None"},
                {"\"\<Ancestral graphs, plotting\>\"", 
                  "\"\<Plotting ancestral graphs\>\"", "None"},
                {"\"\<Ancestral graphs, random\>\"", 
                  "\"\<Random ancestral graphs\>\"", "None"},
                {"\"\<Ancestral graphs, representing\>\"", 
                  "\"\<Representing ancestral graphs\>\"", "None"},
                {"\"\<AncestralLineage\>\"", 
                  "\"\<Representing ancestral graphs\>\"", 
                  "\"\<AncestralLineage\>\""},
                {"\"\<AncestralLineagePattern\>\"", 
                  "\"\<Representing ancestral graphs\>\"", 
                  "\"\<AncestralLineagePattern\>\""},
                {"\"\<Ancestry\>\"", "\"\<Describing individuals\>\"", 
                  "\"\<Ancestry\>\""},
                {
                  "\"\<Arbitrary sets of loci, as used in Kirkpatrick et \
al.\>\"", "\"\<Multilocus MS relation\>\"", 
                  "\"\<Arbitrary sets of loci\>\""},
                {"\"\<Arnold 1996\>\"", "\"\<References\>\"", 
                  "\"\<Arnold 1996\>\""},
                {"\"\<Asmussen and Orive 2000\>\"", 
                  "\"\<Migration example\>\"", 
                  "\"\<Asmussen and Orive 2000\>\""},
                {"\"\<Asmussen and Orive 2000\>\"", "\"\<References\>\"", 
                  "\"\<Asmussen and Orive 2000\>\""},
                {"\"\<Asmussen et al. 1987\>\"", "\"\<References\>\"", 
                  "\"\<Asmussen et al 1987\>\""},
                {"\"\<B\>\"", "\"\<Distribution of coalescence times\>\"", 
                  "\"\<B\>\""},
                {"\"\<Baake 2001\>\"", "\"\<Alternative measures\>\"", 
                  "\"\<Baake\>\""},
                {"\"\<Baake 2001\>\"", "\"\<References\>\"", 
                  "\"\<Baake 2001\>\""},
                {"\"\<BackgroundStyle, option for PlotSegments\>\"", 
                  "\"\<Plotting ancestral graphs\>\"", 
                  "\"\<BackgroundStyle\>\""},
                {"\"\<Barrier, in symmetric model\>\"", 
                  "\"\<Adding a neutral gene\>\"", "\"\<Barrier\>\""},
                {"\"\<BarrierStrength\>\"", "\"\<Describing populations\>\"", 
                  "\"\<BarrierStrength\>\""},
                {"\"\<Barton 1986\>\"", "\"\<References\>\"", 
                  "\"\<Barton 1986\>\""},
                {"\"\<Barton 1995\>\"", "\"\<Multilocus references\>\"", 
                  "\"\<Barton 1995\>\""},
                {"\"\<Barton 2000\>\"", "\"\<References\>\"", 
                  "\"\<Barton 2000\>\""},
                {"\"\<Barton and Turelli 1991\>\"", 
                  "\"\<Multilocus references\>\"", 
                  "\"\<Barton and Turelli 1991\>\""},
                {"\"\<Barton & Gale 1993\>\"", "\"\<References\>\"", 
                  "\"\<Barton & Gale 1993\>\""},
                {"\"\<Barton & Shpak 1999\>\"", "\"\<References\>\"", 
                  "\"\<Barton & Shpak 1999\>\""},
                {"\"\<Barton & Turelli 1991\>\"", "\"\<References\>\"", 
                  "\"\<Barton & Turelli 1991\>\""},
                {"\"\<Bennett 1954\>\"", "\"\<References\>\"", 
                  "\"\<Bennett 1954\>\""},
                {"\"\<BennettB\>\"", "\"\<Alternative measures\>\"", 
                  "\"\<BennettB\>\""},
                {"\"\<BennettC\>\"", "\"\<Alternative measures\>\"", 
                  "\"\<BennettC\>\""},
                {"\"\<BennettExpansion\>\"", "\"\<Alternative measures\>\"", 
                  "\"\<BennettExpansion\>\""},
                {"\"\<Biallelic\>\"", "\"\<Two alleles\>\"", 
                  "\"\<Biallelic\>\""},
                {"\"\<BiallelicMutation\>\"", "\"\<Multilocus mutation\>\"", 
                  "\"\<BiallelicMutation\>\""},
                {"\"\<BiallelicMutation, Mutation option\>\"", 
                  "\"\<Multilocus mutation\>\"", "\"\<Mutation\>\""},
                {"\"\<Biallelic, selection coefficients\>\"", 
                  "\"\<Fitness\>\"", "\"\<Two alleles\>\""},
                {"\"\<Biallelic, selection coefficients\>\"", 
                  "\"\<Phenotypes\>\"", "\"\<Two alleles\>\""},
                {"\"\<Binary integers\>\"", "\"\<Set combinations\>\"", 
                  "\"\<SetOfCombinations\>\""},
                {"\"\<Birth\>\"", "\"\<Iterating  the continuum model\>\"", 
                  "\"\<Birth\>\""},
                {"\"\<BirthTime\>\"", "\"\<Describing individuals\>\"", 
                  "\"\<BirthTime\>\""},
                {"\"\<Boundary conditions, in numerical models\>\"", 
                  "\"\<Allele frequencies:migration\>\"", 
                  "\"\<FixedEnds\>\""},
                {"\"\<Boundary conditions, in numerical models\>\"", 
                  "\"\<Recursions:migration\>\"", "\"\<FixedEnds\>\""},
                {"\"\<Box\>\"", "\"\<Boxing the individuals\>\"", 
                  "\"\<Box\>\""},
                {"\"\<Boxes\>\"", "\"\<Describing individuals\>\"", 
                  "\"\<Boxes\>\""},
                {"\"\<Browser categories\>\"", 
                  "\"\<How the Help Browser works\>\"", 
                  "\"\<Browser categories\>\""},
                {"\"\<Bugs, applying rules\>\"", "\"\<Bugs\>\"", 
                  "\"\<Applying rules\>\""},
                {"\"\<Bugs, clashes between packages\>\"", "\"\<Bugs\>\"", 
                  "\"\<Clashes between packages\>\""},
                {"\"\<Bugs, estimating D\>\"", "\"\<Bugs\>\"", 
                  "\"\<Obsolete EstimatingD\>\""},
                {"\"\<Bugs, incompatibilities\>\"", "\"\<Bugs\>\"", 
                  "\"\<Incompatibilities\>\""},
                {"\"\<Bugs, manipulating notebooks\>\"", "\"\<Bugs\>\"", 
                  "\"\<Manipulating notebooks\>\""},
                {"\"\<Bugs, multilocus notation\>\"", "\"\<Bugs\>\"", 
                  "\"\<Multilocus notation\>\""},
                {"\"\<Bugs, numerical error with AlleleFrequencies\>\"", 
                  "\"\<Allele frequencies: iterating a cline\>\"", 
                  "\"\<Numerical bug\>\""},
                {"\"\<Bugs, pasting hyperlinks\>\"", "\"\<Bugs\>\"", 
                  "\"\<Pasting hyperlinks\>\""},
                {"\"\<Bugs, repeated \\\\\\\\\>\"", "\"\<Bugs\>\"", 
                  "\"\<Repeated \\\\\\\\\>\""},
                {"\"\<Bugs, special notation\>\"", "\"\<Bugs\>\"", 
                  "\"\<Special notation\>\""},
                {"\"\<\\\\\\\\, bugs with\>\"", "\"\<Bugs\>\"", 
                  "\"\<Repeated \\\\\\\\\>\""},
                {"\"\<Bugs, with style sheets\>\"", "\"\<Bugs\>\"", 
                  "\"\<Style sheets\>\""},
                {
                  "\"\<ChangeContext,\[CirclePlus], \[AliasIndicator]c+\
\[AliasIndicator]\>\"", "\"\<Changing contexts\>\"", 
                  "\"\<ChangeContext\>\""},
                {"\"\<ChangeSex\>\"", "\"\<Changing sex\>\"", 
                  "\"\<ChangeSex\>\""},
                {"\"\<ClassToGenotypes\>\"", 
                  "\"\<Symmetric model: converting\>\"", 
                  "\"\<ClassToGenotypes\>\""},
                {"\"\<Cline, example of\>\"", "\"\<Example: epistasis\>\"", 
                  "None"},
                {"\"\<ClineGradient,  for genotype frequencies\>\"", 
                  "\"\<ClineGradient: setting up a cline\>\"", 
                  "\"\<ClineGradient\>\""},
                {"\"\<Cline, in allele frequencies\>\"", 
                  "\"\<Allele frequencies: iterating a cline\>\"", "None"},
                {"\"\<Cline, in allele frequencies\>\"", 
                  "\"\<Allele frequencies: setting up a cline\>\"", "None"},
                {"\"\<Cline, in genotype frequencies\>\"", 
                  "\"\<Recursions: iterating a cline\>\"", "None"},
                {"\"\<Cline, in symmetric model\>\"", 
                  "\"\<Symmetric model: iterating a cline\>\"", "None"},
                {"\"\<Cline, in symmetric model\>\"", 
                  "\"\<Symmetric model: setting up a cline\>\"", "None"},
                {"\"\<Cline, stability of\>\"", 
                  "\"\<Allele frequencies: stability\>\"", "None"},
                {"\"\<Cline, stability of\>\"", "\"\<Example: stability\>\"", 
                  "None"},
                {"\"\<Cline, stability of\>\"", 
                  "\"\<Symmetric stability: a cline\>\"", "None"},
                {"\"\<Cline, stability of\>\"", 
                  "\"\<Symmetric stability: spatially varying selection\>\"", 
                  "None"},
                {"\"\<Cline, symmetric\>\"", 
                  "\"\<Recursions:setting up a symmetric cline\>\"", 
                  "\"\<DoubleCline\>\""},
                {"\"\<Cline, symmetric\>\"", 
                  "\"\<Simulating individuals: setting up a symmetric cline\>\
\"", "None"},
                {"\"\<Cline, symmetric\>\"", 
                  "\"\<Symmetric model: setting up a symmetric cline\>\"", 
                  "None"},
                {"\"\<ClineWidth, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: setting up a cline\>\"", 
                  "\"\<ClineWidth\>\""},
                {"\"\<ClineWidth,  for genotype frequencies\>\"", 
                  "\"\<Recursions: setting up a cline\>\"", 
                  "\"\<ClineWidth\>\""},
                {"\"\<ClineWidth, for individuals\>\"", 
                  "\"\<Simulating individuals:setting up a cline\>\"", 
                  "\"\<ClineWidth\>\""},
                {"\"\<ClineWidth, for symmetric model\>\"", 
                  "\"\<Symmetric model: setting up a cline\>\"", 
                  "\"\<ClineWidth\>\""},
                {"\"\<Cline, with individuals\>\"", 
                  "\"\<Simulating individuals: iterating a cline\>\"", 
                  "None"},
                {"\"\<Cline, with individuals\>\"", 
                  "\"\<Simulating individuals:setting up a cline\>\"", 
                  "None"},
                {"\"\<Cline, with neutral marker\>\"", 
                  "\"\<Adding a neutral gene\>\"", "\"\<Cline\>\""},
                {"\"\<CoalesceLineages\>\"", 
                  "\"\<Coalescence and recombination\>\"", 
                  "\"\<CoalesceLineages\>\""},
                {"\"\<CoalescenceDistribution\>\"", 
                  "\"\<Distribution of coalescence times\>\"", 
                  "\"\<CoalescenceDistribution\>\""},
                {"\"\<CoalescenceEvents, in ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<CoalescenceEvents\>\""},
                {"\"\<Coalescence times, random, for ancestral graphs\>\"", 
                  "\"\<Random ancestral graphs\>\"", 
                  "\"\<RandomCoalescenceTimes\>\""},
                {"\"\<CoalescenceTimes,option for RandomGenealogy\>\"", 
                  "\"\<Drawing a genealogy\>\"", "\"\<CoalescenceTimes\>\""},
                {"\"\<Coalescence times, random\>\"", 
                  "\"\<Distribution of coalescence times\>\"", 
                  "\"\<RandomCoalescenceTimes\>\""},
                {"\"\<CoalescentLineages, in ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<CoalescentLineages\>\""},
                {"\"\<Coalescing lineages, in ancestral graphs\>\"", 
                  "\"\<Coalescence and recombination\>\"", 
                  "\"\<CoalesceLineages\>\""},
                {"\"\<Coalescing lineages, in ancestral graphs\>\"", 
                  "\"\<Coalescence and recombination\>\"", 
                  "\"\<CoalesceLineages\>\""},
                {"\"\<CollapseGenealogy\>\"", 
                  "\"\<Describing genealogies\>\"", 
                  "\"\<CollapseGenealogy\>\""},
                {"\"\<Combinations, set of\>\"", "\"\<Set combinations\>\"", 
                  "\"\<SetOfCombinations\>\""},
                {"\"\<Combine\>\"", "\"\<Tagging sets\>\"", 
                  "\"\<Combine\>\""},
                {"\"\<CompareLogL\>\"", "\"\<Presenting results\>\"", 
                  "\"\<CompareLogL\>\""},
                {"\"\<Compiled, option for IterateExact\>\"", 
                  "\"\<Allele frequencies: iterating a cline\>\"", 
                  "\"\<Compiled\>\""},
                {"\"\<Compiled, option for IterateExact\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<Compiled\>\""},
                {"\"\<Compiled, option for IterateExact\>\"", 
                  "\"\<Recursions: compiling\>\"", "\"\<Compiled\>\""},
                {"\"\<Compiled, option for IterateExact\>\"", 
                  "\"\<Recursions: iterating a cline\>\"", 
                  "\"\<Compiled\>\""},
                {"\"\<Compiled, option for IterateExact\>\"", 
                  "\"\<Symmetric model: iterating a cline\>\"", 
                  "\"\<Compiled\>\""},
                {"\"\<Compiled, option for IterateExact\>\"", 
                  "\"\<Symmetric model: iterating one deme\>\"", 
                  "\"\<Compiled\>\""},
                {"\"\<Compiling, in numerical models\>\"", 
                  "\"\<Allele frequencies: iterating a cline\>\"", 
                  "\"\<Compiled\>\""},
                {"\"\<Compiling, in numerical models\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<Compiled\>\""},
                {"\"\<Compiling, in numerical models\>\"", 
                  "\"\<Recursions: compiling\>\"", "\"\<Compiled\>\""},
                {"\"\<Compiling, in numerical models\>\"", 
                  "\"\<Recursions: iterating a cline\>\"", 
                  "\"\<Compiled\>\""},
                {"\"\<Compiling, in numerical models\>\"", 
                  "\"\<Symmetric model: iterating a cline\>\"", 
                  "\"\<Compiled\>\""},
                {"\"\<Compiling, in numerical models\>\"", 
                  "\"\<Symmetric model: iterating one deme\>\"", 
                  "\"\<Compiled\>\""},
                {"\"\<CondenseGenealogy\>\"", 
                  "\"\<Manipulating genealogies\>\"", 
                  "\"\<CondenseGenealogy\>\""},
                {"\"\<CondenseMatrix\>\"", "\"\<Inferring a genealogy\>\"", 
                  "\"\<CondenseMatrix\>\""},
                {"\"\<ConfigurationSet\>\"", "\"\<Set combinations\>\"", 
                  "\"\<ConfigurationSet\>\""},
                {"\"\<ConstrainedIntervals\>\"", 
                  "\"\<Constrained intervals\>\"", 
                  "\"\<ConstrainedIntervals\>\""},
                {"\"\<ConstructMutateList\>\"", 
                  "\"\<Allele frequencies: mutation\>\"", 
                  "\"\<ConstructMutateList\>\""},
                {"\"\<ConstructMutateList\>\"", 
                  "\"\<Recursions: mutation\>\"", 
                  "\"\<ConstructMutateList\>\""},
                {"\"\<ConstructMutateList\>\"", 
                  "\"\<Simulating individuals: mutation\>\"", 
                  "\"\<ConstructMutateList\>\""},
                {"\"\<ConstructMutateList\>\"", 
                  "\"\<Symmetric model: mutation\>\"", 
                  "\"\<ConstructMutateList\>\""},
                {"\"\<ConstructMutateMatrix\>\"", 
                  "\"\<Recursions: mutation\>\"", 
                  "\"\<ConstructMutateMatrix\>\""},
                {"\"\<ConstructMutateMatrix\>\"", 
                  "\"\<Symmetric model: mutation\>\"", 
                  "\"\<ConstructMutateMatrix\>\""},
                {"\"\<ContextComponentQ\>\"", 
                  "\"\<Stages in the life cycle\>\"", 
                  "\"\<ContextComponentQ\>\""},
                {"\"\<ContextPosition\>\"", 
                  "\"\<Stages in the life cycle\>\"", 
                  "\"\<ContextPosition\>\""},
                {"\"\<ContextStageQ\>\"", "\"\<Stages in the life cycle\>\"", 
                  "\"\<ContextStageQ\>\""},
                {"\"\<ContextStructure\>\"", 
                  "\"\<Stages in the life cycle\>\"", 
                  "\"\<ContextStructure\>\""},
                {"\"\<Continuous populations, estimating covariance\>\"", 
                  "\"\<Estimating the covariance\>\"", "None"},
                {"\"\<Continuous populations, example\>\"", 
                  "\"\<An example\>\"", "None"},
                {"\"\<Continuous populations, implementation\>\"", 
                  "\"\<Implementation\>\"", "None"},
                {"\"\<Continuous populations, saving results\>\"", 
                  "\"\<Global variables\>\"", "\"\<Saving results\>\""},
                {"\"\<Continuous populations, the model\>\"", 
                  "\"\<The model\>\"", "None"},
                {"\"\<ContinuumVariables\>\"", "\"\<Global variables\>\"", 
                  "\"\<ContinuumVariables\>\""},
                {"\"\<ConvertData\>\"", "\"\<Converting a dataset\>\"", 
                  "\"\<ConvertData\>\""},
                {"\"\<ConvertHyperlinkToAddOnsLink\>\"", 
                  "\"\<Hyperlinks\>\"", 
                  "\"\<ConvertHyperlinkToAddOnsLink\>\""},
                {"\"\<Converting, between representations\>\"", 
                  "\"\<Allele frequencies: converting\>\"", "None"},
                {"\"\<Converting, between representations\>\"", 
                  "\"\<Recursions: converting\>\"", "None"},
                {"\"\<CountHeterozygotes\>\"", 
                  "\"\<Recursions: manipulation\>\"", 
                  "\"\<CountHeterozygotes\>\""},
                {"\"\<Covariance, in continuous populations\>\"", 
                  "\"\<Estimating the covariance\>\"", "None"},
                {"\"\<CovarianceMidPoints\>\"", "\"\<Sampling\>\"", 
                  "\"\<CovarianceMidPoints\>\""},
                {"\"\<Crow and Kimura 1970\>\"", 
                  "\"\<Multilocus references\>\"", 
                  "\"\<Crow and Kimura 1970\>\""},
                {"\"\<Cumulant\>\"", "\"\<Moments and cumulants\>\"", 
                  "\"\<Cumulant\>\""},
                {
                  "\"\<CumulantDisequilibrium, \[GothicK], \
\[AliasIndicator]gok\[AliasIndicator]\>\"", "\"\<Populations\>\"", 
                  "\"\<CumulantDisequilibrium\>\""},
                {"\"\<CumulantEquilibrium\>\"", "\"\<Equilibria\>\"", 
                  "\"\<CumulantEquilibrium\>\""},
                {
                  "\"\<CumulantPopulationDisequilibrium, \[GothicCapitalK], \
\[AliasIndicator]goK\[AliasIndicator]\>\"", 
                  "\"\<Introduction to random drift\>\"", 
                  "\"\<Cumulants and moments\>\""},
                {"\"\<CumulantReduced\>\"", "\"\<Obsolete functions\>\"", 
                  "\"\<CumulantReduced\>\""},
                {"\"\<Cumulants\>\"", "\"\<Cumulants\>\"", "\"\<7.2\>\""},
                {"\"\<Cumulants\>\"", "\"\<Cumulants\>\"", 
                  "\"\<Cumulant\>\""},
                {"\"\<Cytoplasmic inheritance\>\"", 
                  "\"\<Non-Mendelian inheritance\>\"", 
                  "\"\<CytoplasmicLoci\>\""},
                {"\"\<Cytoplasmic inheritance\>\"", 
                  "\"\<Reference points\>\"", "\"\<CytoplasmicLoci\>\""},
                {"\"\<Cytoplasmic inheritance, and migration\>\"", 
                  "\"\<Migration example\>\"", 
                  "\"\<Cytonuclear associations\>\""},
                {"\"\<Cytoplasmic inheritance, examples of\>\"", 
                  "\"\<Cytoplasmic inheritance\>\"", "None"},
                {"\"\<CytoplasmicLoci, example of\>\"", 
                  "\"\<Cytoplasmic inheritance\>\"", "None"},
                {"\"\<CytoplasmicLoci, option for NonMendelian\>\"", 
                  "\"\<Non-Mendelian inheritance\>\"", 
                  "\"\<CytoplasmicLoci\>\""},
                {"\"\<CytoplasmicLoci, reference points\>\"", 
                  "\"\<Reference points\>\"", "\"\<CytoplasmicLoci\>\""},
                {"\"\<dAlleleFrequencyPermutations\>\"", 
                  "\"\<Internal functions\>\"", 
                  "\"\<dAlleleFrequencyPermutations\>\""},
                {"\"\<Data\>\"", "\"\<Defining a dataset\>\"", 
                  "\"\<Data\>\""},
                {"\"\<Data, missing\>\"", "\"\<Defining a dataset\>\"", 
                  "\"\<Missing data\>\""},
                {"\"\<Data, notation for\>\"", 
                  "\"\<Notation for genetic data\>\"", 
                  "\"\<NotationPackage\>\""},
                {"\"\<Datasets, defining\>\"", "\"\<Defining a dataset\>\"", 
                  "\"\<Data\>\""},
                {"\"\<Dawson 2000\>\"", "\"\<Alternative measures\>\"", 
                  "\"\<Bennett\>\""},
                {"\"\<Dawson 2000\>\"", "\"\<References\>\"", 
                  "\"\<Dawson 2000\>\""},
                {"\"\<Death\>\"", "\"\<Iterating  the continuum model\>\"", 
                  "\"\<Death\>\""},
                {"\"\<DeathTime\>\"", "\"\<Describing individuals\>\"", 
                  "\"\<DeathTime\>\""},
                {"\"\<DefineContext\>\"", "\"\<Stages in the life cycle\>\"", 
                  "\"\<DefineContext\>\""},
                {"\"\<DegreesOfFreedom\>\"", "\"\<Degrees of freedom\>\"", 
                  "\"\<DegreesOfFreedom\>\""},
                {"\"\<DeletedMutations\>\"", 
                  "\"\<Population bottlenecks\>\"", 
                  "\"\<DeletedMutations\>\""},
                {"\"\<DeleteGenealogy\>\"", 
                  "\"\<Manipulating genealogies\>\"", 
                  "\"\<DeleteGenealogy\>\""},
                {"\"\<DeleteNullLineages, option for RandomGenealogy\>\"", 
                  "\"\<Random ancestral graphs\>\"", 
                  "\"\<DeleteNullLineages\>\""},
                {"\"\<DeleteNullLineages, option for RecombineLineage\>\"", 
                  "\"\<Coalescence and recombination\>\"", 
                  "\"\<DeleteNullLineages\>\""},
                {"\"\<Deme\>\"", "\"\<Life cycle\>\"", "\"\<Deme\>\""},
                {"\"\<Deme\>\"", "\"\<Migration\>\"", "\"\<Deme\>\""},
                {"\"\<DemeSize, compiling\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<DemeSize\>\""},
                {"\"\<DemeSize, compiling\>\"", 
                  "\"\<Recursions: compiling\>\"", "\"\<DemeSize\>\""},
                {"\"\<DemeSize, compiling\>\"", 
                  "\"\<Symmetric model: iterating one deme\>\"", 
                  "\"\<Deme size (compiling)\>\""},
                {"\"\<DemeSize, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: representation\>\"", 
                  "\"\<DemeSize\>\""},
                {"\"\<DemeSize, for genotype frequencies\>\"", 
                  "\"\<Recursions: description\>\"", "\"\<DemeSize\>\""},
                {"\"\<DemeSize, for individuals\>\"", 
                  "\"\<Simulating individuals: Describing populations\>\"", 
                  "\"\<DemeSize\>\""},
                {"\"\<DemeSize, for symmetric model\>\"", 
                  "\"\<Symmetric model: Describing populations\>\"", 
                  "\"\<DemeSize\>\""},
                {"\"\<DemeSize, option for IterateExact\>\"", 
                  "\"\<Allele frequencies: iterating a cline\>\"", 
                  "\"\<DemeSize\>\""},
                {"\"\<DemeSize, option for IterateExact\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<DemeSize\>\""},
                {"\"\<DemeSize, option for IterateExact\>\"", 
                  "\"\<Recursions: iterating a cline\>\"", 
                  "\"\<DemeSize\>\""},
                {"\"\<DemeSize, option for IterateExact\>\"", 
                  "\"\<Recursions: iterating one deme\>\"", 
                  "\"\<DemeSize\>\""},
                {"\"\<DemeSize, option for IterateExact\>\"", 
                  "\"\<Simulating individuals: iterating a cline\>\"", 
                  "\"\<DemeSize\>\""},
                {"\"\<DemeSize, option for IterateExact\>\"", 
                  "\"\<Simulating individuals: iterating one deme\>\"", 
                  "\"\<DemeSize\>\""},
                {"\"\<DemeSize, option for IterateExact\>\"", 
                  "\"\<Symmetric model: iterating a cline\>\"", 
                  "\"\<DemeSize\>\""},
                {"\"\<DemeSize, option for IterateExact\>\"", 
                  "\"\<Symmetric model: iterating one deme\>\"", 
                  "\"\<DemeSize\>\""},
                {"\"\<DemeSize, option for MigrateExact\>\"", 
                  "\"\<Symmetric model: migration\>\"", "\"\<DemeSize\>\""},
                {"\"\<DemeSize, option for NewGametes\>\"", 
                  "\"\<Allele frequencies:reproduction\>\"", 
                  "\"\<DemeSize\>\""},
                {"\"\<DemeSize, option for NewGametes\>\"", 
                  "\"\<Recursions:reproduction\>\"", "\"\<DemeSize\>\""},
                {"\"\<DemeSize, option for NewGametes\>\"", 
                  "\"\<Simulating individuals: reproduction\>\"", 
                  "\"\<DemeSize\>\""},
                {"\"\<DemeSize, option for NewGametes\>\"", 
                  "\"\<Symmetric model: reproduction\>\"", 
                  "\"\<DemeSize\>\""},
                {"\"\<Dempster et al 1977\>\"", "\"\<References\>\"", 
                  "\"\<Dempster et al 1977\>\""},
                {"\"\<Density\>\"", "\"\<Describing individuals\>\"", 
                  "\"\<Density\>\""},
                {"\"\<Descendants\>\"", "\"\<Ancestors and descendants\>\"", 
                  "\"\<Descendants\>\""},
                {"\"\<Descendants, determining\>\"", 
                  "\"\<Determining ancestry\>\"", "\"\<Descendants\>\""},
                {"\"\<Descendants, in ancestral graphs\>\"", 
                  "\"\<Ancestors & descendants\>\"", "\"\<Descendants\>\""},
                {"\"\<Dicytonuclear associations\>\"", 
                  "\"\<Migration example\>\"", 
                  "\"\<Asmussen and Orive 2000\>\""},
                {"\"\<DiploidConstraints\>\"", "\"\<Obsolete functions\>\"", 
                  "\"\<DiploidConstraints\>\""},
                {"\"\<DiploidFrequencies\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<DiploidFrequencies\>\""},
                {"\"\<DiploidGenotypeFrequency\>\"", 
                  "\"\<Genotype frequencies from moments\>\"", 
                  "\"\<DiploidGenotypeFrequency\>\""},
                {"\"\<DiploidGenotypeFrequencyList\>\"", 
                  "\"\<Fast calculations\>\"", 
                  "\"\<DiploidGenotypeFrequencyList\>\""},
                {"\"\<DiploidGenotypeFrequencyReduced\>\"", 
                  "\"\<Obsolete functions\>\"", 
                  "\"\<DiploidGenotypeFrequencyReduced\>\""},
                {"\"\<DiploidGenotypeFrequencyTable\>\"", 
                  "\"\<Obsolete functions\>\"", 
                  "\"\<DiploidGenotypeFrequencyTable\>\""},
                {"\"\<DiploidIndividuals\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<DiploidIndividuals\>\""},
                {"\"\<Diploid, option for MomentFromG\>\"", 
                  "\"\<Moments from genotype frequencies\>\"", 
                  "\"\<Diploid\>\""},
                {"\"\<DiploidPhenotype\>\"", "\"\<Genotype frequencies\>\"", 
                  "\"\<DiploidPhenotype\>\""},
                {"\"\<DiploidPsi\>\"", "\"\<Genotype frequencies\>\"", 
                  "\"\<DiploidPsi\>\""},
                {"\"\<DiploidPsi\>\"", "\"\<Representing the population\>\"", 
                  "\"\<DiploidPsi\>\""},
                {"\"\<DiploidRepresentations\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<DiploidRepresentations\>\""},
                {"\"\<DiploidSource\>\"", "\"\<Genotype frequencies\>\"", 
                  "\"\<DiploidSource\>\""},
                {"\"\<DiploidSource\>\"", 
                  "\"\<Representing the population\>\"", 
                  "\"\<DiploidSource\>\""},
                {"\"\<DiploidSubsets\>\"", "\"\<Subsets of loci\>\"", 
                  "\"\<DiploidSubsets\>\""},
                {"\"\<DiploidTypes\>\"", "\"\<Listing genotypes\>\"", 
                  "\"\<DiploidTypes\>\""},
                {"\"\<Disequilibrium, Baake's measure\>\"", 
                  "\"\<Alternative measures\>\"", "\"\<Baake\>\""},
                {"\"\<Disequilibrium, Bennett's principal components\>\"", 
                  "\"\<Alternative measures\>\"", "\"\<Bennett\>\""},
                {"\"\<DisequilibriumMean, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: representation\>\"", 
                  "\"\<DisequilibriumMean\>\""},
                {"\"\<DisequilibriumMean, for genotype frequencies\>\"", 
                  "\"\<Recursions: description\>\"", 
                  "\"\<DisequilibriumMean\>\""},
                {"\"\<DisequilibriumMean, for individuals\>\"", 
                  "\"\<Simulating individuals: Describing populations\>\"", 
                  "\"\<DisequilibriumMean\>\""},
                {"\"\<DisequilibriumMean, for symmetric model\>\"", 
                  "\"\<Symmetric model: Describing populations\>\"", 
                  "\"\<DisequilibriumMean\>\""},
                {"\"\<Disequilibrium, population\>\"", 
                  "\"\<Expectations\>\"", 
                  "\"\<PopulationDisequilibrium\>\""},
                {"\"\<DisequilibriumTable, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: representation\>\"", 
                  "\"\<DisequilibriumTable\>\""},
                {"\"\<DisequilibriumTable, for genotype frequencies\>\"", 
                  "\"\<Recursions: description\>\"", 
                  "\"\<DisequilibriumTable\>\""},
                {"\"\<DisequilibriumTable, for individuals\>\"", 
                  "\"\<Simulating individuals: Describing populations\>\"", 
                  "\"\<DisequilibriumTable\>\""},
                {"\"\<DisequilibriumTable, for symmetric model\>\"", 
                  "\"\<Symmetric model: Describing populations\>\"", 
                  "\"\<DisequilibriumTable\>\""},
                {
                  "\"\<Disequilibrium, \[GothicCapitalD], \[AliasIndicator]\
\[GothicCapitalD]\[AliasIndicator]\>\"", "\"\<Disequilibrium\>\"", 
                  "\"\<Disequilibrium\>\""},
                {
                  "\"\<Disequilibrium, \[GothicCapitalD], \[AliasIndicator]\
\[GothicCapitalD]\[AliasIndicator]\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<Linkage disequilibrium\>\""},
                {
                  "\"\<Disequilibrium, \[GothicCapitalD], \[AliasIndicator]\
\[GothicCapitalD]\[AliasIndicator]\>\"", "\"\<Populations\>\"", 
                  "\"\<Disequilibrium\>\""},
                {"\"\<Dispersal, in continuum simulations\>\"", 
                  "\"\<Iterating  the continuum model\>\"", "None"},
                {"\"\<DistanceSquared\>\"", "\"\<Boxing the individuals\>\"", 
                  "\"\<DistanceSquared\>\""},
                {"\"\<Distribution\>\"", "\"\<Cumulants\>\"", 
                  "\"\<Distribution\>\""},
                {"\"\<DivideZero\>\"", "\"\<DivideZero\>\"", 
                  "\"\<DivideZero\>\""},
                {"\"\<DoReplicates\>\"", 
                  "\"\<Analysing replicate samples\>\"", 
                  "\"\<DoReplicates\>\""},
                {"\"\<DoubleCline, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: setting up a symmetric cline\>\"", 
                  "\"\<DoubleCline\>\""},
                {"\"\<DoubleCline, for genotype frequencies\>\"", 
                  "\"\<Recursions:setting up a symmetric cline\>\"", 
                  "\"\<DoubleCline\>\""},
                {"\"\<DoubleCline, for individuals\>\"", 
                  "\"\<Simulating individuals: setting up a symmetric cline\>\
\"", "\"\<DoubleCline\>\""},
                {"\"\<DoubleCline, for symmetric model\>\"", 
                  "\"\<Symmetric model: setting up a symmetric cline\>\"", 
                  "\"\<DoubleCline\>\""},
                {"\"\<DrawSamples\>\"", "\"\<Setting up replicates\>\"", 
                  "\"\<DrawSamples\>\""},
                {"\"\<DropOptions\>\"", "\"\<Manipulating options\>\"", 
                  "\"\<DropOptions\>\""},
                {"\"\<Edwards 1972\>\"", "\"\<References\>\"", 
                  "\"\<Edwards 1972\>\""},
                {"\"\<EmptySets,option for PartitionSet\>\"", 
                  "\"\<Set partitions\>\"", "\"\<EmptySets\>\""},
                {"\"\<Epistasis, in numerical models\>\"", 
                  "\"\<Example: epistasis\>\"", "None"},
                {"\"\<EquivalentSexes, obsolete form of SymmetricSexes\>\"", 
                  "\"\<Symmetric sexes\>\"", "\"\<SymmetricSexes\>\""},
                {"\"\<ErrorBound\>\"", "\"\<Options for StructuredMLE\>\"", 
                  "\"\<ErrorBound\>\""},
                {"\"\<EstimateFamilyMoments\>\"", 
                  "\"\<Estimation from families\>\"", 
                  "\"\<EstimateFamilyMoments\>\""},
                {"\"\<EstimateMoments\>\"", "\"\<Estimating the matrix\>\"", 
                  "\"\<EstimateMoments\>\""},
                {"\"\<Estimating D, admixture models\>\"", 
                  "\"\<Admixture models\>\"", "None"},
                {"\"\<Estimating D, alternative methods\>\"", 
                  "\"\<Alternative methods\>\"", 
                  "\"\<Log-linear models\>\""},
                {"\"\<Estimating D, introduction\>\"", 
                  "\"\<Introduction to estimating D\>\"", "None"},
                {"\"\<Estimating D, maximum entropy\>\"", 
                  "\"\<Alternative methods\>\"", "\"\<Maximum entropy\>\""},
                {"\"\<Estimating D, maximum likelihood, example of\>\"", 
                  "\"\<MLE example\>\"", "None"},
                {"\"\<Estimating D, Metropolis random walk\>\"", 
                  "\"\<Random walk\>\"", "None"},
                {"\"\<Estimating D, MLE, cumulants\>\"", 
                  "\"\<Finding the MLE\>\"", "\"\<Cumulant\>\""},
                {"\"\<Estimating D, moments, families\>\"", 
                  "\"\<Estimating the matrix of moments\>\"", 
                  "\"\<Extension to families\>\""},
                {"\"\<Estimating D, naive MLE\>\"", 
                  "\"\<Alternative methods\>\"", "\"\<Naive MLE\>\""},
                {"\"\<Estimating D, obsolete\>\"", "\"\<Bugs\>\"", 
                  "\"\<Obsolete EstimatingD\>\""},
                {"\"\<Estimating D, obsolete\>\"", 
                  "\"\<Obsolete functions\>\"", "None"},
                {"\"\<Estimating D, pairs of loci\>\"", 
                  "\"\<Pairs of loci\>\"", "None"},
                {"\"\<Estimating D, pairs of loci, example of\>\"", 
                  "\"\<Pairwise example\>\"", "None"},
                {"\"\<Estimating D, random sampling, example of\>\"", 
                  "\"\<Sampling example\>\"", "None"},
                {"\"\<Estimating D, summary\>\"", "\"\<Summary\>\"", "None"},
                {"\"\<Estimating D, varying divergence\>\"", 
                  "\"\<Estimating the matrix\>\"", 
                  "\"\<Varying divergence\>\""},
                {"\"\<ExactEigenvalues\>\"", 
                  "\"\<Symmetric stability: one deme\>\"", 
                  "\"\<ExactEigenvalues\>\""},
                {
                  "\"\<ExactIntersection, \[Wedge], \[AliasIndicator]^\
\[AliasIndicator]\>\"", "\"\<ExactIntersection\>\"", 
                  "\"\<ExactIntersection\>\""},
                {
                  "\"\<ExactIntersection, \[Wedge], \[AliasIndicator]^\
\[AliasIndicator]\>\"", "\"\<Operations on sets\>\"", 
                  "\"\<ExactIntersection\>\""},
                {"\"\<ExactProbability\>\"", "\"\<Exact probability\>\"", 
                  "\"\<ExactProbability\>\""},
                {"\"\<<>, Expectation\>\"", "\"\<Populations\>\"", 
                  "\"\<Expectation\>\""},
                {"\"\<Expectation, <>\>\"", "\"\<Populations\>\"", 
                  "\"\<Expectation\>\""},
                {"\"\<Expectation, as used in Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS relation\>\"", "\"\<Expectation\>\""},
                {
                  "\"\<Expectation, population, \[LeftDoubleBracketingBar] \
\[RightDoubleBracketingBar], \[AliasIndicator]l||\[AliasIndicator] \
\[AliasIndicator]r||\[AliasIndicator]\>\"", "\"\<Expectations\>\"", 
                  "\"\<PopulationExpectation\>\""},
                {"\"\<ExponentialF, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<ExponentialF\>\""},
                {"\"\<ExponentialF, for genotype frequencies\>\"", 
                  "\"\<Recursions: iterating one deme\>\"", 
                  "\"\<ExponentialF\>\""},
                {"\"\<ExponentialF, for symmetric model\>\"", 
                  "\"\<Symmetric model: iterating one deme\>\"", 
                  "\"\<ExponentialF\>\""},
                {"\"\<ExponentialF, with individuals\>\"", 
                  "\"\<Simulating individuals: iterating one deme\>\"", 
                  "\"\<ExponentialF\>\""},
                {"\"\<ExponentialF, with individuals\>\"", 
                  "\"\<Simulating individuals: reproduction\>\"", 
                  "\"\<ExponentialF\>\""},
                {"\"\<ExtantIndividuals\>\"", "\"\<Global variables\>\"", 
                  "\"\<ExtantIndividuals\>\""},
                {
                  "\"\<ExtractContexts, \[Chi], \[AliasIndicator]c\
\[AliasIndicator]\>\"", "\"\<Extracting contexts\>\"", 
                  "\"\<ExtractContexts\>\""},
                {"\"\<ExtractExtant\>\"", "\"\<Sampling\>\"", 
                  "\"\<ExtractExtant\>\""},
                {"\"\<ExtractGenealogy\>\"", 
                  "\"\<Extracting genealogies\>\"", 
                  "\"\<ExtractGenealogy\>\""},
                {"\"\<ExtractGenealogy\>\"", 
                  "\"\<Manipulating genealogies\>\"", 
                  "\"\<ExtractGenealogy\>\""},
                {
                  "\"\<ExtractGenes, \[Gamma], \[AliasIndicator]g\
\[AliasIndicator]\>\"", "\"\<Extracting contexts\>\"", 
                  "\"\<ExtractGenes\>\""},
                {"\"\<ExtractInformation\>\"", 
                  "\"\<Describing genealogies\>\"", 
                  "\"\<ExtractInformation\>\""},
                {"\"\<ExtractInformation, from ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<ExtractInformation\>\""},
                {"\"\<ExtractLabel, from ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<ExtractLabel\>\""},
                {"\"\<ExtractLineagesEndingAtT, from ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<ExtractLineagesEndingAtT\>\""},
                {"\"\<ExtractLineagesStartingAtT, from ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<ExtractLineagesStartingAtT\>\""},
                {"\"\<ExtractRepeat\>\"", "\"\<Repeated elements\>\"", 
                  "\"\<ExtractRepeat\>\""},
                {"\"\<ExtractSubMatrix\>\"", 
                  "\"\<Extracting submatrices\>\"", 
                  "\"\<ExtractSubMatrix\>\""},
                {"\"\<FamilyAlleleFrequencyEstimate\>\"", 
                  "\"\<Estimation from families\>\"", 
                  "\"\<FamilyAlleleFrequencyEstimate\>\""},
                {"\"\<FamilyEffects\>\"", "\"\<Estimation from families\>\"", 
                  "\"\<FamilyEffects\>\""},
                {"\"\<FamilyM\>\"", "\"\<Estimation from families\>\"", 
                  "\"\<FamilyM\>\""},
                {"\"\<FamilyProbability\>\"", "\"\<Probabilities\>\"", 
                  "\"\<FamilyProbability\>\""},
                {"\"\<Family structure, set of all\>\"", 
                  "\"\<The set of all structures\>\"", "\"\<NewS\>\""},
                {"\"\<Fecundity\>\"", "\"\<Describing individuals\>\"", 
                  "\"\<Fecundity\>\""},
                {"\"\<FindHyperlinks\>\"", "\"\<Hyperlinks\>\"", 
                  "\"\<FindHyperlinks\>\""},
                {"\"\<FindIndexTag\>\"", "\"\<Hyperlinks\>\"", 
                  "\"\<FindIndexTag\>\""},
                {"\"\<FindMLE\>\"", "\"\<Finding the MLE\>\"", 
                  "\"\<FindMLE\>\""},
                {"\"\<FindNode\>\"", "\"\<Inferring a genealogy\>\"", 
                  "\"\<FindNode\>\""},
                {"\"\<FindPosition\>\"", "\"\<Sampling\>\"", 
                  "\"\<FindPosition\>\""},
                {"\"\<FindTags\>\"", "\"\<Automatic Numbering\>\"", 
                  "\"\<FindTags\>\""},
                {"\"\<Fitness, definition for allele frequencies\>\"", 
                  "\"\<Allele frequencies:fitnesses\>\"", 
                  "\"\<Defining fitnesses\>\""},
                {"\"\<Fitness, in individuals\>\"", 
                  "\"\<Simulating individuals: fitnesses\>\"", "None"},
                {"\"\<Fitness, in symmetric model\>\"", 
                  "\"\<Symmetric model: fitnesses\>\"", "None"},
                {"\"\<Fitness, problems redefining\>\"", 
                  "\"\<Potential problems\>\"", 
                  "\"\<Redefining fitness\>\""},
                {
                  "\"\<FitnessSet, \[DoubleStruckCapitalW], \
\[AliasIndicator]dsW\[AliasIndicator]\>\"", "\"\<Selection\>\"", 
                  "\"\<FitnessSet\>\""},
                {"\"\<FitnessTable, for genotype frequencies\>\"", 
                  "\"\<Recursions:fitnesses\>\"", "\"\<FitnessTable\>\""},
                {"\"\<FitnessTable, for individuals\>\"", 
                  "\"\<Simulating individuals: fitnesses\>\"", 
                  "\"\<FitnessTable\>\""},
                {"\"\<FitnessTable, for symmetric model\>\"", 
                  "\"\<Symmetric model: fitnesses\>\"", 
                  "\"\<FitnessTable\>\""},
                {"\"\<FixedEnds, for allele frequencies\>\"", 
                  "\"\<Allele frequencies:migration\>\"", 
                  "\"\<FixedEnds\>\""},
                {"\"\<FixedEnds, for genotype frequencies\>\"", 
                  "\"\<Recursions:migration\>\"", "\"\<FixedEnds\>\""},
                {"\"\<FixedEnds, option for IterateExact\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<FixedEnds\>\""},
                {"\"\<FixedEnds, option for IterateExact\>\"", 
                  "\"\<Recursions: iterating one deme\>\"", 
                  "\"\<FixedEnds\>\""},
                {"\"\<FixedEnds, option for IterateExact\>\"", 
                  "\"\<Simulating individuals: iterating one deme\>\"", 
                  "\"\<FixedEnds\>\""},
                {"\"\<FixedEnds, option for IterateExact\>\"", 
                  "\"\<Symmetric model: iterating one deme\>\"", 
                  "\"\<FixedEnds\>\""},
                {"\"\<FixedEnds, option for MigrateExact\>\"", 
                  "\"\<Simulating individuals:migration\>\"", 
                  "\"\<FixedEnds\>\""},
                {"\"\<FixedEnds, option for MigrateExact\>\"", 
                  "\"\<Symmetric model: migration\>\"", "\"\<FixedEnds\>\""},
                {"\"\<Flatten\>\"", 
                  "\"\<Flattening lists at specific levels\>\"", 
                  "\"\<Flatten\>\""},
                {"\"\<FlattenList\>\"", 
                  "\"\<Flattening lists by pattern\>\"", 
                  "\"\<FlattenList\>\""},
                {"\"\<FlattenList, PatternFree\>\"", 
                  "\"\<Flattening lists by pattern\>\"", 
                  "\"\<PatternFree\>\""},
                {"\"\<FourierNormalised\>\"", "\"\<Fourier transforms\>\"", 
                  "\"\<FourierNormalised\>\""},
                {"\"\<FourierNormalisedTable\>\"", 
                  "\"\<Fourier transforms\>\"", 
                  "\"\<FourierNormalisedTable\>\""},
                {"\"\<FrequencyRepresentations\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<FrequencyRepresentations\>\""},
                {"\"\<FromBaake\>\"", "\"\<Alternative measures\>\"", 
                  "\"\<FromBaake\>\""},
                {"\"\<FromBennett\>\"", "\"\<Alternative measures\>\"", 
                  "\"\<FromBennett\>\""},
                {"\"\<FromBennettExpression\>\"", 
                  "\"\<Alternative measures\>\"", 
                  "\"\<FromBennettExpression\>\""},
                {"\"\<FullContext\>\"", "\"\<Abbreviating contexts\>\"", 
                  "\"\<FullContext\>\""},
                {"\"\<FullGenotypeFrequencyReduced\>\"", 
                  "\"\<Obsolete functions\>\"", 
                  "\"\<FullGenotypeFrequencyReduced\>\""},
                {"\"\<FullGenotypeFrequencyTable\>\"", 
                  "\"\<Obsolete functions\>\"", 
                  "\"\<FullGenotypeFrequencyTable\>\""},
                {"\"\<FullOutput\>\"", "\"\<Gaussian likelihoods\>\"", 
                  "\"\<FullOutput\>\""},
                {"\"\<Function\>\"", "\"\<Marginal tables\>\"", 
                  "\"\<Function\>\""},
                {"\"\<Gametes, for genotype frequencies\>\"", 
                  "\"\<Recursions:reproduction\>\"", "\"\<Gametes\>\""},
                {"\"\<Gametes, for symmetric model\>\"", 
                  "\"\<Symmetric model: reproduction\>\"", 
                  "\"\<Gametes\>\""},
                {"\"\<Gametes, linkage\>\"", "\"\<Recursions:Linkage\>\"", 
                  "\"\<Gametes\>\""},
                {
                  "\"\<Gametes, new, \\!\\(\\(\[GothicCapitalG]\\^*\\)\\), \
\[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, \
\[GothicCapitalG]new\>\"", "\"\<Life cycle\>\"", "\"\<Gametes new\>\""},
                {
                  "\"\<Gametes, new, \\!\\(\\(\[GothicCapitalG]\\^*\\)\\), \
\[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, \
\[GothicCapitalG]new\>\"", "\"\<Notation reference\>\"", "None"},
                {
                  "\"\<Gametes, \[GothicCapitalG], \[AliasIndicator]goG\
\[AliasIndicator]\>\"", "\"\<Life cycle\>\"", "\"\<Gametes\>\""},
                {
                  "\"\<Gametes, \[GothicCapitalG], \[AliasIndicator]goG\
\[AliasIndicator]\>\"", "\"\<Notation reference\>\"", "None"},
                {"\"\<GameteTable, for genotype frequencies\>\"", 
                  "\"\<Recursions:reproduction\>\"", "\"\<GameteTable\>\""},
                {"\"\<GameteTable, for symmetric model\>\"", 
                  "\"\<Symmetric model: reproduction\>\"", 
                  "\"\<GameteTable\>\""},
                {"\"\<GameteTable, linkage\>\"", 
                  "\"\<Recursions:Linkage\>\"", "\"\<GameteTable\>\""},
                {"\"\<GaussianLogLikelihood\>\"", 
                  "\"\<Gaussian likelihoods\>\"", 
                  "\"\<GaussianLogLikelihood\>\""},
                {"\"\<GaussianMLE\>\"", "\"\<Gaussian likelihoods\>\"", 
                  "\"\<GaussianMLE\>\""},
                {"\"\<Genealogies, exact probability\>\"", 
                  "\"\<Exact probability\>\"", "None"},
                {"\"\<Genealogies, extracting from ancestral graphs\>\"", 
                  "\"\<Extracting genealogies\>\"", 
                  "\"\<ExtractGenealogy\>\""},
                {"\"\<Genealogies, family structure\>\"", 
                  "\"\<Family structure\>\"", "None"},
                {"\"\<Genealogies, generating functions\>\"", 
                  "\"\<Deriving recursions for the MGF\>\"", "None"},
                {"\"\<Genealogies, probability of\>\"", 
                  "\"\<Deriving the probability\>\"", "None"},
                {"\"\<Genealogies, sampling\>\"", 
                  "\"\<Sampling genealogies\>\"", "None"},
                {"\"\<Genealogy, rooting\>\"", "\"\<Rooting a genealogy\>\"", 
                  "\"\<SwapStates\>\""},
                {"\"\<Genealogy, rooting\>\"", 
                  "\"\<Structure of genealogies\>\"", 
                  "\"\<RootedGenealogy\>\""},
                {"\"\<GenealogyToMatrix\>\"", "\"\<Describing mutation\>\"", 
                  "\"\<GenealogyToMatrix\>\""},
                {"\"\<GeneralizedTransform\>\"", "\"\<Cumulants\>\"", 
                  "\"\<GeneralizedTransform\>\""},
                {"\"\<Generating functions, examples\>\"", 
                  "\"\<Examples of the MGF\>\"", "None"},
                {"\"\<Generating functions, for cumulants\>\"", 
                  "\"\<Cumulants\>\"", "\"\<GeneralizedTransform\>\""},
                {"\"\<Generating functions, for genealogies\>\"", 
                  "\"\<Deriving recursions for the MGF\>\"", "None"},
                {"\"\<Genes and contexts\>\"", "\"\<Genes and contexts\>\"", 
                  "\"\<Genes and contexts\>\""},
                {
                  "\"\<Genome, set of all positions in, \
\[DoubleStruckCapitalG], \[AliasIndicator]dsG\[AliasIndicator]\>\"", 
                  "\"\<Notation reference\>\"", "None"},
                {"\"\<Genotype frequencies, recursions\>\"", 
                  "\"\<Recursions: representation\>\"", "None"},
                {"\"\<Genotype frequency, of a given genotype\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<GenotypeFrequency\>\""},
                {"\"\<GenotypeFrequency\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<GenotypeFrequency\>\""},
                {"\"\<GenotypeFrequencyArguments\>\"", 
                  "\"\<Obsolete functions\>\"", 
                  "\"\<GenotypeFrequencyArguments\>\""},
                {"\"\<GenotypeFrequencyConvert\>\"", 
                  "\"\<Full diploid genotypes\>\"", 
                  "\"\<GenotypeFrequencyConvert\>\""},
                {"\"\<GenotypeFrequencyTable\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<GenotypeFrequencyTable\>\""},
                {"\"\<Genotype, in continuum simulations\>\"", 
                  "\"\<Describing individuals\>\"", "\"\<Genotype\>\""},
                {"\"\<Genotype, observable\>\"", "\"\<Diploid genotypes\>\"", 
                  "\"\<ObservableGenotype\>\""},
                {"\"\<Genotype, observable\>\"", 
                  "\"\<Genotype probabilities\>\"", 
                  "\"\<ObservableGenotype\>\""},
                {"\"\<Genotype, option for InitialiseContinuum\>\"", 
                  "\"\<Initialisation\>\"", "\"\<Genotype\>\""},
                {"\"\<GenotypePosition\>\"", 
                  "\"\<Recursions:manipulation\>\"", 
                  "\"\<GenotypePosition\>\""},
                {"\"\<GenotypeProbability\>\"", 
                  "\"\<Genotype probabilities\>\"", 
                  "\"\<GenotypeProbability\>\""},
                {"\"\<GenotypeProbability, segregation ratio\>\"", 
                  "\"\<Genotype probabilities\>\"", 
                  "\"\<SegregationRatio\>\""},
                {"\"\<Genotypes, notation for\>\"", "\"\<Notation\>\"", 
                  "\"\<NotationPackage\>\""},
                {"\"\<GlobalContinuumVariables\>\"", 
                  "\"\<Global variables\>\"", 
                  "\"\<GlobalContinuumVariables\>\""},
                {
                  "\"\<Gnew, \\!\\(\\(\[GothicCapitalG]\\^*\\)\\), \
\[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, new gametes\>\"", 
                  "\"\<Life cycle\>\"", "\"\<Gametes new\>\""},
                {
                  "\"\<Gnew, \\!\\(\\(\[GothicCapitalG]\\^*\\)\\), \
\[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, new gametes\>\"", 
                  "\"\<Notation reference\>\"", "None"},
                {"\"\<Goodman et al 1999\>\"", "\"\<References\>\"", 
                  "\"\<Goodman et al 1999\>\""},
                {"\"\<Graphs, ancestral\>\"", 
                  "\"\<Ancestral graph introduction\>\"", "None"},
                {"\"\<Griffiths-Tavare\>\"", "\"\<Exact algorithm\>\"", 
                  "\"\<GriffithsTavare\>\""},
                {"\"\<Griffiths-Tavare\>\"", 
                  "\"\<Griffiths-Tavare algorithm\>\"", "None"},
                {"\"\<Griffiths-Tavare, stochastic algorithm\>\"", 
                  "\"\<Stochastic algorithm\>\"", 
                  "\"\<MonteCarloGriffithsTavare\>\""},
                {"\"\<Griffiths-Tavare, stochastic algorithm\>\"", 
                  "\"\<Stochastic algorithm\>\"", 
                  "\"\<Stochastic GT algorithm\>\""},
                {
                  "\"\<Griffiths-Tavare, stochastic, comparison with \
MonteCarloProbability\>\"", "\"\<Stochastic algorithm\>\"", 
                  "\"\<Comparison with MonteCarloProbability\>\""},
                {"\"\<Griffiths-Tavare, stochastic example\>\"", 
                  "\"\<Stochastic algorithm\>\"", "\"\<Small example\>\""},
                {"\"\<Guiasu & Shenitzer 1985\>\"", "\"\<References\>\"", 
                  "\"\<Guiasu & Shenitzer 1985\>\""},
                {"\"\<HaploidConstraints\>\"", "\"\<Obsolete functions\>\"", 
                  "\"\<HaploidConstraints\>\""},
                {"\"\<HaploidFrequencies\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<HaploidFrequencies\>\""},
                {"\"\<HaploidGenotypeFrequency\>\"", 
                  "\"\<Genotype frequencies from moments\>\"", 
                  "\"\<HaploidGenotypeFrequency\>\""},
                {"\"\<HaploidIndividuals\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<HaploidIndividuals\>\""},
                {"\"\<HaploidRepresentations\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<HaploidRepresentations\>\""},
                {"\"\<HaploidSource\>\"", "\"\<Genotype frequencies\>\"", 
                  "\"\<HaploidSource\>\""},
                {"\"\<HaploidSource\>\"", 
                  "\"\<Representing the population\>\"", 
                  "\"\<HaploidSource\>\""},
                {"\"\<Haploids, selection on\>\"", 
                  "\"\<Haploid selection\>\"", "None"},
                {"\"\<HaploidSubsets\>\"", "\"\<Subsets of loci\>\"", 
                  "\"\<HaploidSubsets\>\""},
                {"\"\<HaploidTypes\>\"", "\"\<Listing genotypes\>\"", 
                  "\"\<HaploidTypes\>\""},
                {"\"\<Help Browser\>\"", 
                  "\"\<How the Help Browser works\>\"", 
                  "\"\<MasterIndexHeading\>\""},
                {"\"\<Help Browser, setting up hyperlinks\>\"", 
                  "\"\<How the Help Browser works\>\"", 
                  "\"\<Setting up links\>\""},
                {"\"\<Help browser, setting up new files\>\"", 
                  "\"\<Setting up new help files\>\"", 
                  "\"\<Setting up new help files\>\""},
                {
                  "\"\<Hermaphrodites, \[GothicCapitalH], \
\[AliasIndicator]goH\[AliasIndicator]\>\"", "\"\<Life cycle\>\"", 
                  "\"\<Hermaphrodites\>\""},
                {
                  "\"\<Hermaphrodites, \[GothicCapitalH], \
\[AliasIndicator]goH\[AliasIndicator]\>\"", "\"\<Notation reference\>\"", 
                  "None"},
                {"\"\<HeterozygoteB\>\"", 
                  "\"\<Symmetric model: reproduction\>\"", 
                  "\"\<HeterozygoteB\>\""},
                {"\"\<Hill 1974a\>\"", "\"\<References\>\"", 
                  "\"\<Hill 1974a\>\""},
                {"\"\<Hill 1974b\>\"", "\"\<References\>\"", 
                  "\"\<Hill 1974b\>\""},
                {"\"\<Hill 1974c\>\"", "\"\<References\>\"", 
                  "\"\<Hill 1974c\>\""},
                {"\"\<Hudson 1990\>\"", 
                  "\"\<Ancestral graphs introduction\>\"", "None"},
                {"\"\<Hudson 1990\>\"", "\"\<Ancestral graph references\>\"", 
                  "\"\<Hudson 1990\>\""},
                {"\"\<Hypergeometric model\>\"", 
                  "\"\<Symmetric model: genotype frequencies\>\"", "None"},
                {"\"\<Hyperlinks, bugs in pasting\>\"", "\"\<Bugs\>\"", 
                  "\"\<Pasting hyperlinks\>\""},
                {"\"\<Hyperlinks, saving\>\"", "\"\<Automatic Numbering\>\"", 
                  "\"\<Saving the links\>\""},
                {"\"\<Hyperlinks, setting up\>\"", 
                  "\"\<How the Help Browser works\>\"", 
                  "\"\<Setting up links\>\""},
                {"\"\<Hyperlinks, to cell tags\>\"", 
                  "\"\<Automatic Numbering\>\"", 
                  "\"\<Setting up links to a list of tags\>\""},
                {"\"\<IncidenceMatrix\>\"", "\"\<Ordered genealogies\>\"", 
                  "\"\<IncidenceMatrix\>\""},
                {"\"\<Index, setting up\>\"", 
                  "\"\<How the Help Browser works\>\"", 
                  "\"\<Setting up Master Index\>\""},
                {"\"\<Individual\>\"", "\"\<Life cycle\>\"", 
                  "\"\<Individual\>\""},
                {"\"\<IndividualContinuumVariables\>\"", 
                  "\"\<Global variables\>\"", 
                  "\"\<IndividualContinuumVariables\>\""},
                {"\"\<IndividualRepresentations\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<IndividualRepresentations\>\""},
                {"\"\<Individuals\>\"", "\"\<Boxing the individuals\>\"", 
                  "\"\<Individuals\>\""},
                {"\"\<InferParentalGenotypes\>\"", 
                  "\"\<Estimation from families\>\"", 
                  "\"\<InferParentalGenotypes\>\""},
                {"\"\<Infinite sites mutation\>\"", 
                  "\"\<Describing mutation\>\"", "\"\<None\>\""},
                {"\"\<InformationFunction, option for CoalesceLineages\>\"", 
                  "\"\<Coalescence and recombination\>\"", 
                  "\"\<InformationFunctionC\>\""},
                {"\"\<InformationFunction, option for ExtractGenealogy\>\"", 
                  "\"\<Extracting genealogies\>\"", 
                  "\"\<InformationFunction\>\""},
                {"\"\<InformationFunction, option for RecombineLineage\>\"", 
                  "\"\<Coalescence and recombination\>\"", 
                  "\"\<InformationFunctionR\>\""},
                {"\"\<InitialiseContinuum\>\"", "\"\<Initialisation\>\"", 
                  "\"\<InitialiseContinuum\>\""},
                {"\"\<InitialiseCovariance\>\"", "\"\<Sampling\>\"", 
                  "\"\<InitialiseCovariance\>\""},
                {"\"\<InitialiseDemes\>\"", 
                  "\"\<Describing the population\>\"", 
                  "\"\<InitialiseDemes\>\""},
                {"\"\<InitialiseDemes\>\"", "\"\<Setting up a cline\>\"", 
                  "\"\<InitialiseDemes\>\""},
                {"\"\<InitialStep\>\"", "\"\<Initial step size\>\"", 
                  "\"\<InitialStep\>\""},
                {"\"\<InitialStepReduced\>\"", "\"\<Obsolete functions\>\"", 
                  "\"\<InitialStepReduced\>\""},
                {"\"\<InternalNodes\>\"", "\"\<Describing genealogies\>\"", 
                  "\"\<InternalNodes\>\""},
                {"\"\<IntervalCombine\>\"", "\"\<Obsolete functions\>\"", 
                  "\"\<IntervalCombine\>\""},
                {"\"\<IntervalPosition\>\"", "\"\<Obsolete functions\>\"", 
                  "\"\<IntervalPosition\>\""},
                {"\"\<InverseFourierNormalised\>\"", 
                  "\"\<Fourier transforms\>\"", 
                  "\"\<InverseFourierNormalised\>\""},
                {"\"\<InverseFourierNormalisedTable\>\"", 
                  "\"\<Fourier transforms\>\"", 
                  "\"\<InverseFourierNormalisedTable\>\""},
                {"\"\<Island model, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<Immigration\>\""},
                {"\"\<Island model, for allele frequencies\>\"", 
                  "\"\<Allele frequencies:migration\>\"", 
                  "\"\<Immigration\>\""},
                {"\"\<Island model, for genotype frequencies\>\"", 
                  "\"\<Recursions: iterating one deme\>\"", 
                  "\"\<Immigration\>\""},
                {"\"\<Island model, for genotype frequencies\>\"", 
                  "\"\<Recursions:migration\>\"", "\"\<Immigration\>\""},
                {"\"\<Island model, in symmetric model\>\"", 
                  "\"\<Symmetric model: migration\>\"", 
                  "\"\<Immigration\>\""},
                {"\"\<Island model, with individuals\>\"", 
                  "\"\<Simulating individuals:migration\>\"", 
                  "\"\<Immigration\>\""},
                {"\"\<IterateContinuum\>\"", 
                  "\"\<Iterating  the continuum model\>\"", 
                  "\"\<IterateContinuum\>\""},
                {"\"\<IterateExact, example\>\"", 
                  "\"\<Example: epistasis\>\"", "None"},
                {"\"\<IterateExact, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<IterateExact\>\""},
                {"\"\<IterateExact, for allele frequency clines\>\"", 
                  "\"\<Allele frequencies: iterating a cline\>\"", 
                  "\"\<IterateExact\>\""},
                {"\"\<IterateExact, for clines in symmetric model\>\"", 
                  "\"\<Symmetric model: iterating a cline\>\"", 
                  "\"\<IterateExact\>\""},
                {"\"\<IterateExact, for clines with individuals\>\"", 
                  "\"\<Simulating individuals: iterating a cline\>\"", 
                  "\"\<IterateExact\>\""},
                {"\"\<IterateExact, for genotype frequencies\>\"", 
                  "\"\<Recursions: iterating one deme\>\"", 
                  "\"\<IterateExact\>\""},
                {"\"\<IterateExact, for genotype frequency clines\>\"", 
                  "\"\<Recursions: iterating a cline\>\"", 
                  "\"\<IterateExact\>\""},
                {"\"\<IterateExact, for individuals\>\"", 
                  "\"\<Simulating individuals: iterating one deme\>\"", 
                  "\"\<IterateExact\>\""},
                {"\"\<IterateExact, for symmetric model\>\"", 
                  "\"\<Symmetric model: iterating one deme\>\"", 
                  "\"\<IterateExact\>\""},
                {"\"\<Join\>\"", "\"\<Join\>\"", "\"\<Join\>\""},
                {"\"\<Join\>\"", "\"\<Operations on sets\>\"", 
                  "\"\<Join\>\""},
                {"\"\<Junctions, in ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<Junctions\>\""},
                {"\"\<JunctionStyle, option for PlotSegments\>\"", 
                  "\"\<Plotting ancestral graphs\>\"", 
                  "\"\<JunctionStyle\>\""},
                {
                  "\"\<Juveniles, \[GothicCapitalJ], \[AliasIndicator]goJ\
\[AliasIndicator]\>\"", "\"\<Life cycle\>\"", "\"\<Juveniles\>\""},
                {
                  "\"\<Juveniles, \[GothicCapitalJ], \[AliasIndicator]goJ\
\[AliasIndicator]\>\"", "\"\<Notation reference\>\"", "None"},
                {"\"\<Kirkpatrick and Barton 1997\>\"", 
                  "\"\<Multilocus references\>\"", 
                  "\"\<Kirkpatrick and Barton 1997\>\""},
                {"\"\<Kirkpatrick and Servedio 1998\>\"", 
                  "\"\<Multilocus references\>\"", 
                  "\"\<Kirkpatrick and Servedio 1998\>\""},
                {"\"\<Kirkpatrick et al.\>\"", "\"\<Multilocus MS\>\"", 
                  "None"},
                {"\"\<Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus references\>\"", 
                  "\"\<Kirkpatrick et al.\>\""},
                {"\"\<Kirkpatrick et al. 1983\>\"", "\"\<References\>\"", 
                  "\"\<Kirkpatrick et al 1983\>\""},
                {"\"\<Kirkpatrick et al., arbitrary sets of loci\>\"", 
                  "\"\<Multilocus MS relation\>\"", 
                  "\"\<Arbitrary sets of loci\>\""},
                {"\"\<Kirkpatrick et al., Expectation\>\"", 
                  "\"\<Multilocus MS relation\>\"", "\"\<Expectation\>\""},
                {"\"\<Kirkpatrick et al., migration\>\"", 
                  "\"\<Multilocus MS\>\"", "\"\<Migration\>\""},
                {"\"\<Kirkpatrick et al., mutation\>\"", 
                  "\"\<Multilocus MS\>\"", "\"\<Mutation\>\""},
                {
                  "\"\<Kirkpatrick et al., permutations in defining \
coefficients\>\"", "\"\<Multilocus MS\>\"", "\"\<Permutations\>\""},
                {
                  "\"\<Kirkpatrick et al., permutations in defining \
coefficients\>\"", "\"\<Multilocus MS relation\>\"", "\"\<Permutations\>\""},
                {"\"\<Kirkpatrick et al., phenotypes\>\"", 
                  "\"\<Multilocus MS\>\"", "\"\<Phenotypes\>\""},
                {"\"\<Kirkpatrick et al., position\>\"", 
                  "\"\<Multilocus MS\>\"", "\"\<Contexts and positions\>\""},
                {"\"\<Kirkpatrick et al., position\>\"", 
                  "\"\<Multilocus MS relation\>\"", "\"\<position\>\""},
                {"\"\<Kirkpatrick et al., QLE\>\"", "\"\<Multilocus MS\>\"", 
                  "\"\<The QLE approximation\>\""},
                {"\"\<Kirkpatrick et al., quasi-linkage equilibrium\>\"", 
                  "\"\<Multilocus MS\>\"", "\"\<The QLE approximation\>\""},
                {"\"\<Kirkpatrick et al., random drift\>\"", 
                  "\"\<Multilocus MS relation\>\"", "\"\<Random drift\>\""},
                {"\"\<Kirkpatrick et al., reference values\>\"", 
                  "\"\<Multilocus MS\>\"", 
                  "\"\<Describing genotypes and populations\>\""},
                {"\"\<Kirkpatrick et al., reference values\>\"", 
                  "\"\<Multilocus MS relation\>\"", 
                  "\"\<Reference values\>\""},
                {"\"\<Kirkpatrick et al., relation with\>\"", 
                  "\"\<Migration example\>\"", "\"\<Multilocus MS\>\""},
                {"\"\<Kirkpatrick et al., relation with\>\"", 
                  "\"\<Multilocus MS relation\>\"", "None"},
                {"\"\<Kirkpatrick et al., scripts and faces\>\"", 
                  "\"\<Multilocus MS relation\>\"", 
                  "\"\<Scripts and faces\>\""},
                {"\"\<Kirkpatrick et al., selection\>\"", 
                  "\"\<Multilocus MS\>\"", "\"\<Phenotypes\>\""},
                {"\"\<Kirkpatrick et al., sets in subscripts\>\"", 
                  "\"\<Multilocus MS relation\>\"", 
                  "\"\<Sets in subscripts\>\""},
                {"\"\<Kirkpatrick et al., sets of loci\>\"", 
                  "\"\<Multilocus MS relation\>\"", "\"\<Sets of loci\>\""},
                {"\"\<Kirkpatrick et al., stabilising selection\>\"", 
                  "\"\<Multilocus MS\>\"", 
                  "\"\<Natural selection on an additive polygenic \
trait\>\""},
                {"\"\<Kirkpatrick et al., stages and contexts\>\"", 
                  "\"\<Multilocus MS relation\>\"", 
                  "\"\<Stages and contexts\>\""},
                {"\"\<Kirkpatrick et al., transmission rules\>\"", 
                  "\"\<Multilocus MS\>\"", "\"\<Transmission\>\""},
                {"\"\<Kirkpatrick et al., transmission rules\>\"", 
                  "\"\<Multilocus MS relation\>\"", 
                  "\"\<Transmission rules\>\""},
                {"\"\<Kruuk 1997\>\"", "\"\<References\>\"", 
                  "\"\<Kruuk 1997\>\""},
                {"\"\<LeafEvents, in ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<LeafEvents\>\""},
                {"\"\<LeafLabels\>\"", "\"\<Plotting genealogies\>\"", 
                  "\"\<LeafLabels\>\""},
                {"\"\<LeafOffset\>\"", "\"\<Plotting genealogies\>\"", 
                  "\"\<LeafOffset\>\""},
                {"\"\<Leaves\>\"", "\"\<Describing genealogies\>\"", 
                  "\"\<Leaves\>\""},
                {"\"\<Leaves, in ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", "\"\<Leaves\>\""},
                {"\"\<Life cycle\>\"", "\"\<Life cycle\>\"", "None"},
                {"\"\<Life cycle, adults\>\"", "\"\<Life cycle\>\"", 
                  "\"\<Adults\>\""},
                {"\"\<Life cycle, adults\>\"", "\"\<Notation reference\>\"", 
                  "None"},
                {"\"\<Life cycle, complete\>\"", 
                  "\"\<Complete life cycle\>\"", "\"\<Complete rules\>\""},
                {"\"\<Life cycle, gametes\>\"", "\"\<Life cycle\>\"", 
                  "\"\<Gametes\>\""},
                {"\"\<Life cycle, gametes\>\"", "\"\<Notation reference\>\"", 
                  "None"},
                {"\"\<Life cycle, hermaphrodites\>\"", "\"\<Life cycle\>\"", 
                  "\"\<Hermaphrodites\>\""},
                {"\"\<Life cycle, hermaphrodites\>\"", 
                  "\"\<Notation reference\>\"", "None"},
                {"\"\<Life cycle, in numerical models\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<Life cycle\>\""},
                {"\"\<Life cycle, in numerical models\>\"", 
                  "\"\<Recursions: iterating one deme\>\"", 
                  "\"\<Life cycle\>\""},
                {"\"\<Life cycle, in numerical models\>\"", 
                  "\"\<Symmetric model: iterating one deme\>\"", 
                  "\"\<Life cycle\>\""},
                {"\"\<Life cycle, juveniles\>\"", "\"\<Life cycle\>\"", 
                  "\"\<Juveniles\>\""},
                {"\"\<Life cycle, juveniles\>\"", 
                  "\"\<Notation reference\>\"", "None"},
                {"\"\<Life cycle, new gametes\>\"", "\"\<Life cycle\>\"", 
                  "\"\<Gametes new\>\""},
                {"\"\<Life cycle, new gametes\>\"", 
                  "\"\<Notation reference\>\"", "None"},
                {"\"\<Life cycle, stages in\>\"", 
                  "\"\<Genes and contexts\>\"", "\"\<Stages\>\""},
                {"\"\<Life cycle, stages in\>\"", "\"\<Life cycle\>\"", 
                  "\"\<Stages\>\""},
                {"\"\<Life cycle, with cytoplasmic inheritance\>\"", 
                  "\"\<Cytoplasmic inheritance\>\"", "None"},
                {"\"\<Life cycle, with individuals\>\"", 
                  "\"\<Simulating individuals: iterating one deme\>\"", 
                  "\"\<Life cycle\>\""},
                {"\"\<Life cycle, with sex linkage\>\"", 
                  "\"\<Sex linkage\>\"", "None"},
                {"\"\<Life cycle, zygotes\>\"", "\"\<Life cycle\>\"", 
                  "\"\<Zygotes\>\""},
                {"\"\<Life cycle, zygotes\>\"", "\"\<Notation reference\>\"", 
                  "None"},
                {"\"\<LineagesPresent, in ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<LineagesPresent\>\""},
                {"\"\<Li & Nei 1974\>\"", "\"\<References\>\"", 
                  "\"\<Li & Nei 1974\>\""},
                {"\"\<Linkage\>\"", "\"\<Generating families\>\"", 
                  "\"\<Linkage\>\""},
                {"\"\<Linkage\>\"", "\"\<Genotype probabilities\>\"", 
                  "\"\<Linkage\>\""},
                {"\"\<Linkage\>\"", "\"\<Linkage\>\"", "\"\<Linkage\>\""},
                {"\"\<Linkage disequilibrium\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<Linkage disequilibrium\>\""},
                {"\"\<Linkage, in numerical models\>\"", 
                  "\"\<Recursions:Linkage\>\"", "\"\<Linkage\>\""},
                {"\"\<Linkage, with individuals\>\"", 
                  "\"\<Simulating individuals: reproduction\>\"", 
                  "\"\<Linkage\>\""},
                {"\"\<LinkedRecombination\>\"", "\"\<Recombination\>\"", 
                  "\"\<LinkedRecombination\>\""},
                {"\"\<ListToGenealogy\>\"", 
                  "\"\<Constructing genealogies\>\"", 
                  "\"\<ListToGenealogy\>\""},
                {"\"\<ListToMatrix\>\"", 
                  "\"\<Converting between representations\>\"", 
                  "\"\<ListToMatrix\>\""},
                {"\"\<Location\>\"", "\"\<Describing individuals\>\"", 
                  "\"\<Location\>\""},
                {"\"\<Locations\>\"", "\"\<Locations\>\"", 
                  "\"\<Locations\>\""},
                {"\"\<LocusNames\>\"", "\"\<Defining a dataset\>\"", 
                  "\"\<LocusNames\>\""},
                {"\"\<LogLikelihoodDisequilibrium\>\"", "\"\<Likelihood\>\"", 
                  "\"\<LogLikelihoodDisequilibrium\>\""},
                {"\"\<LogLikelihoodDisequilibriumReduced\>\"", 
                  "\"\<Obsolete functions\>\"", 
                  "\"\<LogLikelihoodDisequilibriumReduced\>\""},
                {"\"\<LogLikelihoodTest\>\"", "\"\<Likelihood tests\>\"", 
                  "\"\<LogLikelihoodTest\>\""},
                {"\"\<Log-linear models\>\"", "\"\<Alternative methods\>\"", 
                  "\"\<Log-linear models\>\""},
                {"\"\<Log-linear models\>\"", "\"\<Alternative methods\>\"", 
                  "None"},
                {"\"\<Long et al 1995\>\"", "\"\<References\>\"", 
                  "\"\<Long et al 1995\>\""},
                {"\"\<LowerOffDiagonal\>\"", "\"\<Diagonal matrices\>\"", 
                  "\"\<LowerOffDiagonal\>\""},
                {"\"\<MacCallum 1994\>\"", "\"\<References\>\"", 
                  "\"\<MacCallum 1994\>\""},
                {"\"\<MacCallum et al. 1998\>\"", "\"\<References\>\"", 
                  "\"\<MacCallum et al 1998\>\""},
                {"\"\<MakeCline, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: setting up a cline\>\"", 
                  "\"\<MakeCline\>\""},
                {"\"\<MakeCline,  for genotype frequencies\>\"", 
                  "\"\<Recursions: setting up a cline\>\"", 
                  "\"\<MakeCline\>\""},
                {"\"\<MakeCline, for individuals\>\"", 
                  "\"\<Simulating individuals:setting up a cline\>\"", 
                  "\"\<MakeCline\>\""},
                {"\"\<MakeCline, for symmetric model\>\"", 
                  "\"\<Symmetric model: setting up a cline\>\"", 
                  "\"\<MakeCline\>\""},
                {"\"\<MakeDiploid, for genotype frequencies\>\"", 
                  "\"\<Recursions: converting\>\"", "\"\<MakeDiploid\>\""},
                {"\"\<MakeDiploid, for individuals\>\"", 
                  "\"\<Simulating individuals:converting\>\"", 
                  "\"\<MakeDiploid\>\""},
                {"\"\<MakeDiploid, for symmetric model\>\"", 
                  "\"\<Symmetric model: converting\>\"", 
                  "\"\<MakeDiploid\>\""},
                {"\"\<MakeDistanceList\>\"", 
                  "\"\<Boxing the individuals\>\"", 
                  "\"\<MakeDistanceList\>\""},
                {"\"\<MakeDistances\>\"", "\"\<Boxing the individuals\>\"", 
                  "\"\<MakeDistances\>\""},
                {"\"\<MakeFitnessSet\>\"", "\"\<Fitness\>\"", 
                  "\"\<MakeFitnessSet\>\""},
                {"\"\<MakeFitnessSet, with multiple alleles\>\"", 
                  "\"\<Fitness\>\"", "\"\<Multiple alleles\>\""},
                {"\"\<MakeGenealogy\>\"", "\"\<Making a genealogy\>\"", 
                  "\"\<MakeGenealogy\>\""},
                {"\"\<MakeGenealogyPlot\>\"", "\"\<Plotting genealogies\>\"", 
                  "\"\<MakeGenealogyPlot\>\""},
                {"\"\<MakeHaploid, for genotype frequencies\>\"", 
                  "\"\<Recursions: converting\>\"", "\"\<MakeHaploid\>\""},
                {"\"\<MakeHaploid, for individuals\>\"", 
                  "\"\<Simulating individuals:converting\>\"", 
                  "\"\<MakeHaploid\>\""},
                {"\"\<MakeHaploid, for symmetric model\>\"", 
                  "\"\<Symmetric model: converting\>\"", 
                  "\"\<MakeHaploid\>\""},
                {"\"\<MakeIndividuals, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: converting\>\"", 
                  "\"\<MakeIndividuals\>\""},
                {"\"\<MakeIndividuals, for genotype frequencies\>\"", 
                  "\"\<Recursions: converting\>\"", 
                  "\"\<MakeIndividuals\>\""},
                {"\"\<MakeIndividuals, for individuals\>\"", 
                  "\"\<Simulating individuals:converting\>\"", 
                  "\"\<MakeIndividuals\>\""},
                {"\"\<MakeIndividuals, for symmetric model\>\"", 
                  "\"\<Symmetric model: converting\>\"", 
                  "\"\<MakeIndividuals\>\""},
                {"\"\<MakeOneWayTable\>\"", "\"\<Single-locus tables\>\"", 
                  "\"\<MakeOneWayTable\>\""},
                {"\"\<MakePairwiseTable\>\"", "\"\<Pairwise tables\>\"", 
                  "\"\<MakePairwiseTable\>\""},
                {"\"\<MakePopulation, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: representation\>\"", 
                  "\"\<MakePopulation\>\""},
                {"\"\<MakePopulation, for genotype frequencies\>\"", 
                  "\"\<Recursions: representation\>\"", 
                  "\"\<MakePopulation\>\""},
                {"\"\<MakePopulation, for individuals\>\"", 
                  "\"\<Simulating individuals: Describing populations\>\"", 
                  "\"\<MakePopulation\>\""},
                {"\"\<MakePopulation, for symmetric model\>\"", 
                  "\"\<Symmetric model: representation\>\"", 
                  "\"\<MakePopulation\>\""},
                {"\"\<MakeSelectionCoefficient\>\"", "\"\<Fitness\>\"", 
                  "\"\<MakeSelectionCoefficient\>\""},
                {"\"\<MakeSelectionCoefficient\>\"", "\"\<Phenotypes\>\"", 
                  "\"\<MakeSelectionCoefficient\>\""},
                {"\"\<MakeSelectionCoefficient, with multiple alleles\>\"", 
                  "\"\<Phenotypes\>\"", "\"\<MakeSelectionCoefficient\>\""},
                {"\"\<MakeSelectionCoefficient, with two alleles\>\"", 
                  "\"\<Phenotypes\>\"", "\"\<Two alleles\>\""},
                {"\"\<Mangel & Hilborn 1996\>\"", "\"\<References\>\"", 
                  "\"\<Mangel & Hilborn 1996\>\""},
                {"\"\<MapLength, in ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<MapLength\>\""},
                {"\"\<MapPosition, option for AncestorList\>\"", 
                  "\"\<Ancestors & descendants\>\"", "\"\<MapPositionA\>\""},
                {"\"\<MapPosition, option for DescendantList\>\"", 
                  "\"\<Ancestors & descendants\>\"", "\"\<MapPositionD\>\""},
                {"\"\<Marginal fitness, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: fitnesses\>\"", 
                  "\"\<MarginalW\>\""},
                {"\"\<Marginal fitness,for genotype frequencies\>\"", 
                  "\"\<Recursions:fitnesses\>\"", "\"\<MarginalW\>\""},
                {"\"\<Marginal fitness, in symmetric model\>\"", 
                  "\"\<Symmetric model: fitnesses\>\"", "\"\<MarginalW\>\""},
                {"\"\<Marginal fitness, with individuals\>\"", 
                  "\"\<Simulating individuals: fitnesses\>\"", 
                  "\"\<MarginalW\>\""},
                {"\"\<MarginalTable\>\"", "\"\<Marginal tables\>\"", 
                  "\"\<MarginalTable\>\""},
                {"\"\<MarginalW, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: fitnesses\>\"", 
                  "\"\<MarginalW\>\""},
                {"\"\<MarginalW, for genotype frequencies\>\"", 
                  "\"\<Recursions:fitnesses\>\"", "\"\<MarginalW\>\""},
                {"\"\<MarginalW, for individuals\>\"", 
                  "\"\<Simulating individuals: fitnesses\>\"", 
                  "\"\<MarginalW\>\""},
                {"\"\<MarginalW, for symmetric model\>\"", 
                  "\"\<Symmetric model: fitnesses\>\"", "\"\<MarginalW\>\""},
                {"\"\<MaternalLoci, example of\>\"", 
                  "\"\<Cytoplasmic inheritance\>\"", "None"},
                {"\"\<MaternalLoci, option for NonMendelian\>\"", 
                  "\"\<Non-Mendelian inheritance\>\"", 
                  "\"\<CytoplasmicLoci\>\""},
                {"\"\<MaternalLoci, reference points\>\"", 
                  "\"\<Reference points\>\"", "\"\<CytoplasmicLoci\>\""},
                {"\"\<MatrixGamma\>\"", "\"\<Fast calculations\>\"", 
                  "\"\<MatrixGamma\>\""},
                {"\"\<MatrixToGenealogy\>\"", 
                  "\"\<Inferring a genealogy\>\"", 
                  "\"\<MatrixToGenealogy\>\""},
                {"\"\<MatrixToList\>\"", 
                  "\"\<Converting between representations\>\"", 
                  "\"\<MatrixToList\>\""},
                {
                  "\"\<MeanContribution, \[GothicM], \[AliasIndicator]gom\
\[AliasIndicator]\>\"", "\"\<Populations\>\"", "\"\<MeanContribution\>\""},
                {"\"\<Mean fitness\>\"", 
                  "\"\<Allele frequencies: fitnesses\>\"", "\"\<MeanW\>\""},
                {"\"\<Mean fitness\>\"", "\"\<Recursions:fitnesses\>\"", 
                  "\"\<MeanW\>\""},
                {"\"\<Mean fitness, in symmetric model\>\"", 
                  "\"\<Symmetric model: fitnesses\>\"", "\"\<MeanW\>\""},
                {"\"\<Mean fitness, with individuals\>\"", 
                  "\"\<Simulating individuals: fitnesses\>\"", 
                  "\"\<MeanW\>\""},
                {"\"\<MeanW, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: fitnesses\>\"", "\"\<MeanW\>\""},
                {"\"\<MeanW, for genotype frequencies\>\"", 
                  "\"\<Recursions:fitnesses\>\"", "\"\<MeanW\>\""},
                {"\"\<MeanW, for individuals\>\"", 
                  "\"\<Simulating individuals: fitnesses\>\"", 
                  "\"\<MeanW\>\""},
                {"\"\<MeanW, for symmetric model\>\"", 
                  "\"\<Symmetric model: fitnesses\>\"", "\"\<MeanW\>\""},
                {"\"\<Meiosis\>\"", "\"\<Recombination\>\"", 
                  "\"\<Meiosis\>\""},
                {"\"\<Meiosis, in numerical models\>\"", 
                  "\"\<Recursions:reproduction\>\"", "None"},
                {"\"\<MethodC\>\"", "\"\<Options for DoReplicates\>\"", 
                  "\"\<MethodC\>\""},
                {"\"\<MethodP\>\"", "\"\<Options for DoReplicates\>\"", 
                  "\"\<MethodP\>\""},
                {"\"\<Metropolis algorithm, estimating D\>\"", 
                  "\"\<Random walk\>\"", "None"},
                {"\"\<MetropolisDisequilibrium\>\"", 
                  "\"\<Estimating moments\>\"", 
                  "\"\<MetropolisDisequilibrium\>\""},
                {"\"\<MetropolisDisequilibriumReduced\>\"", 
                  "\"\<Obsolete functions\>\"", 
                  "\"\<MetropolisDisequilibriumReduced\>\""},
                {"\"\<Metropolis et al. 1954\>\"", "\"\<References\>\"", 
                  "\"\<Metropolis et al 1954\>\""},
                {"\"\<MFromC\>\"", "\"\<Estimating the matrix\>\"", 
                  "\"\<MFromC\>\""},
                {"\"\<MFromC\>\"", "\"\<Estimation from families\>\"", 
                  "\"\<MFromC\>\""},
                {"\"\<Migrate\>\"", "\"\<Migration\>\"", "\"\<Migrate\>\""},
                {"\"\<MigrateExact, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: migration\>\"", 
                  "\"\<MigrateExact\>\""},
                {"\"\<MigrateExact, for genotype frequencies\>\"", 
                  "\"\<Recursions:migration\>\"", "\"\<MigrateExact\>\""},
                {"\"\<MigrateExact, for individuals\>\"", 
                  "\"\<Simulating individuals:migration\>\"", 
                  "\"\<MigrateExact\>\""},
                {"\"\<MigrateExact, for symmetric model\>\"", 
                  "\"\<Symmetric model: migration\>\"", 
                  "\"\<MigrateExact\>\""},
                {"\"\<Migration, and cytoplasmic inheritance\>\"", 
                  "\"\<Migration example\>\"", 
                  "\"\<Cytonuclear associations\>\""},
                {"\"\<Migration, and sexual selection\>\"", 
                  "\"\<Migration\>\"", "\"\<Sexual selection\>\""},
                {"\"\<Migration, context-dependent\>\"", "\"\<Migration\>\"", 
                  "\"\<Context-dependent migration\>\""},
                {"\"\<Migration, example of\>\"", "\"\<Migration example\>\"",
                   "None"},
                {"\"\<Migration, genotype-dependent\>\"", 
                  "\"\<Migration\>\"", 
                  "\"\<Genotype-dependent migration\>\""},
                {"\"\<Migration, in numerical models\>\"", 
                  "\"\<Allele frequencies: migration\>\"", 
                  "\"\<MigrateExact\>\""},
                {"\"\<Migration, in numerical models\>\"", 
                  "\"\<Recursions:migration\>\"", "\"\<MigrateExact\>\""},
                {"\"\<Migration, in symmetric model\>\"", 
                  "\"\<Symmetric model: migration\>\"", 
                  "\"\<MigrateExact\>\""},
                {"\"\<Migration, Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS\>\"", "\"\<Migration\>\""},
                {"\"\<Migration, of constant numbers\>\"", 
                  "\"\<Allele frequencies: migration\>\"", 
                  "\"\<Constant numbers\>\""},
                {"\"\<Migration, of haploids\>\"", 
                  "\"\<Migration example\>\"", "\"\<Haploid migration\>\""},
                {"\"\<Migration, of juvenile diploids\>\"", 
                  "\"\<Migration example\>\"", 
                  "\"\<Juvenile diploid migration\>\""},
                {"\"\<Migration, of pollen\>\"", "\"\<Migration example\>\"", 
                  "\"\<Asmussen and Orive 2000\>\""},
                {"\"\<Migration, of seeds\>\"", "\"\<Migration example\>\"", 
                  "\"\<Asmussen and Orive 2000\>\""},
                {"\"\<MigrationOrder,for genotype frequencies\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<MigrationOrder\>\""},
                {"\"\<MigrationOrder,for genotype frequencies\>\"", 
                  "\"\<Recursions: iterating one deme\>\"", 
                  "\"\<MigrationOrder\>\""},
                {"\"\<MigrationOrder, for individuals\>\"", 
                  "\"\<Simulating individuals: iterating one deme\>\"", 
                  "\"\<MigrationOrder\>\""},
                {"\"\<MigrationOrder, for symmetric model\>\"", 
                  "\"\<Symmetric model: iterating one deme\>\"", 
                  "\"\<MigrationOrder\>\""},
                {
                  "\"\<MigrationRate, \[CapitalMu], \[AliasIndicator]M\
\[AliasIndicator]\>\"", "\"\<Notation reference\>\"", "None"},
                {
                  "\"\<MigrationSet, \[DoubleStruckCapitalM], \
\[AliasIndicator]dsM\[AliasIndicator]\>\"", "\"\<Migration\>\"", 
                  "\"\<MigrationSet\>\""},
                {"\"\<Migration, with sindividuals\>\"", 
                  "\"\<Simulating individuals:migration\>\"", 
                  "\"\<MigrateExact\>\""},
                {"\"\<MissingCombination\>\"", 
                  "\"\<Validity of a mutation matrix\>\"", 
                  "\"\<MissingCombination\>\""},
                {"\"\<Missing data, notation\>\"", 
                  "\"\<Defining a dataset\>\"", "\"\<Missing data\>\""},
                {
                  "\"\<Missing data, estimating allele frequencies with nulls\
\>\"", "\"\<Gene & genotype frequencies\>\"", "\"\<NullAllele\>\""},
                {
                  "\"\<Missing data, estimating genotype frequencies with \
nulls\>\"", "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<GenotypeFrequency\>\""},
                {"\"\<MissingData, option for AlleleFrequencyTable\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<NullAllele\>\""},
                {"\"\<MissingData, option for GenotypeFrequency\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<GenotypeFrequency\>\""},
                {"\"\<Moment\>\"", "\"\<Cumulants\>\"", "\"\<Moment\>\""},
                {"\"\<Moment\>\"", "\"\<Moments and cumulants\>\"", 
                  "\"\<Moment\>\""},
                {"\"\<MomentAfterMigration\>\"", 
                  "\"\<Migration in admixture models\>\"", 
                  "\"\<MomentAfterMigration\>\""},
                {"\"\<MomentAfterRecombination\>\"", 
                  "\"\<Recombination in admixture models\>\"", 
                  "\"\<MomentAfterRecombination\>\""},
                {"\"\<MomentEquilibrium\>\"", "\"\<Equilibria\>\"", 
                  "\"\<MomentEquilibrium\>\""},
                {"\"\<MomentGeneratingFunction, deriving\>\"", 
                  "\"\<Deriving recursions for the MGF\>\"", "None"},
                {"\"\<MomentGeneratingFunction, examples\>\"", 
                  "\"\<Examples of the MGF\>\"", "None"},
                {"\"\<MomentGeneratingFunction, for genealogies\>\"", 
                  "\"\<Calculating the MGF\>\"", "None"},
                {"\"\<MomentGeneratingFunction, over topologies\>\"", 
                  "\"\<Calculating over topologies\>\"", "None"},
                {"\"\<MomentLimits\>\"", "\"\<Constraints on moments\>\"", 
                  "\"\<MomentLimits\>\""},
                {"\"\<MomentNew\>\"", "\"\<Iteration\>\"", 
                  "\"\<MomentNew\>\""},
                {"\"\<MomentReduced\>\"", "\"\<Obsolete functions\>\"", 
                  "\"\<MomentReduced\>\""},
                {"\"\<Moments\>\"", "\"\<Cumulants\>\"", "\"\<7.2\>\""},
                {"\"\<Moments, estimating the matrix of\>\"", 
                  "\"\<Estimating the matrix of moments\>\"", 
                  "\"\<Estimating the matrix\>\""},
                {"\"\<Moments, extension to description by\>\"", 
                  "\"\<References\>\"", "\"\<Haber 1984\>\""},
                {"\"\<Moments, extension to estimation of\>\"", 
                  "\"\<Estimating the matrix of moments\>\"", "\"\<MLE\>\""},
                {"\"\<MomentsFromG\>\"", 
                  "\"\<Moments from genotype frequencies\>\"", 
                  "\"\<MomentsFromG\>\""},
                {"\"\<Moments, full description by\>\"", 
                  "\"\<A matrix of moments\>\"", "\"\<g[X] matrix\>\""},
                {"\"\<MomentSimple\>\"", "\"\<Simplifying the moments\>\"", 
                  "\"\<MomentSimple\>\""},
                {"\"\<Moments, matrix of\>\"", "\"\<A matrix of moments\>\"", 
                  "\"\<g[X] full matrix\>\""},
                {"\"\<Moments,ML estimation of\>\"", 
                  "\"\<Estimating the matrix of moments\>\"", 
                  "\"\<simple method\>\""},
                {"\"\<Moments, reduced description by\>\"", 
                  "\"\<A matrix of moments\>\"", "\"\<g[X] matrix\>\""},
                {"\"\<Moments, simple method for estimating\>\"", 
                  "\"\<Estimating the matrix of moments\>\"", 
                  "\"\<extension to families\>\""},
                {"\"\<MonteCarloGriffithsTavare\>\"", 
                  "\"\<Stochastic algorithm\>\"", 
                  "\"\<MonteCarloGriffithsTavare\>\""},
                {"\"\<MonteCarloProbability\>\"", 
                  "\"\<Estimating the probability\>\"", 
                  "\"\<MonteCarloProbability\>\""},
                {"\"\<Mortality\>\"", "\"\<Describing individuals\>\"", 
                  "\"\<Mortality\>\""},
                {"\"\<MostRecentCommonAncestor\>\"", 
                  "\"\<Determining ancestry\>\"", 
                  "\"\<MostRecentCommonAncestor\>\""},
                {"\"\<MToC\>\"", "\"\<Estimating the matrix\>\"", 
                  "\"\<MToC\>\""},
                {"\"\<MToC\>\"", "\"\<Estimation from families\>\"", 
                  "\"\<MToC\>\""},
                {"\"\<MToCEquations\>\"", "\"\<Estimating the matrix\>\"", 
                  "\"\<MToCEquations\>\""},
                {"\"\<MToCEquations\>\"", "\"\<Estimation from families\>\"", 
                  "\"\<MToCEquations\>\""},
                {"\"\<Muddle\>\"", "\"\<Muddling and subdividing sets\>\"", 
                  "\"\<Muddle\>\""},
                {"\"\<Multilocus algebra, basic notation\>\"", 
                  "\"\<Genes and contexts\>\"", "\"\<Basic notation\>\""},
                {"\"\<Multilocus algebra, fitness\>\"", "\"\<Fitness\>\"", 
                  "\"\<Fitness\>\""},
                {"\"\<Multilocus algebra, introduction to\>\"", 
                  "\"\<Introduction to multilocus algebra\>\"", 
                  "\"\<1.1\>\""},
                {"\"\<Multilocus algebra, introduction to\>\"", 
                  "\"\<Introduction to multilocus algebra\>\"", 
                  "\"\<Multilocus`Multilocus`\>\""},
                {"\"\<Multilocus algebra, stages in life cycle\>\"", 
                  "\"\<Genes and contexts\>\"", "\"\<Stages\>\""},
                {"\"\<Multilocus algebra, stages in life cycle\>\"", 
                  "\"\<Life cycle\>\"", "\"\<Stages\>\""},
                {"\"\<Multilocus algebra, technicalities\>\"", 
                  "\"\<Populations\>\"", "\"\<Technicalities\>\""},
                {"\"\<Multilocus MS, relation with\>\"", 
                  "\"\<Migration example\>\"", "\"\<Multilocus MS\>\""},
                {"\"\<Multilocus MS, relation with\>\"", 
                  "\"\<Multilocus MS relation\>\"", "None"},
                {"\"\<Multilocus notation, bugs\>\"", "\"\<Bugs\>\"", 
                  "\"\<Multilocus notation\>\""},
                {"\"\<MultinomialSamplingProbability\>\"", 
                  "\"\<Multinomial distribution\>\"", 
                  "\"\<MultinomialSamplingProbability\>\""},
                {"\"\<Multinomial sampling, without replacement\>\"", 
                  "\"\<Multinomial distribution\>\"", 
                  "\"\<Multinomial sampling wo replacement\>\""},
                {"\"\<Multiple alleles, and selection coefficients\>\"", 
                  "\"\<Phenotypes\>\"", "\"\<Multiple alleles\>\""},
                {"\"\<Multiple alleles, MakeFitnessSet\>\"", 
                  "\"\<Fitness\>\"", "\"\<Multiple alleles\>\""},
                {"\"\<Multiple alleles, mutation\>\"", 
                  "\"\<Multilocus mutation\>\"", "\"\<Multiple alleles\>\""},
                {"\"\<Multiple alleles, representation of\>\"", 
                  "\"\<Allelic state\>\"", "None"},
                {"\"\<Multiple alleles, selection on\>\"", 
                  "\"\<Selection\>\"", "\"\<Multiple alleles\>\""},
                {"\"\<Multiple arguments, in PopulationExpectation\>\"", 
                  "\"\<Expectations\>\"", "\"\<multiple arguments\>\""},
                {"\"\<Multiplicative models, in negative binomial\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", 
                  "\"\<multiplicative models\>\""},
                {"\"\<MUS, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<MUS\>\""},
                {"\"\<MUS,for genotype frequencies\>\"", 
                  "\"\<Recursions: iterating one deme\>\"", "\"\<MUS\>\""},
                {"\"\<MUS, for individuals\>\"", 
                  "\"\<Simulating individuals: iterating one deme\>\"", 
                  "\"\<MUS\>\""},
                {"\"\<MUS, for symmetric model\>\"", 
                  "\"\<Symmetric model: iterating one deme\>\"", 
                  "\"\<MUS\>\""},
                {"\"\<Mutate, allele frequencies\>\"", 
                  "\"\<Allele frequencies: mutation\>\"", "\"\<Mutate\>\""},
                {"\"\<MutateCompiled\>\"", 
                  "\"\<Allele frequencies: mutation\>\"", 
                  "\"\<MutateCompiled\>\""},
                {"\"\<MutateCompiled\>\"", "\"\<Recursions: mutation\>\"", 
                  "\"\<MutateCompiled\>\""},
                {"\"\<MutateCompiled\>\"", 
                  "\"\<Simulating individuals: mutation\>\"", 
                  "\"\<MutateCompiled\>\""},
                {"\"\<MutateCompiled\>\"", 
                  "\"\<Symmetric model: mutation\>\"", 
                  "\"\<MutateCompiled\>\""},
                {"\"\<Mutate,genotype frequencies\>\"", 
                  "\"\<Recursions: mutation\>\"", "\"\<Mutate\>\""},
                {"\"\<Mutate, individuals\>\"", 
                  "\"\<Simulating individuals: mutation\>\"", 
                  "\"\<Mutate\>\""},
                {"\"\<Mutate, symmetric model\>\"", 
                  "\"\<Symmetric model: mutation\>\"", "\"\<Mutate\>\""},
                {"\"\<MutationInterval\>\"", "\"\<Describing mutations\>\"", 
                  "\"\<MutationInterval\>\""},
                {"\"\<Mutation, Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS\>\"", "\"\<Mutation\>\""},
                {"\"\<MutationLabels\>\"", 
                  "\"\<Converting between representations\>\"", 
                  "\"\<MutationLabels\>\""},
                {"\"\<Mutation, Mutations, in multilocus genetics\>\"", 
                  "\"\<Multilocus mutation\>\"", "\"\<Mutation\>\""},
                {"\"\<Mutation, option for BiallelicMutation\>\"", 
                  "\"\<Multilocus mutation\>\"", "\"\<Mutation\>\""},
                {"\"\<Mutation, option for NewGametes\>\"", 
                  "\"\<Allele frequencies: reproduction\>\"", 
                  "\"\<Mutation\>\""},
                {"\"\<Mutation, option for NewGametes\>\"", 
                  "\"\<Recursions: reproduction\>\"", "\"\<Mutation\>\""},
                {"\"\<Mutation, option for NewGametes\>\"", 
                  "\"\<Simulating individuals: reproduction\>\"", 
                  "\"\<Mutation\>\""},
                {"\"\<Mutation, option for NewGametes\>\"", 
                  "\"\<Symmetric model: reproduction\>\"", 
                  "\"\<Mutation\>\""},
                {"\"\<MutationOrigin\>\"", "\"\<Describing mutations\>\"", 
                  "\"\<MutationOrigin\>\""},
                {"\"\<MutationRate\>\"", "\"\<Drawing a genealogy\>\"", 
                  "\"\<MutationRate\>\""},
                {"\"\<Mutations, adding to a genealogy\>\"", 
                  "\"\<Manipulating genealogies\>\"", "\"\<AddMutation\>\""},
                {"\"\<Mutations, consistency with a genealogy\>\"", 
                  "\"\<Validity of a mutation matrix\>\"", "None"},
                {"\"\<Mutations, inferring genealogies from\>\"", 
                  "\"\<Inferring a genealogy\>\"", "None"},
                {"\"\<Mutations,infinite site\>\"", 
                  "\"\<Describing mutations\>\"", "\"\<Mutations\>\""},
                {"\"\<Mutations, in genealogies\>\"", 
                  "\"\<Describing mutations\>\"", "\"\<Mutations\>\""},
                {"\"\<MVariables\>\"", "\"\<Estimating the matrix\>\"", 
                  "\"\<MVariables\>\""},
                {"\"\<MVariables\>\"", "\"\<Estimation from families\>\"", 
                  "\"\<MVariables\>\""},
                {"\"\<Negative binomial, c<1\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", "\"\<c<1\>\""},
                {"\"\<Negative binomial, compiled\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", 
                  "\"\<Compiled\>\""},
                {"\"\<NegativeBinomialLogLikelihood\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", 
                  "\"\<NegativeBinomialLogLikelihood\>\""},
                {"\"\<NegativeBinomialMLE\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", 
                  "\"\<NegativeBinomialMLE\>\""},
                {"\"\<Negative binomial, multiplicative models\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", 
                  "\"\<multiplicative models\>\""},
                {"\"\<Negative binomial, normalisation\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", 
                  "\"\<Normalisation\>\""},
                {"\"\<Negative binomial, timings\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", 
                  "\"\<Timings\>\""},
                {"\"\<NegativeHypergeometricDistribution\>\"", 
                  "\"\<Negative hypergeometric distribution\>\"", 
                  "\"\<NegativeHypergeometricDistribution\>\""},
                {"\"\<NeighbourArray\>\"", "\"\<Boxing the individuals\>\"", 
                  "\"\<NeighbourArray\>\""},
                {"\"\<Neighbours\>\"", "\"\<Boxing the individuals\>\"", 
                  "\"\<Neighbours\>\""},
                {"\"\<NetCovariance\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<NetCovariance\>\""},
                {"\"\<NetFecundity\>\"", "\"\<Global variables\>\"", 
                  "\"\<NetFecundity\>\""},
                {"\"\<NetMortality\>\"", "\"\<Global variables\>\"", 
                  "\"\<NetMortality\>\""},
                {"\"\<NetRecombination\>\"", "\"\<Linkage\>\"", 
                  "\"\<NetRecombination\>\""},
                {"\"\<NetRecombination\>\"", "\"\<Linkage in families\>\"", 
                  "\"\<NetRecombination\>\""},
                {"\"\<NetRecombination, in multilocus genetics\>\"", 
                  "\"\<Recombination\>\"", "\"\<NetRecombination\>\""},
                {"\"\<NetRecombination, in numerical models\>\"", 
                  "\"\<Recursions:Linkage\>\"", "\"\<NetRecombination\>\""},
                {"\"\<Neutral marker, in symmetric model\>\"", 
                  "\"\<Adding a neutral gene\>\"", "None"},
                {"\"\<NeutralRepresentations\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<NeutralRepresentations\>\""},
                {"\"\<NewGametes, for allele frequencies\>\"", 
                  "\"\<Allele frequencies:reproduction\>\"", 
                  "\"\<NewGametes\>\""},
                {"\"\<NewGametes, for genotype frequencies\>\"", 
                  "\"\<Recursions:reproduction\>\"", "\"\<NewGametes\>\""},
                {"\"\<NewGametes, for symmetric model\>\"", 
                  "\"\<Symmetric model: reproduction\>\"", 
                  "\"\<NewGametes\>\""},
                {"\"\<NewGametes, linkage\>\"", "\"\<Recursions:Linkage\>\"", 
                  "\"\<NewGametes\>\""},
                {"\"\<NewGametes, Mutation option\>\"", 
                  "\"\<Allele frequencies: reproduction\>\"", 
                  "\"\<Mutation\>\""},
                {"\"\<NewGametes, Mutation option\>\"", 
                  "\"\<Recursions: reproduction\>\"", "\"\<Mutation\>\""},
                {"\"\<NewGametes, Mutation option\>\"", 
                  "\"\<Simulating individuals: reproduction\>\"", 
                  "\"\<Mutation\>\""},
                {"\"\<NewGametes, Mutation option\>\"", 
                  "\"\<Symmetric model: reproduction\>\"", 
                  "\"\<Mutation\>\""},
                {"\"\<NewGametes, truncation selection\>\"", 
                  "\"\<Simulating individuals: reproduction\>\"", 
                  "\"\<TruncationSelection\>\""},
                {"\"\<NewGametes, with individuals\>\"", 
                  "\"\<Simulating individuals: reproduction\>\"", 
                  "\"\<NewGametes\>\""},
                {"\"\<NewS\>\"", "\"\<The set of all structures\>\"", 
                  "\"\<NewS\>\""},
                {"\"\<Node\>\"", "\"\<Constructing genealogies\>\"", 
                  "\"\<Node\>\""},
                {"\"\<Node\>\"", "\"\<Structure of genealogies\>\"", 
                  "\"\<Node\>\""},
                {"\"\<NodeFunction\>\"", "\"\<Constructing genealogies\>\"", 
                  "\"\<NodeFunction\>\""},
                {"\"\<NodeFunction\>\"", "\"\<Plotting genealogies\>\"", 
                  "\"\<NodeFunction\>\""},
                {"\"\<NodeFunction, option for ExactProbability\>\"", 
                  "\"\<Exact probability\>\"", "\"\<NodeFunction\>\""},
                {"\"\<NodeLabels\>\"", "\"\<Plotting genealogies\>\"", 
                  "\"\<NodeLabels\>\""},
                {"\"\<NodeOffset\>\"", "\"\<Plotting genealogies\>\"", 
                  "\"\<NodeOffset\>\""},
                {"\"\<Nodes\>\"", "\"\<Describing genealogies\>\"", 
                  "\"\<Nodes\>\""},
                {"\"\<NonMendelian\>\"", "\"\<Non-Mendelian inheritance\>\"", 
                  "None"},
                {"\"\<NonMendelian, examples of\>\"", 
                  "\"\<Cytoplasmic inheritance\>\"", "None"},
                {"\"\<NonMendelian, examples of\>\"", "\"\<Sex linkage\>\"", 
                  "None"},
                {"\"\<NonNeutralRepresentations\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<NonNeutralRepresentations\>\""},
                {"\"\<NonSymmetricRepresentations\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<NonSymmetricRepresentations\>\""},
                {"\"\<Normalisation\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", 
                  "\"\<Normalisation\>\""},
                {"\"\<Normalised\>\"", 
                  "\"\<Negative binomial likelihoods\>\"", 
                  "\"\<Normalised\>\""},
                {"\"\<Notation, clearing definitions\>\"", 
                  "\"\<Notation reference\>\"", 
                  "\"\<Clearing definitions\>\""},
                {"\"\<Notation, data\>\"", 
                  "\"\<Notation for genetic data\>\"", 
                  "\"\<NotationPackage\>\""},
                {"\"\<Notation, defining new\>\"", 
                  "\"\<Notation reference\>\"", 
                  "\"\<Defining new notation\>\""},
                {"\"\<Notation, genotypes\>\"", "\"\<Notation\>\"", 
                  "\"\<NotationPackage\>\""},
                {"\"\<Notation Package\>\"", "\"\<Notation package\>\"", 
                  "None"},
                {"\"\<Notation, reference\>\"", "\"\<Notation reference\>\"", 
                  "\"\<NotationPackage\>\""},
                {"\"\<Null alleles, estimating allele frequencies\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<NullAllele\>\""},
                {"\"\<Null alleles, estimating genotype frequencies\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<GenotypeFrequency\>\""},
                {"\"\<NullAllele, option for AlleleFrequencyTable\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<NullAllele\>\""},
                {"\"\<NullAllele, option for GenotypeFrequency\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<GenotypeFrequency\>\""},
                {"\"\<Null lineages, in ancestral graphs\>\"", 
                  "\"\<Random ancestral graphs\>\"", 
                  "\"\<DeleteNullLineages\>\""},
                {"\"\<NullLineages, in ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<NullLineages\>\""},
                {"\"\<NullRecombinationEvents, in ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<NullRecombinationEvents\>\""},
                {"\"\<NumberedLink\>\"", "\"\<Automatic Numbering\>\"", 
                  "\"\<NumberedLink\>\""},
                {"\"\<Numbering, aesthetics\>\"", 
                  "\"\<Automatic Numbering\>\"", "\"\<Aesthetics\>\""},
                {"\"\<Numbering, automatic\>\"", 
                  "\"\<Automatic Numbering\>\"", "\"\<7.2\>\""},
                {"\"\<Numbering, notes on\>\"", 
                  "\"\<Automatic Numbering\>\"", "\"\<Notes\>\""},
                {"\"\<Numbering, saving links\>\"", 
                  "\"\<Automatic Numbering\>\"", "\"\<Saving the links\>\""},
                {"\"\<NumberOfCoalescences\>\"", 
                  "\"\<Distribution of coalescence times\>\"", 
                  "\"\<NumberOfCoalescences\>\""},
                {"\"\<NumberOfGenes\>\"", "\"\<Describing a dataset\>\"", 
                  "\"\<NumberOfGenes\>\""},
                {"\"\<NumberOfGenes, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: representation\>\"", 
                  "\"\<NumberOfGenes\>\""},
                {"\"\<NumberOfGenes, for genotype frequencies\>\"", 
                  "\"\<Recursions: description\>\"", 
                  "\"\<NumberOfGenes\>\""},
                {"\"\<NumberOfGenes, for individuals\>\"", 
                  "\"\<Simulating individuals: Describing populations\>\"", 
                  "\"\<NumberOfGenes\>\""},
                {"\"\<NumberOfGenes, for symmetric model\>\"", 
                  "\"\<Symmetric model: Describing populations\>\"", 
                  "\"\<NumberOfGenes\>\""},
                {"\"\<NumberOfGenesTable\>\"", 
                  "\"\<Describing a dataset\>\"", 
                  "\"\<NumberOfGenesTable\>\""},
                {"\"\<NumberOfIndividuals\>\"", 
                  "\"\<Describing a dataset\>\"", 
                  "\"\<NumberOfIndividuals\>\""},
                {"\"\<NumberOfIndividuals\>\"", "\"\<Global variables\>\"", 
                  "\"\<NumberOfIndividuals\>\""},
                {"\"\<NumberOfIndividualsTable\>\"", 
                  "\"\<Describing a dataset\>\"", 
                  "\"\<NumberOfIndividualsTable\>\""},
                {"\"\<NumberOfLineages\>\"", 
                  "\"\<Describing genealogies\>\"", 
                  "\"\<NumberOfLineages\>\""},
                {"\"\<NumberOfLoci\>\"", "\"\<Describing a dataset\>\"", 
                  "\"\<NumberOfLoci\>\""},
                {"\"\<NumberOfMutations\>\"", "\"\<Describing mutations\>\"", 
                  "\"\<NumberOfMutations\>\""},
                {"\"\<NumberOfPossibleCoalescences\>\"", 
                  "\"\<Finding possible orders\>\"", 
                  "\"\<NumberOfPossibleCoalescences\>\""},
                {"\"\<NumberOfSamplePartitions\>\"", 
                  "\"\<Set partitions\>\"", 
                  "\"\<NumberOfSamplePartitions\>\""},
                {"\"\<NumberOfSetPartitions\>\"", "\"\<Set partitions\>\"", 
                  "\"\<NumberOfSetPartitions\>\""},
                {"\"\<NumericalModel, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: representation\>\"", 
                  "\"\<NumericalModel\>\""},
                {"\"\<NumericalModel, for genotype frequencies\>\"", 
                  "\"\<Recursions: representation\>\"", 
                  "\"\<NumericalModel\>\""},
                {"\"\<Numerical models, genotype frequencies\>\"", 
                  "\"\<Recursions: representation\>\"", "None"},
                {"\"\<Numerical models, of allele frequencies\>\"", 
                  "\"\<Allele frequencies: representation\>\"", "None"},
                {"\"\<Numerical models, overview\>\"", 
                  "\"\<Overview of numerical models\>\"", "None"},
                {"\"\<Numerical models, problems\>\"", 
                  "\"\<Potential problems\>\"", "None"},
                {"\"\<Numerical models, problems with migration\>\"", 
                  "\"\<Allele frequencies: migration\>\"", 
                  "\"\<Constant numbers\>\""},
                {"\"\<Numerical models, stability of\>\"", 
                  "\"\<Allele frequencies: stability\>\"", "None"},
                {"\"\<Numerical models, stability of\>\"", 
                  "\"\<Example: stability\>\"", "None"},
                {"\"\<Numerical models, symmetric\>\"", 
                  "\"\<Symmetric model: genotype frequencies\>\"", "None"},
                {"\"\<Observable genotype\>\"", "\"\<Diploid genotypes\>\"", 
                  "\"\<ObservableGenotype\>\""},
                {"\"\<Observable genotype\>\"", 
                  "\"\<Genotype probabilities\>\"", 
                  "\"\<ObservableGenotype\>\""},
                {"\"\<Obsolete, Combine\>\"", "\"\<Tagging sets\>\"", 
                  "\"\<Separate\>\""},
                {"\"\<Obsolete, CumulantReduced\>\"", 
                  "\"\<Obsolete functions\>\"", "\"\<CumulantReduced\>\""},
                {"\"\<Obsolete, DiploidConstraints\>\"", 
                  "\"\<Obsolete functions\>\"", 
                  "\"\<DiploidConstraints\>\""},
                {"\"\<Obsolete, DiploidGenotypeFrequencyReduced\>\"", 
                  "\"\<Obsolete functions\>\"", 
                  "\"\<DiploidGenotypeFrequencyReduced\>\""},
                {"\"\<Obsolete, DiploidGenotypeFrequencyTable\>\"", 
                  "\"\<Obsolete functions\>\"", 
                  "\"\<DiploidGenotypeFrequencyTable\>\""},
                {"\"\<Obsolete, Estimating D\>\"", "\"\<Bugs\>\"", 
                  "\"\<Obsolete EstimatingD\>\""},
                {"\"\<Obsolete, fitness\>\"", "\"\<Fitness\>\"", 
                  "\"\<Obsolete notation\>\""},
                {"\"\<Obsolete, FullGenotypeFrequencyReduced\>\"", 
                  "\"\<Obsolete functions\>\"", 
                  "\"\<FullGenotypeFrequencyReduced\>\""},
                {"\"\<Obsolete, FullGenotypeFrequencyTable\>\"", 
                  "\"\<Obsolete functions\>\"", 
                  "\"\<FullGenotypeFrequencyTable\>\""},
                {"\"\<Obsolete, GenotypeFrequencyArguments\>\"", 
                  "\"\<Obsolete functions\>\"", 
                  "\"\<GenotypeFrequencyArguments\>\""},
                {"\"\<Obsolete, HaploidConstraints\>\"", 
                  "\"\<Obsolete functions\>\"", 
                  "\"\<HaploidConstraints\>\""},
                {"\"\<Obsolete, InitialStepReduced\>\"", 
                  "\"\<Obsolete functions\>\"", 
                  "\"\<InitialStepReduced\>\""},
                {"\"\<Obsolete, IntervalCombine\>\"", 
                  "\"\<Obsolete functions\>\"", "\"\<IntervalCombine\>\""},
                {"\"\<Obsolete, IntervalPosition\>\"", 
                  "\"\<Obsolete functions\>\"", "\"\<IntervalPosition\>\""},
                {"\"\<Obsolete, LogLikelihoodDisequilibriumReduced\>\"", 
                  "\"\<Obsolete functions\>\"", 
                  "\"\<LogLikelihoodDisequilibriumReduced\>\""},
                {"\"\<Obsolete, MetropolisDisequilibriumReduced\>\"", 
                  "\"\<Obsolete functions\>\"", 
                  "\"\<MetropolisDisequilibriumReduced\>\""},
                {"\"\<Obsolete, MomentReduced\>\"", 
                  "\"\<Obsolete functions\>\"", "\"\<MomentReduced\>\""},
                {"\"\<Obsolete, notation\>\"", "\"\<Bugs\>\"", 
                  "\"\<Obsolete EstimatingD\>\""},
                {"\"\<Obsolete, notation\>\"", "\"\<Tagging sets\>\"", 
                  "\"\<Obsolete\>\""},
                {"\"\<Obsolete, Separate\>\"", "\"\<Tagging sets\>\"", 
                  "\"\<Combine\>\""},
                {"\"\<Obsolete, SetPartition\>\"", "\"\<Set partitions\>\"", 
                  "\"\<SetPartition\>\""},
                {"\"\<Offspring\>\"", "\"\<Describing individuals\>\"", 
                  "\"\<Offspring\>\""},
                {"\"\<Ordered,option for PartitionSet\>\"", 
                  "\"\<Set partitions\>\"", "\"\<Ordered\>\""},
                {"\"\<Orive & Barton 1999\>\"", "\"\<References\>\"", 
                  "\"\<Orive & Barton 1999\>\""},
                {"\"\<OtherSex\>\"", "\"\<Genes and contexts\>\"", 
                  "\"\<OtherSex\>\""},
                {"\"\<PackageSaver\>\"", "\"\<Bugs\>\"", 
                  "\"\<Special notation\>\""},
                {"\"\<Packages, help\>\"", 
                  "\"\<How the Help Browser works\>\"", "\"\<Packages\>\""},
                {"\"\<Packages, overview of\>\"", 
                  "\"\<Overview of the packages\>\"", "None"},
                {"\"\<Packages, saving using PackageSaver\>\"", 
                  "\"\<Bugs\>\"", "\"\<Special notation\>\""},
                {"\"\<Packages, setting up\>\"", 
                  "\"\<Setting up the packages\>\"", 
                  "\"\<Setting up the packages\>\""},
                {"\"\<Packages, setting up\>\"", "\"\<Special notation\>\"", 
                  "\"\<Setting up packages\>\""},
                {"\"\<Packages, versions of\>\"", "\"\<Versions\>\"", 
                  "None"},
                {"\"\<ParentalGenotypes\>\"", "\"\<Inferring parents\>\"", 
                  "\"\<ParentalGenotypes\>\""},
                {"\"\<PartitionSet\>\"", "\"\<Set partitions\>\"", 
                  "\"\<PartitionSet\>\""},
                {"\"\<Partitions, of sets\>\"", "\"\<Set partitions\>\"", 
                  "\"\<PartitionSet\>\""},
                {"\"\<Partitions, standard form\>\"", 
                  "\"\<Set partitions\>\"", "\"\<StandardPartition\>\""},
                {"\"\<Partitions, testing for standard form\>\"", 
                  "\"\<Set partitions\>\"", "\"\<StandardPartitionQ\>\""},
                {"\"\<Paternal inheritance\>\"", 
                  "\"\<Non-Mendelian inheritance\>\"", 
                  "\"\<PaternalLoci\>\""},
                {"\"\<Paternal inheritance\>\"", "\"\<Reference points\>\"", 
                  "\"\<PaternalLoci\>\""},
                {"\"\<PaternalLoci, example of\>\"", 
                  "\"\<Cytoplasmic inheritance\>\"", "None"},
                {"\"\<PaternalLoci, option for NonMendelian\>\"", 
                  "\"\<Non-Mendelian inheritance\>\"", 
                  "\"\<PaternalLoci\>\""},
                {"\"\<PaternalLoci, reference points\>\"", 
                  "\"\<Reference points\>\"", "\"\<PaternalLoci\>\""},
                {"\"\<PatternFree\>\"", 
                  "\"\<Flattening lists by pattern\>\"", 
                  "\"\<PatternFree\>\""},
                {
                  "\"\<Permutations in defining coefficients, Kirkpatrick et \
al.\>\"", "\"\<Multilocus MS\>\"", "\"\<Permutations\>\""},
                {"\"\<Permutations,option for PartitionSet\>\"", 
                  "\"\<Set partitions\>\"", "\"\<Permutations\>\""},
                {"\"\<Phenotypes, Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS\>\"", "\"\<Phenotypes\>\""},
                {"\"\<Phipps & Brill 1995\>\"", "\"\<References\>\"", 
                  "\"\<Phipps & Brill 1995\>\""},
                {"\"\<Ploidy\>\"", "\"\<Describing a dataset\>\"", 
                  "\"\<Ploidy\>\""},
                {"\"\<PloidyWeightList\>\"", "\"\<Internal functions\>\"", 
                  "\"\<PloidyWeightList\>\""},
                {"\"\<PlotGenealogy\>\"", "\"\<Plotting genealogies\>\"", 
                  "\"\<PlotGenealogy\>\""},
                {"\"\<PlotLogL\>\"", "\"\<Presenting results\>\"", 
                  "\"\<PlotLogL\>\""},
                {"\"\<PlotSegments, of ancestral graphs\>\"", 
                  "\"\<Plotting ancestral graphs\>\"", 
                  "\"\<PlotSegments\>\""},
                {"\"\<Plotting, ancestral graphs\>\"", 
                  "\"\<Plotting ancestral graphs\>\"", "None"},
                {
                  "\"\<PopulationDisequilibrium,\[GothicCapitalC], \
\[AliasIndicator]goC\[AliasIndicator]\>\"", "\"\<Expectations\>\"", 
                  "\"\<PopulationDisequilibrium\>\""},
                {"\"\<PopulationExpectation\>\"", "\"\<Expectations\>\"", 
                  "\"\<PopulationExpectation\>\""},
                {"\"\<PopulationExpectation, multiple arguments\>\"", 
                  "\"\<Expectations\>\"", "\"\<multiple arguments\>\""},
                {"\"\<PopulationRepresentations\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<PopulationRepresentations\>\""},
                {"\"\<Position\>\"", "\"\<Genes and contexts\>\"", 
                  "\"\<position\>\""},
                {"\"\<Position\>\"", "\"\<Multilocus MS relation\>\"", 
                  "\"\<position\>\""},
                {"\"\<Position, as used in Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS relation\>\"", "\"\<position\>\""},
                {"\"\<Position, Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS\>\"", "\"\<Contexts and positions\>\""},
                {"\"\<PositionsList\>\"", "\"\<Full diploid genotypes\>\"", 
                  "\"\<PositionsList\>\""},
                {"\"\<PositionsMatrix\>\"", "\"\<Full diploid genotypes\>\"", 
                  "\"\<PositionsMatrix\>\""},
                {"\"\<PossibleCoalescenceOrder\>\"", 
                  "\"\<Finding possible orders\>\"", 
                  "\"\<PossibleCoalescenceOrder\>\""},
                {"\"\<PossibleDiploidGenotypes\>\"", 
                  "\"\<Full diploid genotypes\>\"", 
                  "\"\<PossibleDiploidGenotypes\>\""},
                {"\"\<PossibleGenotypes\>\"", "\"\<Diploid genotypes\>\"", 
                  "\"\<PossibleGenotypes\>\""},
                {"\"\<PossibleRootings\>\"", "\"\<Rooting a genealogy\>\"", 
                  "\"\<PossibleRootings\>\""},
                {"\"\<PowerF, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<PowerF\>\""},
                {"\"\<PowerF, for genotype frequencies\>\"", 
                  "\"\<Recursions: iterating one deme\>\"", 
                  "\"\<PowerF\>\""},
                {"\"\<PowerF, for individuals\>\"", 
                  "\"\<Simulating individuals: iterating one deme\>\"", 
                  "\"\<PowerF\>\""},
                {"\"\<PowerF, for symmetric model\>\"", 
                  "\"\<Symmetric model: iterating one deme\>\"", 
                  "\"\<PowerF\>\""},
                {"\"\<PowerF, with individuals\>\"", 
                  "\"\<Simulating individuals: reproduction\>\"", 
                  "\"\<PowerF\>\""},
                {"\"\<PresentOneWayTable\>\"", "\"\<Single-locus tables\>\"", 
                  "\"\<PresentOneWayTable\>\""},
                {"\"\<PresentPairwiseTable\>\"", "\"\<Pairwise tables\>\"", 
                  "\"\<PresentPairwiseTable\>\""},
                {"\"\<PresentResults\>\"", "\"\<Presenting results\>\"", 
                  "\"\<PresentResults\>\""},
                {
                  "\"\<Principal components, Bennett's measure of \
disequilibrium\>\"", "\"\<Alternative measures\>\"", "\"\<Bennett\>\""},
                {"\"\<PrintDetails\>\"", "\"\<Options for StructuredMLE\>\"", 
                  "\"\<PrintDetails\>\""},
                {"\"\<PrintDetails, option for RandomGenealogy\>\"", 
                  "\"\<Random ancestral graphs\>\"", 
                  "\"\<PrintDetails, option for RandomGenealogy\>\""},
                {"\"\<Problems, avoid integers\>\"", 
                  "\"\<Potential problems\>\"", "\"\<Avoid integers\>\""},
                {"\"\<Problems, redefining fitness\>\"", 
                  "\"\<Potential problems\>\"", 
                  "\"\<Allele frequencies\>\""},
                {"\"\<Problems, redefining fitness\>\"", 
                  "\"\<Potential problems\>\"", 
                  "\"\<Redefining fitness\>\""},
                {"\"\<Problems, redefining fitness\>\"", 
                  "\"\<Symmetric model: iterating one deme\>\"", 
                  "\"\<StoreResults (compiling)\>\""},
                {"\"\<Products, multiple\>\"", "\"\<TimesUp\>\"", 
                  "\"\<Multiple products\>\""},
                {"\"\<ProductSum\>\"", "\"\<ProductSum\>\"", 
                  "\"\<ProductSum\>\""},
                {"\"\<ProductSum, over sets\>\"", "\"\<ProductSum\>\"", 
                  "\"\<ProductSum over sets\>\""},
                {"\"\<QLE, haploid selection example\>\"", 
                  "\"\<Haploid selection\>\"", "\"\<QLE\>\""},
                {"\"\<QLE, Kirkpatrick et al.\>\"", "\"\<Multilocus MS\>\"", 
                  "\"\<The QLE approximation\>\""},
                {"\"\<Quasi-linkage equilibrium, Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS\>\"", "\"\<The QLE approximation\>\""},
                {"\"\<RandomBottleneckedGenealogy\>\"", 
                  "\"\<Population bottlenecks\>\"", 
                  "\"\<RandomBottleneckedGenealogy\>\""},
                {"\"\<RandomCoalescenceOrder\>\"", 
                  "\"\<Finding possible orders\>\"", 
                  "\"\<RandomCoalescenceOrder\>\""},
                {"\"\<RandomCoalescenceTimes\>\"", 
                  "\"\<Distribution of coalescence times\>\"", 
                  "\"\<RandomCoalescenceTimes\>\""},
                {"\"\<RandomCoalescenceTimes, for ancestral graphs\>\"", 
                  "\"\<Random ancestral graphs\>\"", 
                  "\"\<RandomCoalescenceTimes\>\""},
                {"\"\<RandomCum\>\"", 
                  "\"\<Sampling from arbitrary distributions\>\"", 
                  "\"\<RandomCum\>\""},
                {"\"\<Random drift, changing reference points\>\"", 
                  "\"\<Introduction to random drift\>\"", 
                  "\"\<Changing reference points\>\""},
                {"\"\<Random drift, cumulants and moments\>\"", 
                  "\"\<Introduction to random drift\>\"", 
                  "\"\<Cumulants and moments\>\""},
                {"\"\<Random drift, describing a distribution\>\"", 
                  "\"\<Introduction to random drift\>\"", 
                  "\"\<Describing a distribution\>\""},
                {"\"\<Random drift, equations for the moments\>\"", 
                  "\"\<Introduction to random drift\>\"", 
                  "\"\<Equations for the moments\>\""},
                {"\"\<RandomDrift, for genotype frequencies\>\"", 
                  "\"\<Recursions: drift\>\"", "\"\<RandomDrift\>\""},
                {"\"\<Random drift, in a cline\>\"", 
                  "\"\<Allele frequencies: iterating a cline\>\"", 
                  "\"\<RandomDrift\>\""},
                {"\"\<Random drift, in a cline\>\"", 
                  "\"\<Recursions: iterating a cline\>\"", 
                  "\"\<RandomDrift\>\""},
                {"\"\<Random drift, of allele frequencies\>\"", 
                  "\"\<Allele frequencies: drift\>\"", "None"},
                {"\"\<Random drift, of allele frequencies\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<RandomDrift\>\""},
                {"\"\<Random drift, of allele frequencies\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<RandomDrift\>\""},
                {"\"\<Random drift, of genotype frequencies\>\"", 
                  "\"\<Recursions: drift\>\"", "None"},
                {"\"\<Random drift, of genotype frequencies\>\"", 
                  "\"\<Recursions: iterating one deme\>\"", 
                  "\"\<RandomDrift\>\""},
                {"\"\<RandomDrift, option for IterateExact\>\"", 
                  "\"\<Allele frequencies: iterating a cline\>\"", 
                  "\"\<RandomDrift\>\""},
                {"\"\<RandomDrift, option for IterateExact\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<RandomDrift\>\""},
                {"\"\<RandomDrift, option for IterateExact\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<RandomDrift\>\""},
                {"\"\<RandomDrift, option for IterateExact\>\"", 
                  "\"\<Recursions: iterating a cline\>\"", 
                  "\"\<RandomDrift\>\""},
                {"\"\<RandomDrift, option for NewGametes\>\"", 
                  "\"\<Allele frequencies:reproduction\>\"", 
                  "\"\<RandomDrift\>\""},
                {"\"\<RandomDrift, option for NewGametes\>\"", 
                  "\"\<Recursions:reproduction\>\"", "\"\<RandomDrift\>\""},
                {"\"\<Random drift, population disequilibrium\>\"", 
                  "\"\<Expectations\>\"", 
                  "\"\<PopulationDisequilibrium\>\""},
                {"\"\<Random drift, population expectation\>\"", 
                  "\"\<Expectations\>\"", "\"\<PopulationExpectation\>\""},
                {"\"\<Random drift, population expectations\>\"", 
                  "\"\<Expectations\>\"", "None"},
                {"\"\<Random drift, Wright-Fisher sampling\>\"", 
                  "\"\<Wright-Fisher sampling\>\"", "None"},
                {"\"\<RandomFamilies\>\"", "\"\<Random families\>\"", 
                  "\"\<RandomFamilies\>\""},
                {"\"\<RandomFamily\>\"", "\"\<Generating families\>\"", 
                  "\"\<RandomFamily\>\""},
                {"\"\<RandomFamily, segregation ratio\>\"", 
                  "\"\<Generating families\>\"", "\"\<SegregationRatio\>\""},
                {"\"\<Random genealogies, population bottlenecks\>\"", 
                  "\"\<Population bottlenecks\>\"", "None"},
                {"\"\<RandomGenealogy\>\"", "\"\<Drawing a genealogy\>\"", 
                  "\"\<RandomGenealogy\>\""},
                {"\"\<RandomGenealogy, for ancestral graphs\>\"", 
                  "\"\<Random ancestral graphs\>\"", 
                  "\"\<RandomGenealogy\>\""},
                {"\"\<RandomList\>\"", "\"\<Random lists\>\"", 
                  "\"\<RandomList\>\""},
                {"\"\<RandomList, sampling without replacement\>\"", 
                  "\"\<Random lists\>\"", "\"\<Replace\>\""},
                {"\"\<Random lists, compiled\>\"", "\"\<Random lists\>\"", 
                  "\"\<Compiled\>\""},
                {"\"\<RandomMating\>\"", 
                  "\"\<Recombination in admixture models\>\"", 
                  "\"\<RandomMating\>\""},
                {"\"\<RandomMultinomial\>\"", 
                  "\"\<Multinomial distribution\>\"", 
                  "\"\<RandomMultinomial\>\""},
                {"\"\<RandomPreviousFamily\>\"", "\"\<Random families\>\"", 
                  "\"\<RandomPreviousFamily\>\""},
                {"\"\<Random sampling\>\"", 
                  "\"\<Introduction to random drift\>\"", 
                  "\"\<Random sampling\>\""},
                {"\"\<Random sampling, example in estimating D\>\"", 
                  "\"\<Sampling example\>\"", "None"},
                {"\"\<Random sampling, of genealogies\>\"", 
                  "\"\<Sampling genealogies\>\"", "None"},
                {"\"\<RandomSet\>\"", "\"\<Random sets\>\"", 
                  "\"\<RandomSet\>\""},
                {"\"\<Random union\>\"", "\"\<Random union\>\"", 
                  "\"\<RandomUnion\>\""},
                {"\"\<Random union\>\"", "\"\<Sexual selection\>\"", 
                  "\"\<Random union\>\""},
                {"\"\<RandomUnion\>\"", "\"\<Random union\>\"", 
                  "\"\<RandomUnion\>\""},
                {"\"\<Random union, in admixture models\>\"", 
                  "\"\<Recombination in admixture models\>\"", 
                  "\"\<RandomUnionObsolete\>\""},
                {"\"\<Random union, in admixture models\>\"", 
                  "\"\<Recombination in admixture models\>\"", 
                  "\"\<RandomUnionObsolete\>\""},
                {"\"\<RandomUnionMethod\>\"", 
                  "\"\<Options for DoReplicates\>\"", "\"\<MethodC\>\""},
                {"\"\<RandomUnionObsolete\>\"", "\"\<Random union\>\"", 
                  "\"\<RandomUnion\>\""},
                {"\"\<Random walk, in estimating D\>\"", 
                  "\"\<Random walk\>\"", "None"},
                {"\"\<RecombinantLineages, in ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<RecombinantLineages\>\""},
                {"\"\<Recombination\>\"", "\"\<Recombination\>\"", 
                  "\"\<Recombination\>\""},
                {"\"\<Recombination\>\"", "\"\<Sexual selection\>\"", 
                  "\"\<Recombination\>\""},
                {"\"\<Recombination, across several linked loci\>\"", 
                  "\"\<Recombination\>\"", "\"\<NetRecombination\>\""},
                {"\"\<Recombination, between linked loci\>\"", 
                  "\"\<Recombination\>\"", "\"\<LinkedRecombination\>\""},
                {"\"\<Recombination, context-dependent\>\"", 
                  "\"\<Recombination\>\"", 
                  "\"\<Context-dependent recombination\>\""},
                {"\"\<RecombinationEvents, in ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<RecombinationEvents\>\""},
                {"\"\<Recombination, genotype-dependent\>\"", 
                  "\"\<Recombination\>\"", 
                  "\"\<Genotype-dependent recombination\>\""},
                {"\"\<Recombination, in admixture models\>\"", 
                  "\"\<Recombination in admixture models\>\"", 
                  "\"\<Recombined\>\""},
                {"\"\<Recombination, no linkage\>\"", 
                  "\"\<Recombination\>\"", "\"\<UnlinkedRecombination\>\""},
                {
                  "\"\<RecombinationRate, \[GothicR], \[AliasIndicator]gor\
\[AliasIndicator]\>\"", "\"\<Recombination\>\"", 
                  "\"\<RecombinationRate\>\""},
                {
                  "\"\<RecombinationSet, \[DoubleStruckCapitalR], \
\[AliasIndicator]dsR\[AliasIndicator]\>\"", "\"\<Notation reference\>\"", 
                  "None"},
                {
                  "\"\<RecombinationSet, \[DoubleStruckCapitalR], \
\[AliasIndicator]dsR\[AliasIndicator]\>\"", "\"\<Recombination\>\"", 
                  "\"\<RecombinationSet\>\""},
                {"\"\<Recombined\>\"", 
                  "\"\<Recombination in admixture models\>\"", 
                  "\"\<Recombined\>\""},
                {"\"\<RecombineLineage\>\"", 
                  "\"\<Coalescence and recombination\>\"", 
                  "\"\<RecombineLineage\>\""},
                {"\"\<ReducedData\>\"", "\"\<Simplifying a dataset\>\"", 
                  "\"\<ReducedData\>\""},
                {"\"\<ReferencePointMean\>\"", "\"\<Reference points\>\"", 
                  "\"\<ReferencePointMean\>\""},
                {"\"\<ReferencePointMean, cytoplasmic inheritance\>\"", 
                  "\"\<Cytoplasmic inheritance\>\"", 
                  "\"\<ReferencePointMean\>\""},
                {"\"\<ReferencePointMean, cytoplasmic inheritance\>\"", 
                  "\"\<Reference points\>\"", "\"\<CytoplasmicLoci\>\""},
                {"\"\<ReferencePointMean, paternal inheritance\>\"", 
                  "\"\<Cytoplasmic inheritance\>\"", 
                  "\"\<ReferencePointMean\>\""},
                {"\"\<ReferencePointMean, paternal inheritance\>\"", 
                  "\"\<Reference points\>\"", "\"\<PaternalLoci\>\""},
                {"\"\<ReferencePointMean, sex-linkage\>\"", 
                  "\"\<Reference points\>\"", "\"\<XLinkedLoci\>\""},
                {"\"\<ReferencePointMean, sex-linkage\>\"", 
                  "\"\<Reference points\>\"", "\"\<ZLinkedLoci\>\""},
                {"\"\<ReferencePointMean, sex-linkage\>\"", 
                  "\"\<Sex linkage\>\"", "\"\<ReferencePointMean\>\""},
                {"\"\<ReferencePointSame\>\"", "\"\<Reference points\>\"", 
                  "\"\<ReferencePointSame\>\""},
                {"\"\<ReferencePointZero\>\"", "\"\<Reference points\>\"", 
                  "\"\<ReferencePointZero\>\""},
                {
                  "\"\<ReferencePoint, \[WeierstrassP], \[AliasIndicator]wp\
\[AliasIndicator]\>\"", "\"\<Allelic state\>\"", "\"\<ReferencePoint\>\""},
                {"\"\<References, for ancestral graphs\>\"", 
                  "\"\<Ancestral graph references\>\"", "None"},
                {"\"\<Reference values\>\"", "\"\<Allelic state\>\"", 
                  "\"\<ReferencePoint\>\""},
                {"\"\<Reference values\>\"", 
                  "\"\<Multilocus MS relation\>\"", 
                  "\"\<Reference values\>\""},
                {"\"\<Reference values, as used in Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS relation\>\"", 
                  "\"\<Reference values\>\""},
                {"\"\<Reference values, Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS\>\"", 
                  "\"\<Describing genotypes and populations\>\""},
                {"\"\<RemoveTag\>\"", "\"\<Tagging sets\>\"", 
                  "\"\<RemoveTag\>\""},
                {"\"\<Repeat\>\"", "\"\<Repeated elements\>\"", 
                  "\"\<Repeat\>\""},
                {"\"\<Replace\>\"", "\"\<Random lists\>\"", 
                  "\"\<Replace\>\""},
                {"\"\<|., ReplaceAllSpecial\>\"", "\"\<|., ||.\>\"", 
                  "\"\<ReplaceAllSpecial\>\""},
                {"\"\<ReplaceAllSpecial, |.\>\"", "\"\<|., ||.\>\"", 
                  "\"\<ReplaceAllSpecial\>\""},
                {"\"\<||., ReplaceRepeatedSpecial\>\"", "\"\<|., ||.\>\"", 
                  "\"\<ReplaceAllSpecial\>\""},
                {"\"\<ReplaceRepeatedSpecial, ||.\>\"", "\"\<|., ||.\>\"", 
                  "\"\<ReplaceRepeatedSpecial\>\""},
                {"\"\<Representations, converting between\>\"", 
                  "\"\<Simulating individuals:converting\>\"", "None"},
                {"\"\<Representations,of populations\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<Representing the population\>\""},
                {"\"\<Reproduction, in numerical models\>\"", 
                  "\"\<Recursions:reproduction\>\"", "None"},
                {"\"\<Reverse\>\"", "\"\<Sorting\>\"", "\"\<Reverse\>\""},
                {"\"\<RootedGenealogy\>\"", 
                  "\"\<Structure of genealogies\>\"", 
                  "\"\<RootedGenealogy\>\""},
                {"\"\<RootEvents, in ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<RootEvents\>\""},
                {"\"\<RootEvents, in ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<RootEvents\>\""},
                {"\"\<Rootings, of a genealogy, possible\>\"", 
                  "\"\<Rooting a genealogy\>\"", "\"\<PossibleRootings\>\""},
                {"\"\<Root, of a genealogy\>\"", 
                  "\"\<Rooting a genealogy\>\"", "None"},
                {"\"\<Root, of a genealogy\>\"", 
                  "\"\<Structure of genealogies\>\"", 
                  "\"\<RootedGenealogy\>\""},
                {"\"\<Rules\>\"", "\"\<Stabilising selection\>\"", 
                  "\"\<Rules\>\""},
                {"\"\<Rules, non-evaluation of\>\"", "\"\<Bugs\>\"", 
                  "\"\<Applying rules\>\""},
                {"\"\<SampleCovariance\>\"", "\"\<Sampling\>\"", 
                  "\"\<SampleCovariance\>\""},
                {"\"\<SampleIndividuals\>\"", "\"\<Sampling individuals\>\"", 
                  "\"\<SampleIndividuals\>\""},
                {"\"\<SamplePartition\>\"", "\"\<Set partitions\>\"", 
                  "\"\<SamplePartition\>\""},
                {"\"\<Sampling, without replacement\>\"", 
                  "\"\<Random lists\>\"", "\"\<Replace\>\""},
                {"\"\<Scripts and faces, as used in Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS relation\>\"", 
                  "\"\<Scripts and faces\>\""},
                {"\"\<Segments, in ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", "\"\<Segments\>\""},
                {"\"\<SegmentStyle, option for PlotSegments\>\"", 
                  "\"\<Plotting ancestral graphs\>\"", 
                  "\"\<SegmentStyle\>\""},
                {"\"\<SegregationRatio\>\"", "\"\<Generating families\>\"", 
                  "\"\<SegregationRatio\>\""},
                {"\"\<SegregationRatio\>\"", 
                  "\"\<Genotype probabilities\>\"", 
                  "\"\<SegregationRatio\>\""},
                {
                  "\"\<SelectContext, \[CircleDot], \[AliasIndicator]c.\
\[AliasIndicator]\>\"", "\"\<Selecting contexts\>\"", 
                  "\"\<SelectContexts\>\""},
                {"\"\<SelectIndividuals\>\"", "\"\<Selecting subsets\>\"", 
                  "\"\<SelectIndividuals\>\""},
                {"\"\<Selection\>\"", "\"\<Selection\>\"", 
                  "\"\<Selection\>\""},
                {
                  "\"\<Selection coefficients, as defined in Kirkpatrick et \
al.\>\"", "\"\<Multilocus MS relation\>\"", "\"\<Permutations\>\""},
                {"\"\<Selection coefficients, making\>\"", 
                  "\"\<Phenotypes\>\"", "\"\<Multiple alleles\>\""},
                {"\"\<Selection coefficients, with multiple alleles\>\"", 
                  "\"\<Fitness\>\"", "\"\<Multiple alleles\>\""},
                {"\"\<Selection coefficients, with multiple alleles\>\"", 
                  "\"\<Phenotypes\>\"", "\"\<Multiple alleles\>\""},
                {
                  "\"\<SelectionCoefficient, \[GothicA], \[AliasIndicator]goa\
\[AliasIndicator]\>\"", "\"\<Fitness\>\"", "\"\<SelectionCoefficient\>\""},
                {
                  "\"\<SelectionCoefficient, \[GothicA], \[AliasIndicator]goa\
\[AliasIndicator]\>\"", "\"\<Selection\>\"", "\"\<SelectionCoefficient\>\""},
                {"\"\<SelectionExact, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: fitnesses\>\"", 
                  "\"\<SelectionExact\>\""},
                {"\"\<SelectionExact, for genotype frequencies\>\"", 
                  "\"\<Recursions: fitnesses\>\"", "\"\<SelectionExact\>\""},
                {"\"\<SelectionExact, for individuals\>\"", 
                  "\"\<Simulating individuals: fitnesses\>\"", 
                  "\"\<SelectionExact\>\""},
                {"\"\<SelectionExact, for symmetric model\>\"", 
                  "\"\<Symmetric model: fitnesses\>\"", 
                  "\"\<SelectionExact\>\""},
                {"\"\<Selection, in symmetric model\>\"", 
                  "\"\<Symmetric model: fitnesses\>\"", 
                  "\"\<SelectionExact\>\""},
                {"\"\<Selection, Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS\>\"", "\"\<Phenotypes\>\""},
                {"\"\<Selection, on allele frequencies\>\"", 
                  "\"\<Allele frequencies: fitnesses\>\"", "None"},
                {"\"\<Selection on diploids, a method to avoid\>\"", 
                  "\"\<A method to avoid\>\"", "None"},
                {"\"\<Selection on diploids, cautionary notes\>\"", 
                  "\"\<Cautionary notes\>\"", "None"},
                {"\"\<Selection on diploids, complete life cycle\>\"", 
                  "\"\<Complete life cyle\>\"", "None"},
                {"\"\<Selection on diploids, explaining the rules\>\"", 
                  "\"\<Explaining the rules\>\"", "None"},
                {"\"\<Selection on diploids, introduction\>\"", 
                  "\"\<Introduction to selection on diploids\>\"", "None"},
                {"\"\<Selection on diploids, life cycle\>\"", 
                  "\"\<Life cycle\>\"", "None"},
                {"\"\<Selection, on genotype frequencies\>\"", 
                  "\"\<Recursions: fitnesses\>\"", "None"},
                {"\"\<Selection, on multiple alleles\>\"", 
                  "\"\<Selection\>\"", "\"\<Multiple alleles\>\""},
                {
                  "\"\<SelectionRate, \[GothicS],\[AliasIndicator]gos\
\[AliasIndicator]\>\"", "\"\<Slow change\>\"", "\"\<SelectionRate\>\""},
                {"\"\<Selection, technicalities\>\"", "\"\<Selection\>\"", 
                  "\"\<Technicalities\>\""},
                {"\"\<Selection, truncation\>\"", 
                  "\"\<Simulating individuals: fitnesses\>\"", 
                  "\"\<TruncationSelection\>\""},
                {"\"\<Selection, with individuals\>\"", 
                  "\"\<Simulating individuals: fitnesses\>\"", 
                  "\"\<SelectionExact\>\""},
                {"\"\<Selection, with two alleles\>\"", "\"\<Fitness\>\"", 
                  "\"\<Two alleles\>\""},
                {"\"\<Selection, with two alleles\>\"", "\"\<Phenotypes\>\"", 
                  "\"\<Two alleles\>\""},
                {"\"\<SelectLoci\>\"", "\"\<Selecting subsets\>\"", 
                  "\"\<SelectLoci\>\""},
                {"\"\<Selfing\>\"", "\"\<Selfing\>\"", "None"},
                {"\"\<Separate\>\"", "\"\<Tagging sets\>\"", 
                  "\"\<Separate\>\""},
                {"\"\<Servedio, Maria\>\"", "\"\<Haploid selection\>\"", 
                  "\"\<Servedio\>\""},
                {"\"\<Set manipulation, overview\>\"", 
                  "\"\<Overview of set manipulation\>\"", "None"},
                {
                  "\"\<Set, of all positions affecting a trait, \
\[DoubleStruckCapitalZ], \[AliasIndicator]dsZ\[AliasIndicator]\>\"", 
                  "\"\<Notation reference\>\"", "None"},
                {
                  "\"\<Set, of all positions in genome, \
\[DoubleStruckCapitalG], \[AliasIndicator]dsG\[AliasIndicator]\>\"", 
                  "\"\<Notation reference\>\"", "None"},
                {"\"\<SetOfCombinations\>\"", "\"\<Set combinations\>\"", 
                  "\"\<SetOfCombinations\>\""},
                {"\"\<SetPartition\>\"", "\"\<Set partitions\>\"", 
                  "\"\<SetPartition\>\""},
                {"\"\<Sets of loci, as used in Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS relation\>\"", "\"\<Sets of loci\>\""},
                {"\"\<Sex\>\"", "\"\<Life cycle\>\"", "\"\<Sex\>\""},
                {"\"\<Sex linkage\>\"", "\"\<Non-Mendelian inheritance\>\"", 
                  "\"\<XLinkedLoci\>\""},
                {"\"\<Sex linkage\>\"", "\"\<Reference points\>\"", 
                  "\"\<XLinkedLoci\>\""},
                {"\"\<Sex linkage, examples of\>\"", "\"\<Sex linkage\>\"", 
                  "None"},
                {"\"\<SexOfOrigin\>\"", "\"\<Life cycle\>\"", 
                  "\"\<SexOfOrigin\>\""},
                {"\"\<Sexual selection\>\"", "\"\<Sexual selection\>\"", 
                  "\"\<Sexual selection\>\""},
                {"\"\<Sexual selection, and migration\>\"", 
                  "\"\<Migration\>\"", "\"\<Sexual selection\>\""},
                {"\"\<Sexual selection, complete life cycle\>\"", 
                  "\"\<Sexual selection\>\"", "\"\<Complete cycle\>\""},
                {"\"\<Sexual selection, defining fitnesses\>\"", 
                  "\"\<Sexual selection\>\"", "\"\<Defining fitnesses\>\""},
                {"\"\<Sexual selection, Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS\>\"", 
                  "\"\<Sexual selection by female choice\>\""},
                {"\"\<Sexual selection, Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS\>\"", 
                  "\"\<Sexual selection by female choice\>\""},
                {"\"\<Sexual selection,on haploids\>\"", 
                  "\"\<Haploid selection\>\"", "None"},
                {"\"\<Sexual selection, recombination\>\"", 
                  "\"\<Sexual selection\>\"", "\"\<Recombination\>\""},
                {"\"\<Sexual selection, subtle problem\>\"", 
                  "\"\<Sexual selection\>\"", "\"\<subtle problem\>\""},
                {"\"\<ShortContext\>\"", "\"\<Abbreviating contexts\>\"", 
                  "\"\<ShortContext\>\""},
                {"\"\<SigmaMatrix\>\"", 
                  "\"\<Symmetric stability: one deme\>\"", 
                  "\"\<SigmaMatrix\>\""},
                {"\"\<SignMask\>\"", "\"\<Internal functions\>\"", 
                  "\"\<SignMask\>\""},
                {"\"\<SimplifyAddUp\>\"", "\"\<AddUp\>\"", 
                  "\"\<SimplifyAddUp\>\""},
                {"\"\<SimplifyAddUpQ\>\"", "\"\<AddUp\>\"", 
                  "\"\<SimplifyAddUpQ\>\""},
                {"\"\<SimplifyFamilies\>\"", "\"\<Probabilities\>\"", 
                  "\"\<SimplifyFamilies\>\""},
                {"\"\<Simulating individuals, recursions\>\"", 
                  "\"\<Simulating individuals: iterating one deme\>\"", 
                  "None"},
                {"\"\<Simulating individuals, representation\>\"", 
                  "\"\<Simulating individuals: Describing populations\>\"", 
                  "None"},
                {"\"\<Simulating individuals, reproduction\>\"", 
                  "\"\<Simulating individuals: reproduction\>\"", "None"},
                {"\"\<SizeOfGenealogyPlot\>\"", 
                  "\"\<Plotting genealogies\>\"", 
                  "\"\<SizeOfGenealogyPlot\>\""},
                {"\"\<Slatkin & Excoffier 1996\>\"", "\"\<References\>\"", 
                  "\"\<Slatkin & Excoffier 1996\>\""},
                {"\"\<SlowChange\>\"", "\"\<Slow change\>\"", 
                  "\"\<SlowChange\>\""},
                {"\"\<SortByClass\>\"", 
                  "\"\<Representing the population\>\"", 
                  "\"\<SortByClass\>\""},
                {"\"\<SortByClass, genotype frequencies\>\"", 
                  "\"\<Recursions: representation\>\"", 
                  "\"\<SortByClass\>\""},
                {"\"\<SortByHead\>\"", "\"\<Sorting\>\"", 
                  "\"\<SortByHead\>\""},
                {"\"\<SpatialCovariance\>\"", "\"\<Sampling\>\"", 
                  "\"\<SpatialCovariance\>\""},
                {"\"\<Spatially varying selection, in symmetric model\>\"", 
                  "\"\<Spatially varying selection\>\"", "None"},
                {"\"\<Special notation\>\"", "\"\<Special notation\>\"", 
                  "\"\<Defining notation\>\""},
                {"\"\<SplitSet\>\"", "\"\<Set partitions\>\"", 
                  "\"\<SplitSet\>\""},
                {"\"\<Stabilising selection, change in D\>\"", 
                  "\"\<Stabilising selection\>\"", "\"\<Change in D\>\""},
                {"\"\<Stabilising selection, change in mean\>\"", 
                  "\"\<Stabilising selection\>\"", "\"\<Change in mean\>\""},
                {"\"\<Stabilising selection, defining fitness\>\"", 
                  "\"\<Stabilising selection\>\"", 
                  "\"\<Defining fitness\>\""},
                {"\"\<Stabilising selection,Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS\>\"", 
                  "\"\<Natural selection on an additive polygenic \
trait\>\""},
                {"\"\<Stabilising selection,mean fitness\>\"", 
                  "\"\<Stabilising selection\>\"", "\"\<Mean fitness\>\""},
                {"\"\<Stabilising selection, new mean\>\"", 
                  "\"\<Stabilising selection\>\"", "\"\<New mean\>\""},
                {"\"\<Stabilising selection, new mean fitness\>\"", 
                  "\"\<Stabilising selection\>\"", 
                  "\"\<New mean fitness\>\""},
                {"\"\<StabilityDirect, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: stability\>\"", 
                  "\"\<StabilityDirect\>\""},
                {"\"\<StabilityDirect, for genotype frequencies\>\"", 
                  "\"\<Example: stability\>\"", "\"\<StabilityDirect\>\""},
                {"\"\<StabilityK\>\"", 
                  "\"\<Symmetric stability: a cline\>\"", 
                  "\"\<StabilityK\>\""},
                {"\"\<StabilityK\>\"", 
                  "\"\<Symmetric stability: one deme\>\"", 
                  "\"\<StabilityK\>\""},
                {"\"\<StabilityKTable\>\"", 
                  "\"\<Symmetric stability: faster algorithms\>\"", 
                  "\"\<StabilityKTable\>\""},
                {"\"\<StabilityMatrix\>\"", 
                  "\"\<Making a stability matrix\>\"", 
                  "\"\<StabilityMatrix\>\""},
                {"\"\<Stability, of numerical models\>\"", 
                  "\"\<Allele frequencies: stability\>\"", "None"},
                {"\"\<Stability, of numerical models\>\"", 
                  "\"\<Example: stability\>\"", "None"},
                {"\"\<Stability, of symmetric model\>\"", 
                  "\"\<Symmetric stability: outline\>\"", "None"},
                {"\"\<Stages\>\"", "\"\<Life cycle\>\"", "\"\<Stages\>\""},
                {"\"\<Stages, as used in Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS relation\>\"", 
                  "\"\<Stages and contexts\>\""},
                {
                  "\"\<Stage, \[Sampi], \
\[AliasIndicator]sa\[AliasIndicator]\>\"", "\"\<Genes and contexts\>\"", 
                  "\"\<Stages\>\""},
                {"\"\<StandardPartition\>\"", "\"\<Set partitions\>\"", 
                  "\"\<StandardPartition\>\""},
                {"\"\<StandardPartitionQ\>\"", "\"\<Set partitions\>\"", 
                  "\"\<StandardPartitionQ\>\""},
                {"\"\<StartingStepSize\>\"", 
                  "\"\<Options for StructuredMLE\>\"", 
                  "\"\<StartingStepSize\>\""},
                {"\"\<Stepping-stone migration, with individuals\>\"", 
                  "\"\<Simulating individuals:migration\>\"", 
                  "\"\<Nearest-neighbour migration\>\""},
                {"\"\<Stepping-stone model, for allele frequencies\>\"", 
                  "\"\<Allele frequencies:migration\>\"", 
                  "\"\<Nearest-neighbour migration\>\""},
                {"\"\<Stepping-stone model, for genotype frequencies\>\"", 
                  "\"\<Recursions:migration\>\"", 
                  "\"\<Nearest-neighbour migration\>\""},
                {"\"\<Stepping-stone model, for symmetric model\>\"", 
                  "\"\<Symmetric model: migration\>\"", 
                  "\"\<Nearest-neighbour migration\>\""},
                {"\"\<StoreExact, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<StoreExact\>\""},
                {"\"\<StoreExact, for allele frequency clines\>\"", 
                  "\"\<Allele frequencies: iterating a cline\>\"", 
                  "\"\<StoreExact\>\""},
                {"\"\<StoreExact, for clines in symmetric model\>\"", 
                  "\"\<Symmetric model: iterating a cline\>\"", 
                  "\"\<StoreExact\>\""},
                {"\"\<StoreExact, for clines with individuals\>\"", 
                  "\"\<Simulating individuals: iterating a cline\>\"", 
                  "\"\<StoreExact\>\""},
                {"\"\<StoreExact, for genotype frequencies\>\"", 
                  "\"\<Recursions: iterating one deme\>\"", 
                  "\"\<StoreExact\>\""},
                {"\"\<StoreExact, for genotype frequency clines\>\"", 
                  "\"\<Recursions: iterating a cline\>\"", 
                  "\"\<StoreExact\>\""},
                {"\"\<StoreExact, for individuals\>\"", 
                  "\"\<Simulating individuals: iterating one deme\>\"", 
                  "\"\<StoreExact\>\""},
                {"\"\<StoreExact, for symmetric model\>\"", 
                  "\"\<Symmetric model: iterating one deme\>\"", 
                  "\"\<StoreExact\>\""},
                {"\"\<StoreResults, option for GameteTable\>\"", 
                  "\"\<Recursions:reproduction\>\"", "\"\<StoreResults\>\""},
                {"\"\<StoreResults, option for GameteTable\>\"", 
                  "\"\<Symmetric model: reproduction\>\"", 
                  "\"\<StoreResults\>\""},
                {"\"\<StoreResults, option for NewGametes\>\"", 
                  "\"\<Symmetric model: reproduction\>\"", 
                  "\"\<StoreResults\>\""},
                {"\"\<StoreResults, use when compiling\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<StoreResults\>\""},
                {"\"\<StoreResults, use when compiling\>\"", 
                  "\"\<Recursions: compiling\>\"", "\"\<StoreResults\>\""},
                {"\"\<StoreResults, use when compiling\>\"", 
                  "\"\<Symmetric model: iterating one deme\>\"", 
                  "\"\<StoreResults (compiling)\>\""},
                {"\"\<StructuredArray\>\"", "\"\<Useful functions\>\"", 
                  "\"\<StructuredArray\>\""},
                {"\"\<StructuredInitialParameters\>\"", 
                  "\"\<Initial parameters\>\"", 
                  "\"\<StructuredInitialParameters\>\""},
                {"\"\<StructuredLogLikelihood\>\"", 
                  "\"\<Likelihood of a structured model\>\"", 
                  "\"\<StructuredLogLikelihood\>\""},
                {"\"\<StructuredMLE\>\"", 
                  "\"\<Likelihood of a structured model\>\"", 
                  "\"\<StructuredMLE\>\""},
                {"\"\<StructuredMLE\>\"", 
                  "\"\<Options for StructuredMLE\>\"", 
                  "\"\<StructuredMLE\>\""},
                {"\"\<StructuredModel\>\"", "\"\<Useful functions\>\"", 
                  "\"\<StructuredModel\>\""},
                {"\"\<StructuredModelReduce\>\"", 
                  "\"\<Simplifying a model\>\"", 
                  "\"\<StructuredModelReduce\>\""},
                {"\"\<Structured models, example\>\"", "\"\<Example data\>\"",
                   "None"},
                {"\"\<Structured models, hierarchical analysis\>\"", 
                  "\"\<Hierarchical analysis\>\"", "None"},
                {"\"\<StructuredParameter\>\"", 
                  "\"\<Structured parameters\>\"", 
                  "\"\<StructuredParameter\>\""},
                {"\"\<StructuredVariance\>\"", 
                  "\"\<Variance components for a structured model\>\"", 
                  "\"\<StructuredVariance\>\""},
                {"\"\<Style sheets, bugs with\>\"", "\"\<Bugs\>\"", 
                  "\"\<Style sheets\>\""},
                {"\"\<Subdivide\>\"", 
                  "\"\<Muddling and subdividing sets\>\"", 
                  "\"\<Subdivide\>\""},
                {"\"\<Subscripts, as written in Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS relation\>\"", 
                  "\"\<Sets in subscripts\>\""},
                {"\"\<Subsets\>\"", "\"\<Subsets\>\"", "\"\<Subsets\>\""},
                {"\"\<Subsets, option for AddUp\>\"", "\"\<AddUp\>\"", 
                  "\"\<Subsets\>\""},
                {"\"\<Subsets, option for TimesUp\>\"", "\"\<TimesUp\>\"", 
                  "\"\<Subsets\>\""},
                {"\"\<Sums, multiple\>\"", "\"\<AddUp\>\"", 
                  "\"\<Multiple sums\>\""},
                {"\"\<SwapStates\>\"", "\"\<Rooting a genealogy\>\"", 
                  "\"\<SwapStates\>\""},
                {"\"\<Symmetric cline, in allele frequencies\>\"", 
                  "\"\<Allele frequencies: setting up a symmetric cline\>\"", 
                  "None"},
                {"\"\<Symmetric cline, in genotype frequencies\>\"", 
                  "\"\<Recursions:setting up a symmetric cline\>\"", 
                  "\"\<DoubleCline\>\""},
                {"\"\<SymmetricDiploidFrequencies\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<SymmetricDiploidFrequencies\>\""},
                {"\"\<SymmetricHaploidFrequencies\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<SymmetricHaploidFrequencies\>\""},
                {"\"\<Symmetric model, adding a neutral marker\>\"", 
                  "\"\<Adding a neutral gene\>\"", "None"},
                {"\"\<Symmetric model, adding a neutral marker\>\"", 
                  "\"\<Symmetric model: limitations\>\"", "None"},
                {"\"\<Symmetric model, cline example\>\"", 
                  "\"\<Symmetric stability: a cline\>\"", "None"},
                {"\"\<Symmetric model, cline example\>\"", 
                  "\"\<Symmetric stability: spatially varying selection\>\"", 
                  "None"},
                {"\"\<Symmetric model, limitations\>\"", 
                  "\"\<Symmetric model: limitations\>\"", "None"},
                {"\"\<Symmetric model, one deme example\>\"", 
                  "\"\<Symmetric stability: one deme\>\"", "None"},
                {"\"\<Symmetric model,overview\>\"", 
                  "\"\<Symmetric model: genotype frequencies\>\"", "None"},
                {"\"\<Symmetric model, references\>\"", 
                  "\"\<Symmetric model: references\>\"", "None"},
                {"\"\<Symmetric model, reproduction\>\"", 
                  "\"\<Symmetric model: reproduction\>\"", "None"},
                {"\"\<Symmetric model, stability of\>\"", 
                  "\"\<Symmetric stability: outline\>\"", "None"},
                {"\"\<SymmetricNeutralDiploidFrequencies\>\"", 
                  "\"\<Adding a neutral gene\>\"", "None"},
                {"\"\<SymmetricNeutralDiploidFrequencies\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<SymmetricNeutralDiploidFrequencies\>\""},
                {"\"\<SymmetricNeutralHaploidFrequencies\>\"", 
                  "\"\<Adding a neutral gene\>\"", "None"},
                {"\"\<SymmetricNeutralHaploidFrequencies\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<SymmetricNeutralHaploidFrequencies\>\""},
                {"\"\<SymmetricRecombination\>\"", "\"\<Recombination\>\"", 
                  "\"\<SymmetricRecombination\>\""},
                {"\"\<SymmetricRepresentations\>\"", 
                  "\"\<Overview of numerical models\>\"", 
                  "\"\<SymmetricRepresentations\>\""},
                {"\"\<SymmetricSexes\>\"", "\"\<Symmetric sexes\>\"", 
                  "\"\<SymmetricSexes\>\""},
                {"\"\<Symmetrise\>\"", "\"\<Disequilibrium\>\"", 
                  "\"\<Symmetrise\>\""},
                {"\"\<Symmetrise\>\"", "\"\<Symmetrise\>\"", 
                  "\"\<Symmetrise\>\""},
                {"\"\<Table, option for VarianceComponents\>\"", 
                  "\"\<Variance components\>\"", "\"\<Table\>\""},
                {"\"\<Tag\>\"", "\"\<Tagging sets\>\"", "\"\<Tag\>\""},
                {"\"\<Tags, finding\>\"", "\"\<Automatic Numbering\>\"", 
                  "\"\<Finding tags\>\""},
                {"\"\<Tags, setting up hyperlinks to\>\"", 
                  "\"\<Automatic Numbering\>\"", 
                  "\"\<Setting up links to a list of tags\>\""},
                {
                  "\"\<TakeAway, \[Backslash], \
\[AliasIndicator]\\\\:f768\>\"", "\"\<Operations on sets\>\"", 
                  "\"\<TakeAway\>\""},
                {
                  "\"\<TakeAway, \[Backslash], \
\[AliasIndicator]\\\\:f768\>\"", "\"\<TakeAway\>\"", "\"\<TakeAway\>\""},
                {"\"\<TakeOptions\>\"", "\"\<Manipulating options\>\"", 
                  "\"\<TakeOptions\>\""},
                {"\"\<TimesOfEvents, in ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<TimesOfEvents\>\""},
                {"\"\<TimespanOfJunction, in ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<TimespanOfJunction\>\""},
                {"\"\<TimespanOfLineage, in ancestral graphs\>\"", 
                  "\"\<Describing ancestral graphs\>\"", 
                  "\"\<TimespanOfLineage\>\""},
                {"\"\<TimesUp\>\"", "\"\<Operations on sets\>\"", 
                  "\"\<TimesUp\>\""},
                {"\"\<TimesUp\>\"", "\"\<TimesUp\>\"", "\"\<TimesUp\>\""},
                {"\"\<TimesUp, multiple products\>\"", "\"\<TimesUp\>\"", 
                  "\"\<Multiple products\>\""},
                {"\"\<TimesUp, over subsets\>\"", "\"\<TimesUp\>\"", 
                  "\"\<Subsets\>\""},
                {"\"\<Time, T\>\"", "\"\<Global variables\>\"", "\"\<T\>\""},
                {"\"\<ToBaake\>\"", "\"\<Alternative measures\>\"", 
                  "\"\<ToBaake\>\""},
                {"\"\<ToBennett\>\"", "\"\<Alternative measures\>\"", 
                  "\"\<ToBennett\>\""},
                {"\"\<ToBennettExpression\>\"", 
                  "\"\<Alternative measures\>\"", 
                  "\"\<ToBennettExpression\>\""},
                {"\"\<ToCumulants\>\"", "\"\<Multilocus cumulants\>\"", 
                  "\"\<ToCumulants\>\""},
                {"\"\<ToMoments\>\"", "\"\<Multilocus cumulants\>\"", 
                  "\"\<ToMoments\>\""},
                {"\"\<ToPopulationCumulants\>\"", 
                  "\"\<Random drift: cumulants\>\"", 
                  "\"\<ToPopulationCumulants\>\""},
                {"\"\<ToPopulationMoments\>\"", 
                  "\"\<Random drift: cumulants\>\"", 
                  "\"\<ToPopulationMoments\>\""},
                {"\"\<TotalLength\>\"", 
                  "\"\<Distribution of coalescence times\>\"", 
                  "\"\<TotalLength\>\""},
                {"\"\<TotalNumber\>\"", "\"\<Global variables\>\"", 
                  "\"\<TotalNumber\>\""},
                {
                  "\"\<Trait, set of all positions affecting, \
\[DoubleStruckCapitalZ], \[AliasIndicator]dsZ\[AliasIndicator]\>\"", 
                  "\"\<Notation reference\>\"", "None"},
                {"\"\<TransformedRange\>\"", "\"\<Fourier transforms\>\"", 
                  "\"\<TransformedRange\>\""},
                {"\"\<TransformInformation\>\"", 
                  "\"\<Describing genealogies\>\"", 
                  "\"\<TransformInformation\>\""},
                {"\"\<TransmissionRule\>\"", "\"\<Changing contexts\>\"", 
                  "\"\<TransmissionRule\>\""},
                {"\"\<Transmission rules, applying\>\"", 
                  "\"\<Changing contexts\>\"", 
                  "\"\<Applying transmission rules\>\""},
                {"\"\<Transmission rules, as used in Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS relation\>\"", 
                  "\"\<Transmission rules\>\""},
                {
                  "\"\<Transmission rules, distinct from Mathematica \
rules\>\"", "\"\<Changing contexts\>\"", 
                  "\"\<Transmission vs Mathematica rules\>\""},
                {"\"\<Transmission rules, Kirkpatrick et al.\>\"", 
                  "\"\<Multilocus MS\>\"", "\"\<Transmission\>\""},
                {"\"\<TriDiagonalMatrix\>\"", "\"\<Diagonal matrices\>\"", 
                  "\"\<TriDiagonalMatrix\>\""},
                {"\"\<TruncationSelection, option for NewGametes\>\"", 
                  "\"\<Simulating individuals: reproduction\>\"", 
                  "\"\<TruncationSelection\>\""},
                {"\"\<TruncationSelection,option for SelectionExact\>\"", 
                  "\"\<Simulating individuals: fitnesses\>\"", 
                  "\"\<TruncationSelection\>\""},
                {"\"\<T, time\>\"", "\"\<Global variables\>\"", "\"\<T\>\""},
                {"\"\<Turelli and Barton 1994\>\"", 
                  "\"\<Multilocus references\>\"", 
                  "\"\<Turelli and Barton 1994\>\""},
                {"\"\<Turelli & Barton 1994\>\"", "\"\<References\>\"", 
                  "\"\<Turelli & Barton 1994\>\""},
                {"\"\<Two alleles\>\"", "\"\<Two alleles\>\"", 
                  "\"\<Biallelic\>\""},
                {"\"\<Two alleles, selection coefficients\>\"", 
                  "\"\<Fitness\>\"", "\"\<Two alleles\>\""},
                {"\"\<Two alleles, selection coefficients\>\"", 
                  "\"\<Phenotypes\>\"", "\"\<Two alleles\>\""},
                {"\"\<UMS, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<UMS\>\""},
                {"\"\<UMS,for genotype frequencies\>\"", 
                  "\"\<Recursions: iterating one deme\>\"", "\"\<UMS\>\""},
                {"\"\<UMS, for individuals\>\"", 
                  "\"\<Simulating individuals: iterating one deme\>\"", 
                  "\"\<UMS\>\""},
                {"\"\<UMS, for symmetric model\>\"", 
                  "\"\<Symmetric model: iterating one deme\>\"", 
                  "\"\<UMS\>\""},
                {"\"\<UnionOfGametes\>\"", "\"\<Union of gametes\>\"", 
                  "\"\<UnionOfGametes\>\""},
                {"\"\<UnlinkedRecombination\>\"", "\"\<Recombination\>\"", 
                  "\"\<UnlinkedRecombination\>\""},
                {"\"\<UnrootedGenealogy\>\"", 
                  "\"\<Structure of genealogies\>\"", 
                  "\"\<UnrootedGenealogy\>\""},
                {"\"\<UpperOffDiagonal\>\"", "\"\<Diagonal matrices\>\"", 
                  "\"\<UpperOffDiagonal\>\""},
                {"\"\<USM, for allele frequencies\>\"", 
                  "\"\<Allele frequencies: iterating one deme\>\"", 
                  "\"\<USM\>\""},
                {"\"\<USM,for genotype frequencies\>\"", 
                  "\"\<Recursions: iterating one deme\>\"", "\"\<USM\>\""},
                {"\"\<USM, for individuals\>\"", 
                  "\"\<Simulating individuals: iterating one deme\>\"", 
                  "\"\<USM\>\""},
                {"\"\<USM, for symmetric model\>\"", 
                  "\"\<Symmetric model: iterating one deme\>\"", 
                  "\"\<USM\>\""},
                {"\"\<ValidMatrixQ\>\"", 
                  "\"\<Validity of a mutation matrix\>\"", 
                  "\"\<ValidMatrixQ\>\""},
                {"\"\<VarianceComponents\>\"", 
                  "\"\<Variance components for a structured model\>\"", 
                  "\"\<VarianceComponents\>\""},
                {"\"\<VarianceComponents, Table option\>\"", 
                  "\"\<Variance components\>\"", "\"\<Table\>\""},
                {"\"\<Versions, of applications packages\>\"", 
                  "\"\<Versions\>\"", "None"},
                {"\"\<Wiuf & Hein 1999\>\"", 
                  "\"\<Ancestral graphs introduction\>\"", "None"},
                {"\"\<Wiuf & Hein 1999\>\"", 
                  "\"\<Ancestral graph references\>\"", 
                  "\"\<Wiuf & Hein 1999\>\""},
                {"\"\<WLinkedLoci, example of\>\"", "\"\<Sex linkage\>\"", 
                  "\"\<WLinkedLoci\>\""},
                {"\"\<WLinkedLoci, option for NonMendelian\>\"", 
                  "\"\<Non-Mendelian inheritance\>\"", 
                  "\"\<WLinkedLoci\>\""},
                {"\"\<WLinkedLoci, reference points\>\"", 
                  "\"\<Reference points\>\"", "\"\<WLinkedLoci\>\""},
                {"\"\<Wright-Fisher sampling\>\"", 
                  "\"\<Wright-Fisher sampling\>\"", "None"},
                {"\"\<X, AllelicState\>\"", "\"\<Allelic state\>\"", 
                  "\"\<AllelicState\>\""},
                {"\"\<XLinkedLoci, example of\>\"", "\"\<Sex linkage\>\"", 
                  "\"\<XLinkedLoci\>\""},
                {"\"\<XLinkedLoci, option for NonMendelian\>\"", 
                  "\"\<Non-Mendelian inheritance\>\"", 
                  "\"\<XLinkedLoci\>\""},
                {"\"\<XLinkedLoci, reference points\>\"", 
                  "\"\<Reference points\>\"", "\"\<XLinkedLoci\>\""},
                {"\"\<YLinkedLoci, example of\>\"", "\"\<Sex linkage\>\"", 
                  "\"\<YLinkedLoci\>\""},
                {"\"\<YLinkedLoci, option for NonMendelian\>\"", 
                  "\"\<Non-Mendelian inheritance\>\"", 
                  "\"\<YLinkedLoci\>\""},
                {"\"\<YLinkedLoci, reference points\>\"", 
                  "\"\<Reference points\>\"", "\"\<YLinkedLoci\>\""},
                {"\"\<ZLinkedLoci, example of\>\"", "\"\<Sex linkage\>\"", 
                  "\"\<ZLinkedLoci\>\""},
                {"\"\<ZLinkedLoci, option for NonMendelian\>\"", 
                  "\"\<Non-Mendelian inheritance\>\"", 
                  "\"\<ZLinkedLoci\>\""},
                {"\"\<ZLinkedLoci, reference points\>\"", 
                  "\"\<Reference points\>\"", "\"\<ZLinkedLoci\>\""},
                {
                  "\"\<Zygotes, \[GothicCapitalZ], \[AliasIndicator]goZ\
\[AliasIndicator]\>\"", "\"\<Life cycle\>\"", "\"\<Zygotes\>\""},
                {
                  "\"\<Zygotes, \[GothicCapitalZ], \[AliasIndicator]goZ\
\[AliasIndicator]\>\"", "\"\<Notation reference\>\"", "None"},
                {
                  "\"\<Zygotes, \[GothicCapitalZ], \[AliasIndicator]goZ\
\[AliasIndicator]\>\"", "\"\<Notation reference\>\"", "None"},
                {
                  "\"\<\[GothicCapitalA], \[AliasIndicator]goA\
\[AliasIndicator], adults\>\"", "\"\<Life cycle\>\"", "\"\<Adults\>\""},
                {
                  "\"\<\[GothicCapitalA], \[AliasIndicator]goA\
\[AliasIndicator], adults\>\"", "\"\<Notation reference\>\"", "None"},
                {
                  "\"\<\[GothicA], \[AliasIndicator]goa\[AliasIndicator], \
SelectionCoefficient\>\"", "\"\<Fitness\>\"", 
                  "\"\<SelectionCoefficient\>\""},
                {
                  "\"\<\[GothicA], \[AliasIndicator]goa\[AliasIndicator], \
SelectionCoefficient\>\"", "\"\<Selection\>\"", 
                  "\"\<SelectionCoefficient\>\""},
                {
                  "\"\<\[GothicCapitalC], \[AliasIndicator]goC\
\[AliasIndicator], PopulationDisequilibrium\>\"", "\"\<Expectations\>\"", 
                  "\"\<PopulationDisequilibrium\>\""},
                {
                  "\"\<\[GothicCapitalD], \[AliasIndicator]\[GothicCapitalD]\
\[AliasIndicator], Disequilibrium\>\"", "\"\<Disequilibrium\>\"", 
                  "\"\<Disequilibrium\>\""},
                {
                  "\"\<\[GothicCapitalD], \[AliasIndicator]\[GothicCapitalD]\
\[AliasIndicator], Disequilibrium\>\"", 
                  "\"\<Gene & genotype frequencies\>\"", 
                  "\"\<Linkage disequilibrium\>\""},
                {
                  "\"\<\[GothicCapitalD], \[AliasIndicator]\[GothicCapitalD]\
\[AliasIndicator], Disequilibrium\>\"", "\"\<Populations\>\"", 
                  "\"\<Disequilibrium\>\""},
                {
                  "\"\<\[GothicCapitalG], \[AliasIndicator]goG\
\[AliasIndicator], Gametes\>\"", "\"\<Life cycle\>\"", "\"\<Gametes\>\""},
                {
                  "\"\<\[GothicCapitalG], \[AliasIndicator]goG\
\[AliasIndicator], Gametes\>\"", "\"\<Notation reference\>\"", "None"},
                {
                  "\"\<\\!\\(\\(\[GothicCapitalG]\\^*\\)\\), \
\[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, \[GothicCapitalG]new, \
new gametes\>\"", "\"\<Life cycle\>\"", "\"\<Gametes new\>\""},
                {
                  "\"\<\\!\\(\\(\[GothicCapitalG]\\^*\\)\\), \
\[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, \[GothicCapitalG]new, \
new gametes\>\"", "\"\<Notation reference\>\"", "None"},
                {
                  "\"\<\[GothicCapitalH], \[AliasIndicator]goH\
\[AliasIndicator], hermaphrodites\>\"", "\"\<Life cycle\>\"", 
                  "\"\<Hermaphrodites\>\""},
                {
                  "\"\<\[GothicCapitalH], \[AliasIndicator]goH\
\[AliasIndicator], hermaphrodites\>\"", "\"\<Notation reference\>\"", 
                  "None"},
                {
                  "\"\<\[GothicCapitalJ], \[AliasIndicator]goJ\
\[AliasIndicator], juveniles\>\"", "\"\<Life cycle\>\"", 
                  "\"\<Juveniles\>\""},
                {
                  "\"\<\[GothicCapitalJ], \[AliasIndicator]goJ\
\[AliasIndicator], juveniles\>\"", "\"\<Notation reference\>\"", "None"},
                {
                  "\"\<\[GothicK], \[AliasIndicator]gok\[AliasIndicator], \
CumulantDisequilibrium\>\"", "\"\<Populations\>\"", 
                  "\"\<CumulantDisequilibrium\>\""},
                {
                  "\"\<\[GothicCapitalK], \[AliasIndicator]goK\
\[AliasIndicator], CumulantPopulationDisequilibrium\>\"", 
                  "\"\<Introduction to random drift\>\"", 
                  "\"\<Cumulants and moments\>\""},
                {
                  "\"\<\[GothicM], \[AliasIndicator]gom\[AliasIndicator], \
MeanContribution\>\"", "\"\<Populations\>\"", "\"\<MeanContribution\>\""},
                {
                  "\"\<\[GothicP]\[GothicQ], \[AliasIndicator]gop\
\[AliasIndicator]\[AliasIndicator]goq\[AliasIndicator], \
AlleleFrequencyPQ\>\"", "\"\<Populations\>\"", "\"\<AlleleFrequencyPQ\>\""},
                {
                  "\"\<\[GothicP], \[AliasIndicator]gop\[AliasIndicator], \
AlleleFrequencyP\>\"", "\"\<Populations\>\"", "\"\<AlleleFrequencyP\>\""},
                {
                  "\"\<\[GothicQ], \[AliasIndicator]goq\[AliasIndicator], \
AlleleFrequencyQ\>\"", "\"\<Populations\>\"", "\"\<AlleleFrequencyQ\>\""},
                {
                  "\"\<\[GothicR], \[AliasIndicator]gor\[AliasIndicator], \
RecombinationRate\>\"", "\"\<Recombination\>\"", 
                  "\"\<RecombinationRate\>\""},
                {
                  "\"\<\[GothicS],\[AliasIndicator]gos\[AliasIndicator], \
SelectionRate\>\"", "\"\<Slow change\>\"", "\"\<SelectionRate\>\""},
                {
                  "\"\<\[GothicCapitalZ], \[AliasIndicator]goZ\
\[AliasIndicator], Zygotes\>\"", "\"\<Life cycle\>\"", "\"\<Zygotes\>\""},
                {
                  "\"\<\[GothicCapitalZ], \[AliasIndicator]goZ\
\[AliasIndicator], Zygotes\>\"", "\"\<Notation reference\>\"", "None"},
                {
                  "\"\<\[GothicCapitalZ], \[AliasIndicator]goZ\
\[AliasIndicator], Zygotes\>\"", "\"\<Notation reference\>\"", "None"},
                {
                  "\"\<\[DoubleStruckCapitalG], \[AliasIndicator]dsG\
\[AliasIndicator], set of all positions in genome\>\"", 
                  "\"\<Notation reference\>\"", "None"},
                {
                  "\"\<\[DoubleStruckCapitalM], \[AliasIndicator]dsM\
\[AliasIndicator], MigrationSet\>\"", "\"\<Migration\>\"", 
                  "\"\<MigrationSet\>\""},
                {
                  "\"\<\[DoubleStruckCapitalR], \[AliasIndicator]dsR\
\[AliasIndicator], RecombinationSet\>\"", "\"\<Notation reference\>\"", 
                  "None"},
                {
                  "\"\<\[DoubleStruckCapitalR], \[AliasIndicator]dsR\
\[AliasIndicator], RecombinationSet\>\"", "\"\<Recombination\>\"", 
                  "\"\<RecombinationSet\>\""},
                {
                  "\"\<\[DoubleStruckCapitalW], \[AliasIndicator]dsW\
\[AliasIndicator], FitnessSet\>\"", "\"\<Selection\>\"", 
                  "\"\<FitnessSet\>\""},
                {
                  "\"\<\[DoubleStruckCapitalZ], \[AliasIndicator]dsZ\
\[AliasIndicator], set of all positions affecting a trait\>\"", 
                  "\"\<Notation reference\>\"", "None"},
                {
                  "\"\<\[Gamma], \[AliasIndicator]g\[AliasIndicator], \
ExtractGenes\>\"", "\"\<Extracting contexts\>\"", "\"\<ExtractGenes\>\""},
                {
                  "\"\<\[Zeta], \[AliasIndicator]z\[AliasIndicator], \
AllelicDeviation\>\"", "\"\<Allelic state\>\"", "\"\<AllelicDeviation\>\""},
                {
                  "\"\<\[CapitalMu], \[AliasIndicator]M\[AliasIndicator], \
MigrationRate\>\"", "\"\<Notation reference\>\"", "None"},
                {
                  "\"\<\[Chi], \[AliasIndicator]c\[AliasIndicator], \
ExtractContexts\>\"", "\"\<Extracting contexts\>\"", 
                  "\"\<ExtractContexts\>\""},
                {
                  "\"\<\[Sampi], \[AliasIndicator]sa\[AliasIndicator], \
Stage\>\"", "\"\<Genes and contexts\>\"", "\"\<Stages\>\""},
                {"\"\<$MetropolisAdjustment\>\"", 
                  "\"\<Metropolis algorithm\>\"", 
                  "\"\<$MetropolisAdjustment\>\""},
                {
                  "\"\<\[WeierstrassP], \[AliasIndicator]wp\[AliasIndicator], \
ReferencePoint\>\"", "\"\<Allelic state\>\"", "\"\<ReferencePoint\>\""},
                {
                  "\"\<\[LeftDoubleBracketingBar] \
\[RightDoubleBracketingBar], \[AliasIndicator]l||\[AliasIndicator] \
\[AliasIndicator]r||\[AliasIndicator], population expectation\>\"", 
                  "\"\<Expectations\>\"", "\"\<PopulationExpectation\>\""},
                {
                  "\"\<\[CircleDot], \[AliasIndicator]c.\[AliasIndicator], \
SelectContext\>\"", "\"\<Selecting contexts\>\"", "\"\<SelectContexts\>\""},
                {
                  "\"\<\[Backslash], \[AliasIndicator]\\\\:f768, \
TakeAway\>\"", "\"\<Operations on sets\>\"", "\"\<TakeAway\>\""},
                {
                  "\"\<\[Backslash], \[AliasIndicator]\\\\:f768, \
TakeAway\>\"", "\"\<TakeAway\>\"", "\"\<TakeAway\>\""},
                {
                  "\"\<\[Wedge], \[AliasIndicator]^\[AliasIndicator], \
ExactIntersection\>\"", "\"\<ExactIntersection\>\"", 
                  "\"\<ExactIntersection\>\""},
                {
                  "\"\<\[Wedge], \[AliasIndicator]^\[AliasIndicator], \
ExactIntersection\>\"", "\"\<Operations on sets\>\"", 
                  "\"\<ExactIntersection\>\""},
                {
                  "\"\<\[CirclePlus], \[AliasIndicator]c+\[AliasIndicator], \
ChangeContext\>\"", "\"\<Changing contexts\>\"", "\"\<ChangeContext\>\""}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)]}], ";"}]], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{1128, 661},
WindowMargins->{{Automatic, -1}, {28, Automatic}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", 
                  BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    Hyphenation->True,
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Setting up IndexTags"->{
    Cell[1739, 51, 75, 1, 50, "Section",
      CellTags->"Setting up IndexTags"]},
  "Checking files"->{
    Cell[4101, 132, 138, 4, 30, "Section",
      CellTags->"Checking files"]},
  "Converting hyperlinks"->{
    Cell[4841, 160, 92, 1, 50, "Section",
      CellTags->"Converting hyperlinks"]},
  "Index initial set-up"->{
    Cell[16608, 475, 87, 1, 30, "Section",
      CellTags->"Index initial set-up"]},
  "Generating the index"->{
    Cell[150880, 3060, 75, 1, 30, "Section",
      CellTags->"Generating the index"]},
  "|."->{
    Cell[151560, 3085, 247, 11, 23, "Index",
      CellTags->"|."],
    Cell[463504, 15692, 247, 11, 23, "Index",
      CellTags->"|."],
    Cell[779830, 28469, 247, 11, 15, "Index",
      CellTags->"|."],
    Cell[1073106, 40329, 247, 11, 15, "Index",
      CellTags->"|."],
    Cell[1361336, 51980, 247, 11, 23, "Index",
      CellTags->"|."],
    Cell[1639347, 63191, 247, 11, 23, "Index",
      CellTags->"|."]},
  "\\\\"->{
    Cell[151810, 3098, 233, 11, 23, "Index",
      CellTags->"\\\\"],
    Cell[463754, 15705, 233, 11, 23, "Index",
      CellTags->"\\\\"],
    Cell[780080, 28482, 233, 11, 15, "Index",
      CellTags->"\\\\"],
    Cell[1073356, 40342, 233, 11, 15, "Index",
      CellTags->"\\\\"],
    Cell[1361586, 51993, 233, 11, 23, "Index",
      CellTags->"\\\\"],
    Cell[1639597, 63204, 233, 11, 23, "Index",
      CellTags->"\\\\"]},
  "<>"->{
    Cell[152046, 3111, 243, 11, 23, "Index",
      CellTags->"<>"],
    Cell[463990, 15718, 243, 11, 23, "Index",
      CellTags->"<>"],
    Cell[780316, 28495, 243, 11, 15, "Index",
      CellTags->"<>"],
    Cell[1073592, 40355, 243, 11, 15, "Index",
      CellTags->"<>"],
    Cell[1361822, 52006, 243, 11, 23, "Index",
      CellTags->"<>"],
    Cell[1639833, 63217, 243, 11, 23, "Index",
      CellTags->"<>"]},
  "||."->{
    Cell[152292, 3124, 254, 11, 23, "Index",
      CellTags->"||."],
    Cell[464236, 15731, 254, 11, 23, "Index",
      CellTags->"||."],
    Cell[780562, 28508, 254, 11, 15, "Index",
      CellTags->"||."],
    Cell[1073838, 40368, 254, 11, 15, "Index",
      CellTags->"||."],
    Cell[1362068, 52019, 254, 11, 23, "Index",
      CellTags->"||."],
    Cell[1640079, 63230, 254, 11, 23, "Index",
      CellTags->"||."]},
  "AddAncestors"->{
    Cell[152549, 3137, 296, 11, 23, "Index",
      CellTags->"AddAncestors"],
    Cell[464493, 15744, 296, 11, 23, "Index",
      CellTags->"AddAncestors"]},
  "AddCoalescentLineage"->{
    Cell[152848, 3150, 331, 11, 23, "Index",
      CellTags->"AddCoalescentLineage"],
    Cell[464792, 15757, 331, 11, 23, "Index",
      CellTags->"AddCoalescentLineage"]},
  "AddDescendants"->{
    Cell[153182, 3163, 302, 11, 23, "Index",
      CellTags->"AddDescendants"],
    Cell[465126, 15770, 302, 11, 23, "Index",
      CellTags->"AddDescendants"]},
  "AddGenealogy"->{
    Cell[153487, 3176, 271, 10, 23, "Index",
      CellTags->"AddGenealogy"],
    Cell[465431, 15783, 271, 10, 23, "Index",
      CellTags->"AddGenealogy"],
    Cell[780819, 28521, 271, 10, 15, "Index",
      CellTags->"AddGenealogy"],
    Cell[1074095, 40381, 271, 10, 15, "Index",
      CellTags->"AddGenealogy"],
    Cell[1362325, 52032, 271, 10, 23, "Index",
      CellTags->"AddGenealogy"],
    Cell[1640336, 63243, 271, 10, 23, "Index",
      CellTags->"AddGenealogy"]},
  "Additive models"->{
    Cell[153761, 3188, 272, 10, 23, "Index",
      CellTags->"Additive models"],
    Cell[465705, 15795, 272, 10, 23, "Index",
      CellTags->"Additive models"],
    Cell[781093, 28533, 272, 10, 15, "Index",
      CellTags->"Additive models"],
    Cell[1074369, 40393, 272, 10, 15, "Index",
      CellTags->"Additive models"],
    Cell[1362599, 52044, 272, 10, 23, "Index",
      CellTags->"Additive models"],
    Cell[1640610, 63255, 272, 10, 23, "Index",
      CellTags->"Additive models"]},
  "Additive selection"->{
    Cell[154036, 3200, 303, 11, 23, "Index",
      CellTags->"Additive selection"],
    Cell[154342, 3213, 713, 27, 68, "IndexSubentry",
      CellTags->"Additive selection"],
    Cell[465980, 15807, 303, 11, 23, "Index",
      CellTags->"Additive selection"],
    Cell[466286, 15820, 713, 27, 68, "IndexSubentry",
      CellTags->"Additive selection"],
    Cell[781368, 28545, 303, 11, 15, "Index",
      CellTags->"Additive selection"],
    Cell[781674, 28558, 713, 27, 60, "IndexSubentry",
      CellTags->"Additive selection"],
    Cell[1074644, 40405, 303, 11, 15, "Index",
      CellTags->"Additive selection"],
    Cell[1074950, 40418, 713, 27, 60, "IndexSubentry",
      CellTags->"Additive selection"],
    Cell[1362874, 52056, 303, 11, 23, "Index",
      CellTags->"Additive selection"],
    Cell[1363180, 52069, 713, 27, 68, "IndexSubentry",
      CellTags->"Additive selection"],
    Cell[1640885, 63267, 303, 11, 23, "Index",
      CellTags->"Additive selection"],
    Cell[1641191, 63280, 713, 27, 68, "IndexSubentry",
      CellTags->"Additive selection"]},
  "AddMutation"->{
    Cell[155058, 3242, 268, 10, 23, "Index",
      CellTags->"AddMutation"],
    Cell[467002, 15849, 268, 10, 23, "Index",
      CellTags->"AddMutation"],
    Cell[782390, 28587, 268, 10, 15, "Index",
      CellTags->"AddMutation"]},
  "AddNode"->{
    Cell[155329, 3254, 256, 10, 23, "Index",
      CellTags->"AddNode"],
    Cell[467273, 15861, 256, 10, 23, "Index",
      CellTags->"AddNode"],
    Cell[782661, 28599, 256, 10, 15, "Index",
      CellTags->"AddNode"],
    Cell[1075666, 40447, 256, 10, 15, "Index",
      CellTags->"AddNode"],
    Cell[1363896, 52098, 256, 10, 23, "Index",
      CellTags->"AddNode"],
    Cell[1641907, 63309, 256, 10, 23, "Index",
      CellTags->"AddNode"]},
  "AddRecombinantLineages"->{
    Cell[155588, 3266, 337, 11, 23, "Index",
      CellTags->"AddRecombinantLineages"],
    Cell[467532, 15873, 337, 11, 23, "Index",
      CellTags->"AddRecombinantLineages"]},
  "AddTag"->{
    Cell[155928, 3279, 229, 10, 23, "Index",
      CellTags->"AddTag"],
    Cell[467872, 15886, 229, 10, 23, "Index",
      CellTags->"AddTag"],
    Cell[782920, 28611, 229, 10, 15, "Index",
      CellTags->"AddTag"],
    Cell[1075925, 40459, 229, 10, 15, "Index",
      CellTags->"AddTag"],
    Cell[1364155, 52110, 229, 10, 23, "Index",
      CellTags->"AddTag"],
    Cell[1642166, 63321, 229, 10, 23, "Index",
      CellTags->"AddTag"]},
  "AddUp"->{
    Cell[156160, 3291, 334, 14, 23, "Index",
      CellTags->"AddUp"],
    Cell[156497, 3307, 492, 21, 45, "IndexSubentry",
      CellTags->"AddUp"],
    Cell[468104, 15898, 334, 14, 23, "Index",
      CellTags->"AddUp"],
    Cell[468441, 15914, 492, 21, 53, "IndexSubentry",
      CellTags->"AddUp"],
    Cell[783152, 28623, 334, 14, 15, "Index",
      CellTags->"AddUp"],
    Cell[783489, 28639, 492, 21, 45, "IndexSubentry",
      CellTags->"AddUp"],
    Cell[1076157, 40471, 334, 14, 15, "Index",
      CellTags->"AddUp"],
    Cell[1076494, 40487, 492, 21, 45, "IndexSubentry",
      CellTags->"AddUp"],
    Cell[1364387, 52122, 334, 14, 23, "Index",
      CellTags->"AddUp"],
    Cell[1364724, 52138, 492, 21, 53, "IndexSubentry",
      CellTags->"AddUp"],
    Cell[1642398, 63333, 334, 14, 23, "Index",
      CellTags->"AddUp"],
    Cell[1642735, 63349, 492, 21, 53, "IndexSubentry",
      CellTags->"AddUp"]},
  "AdmixtureFrequency"->{
    Cell[156992, 3330, 261, 10, 15, "Index",
      CellTags->"AdmixtureFrequency"],
    Cell[468936, 15937, 261, 10, 23, "Index",
      CellTags->"AdmixtureFrequency"],
    Cell[783984, 28662, 261, 10, 15, "Index",
      CellTags->"AdmixtureFrequency"],
    Cell[1076989, 40510, 261, 10, 15, "Index",
      CellTags->"AdmixtureFrequency"],
    Cell[1365219, 52161, 261, 10, 23, "Index",
      CellTags->"AdmixtureFrequency"],
    Cell[1643230, 63372, 261, 10, 23, "Index",
      CellTags->"AdmixtureFrequency"]},
  "Admixture models"->{
    Cell[157256, 3342, 352, 14, 15, "Index",
      CellTags->"Admixture models"],
    Cell[157611, 3358, 843, 33, 75, "IndexSubentry",
      CellTags->"Admixture models"],
    Cell[469200, 15949, 352, 14, 23, "Index",
      CellTags->"Admixture models"],
    Cell[469555, 15965, 843, 33, 83, "IndexSubentry",
      CellTags->"Admixture models"],
    Cell[784248, 28674, 352, 14, 15, "Index",
      CellTags->"Admixture models"],
    Cell[784603, 28690, 843, 33, 75, "IndexSubentry",
      CellTags->"Admixture models"],
    Cell[1077253, 40522, 352, 14, 15, "Index",
      CellTags->"Admixture models"],
    Cell[1077608, 40538, 843, 33, 75, "IndexSubentry",
      CellTags->"Admixture models"],
    Cell[1365483, 52173, 352, 14, 23, "Index",
      CellTags->"Admixture models"],
    Cell[1365838, 52189, 843, 33, 83, "IndexSubentry",
      CellTags->"Admixture models"],
    Cell[1643494, 63384, 352, 14, 23, "Index",
      CellTags->"Admixture models"],
    Cell[1643849, 63400, 843, 33, 83, "IndexSubentry",
      CellTags->"Admixture models"]},
  "Adults"->{
    Cell[158457, 3393, 408, 15, 15, "Index",
      CellTags->"Adults"],
    Cell[470401, 16000, 408, 15, 23, "Index",
      CellTags->"Adults"],
    Cell[785449, 28725, 408, 15, 15, "Index",
      CellTags->"Adults"],
    Cell[1078454, 40573, 408, 15, 15, "Index",
      CellTags->"Adults"],
    Cell[1366684, 52224, 408, 15, 23, "Index",
      CellTags->"Adults"],
    Cell[1644695, 63435, 408, 15, 23, "Index",
      CellTags->"Adults"]},
  "Allele frequencies"->{
    Cell[158868, 3410, 326, 11, 15, "Index",
      CellTags->"Allele frequencies"],
    Cell[470812, 16017, 326, 11, 23, "Index",
      CellTags->"Allele frequencies"],
    Cell[471141, 16030, 287, 9, 23, "IndexSubentry",
      CellTags->"Allele frequencies"],
    Cell[785860, 28742, 326, 11, 15, "Index",
      CellTags->"Allele frequencies"],
    Cell[1078865, 40590, 326, 11, 15, "Index",
      CellTags->"Allele frequencies"],
    Cell[1367095, 52241, 326, 11, 23, "Index",
      CellTags->"Allele frequencies"],
    Cell[1645106, 63452, 326, 11, 23, "Index",
      CellTags->"Allele frequencies"]},
  "AlleleFrequencies"->{
    Cell[159197, 3423, 470, 15, 15, "Index",
      CellTags->"AlleleFrequencies"],
    Cell[471431, 16041, 472, 15, 23, "Index",
      CellTags->"AlleleFrequencies"],
    Cell[786189, 28755, 470, 15, 15, "Index",
      CellTags->"AlleleFrequencies"],
    Cell[1079194, 40603, 470, 15, 15, "Index",
      CellTags->"AlleleFrequencies"],
    Cell[1367424, 52254, 470, 15, 23, "Index",
      CellTags->"AlleleFrequencies"],
    Cell[1645435, 63465, 470, 15, 15, "Index",
      CellTags->"AlleleFrequencies"]},
  "AlleleFrequencyMean"->{
    Cell[159670, 3440, 298, 10, 15, "Index",
      CellTags->"AlleleFrequencyMean"],
    Cell[159971, 3452, 952, 29, 60, "IndexSubentry",
      CellTags->"AlleleFrequencyMean"],
    Cell[472195, 16070, 298, 10, 23, "Index",
      CellTags->"AlleleFrequencyMean"],
    Cell[472496, 16082, 959, 30, 68, "IndexSubentry",
      CellTags->"AlleleFrequencyMean"],
    Cell[786662, 28772, 298, 10, 15, "Index",
      CellTags->"AlleleFrequencyMean"],
    Cell[786963, 28784, 952, 29, 60, "IndexSubentry",
      CellTags->"AlleleFrequencyMean"],
    Cell[1079667, 40620, 298, 10, 15, "Index",
      CellTags->"AlleleFrequencyMean"],
    Cell[1079968, 40632, 952, 29, 60, "IndexSubentry",
      CellTags->"AlleleFrequencyMean"],
    Cell[1367897, 52271, 298, 10, 23, "Index",
      CellTags->"AlleleFrequencyMean"],
    Cell[1368198, 52283, 952, 29, 68, "IndexSubentry",
      CellTags->"AlleleFrequencyMean"],
    Cell[1645908, 63482, 298, 10, 15, "Index",
      CellTags->"AlleleFrequencyMean"],
    Cell[1646209, 63494, 952, 29, 60, "IndexSubentry",
      CellTags->"AlleleFrequencyMean"]},
  "AlleleFrequencyP"->{
    Cell[160926, 3483, 314, 11, 15, "Index",
      CellTags->"AlleleFrequencyP"],
    Cell[473458, 16114, 314, 11, 23, "Index",
      CellTags->"AlleleFrequencyP"],
    Cell[787918, 28815, 314, 11, 15, "Index",
      CellTags->"AlleleFrequencyP"],
    Cell[1080923, 40663, 314, 11, 15, "Index",
      CellTags->"AlleleFrequencyP"],
    Cell[1369153, 52314, 314, 11, 23, "Index",
      CellTags->"AlleleFrequencyP"],
    Cell[1647164, 63525, 314, 11, 15, "Index",
      CellTags->"AlleleFrequencyP"]},
  "AlleleFrequencyPermutations"->{
    Cell[161243, 3496, 304, 10, 15, "Index",
      CellTags->"AlleleFrequencyPermutations"],
    Cell[473775, 16127, 304, 10, 23, "Index",
      CellTags->"AlleleFrequencyPermutations"],
    Cell[788235, 28828, 304, 10, 15, "Index",
      CellTags->"AlleleFrequencyPermutations"],
    Cell[1081240, 40676, 304, 10, 15, "Index",
      CellTags->"AlleleFrequencyPermutations"],
    Cell[1369470, 52327, 304, 10, 23, "Index",
      CellTags->"AlleleFrequencyPermutations"],
    Cell[1647481, 63538, 304, 10, 15, "Index",
      CellTags->"AlleleFrequencyPermutations"]},
  "AlleleFrequencyPQ"->{
    Cell[161550, 3508, 366, 12, 15, "Index",
      CellTags->"AlleleFrequencyPQ"],
    Cell[474082, 16139, 366, 12, 23, "Index",
      CellTags->"AlleleFrequencyPQ"],
    Cell[788542, 28840, 366, 12, 15, "Index",
      CellTags->"AlleleFrequencyPQ"],
    Cell[1081547, 40688, 366, 12, 23, "Index",
      CellTags->"AlleleFrequencyPQ"],
    Cell[1369777, 52339, 366, 12, 23, "Index",
      CellTags->"AlleleFrequencyPQ"],
    Cell[1647788, 63550, 366, 12, 15, "Index",
      CellTags->"AlleleFrequencyPQ"]},
  "AlleleFrequencyQ"->{
    Cell[161919, 3522, 314, 11, 15, "Index",
      CellTags->"AlleleFrequencyQ"],
    Cell[474451, 16153, 314, 11, 23, "Index",
      CellTags->"AlleleFrequencyQ"],
    Cell[788911, 28854, 314, 11, 15, "Index",
      CellTags->"AlleleFrequencyQ"],
    Cell[1081916, 40702, 314, 11, 23, "Index",
      CellTags->"AlleleFrequencyQ"],
    Cell[1370146, 52353, 314, 11, 23, "Index",
      CellTags->"AlleleFrequencyQ"],
    Cell[1648157, 63564, 314, 11, 15, "Index",
      CellTags->"AlleleFrequencyQ"]},
  "AlleleFrequencyTable"->{
    Cell[162236, 3535, 301, 10, 15, "Index",
      CellTags->"AlleleFrequencyTable"],
    Cell[162540, 3547, 962, 30, 60, "IndexSubentry",
      CellTags->"AlleleFrequencyTable"],
    Cell[474768, 16166, 301, 10, 23, "Index",
      CellTags->"AlleleFrequencyTable"],
    Cell[475072, 16178, 1143, 36, 83, "IndexSubentry",
      CellTags->"AlleleFrequencyTable"],
    Cell[789228, 28867, 301, 10, 15, "Index",
      CellTags->"AlleleFrequencyTable"],
    Cell[789532, 28879, 962, 30, 60, "IndexSubentry",
      CellTags->"AlleleFrequencyTable"],
    Cell[1082233, 40715, 301, 10, 23, "Index",
      CellTags->"AlleleFrequencyTable"],
    Cell[1082537, 40727, 962, 30, 68, "IndexSubentry",
      CellTags->"AlleleFrequencyTable"],
    Cell[1370463, 52366, 301, 10, 23, "Index",
      CellTags->"AlleleFrequencyTable"],
    Cell[1370767, 52378, 962, 30, 68, "IndexSubentry",
      CellTags->"AlleleFrequencyTable"],
    Cell[1648474, 63577, 301, 10, 15, "Index",
      CellTags->"AlleleFrequencyTable"],
    Cell[1648778, 63589, 962, 30, 60, "IndexSubentry",
      CellTags->"AlleleFrequencyTable"]},
  "AllelicDeviation"->{
    Cell[163505, 3579, 313, 11, 15, "Index",
      CellTags->"AllelicDeviation"],
    Cell[476218, 16216, 313, 11, 23, "Index",
      CellTags->"AllelicDeviation"],
    Cell[790497, 28911, 313, 11, 15, "Index",
      CellTags->"AllelicDeviation"],
    Cell[1083502, 40759, 313, 11, 23, "Index",
      CellTags->"AllelicDeviation"],
    Cell[1371732, 52410, 313, 11, 23, "Index",
      CellTags->"AllelicDeviation"],
    Cell[1649743, 63621, 313, 11, 15, "Index",
      CellTags->"AllelicDeviation"]},
  "AllelicState"->{
    Cell[163821, 3592, 258, 11, 15, "Index",
      CellTags->"AllelicState"],
    Cell[476534, 16229, 258, 11, 23, "Index",
      CellTags->"AllelicState"],
    Cell[790813, 28924, 258, 11, 15, "Index",
      CellTags->"AllelicState"],
    Cell[1083818, 40772, 258, 11, 23, "Index",
      CellTags->"AllelicState"],
    Cell[1372048, 52423, 258, 11, 23, "Index",
      CellTags->"AllelicState"],
    Cell[1650059, 63634, 258, 11, 15, "Index",
      CellTags->"AllelicState"]},
  "AllEvents"->{
    Cell[164082, 3605, 295, 11, 15, "Index",
      CellTags->"AllEvents"],
    Cell[476795, 16242, 295, 11, 23, "Index",
      CellTags->"AllEvents"]},
  "AllSets"->{
    Cell[164380, 3618, 258, 10, 15, "Index",
      CellTags->"AllSets"],
    Cell[477093, 16255, 258, 10, 23, "Index",
      CellTags->"AllSets"],
    Cell[791074, 28937, 258, 10, 15, "Index",
      CellTags->"AllSets"],
    Cell[1084079, 40785, 258, 10, 23, "Index",
      CellTags->"AllSets"],
    Cell[1372309, 52436, 258, 10, 23, "Index",
      CellTags->"AllSets"],
    Cell[1650320, 63647, 258, 10, 15, "Index",
      CellTags->"AllSets"]},
  "Ancestors"->{
    Cell[164641, 3630, 273, 11, 15, "Index",
      CellTags->"Ancestors"],
    Cell[164917, 3643, 273, 9, 15, "IndexSubentry",
      CellTags->"Ancestors"],
    Cell[477354, 16267, 273, 11, 23, "Index",
      CellTags->"Ancestors"],
    Cell[477630, 16280, 273, 9, 23, "IndexSubentry",
      CellTags->"Ancestors"],
    Cell[791335, 28949, 273, 11, 15, "Index",
      CellTags->"Ancestors"],
    Cell[1084340, 40797, 273, 11, 23, "Index",
      CellTags->"Ancestors"],
    Cell[1372570, 52448, 273, 11, 23, "Index",
      CellTags->"Ancestors"],
    Cell[1650581, 63659, 273, 11, 15, "Index",
      CellTags->"Ancestors"]},
  "AncestralGraphPattern"->{
    Cell[165193, 3654, 308, 10, 15, "Index",
      CellTags->"AncestralGraphPattern"],
    Cell[477906, 16291, 308, 10, 23, "Index",
      CellTags->"AncestralGraphPattern"]},
  "Ancestral graphs"->{
    Cell[165504, 3666, 293, 11, 15, "Index",
      CellTags->"Ancestral graphs"],
    Cell[165800, 3679, 924, 33, 75, "IndexSubentry",
      CellTags->"Ancestral graphs"],
    Cell[478217, 16303, 293, 11, 23, "Index",
      CellTags->"Ancestral graphs"],
    Cell[478513, 16316, 926, 33, 83, "IndexSubentry",
      CellTags->"Ancestral graphs"]},
  "AncestralLineage"->{
    Cell[166727, 3714, 293, 10, 15, "Index",
      CellTags->"AncestralLineage"],
    Cell[479442, 16351, 293, 10, 23, "Index",
      CellTags->"AncestralLineage"]},
  "AncestralLineagePattern"->{
    Cell[167023, 3726, 314, 10, 15, "Index",
      CellTags->"AncestralLineagePattern"],
    Cell[479738, 16363, 314, 10, 23, "Index",
      CellTags->"AncestralLineagePattern"]},
  "Ancestry"->{
    Cell[167340, 3738, 255, 10, 15, "Index",
      CellTags->"Ancestry"],
    Cell[480055, 16375, 255, 10, 23, "Index",
      CellTags->"Ancestry"],
    Cell[791611, 28962, 255, 10, 15, "Index",
      CellTags->"Ancestry"],
    Cell[1084616, 40810, 255, 10, 23, "Index",
      CellTags->"Ancestry"],
    Cell[1372846, 52461, 255, 10, 23, "Index",
      CellTags->"Ancestry"],
    Cell[1650857, 63672, 255, 10, 15, "Index",
      CellTags->"Ancestry"]},
  "Arbitrary sets of loci"->{
    Cell[167598, 3750, 334, 11, 15, "Index",
      CellTags->"Arbitrary sets of loci"],
    Cell[480313, 16387, 334, 11, 23, "Index",
      CellTags->"Arbitrary sets of loci"],
    Cell[791869, 28974, 334, 11, 15, "Index",
      CellTags->"Arbitrary sets of loci"],
    Cell[1084874, 40822, 334, 11, 23, "Index",
      CellTags->"Arbitrary sets of loci"],
    Cell[1373104, 52473, 334, 11, 23, "Index",
      CellTags->"Arbitrary sets of loci"],
    Cell[1651115, 63684, 312, 11, 15, "Index",
      CellTags->"Arbitrary sets of loci"]},
  "Arnold 1996"->{
    Cell[167935, 3763, 240, 10, 15, "Index",
      CellTags->"Arnold 1996"],
    Cell[480650, 16400, 240, 10, 23, "Index",
      CellTags->"Arnold 1996"],
    Cell[792206, 28987, 240, 10, 15, "Index",
      CellTags->"Arnold 1996"],
    Cell[1085211, 40835, 240, 10, 23, "Index",
      CellTags->"Arnold 1996"],
    Cell[1373441, 52486, 240, 10, 23, "Index",
      CellTags->"Arnold 1996"],
    Cell[1651430, 63697, 240, 10, 15, "Index",
      CellTags->"Arnold 1996"]},
  "Asmussen and Orive 2000"->{
    Cell[168178, 3775, 414, 14, 15, "Index",
      CellTags->"Asmussen and Orive 2000"],
    Cell[480893, 16412, 414, 14, 23, "Index",
      CellTags->"Asmussen and Orive 2000"],
    Cell[792449, 28999, 414, 14, 15, "Index",
      CellTags->"Asmussen and Orive 2000"],
    Cell[1085454, 40847, 414, 14, 23, "Index",
      CellTags->"Asmussen and Orive 2000"],
    Cell[1373684, 52498, 414, 14, 23, "Index",
      CellTags->"Asmussen and Orive 2000"],
    Cell[1651673, 63709, 414, 14, 15, "Index",
      CellTags->"Asmussen and Orive 2000"]},
  "Asmussen et al. 1987"->{
    Cell[168595, 3791, 266, 10, 15, "Index",
      CellTags->"Asmussen et al. 1987"],
    Cell[481310, 16428, 266, 10, 23, "Index",
      CellTags->"Asmussen et al. 1987"],
    Cell[792866, 29015, 266, 10, 15, "Index",
      CellTags->"Asmussen et al. 1987"],
    Cell[1085871, 40863, 266, 10, 23, "Index",
      CellTags->"Asmussen et al. 1987"],
    Cell[1374101, 52514, 266, 10, 23, "Index",
      CellTags->"Asmussen et al. 1987"],
    Cell[1652090, 63725, 266, 10, 15, "Index",
      CellTags->"Asmussen et al. 1987"]},
  "B"->{
    Cell[168864, 3803, 256, 10, 15, "Index",
      CellTags->"B"],
    Cell[481579, 16440, 256, 10, 23, "Index",
      CellTags->"B"],
    Cell[793135, 29027, 256, 10, 15, "Index",
      CellTags->"B"],
    Cell[1086140, 40875, 256, 10, 23, "Index",
      CellTags->"B"],
    Cell[1374370, 52526, 256, 10, 23, "Index",
      CellTags->"B"],
    Cell[1652359, 63737, 256, 10, 15, "Index",
      CellTags->"B"]},
  "Baake 2001"->{
    Cell[169123, 3815, 363, 14, 15, "Index",
      CellTags->"Baake 2001"],
    Cell[481838, 16452, 363, 14, 23, "Index",
      CellTags->"Baake 2001"],
    Cell[793394, 29039, 363, 14, 15, "Index",
      CellTags->"Baake 2001"],
    Cell[1086399, 40887, 363, 14, 23, "Index",
      CellTags->"Baake 2001"]},
  "BackgroundStyle"->{
    Cell[169489, 3831, 313, 11, 15, "Index",
      CellTags->"BackgroundStyle"],
    Cell[482204, 16468, 313, 11, 23, "Index",
      CellTags->"BackgroundStyle"]},
  "Barrier"->{
    Cell[169805, 3844, 276, 11, 15, "Index",
      CellTags->"Barrier"],
    Cell[482520, 16481, 276, 11, 23, "Index",
      CellTags->"Barrier"],
    Cell[793760, 29055, 276, 11, 15, "Index",
      CellTags->"Barrier"],
    Cell[1086765, 40903, 276, 11, 23, "Index",
      CellTags->"Barrier"],
    Cell[1374629, 52538, 276, 11, 23, "Index",
      CellTags->"Barrier"],
    Cell[1652618, 63749, 276, 11, 15, "Index",
      CellTags->"Barrier"]},
  "BarrierStrength"->{
    Cell[170084, 3857, 276, 10, 15, "Index",
      CellTags->"BarrierStrength"],
    Cell[482799, 16494, 276, 10, 23, "Index",
      CellTags->"BarrierStrength"],
    Cell[794039, 29068, 276, 10, 15, "Index",
      CellTags->"BarrierStrength"],
    Cell[1087044, 40916, 276, 10, 23, "Index",
      CellTags->"BarrierStrength"],
    Cell[1374908, 52551, 276, 10, 23, "Index",
      CellTags->"BarrierStrength"],
    Cell[1652897, 63762, 276, 10, 15, "Index",
      CellTags->"BarrierStrength"]},
  "Barton 1986"->{
    Cell[170363, 3869, 240, 10, 15, "Index",
      CellTags->"Barton 1986"],
    Cell[483078, 16506, 240, 10, 23, "Index",
      CellTags->"Barton 1986"],
    Cell[794318, 29080, 240, 10, 15, "Index",
      CellTags->"Barton 1986"],
    Cell[1087323, 40928, 240, 10, 23, "Index",
      CellTags->"Barton 1986"],
    Cell[1375187, 52563, 240, 10, 23, "Index",
      CellTags->"Barton 1986"],
    Cell[1653176, 63774, 240, 10, 15, "Index",
      CellTags->"Barton 1986"]},
  "Barton 1995"->{
    Cell[170606, 3881, 262, 10, 15, "Index",
      CellTags->"Barton 1995"],
    Cell[483321, 16518, 262, 10, 23, "Index",
      CellTags->"Barton 1995"],
    Cell[794561, 29092, 262, 10, 15, "Index",
      CellTags->"Barton 1995"],
    Cell[1087566, 40940, 262, 10, 23, "Index",
      CellTags->"Barton 1995"],
    Cell[1375430, 52575, 262, 10, 23, "Index",
      CellTags->"Barton 1995"],
    Cell[1653419, 63786, 262, 10, 15, "Index",
      CellTags->"Barton 1995"]},
  "Barton 2000"->{
    Cell[170871, 3893, 240, 10, 15, "Index",
      CellTags->"Barton 2000"],
    Cell[483586, 16530, 240, 10, 23, "Index",
      CellTags->"Barton 2000"],
    Cell[794826, 29104, 240, 10, 15, "Index",
      CellTags->"Barton 2000"],
    Cell[1087831, 40952, 240, 10, 23, "Index",
      CellTags->"Barton 2000"],
    Cell[1375695, 52587, 240, 10, 23, "Index",
      CellTags->"Barton 2000"],
    Cell[1653684, 63798, 240, 10, 15, "Index",
      CellTags->"Barton 2000"]},
  "Barton and Turelli 1991"->{
    Cell[171114, 3905, 298, 10, 15, "Index",
      CellTags->"Barton and Turelli 1991"],
    Cell[483829, 16542, 298, 10, 23, "Index",
      CellTags->"Barton and Turelli 1991"],
    Cell[795069, 29116, 298, 10, 15, "Index",
      CellTags->"Barton and Turelli 1991"],
    Cell[1088074, 40964, 298, 10, 23, "Index",
      CellTags->"Barton and Turelli 1991"],
    Cell[1375938, 52599, 298, 10, 23, "Index",
      CellTags->"Barton and Turelli 1991"],
    Cell[1653927, 63810, 298, 10, 15, "Index",
      CellTags->"Barton and Turelli 1991"]},
  "Barton & Gale 1993"->{
    Cell[171415, 3917, 261, 10, 15, "Index",
      CellTags->"Barton & Gale 1993"],
    Cell[484130, 16554, 261, 10, 23, "Index",
      CellTags->"Barton & Gale 1993"],
    Cell[795370, 29128, 261, 10, 15, "Index",
      CellTags->"Barton & Gale 1993"],
    Cell[1088375, 40976, 261, 10, 23, "Index",
      CellTags->"Barton & Gale 1993"],
    Cell[1376239, 52611, 261, 10, 23, "Index",
      CellTags->"Barton & Gale 1993"],
    Cell[1654228, 63822, 261, 10, 15, "Index",
      CellTags->"Barton & Gale 1993"]},
  "Barton & Shpak 1999"->{
    Cell[171679, 3929, 264, 10, 15, "Index",
      CellTags->"Barton & Shpak 1999"],
    Cell[484394, 16566, 264, 10, 23, "Index",
      CellTags->"Barton & Shpak 1999"],
    Cell[795634, 29140, 264, 10, 15, "Index",
      CellTags->"Barton & Shpak 1999"],
    Cell[1088639, 40988, 264, 10, 23, "Index",
      CellTags->"Barton & Shpak 1999"],
    Cell[1376503, 52623, 264, 10, 23, "Index",
      CellTags->"Barton & Shpak 1999"],
    Cell[1654492, 63834, 264, 10, 15, "Index",
      CellTags->"Barton & Shpak 1999"]},
  "Barton & Turelli 1991"->{
    Cell[171946, 3941, 270, 10, 15, "Index",
      CellTags->"Barton & Turelli 1991"],
    Cell[484661, 16578, 270, 10, 23, "Index",
      CellTags->"Barton & Turelli 1991"],
    Cell[795901, 29152, 270, 10, 15, "Index",
      CellTags->"Barton & Turelli 1991"],
    Cell[1088906, 41000, 270, 10, 23, "Index",
      CellTags->"Barton & Turelli 1991"],
    Cell[1376770, 52635, 270, 10, 23, "Index",
      CellTags->"Barton & Turelli 1991"],
    Cell[1654759, 63846, 270, 10, 15, "Index",
      CellTags->"Barton & Turelli 1991"]},
  "Bennett 1954"->{
    Cell[172219, 3953, 243, 10, 15, "Index",
      CellTags->"Bennett 1954"],
    Cell[484934, 16590, 243, 10, 23, "Index",
      CellTags->"Bennett 1954"],
    Cell[796174, 29164, 243, 10, 15, "Index",
      CellTags->"Bennett 1954"],
    Cell[1089179, 41012, 243, 10, 23, "Index",
      CellTags->"Bennett 1954"]},
  "BennettB"->{
    Cell[172465, 3965, 251, 10, 15, "Index",
      CellTags->"BennettB"],
    Cell[485180, 16602, 251, 10, 23, "Index",
      CellTags->"BennettB"],
    Cell[796420, 29176, 251, 10, 15, "Index",
      CellTags->"BennettB"],
    Cell[1089425, 41024, 251, 10, 23, "Index",
      CellTags->"BennettB"]},
  "BennettC"->{
    Cell[172719, 3977, 251, 10, 15, "Index",
      CellTags->"BennettC"],
    Cell[485434, 16614, 251, 10, 23, "Index",
      CellTags->"BennettC"],
    Cell[796674, 29188, 251, 10, 15, "Index",
      CellTags->"BennettC"],
    Cell[1089679, 41036, 251, 10, 23, "Index",
      CellTags->"BennettC"]},
  "BennettExpansion"->{
    Cell[172973, 3989, 275, 10, 15, "Index",
      CellTags->"BennettExpansion"],
    Cell[485688, 16626, 275, 10, 23, "Index",
      CellTags->"BennettExpansion"],
    Cell[796928, 29200, 275, 10, 15, "Index",
      CellTags->"BennettExpansion"],
    Cell[1089933, 41048, 275, 10, 23, "Index",
      CellTags->"BennettExpansion"]},
  "Biallelic"->{
    Cell[173251, 4001, 236, 10, 15, "Index",
      CellTags->"Biallelic"],
    Cell[173490, 4013, 358, 13, 15, "IndexSubentry",
      CellTags->"Biallelic"],
    Cell[485966, 16638, 236, 10, 23, "Index",
      CellTags->"Biallelic"],
    Cell[486205, 16650, 358, 13, 23, "IndexSubentry",
      CellTags->"Biallelic"],
    Cell[797206, 29212, 236, 10, 15, "Index",
      CellTags->"Biallelic"],
    Cell[797445, 29224, 358, 13, 15, "IndexSubentry",
      CellTags->"Biallelic"],
    Cell[1090211, 41060, 236, 10, 23, "Index",
      CellTags->"Biallelic"],
    Cell[1090450, 41072, 358, 13, 23, "IndexSubentry",
      CellTags->"Biallelic"],
    Cell[1377043, 52647, 236, 10, 23, "Index",
      CellTags->"Biallelic"],
    Cell[1377282, 52659, 358, 13, 23, "IndexSubentry",
      CellTags->"Biallelic"],
    Cell[1655032, 63858, 236, 10, 15, "Index",
      CellTags->"Biallelic"],
    Cell[1655271, 63870, 358, 13, 15, "IndexSubentry",
      CellTags->"Biallelic"]},
  "BiallelicMutation"->{
    Cell[173851, 4028, 276, 10, 15, "Index",
      CellTags->"BiallelicMutation"],
    Cell[174130, 4040, 268, 9, 15, "IndexSubentry",
      CellTags->"BiallelicMutation"],
    Cell[486566, 16665, 276, 10, 23, "Index",
      CellTags->"BiallelicMutation"],
    Cell[486845, 16677, 268, 9, 23, "IndexSubentry",
      CellTags->"BiallelicMutation"],
    Cell[797806, 29239, 276, 10, 15, "Index",
      CellTags->"BiallelicMutation"],
    Cell[798085, 29251, 268, 9, 15, "IndexSubentry",
      CellTags->"BiallelicMutation"],
    Cell[1090811, 41087, 276, 10, 23, "Index",
      CellTags->"BiallelicMutation"],
    Cell[1091090, 41099, 268, 9, 23, "IndexSubentry",
      CellTags->"BiallelicMutation"]},
  "Binary integers"->{
    Cell[174401, 4051, 266, 10, 15, "Index",
      CellTags->"Binary integers"],
    Cell[487116, 16688, 266, 10, 23, "Index",
      CellTags->"Binary integers"],
    Cell[798356, 29262, 266, 10, 15, "Index",
      CellTags->"Binary integers"]},
  "Birth"->{
    Cell[174670, 4063, 262, 10, 15, "Index",
      CellTags->"Birth"],
    Cell[487385, 16700, 262, 10, 23, "Index",
      CellTags->"Birth"],
    Cell[798625, 29274, 262, 10, 15, "Index",
      CellTags->"Birth"],
    Cell[1091361, 41110, 262, 10, 23, "Index",
      CellTags->"Birth"],
    Cell[1377643, 52674, 262, 10, 23, "Index",
      CellTags->"Birth"],
    Cell[1655632, 63885, 262, 10, 15, "Index",
      CellTags->"Birth"]},
  "BirthTime"->{
    Cell[174935, 4075, 258, 10, 15, "Index",
      CellTags->"BirthTime"],
    Cell[487650, 16712, 258, 10, 23, "Index",
      CellTags->"BirthTime"],
    Cell[798890, 29286, 258, 10, 15, "Index",
      CellTags->"BirthTime"],
    Cell[1091626, 41122, 258, 10, 23, "Index",
      CellTags->"BirthTime"],
    Cell[1377908, 52686, 258, 10, 23, "Index",
      CellTags->"BirthTime"],
    Cell[1655897, 63897, 258, 10, 15, "Index",
      CellTags->"BirthTime"]},
  "Boundary conditions"->{
    Cell[175196, 4087, 447, 15, 15, "Index",
      CellTags->"Boundary conditions"],
    Cell[487911, 16724, 447, 15, 23, "Index",
      CellTags->"Boundary conditions"],
    Cell[799151, 29298, 447, 15, 15, "Index",
      CellTags->"Boundary conditions"],
    Cell[1091887, 41134, 447, 15, 23, "Index",
      CellTags->"Boundary conditions"],
    Cell[1378169, 52698, 447, 15, 23, "Index",
      CellTags->"Boundary conditions"],
    Cell[1656158, 63909, 447, 15, 15, "Index",
      CellTags->"Boundary conditions"]},
  "Box"->{
    Cell[175646, 4104, 240, 10, 15, "Index",
      CellTags->"Box"],
    Cell[488361, 16741, 240, 10, 23, "Index",
      CellTags->"Box"],
    Cell[799601, 29315, 240, 10, 15, "Index",
      CellTags->"Box"],
    Cell[1092337, 41151, 240, 10, 23, "Index",
      CellTags->"Box"],
    Cell[1378619, 52715, 240, 10, 23, "Index",
      CellTags->"Box"],
    Cell[1656608, 63926, 240, 10, 15, "Index",
      CellTags->"Box"]},
  "Boxes"->{
    Cell[175889, 4116, 246, 10, 15, "Index",
      CellTags->"Boxes"],
    Cell[488604, 16753, 246, 10, 23, "Index",
      CellTags->"Boxes"],
    Cell[799844, 29327, 246, 10, 15, "Index",
      CellTags->"Boxes"],
    Cell[1092580, 41163, 246, 10, 23, "Index",
      CellTags->"Boxes"],
    Cell[1378862, 52727, 246, 10, 23, "Index",
      CellTags->"Boxes"],
    Cell[1656851, 63938, 246, 10, 15, "Index",
      CellTags->"Boxes"]},
  "Browser categories"->{
    Cell[176138, 4128, 293, 10, 15, "Index",
      CellTags->"Browser categories"],
    Cell[488853, 16765, 293, 10, 23, "Index",
      CellTags->"Browser categories"],
    Cell[800093, 29339, 293, 10, 15, "Index",
      CellTags->"Browser categories"],
    Cell[1092829, 41175, 293, 10, 23, "Index",
      CellTags->"Browser categories"],
    Cell[1379111, 52739, 293, 10, 23, "Index",
      CellTags->"Browser categories"],
    Cell[1657100, 63950, 293, 10, 15, "Index",
      CellTags->"Browser categories"]},
  "Bugs"->{
    Cell[176434, 4140, 239, 11, 15, "Index",
      CellTags->"Bugs"],
    Cell[176676, 4153, 1583, 63, 150, "IndexSubentry",
      CellTags->"Bugs"],
    Cell[489149, 16777, 239, 11, 23, "Index",
      CellTags->"Bugs"],
    Cell[489391, 16790, 1583, 63, 158, "IndexSubentry",
      CellTags->"Bugs"],
    Cell[800389, 29351, 239, 11, 15, "Index",
      CellTags->"Bugs"],
    Cell[800631, 29364, 1583, 63, 150, "IndexSubentry",
      CellTags->"Bugs"],
    Cell[1093125, 41187, 239, 11, 23, "Index",
      CellTags->"Bugs"],
    Cell[1093367, 41200, 1583, 63, 158, "IndexSubentry",
      CellTags->"Bugs"],
    Cell[1379407, 52751, 239, 11, 23, "Index",
      CellTags->"Bugs"],
    Cell[1379649, 52764, 1583, 63, 158, "IndexSubentry",
      CellTags->"Bugs"],
    Cell[1657396, 63962, 239, 11, 15, "Index",
      CellTags->"Bugs"],
    Cell[1657638, 63975, 1449, 57, 135, "IndexSubentry",
      CellTags->"Bugs"]},
  "ChangeContext"->{
    Cell[178262, 4218, 318, 11, 15, "Index",
      CellTags->"ChangeContext"],
    Cell[490977, 16855, 318, 11, 23, "Index",
      CellTags->"ChangeContext"],
    Cell[802217, 29429, 318, 11, 15, "Index",
      CellTags->"ChangeContext"],
    Cell[1094953, 41265, 318, 11, 23, "Index",
      CellTags->"ChangeContext"],
    Cell[1381235, 52829, 318, 11, 23, "Index",
      CellTags->"ChangeContext"],
    Cell[1659090, 64034, 318, 11, 15, "Index",
      CellTags->"ChangeContext"]},
  "ChangeSex"->{
    Cell[178583, 4231, 238, 10, 15, "Index",
      CellTags->"ChangeSex"],
    Cell[491298, 16868, 238, 10, 23, "Index",
      CellTags->"ChangeSex"],
    Cell[802538, 29442, 238, 10, 15, "Index",
      CellTags->"ChangeSex"],
    Cell[1095274, 41278, 238, 10, 23, "Index",
      CellTags->"ChangeSex"],
    Cell[1381556, 52842, 238, 10, 23, "Index",
      CellTags->"ChangeSex"],
    Cell[1659411, 64047, 238, 10, 15, "Index",
      CellTags->"ChangeSex"]},
  "ClassToGenotypes"->{
    Cell[178824, 4243, 289, 10, 15, "Index",
      CellTags->"ClassToGenotypes"],
    Cell[491539, 16880, 289, 10, 23, "Index",
      CellTags->"ClassToGenotypes"],
    Cell[802779, 29454, 289, 10, 15, "Index",
      CellTags->"ClassToGenotypes"],
    Cell[1095515, 41290, 289, 10, 23, "Index",
      CellTags->"ClassToGenotypes"],
    Cell[1381797, 52854, 289, 10, 23, "Index",
      CellTags->"ClassToGenotypes"],
    Cell[1659652, 64059, 289, 10, 15, "Index",
      CellTags->"ClassToGenotypes"]},
  "Cline"->{
    Cell[179116, 4255, 253, 11, 15, "Index",
      CellTags->"Cline"],
    Cell[179372, 4268, 2662, 78, 119, "IndexSubentry",
      CellTags->"Cline"],
    Cell[491831, 16892, 253, 11, 23, "Index",
      CellTags->"Cline"],
    Cell[492087, 16905, 2662, 78, 113, "IndexSubentry",
      CellTags->"Cline"],
    Cell[803071, 29466, 253, 11, 15, "Index",
      CellTags->"Cline"],
    Cell[803327, 29479, 2662, 78, 105, "IndexSubentry",
      CellTags->"Cline"],
    Cell[1095807, 41302, 253, 11, 23, "Index",
      CellTags->"Cline"],
    Cell[1096063, 41315, 2662, 78, 113, "IndexSubentry",
      CellTags->"Cline"],
    Cell[1382089, 52866, 253, 11, 23, "Index",
      CellTags->"Cline"],
    Cell[1382345, 52879, 2662, 78, 113, "IndexSubentry",
      CellTags->"Cline"],
    Cell[1659944, 64071, 253, 11, 15, "Index",
      CellTags->"Cline"],
    Cell[1660200, 64084, 2662, 78, 105, "IndexSubentry",
      CellTags->"Cline"]},
  "ClineGradient"->{
    Cell[182037, 4348, 325, 11, 15, "Index",
      CellTags->"ClineGradient"],
    Cell[494752, 16985, 325, 11, 23, "Index",
      CellTags->"ClineGradient"],
    Cell[805992, 29559, 325, 11, 15, "Index",
      CellTags->"ClineGradient"],
    Cell[1098728, 41395, 325, 11, 23, "Index",
      CellTags->"ClineGradient"],
    Cell[1385010, 52959, 325, 11, 23, "Index",
      CellTags->"ClineGradient"],
    Cell[1662865, 64164, 325, 11, 15, "Index",
      CellTags->"ClineGradient"]},
  "ClineWidth"->{
    Cell[182365, 4361, 323, 11, 15, "Index",
      CellTags->"ClineWidth"],
    Cell[182691, 4374, 695, 21, 45, "IndexSubentry",
      CellTags->"ClineWidth"],
    Cell[495080, 16998, 323, 11, 23, "Index",
      CellTags->"ClineWidth"],
    Cell[495406, 17011, 695, 21, 53, "IndexSubentry",
      CellTags->"ClineWidth"],
    Cell[806320, 29572, 323, 11, 15, "Index",
      CellTags->"ClineWidth"],
    Cell[806646, 29585, 695, 21, 45, "IndexSubentry",
      CellTags->"ClineWidth"],
    Cell[1099056, 41408, 323, 11, 23, "Index",
      CellTags->"ClineWidth"],
    Cell[1099382, 41421, 695, 21, 53, "IndexSubentry",
      CellTags->"ClineWidth"],
    Cell[1385338, 52972, 323, 11, 23, "Index",
      CellTags->"ClineWidth"],
    Cell[1385664, 52985, 695, 21, 53, "IndexSubentry",
      CellTags->"ClineWidth"],
    Cell[1663193, 64177, 323, 11, 15, "Index",
      CellTags->"ClineWidth"],
    Cell[1663519, 64190, 695, 21, 45, "IndexSubentry",
      CellTags->"ClineWidth"]},
  "CoalesceLineages"->{
    Cell[183389, 4397, 293, 10, 15, "Index",
      CellTags->"CoalesceLineages"],
    Cell[496104, 17034, 293, 10, 23, "Index",
      CellTags->"CoalesceLineages"]},
  "CoalescenceDistribution"->{
    Cell[183685, 4409, 329, 11, 15, "Index",
      CellTags->"CoalescenceDistribution"],
    Cell[496400, 17046, 329, 11, 23, "Index",
      CellTags->"CoalescenceDistribution"],
    Cell[807344, 29608, 329, 11, 15, "Index",
      CellTags->"CoalescenceDistribution"],
    Cell[1100080, 41444, 329, 11, 23, "Index",
      CellTags->"CoalescenceDistribution"],
    Cell[1386362, 53008, 329, 11, 23, "Index",
      CellTags->"CoalescenceDistribution"],
    Cell[1664217, 64213, 329, 11, 15, "Index",
      CellTags->"CoalescenceDistribution"]},
  "CoalescenceEvents"->{
    Cell[184017, 4422, 319, 11, 15, "Index",
      CellTags->"CoalescenceEvents"],
    Cell[496732, 17059, 319, 11, 23, "Index",
      CellTags->"CoalescenceEvents"]},
  "Coalescence times"->{
    Cell[184339, 4435, 325, 11, 15, "Index",
      CellTags->"Coalescence times"],
    Cell[497054, 17072, 325, 11, 23, "Index",
      CellTags->"Coalescence times"]},
  "CoalescentLineages"->{
    Cell[184667, 4448, 322, 11, 15, "Index",
      CellTags->"CoalescentLineages"],
    Cell[497382, 17085, 322, 11, 23, "Index",
      CellTags->"CoalescentLineages"]},
  "Coalescing lineages"->{
    Cell[184992, 4461, 326, 11, 15, "Index",
      CellTags->"Coalescing lineages"],
    Cell[497707, 17098, 326, 11, 23, "Index",
      CellTags->"Coalescing lineages"]},
  "CollapseGenealogy"->{
    Cell[185321, 4474, 282, 10, 15, "Index",
      CellTags->"CollapseGenealogy"],
    Cell[498036, 17111, 282, 10, 23, "Index",
      CellTags->"CollapseGenealogy"],
    Cell[807676, 29621, 282, 10, 15, "Index",
      CellTags->"CollapseGenealogy"],
    Cell[1100412, 41457, 282, 10, 23, "Index",
      CellTags->"CollapseGenealogy"],
    Cell[1386694, 53021, 282, 10, 23, "Index",
      CellTags->"CollapseGenealogy"],
    Cell[1664549, 64226, 282, 10, 15, "Index",
      CellTags->"CollapseGenealogy"]},
  "Combinations"->{
    Cell[185606, 4486, 274, 11, 15, "Index",
      CellTags->"Combinations"],
    Cell[498321, 17123, 274, 11, 23, "Index",
      CellTags->"Combinations"],
    Cell[807961, 29633, 274, 11, 15, "Index",
      CellTags->"Combinations"]},
  "Combine"->{
    Cell[185883, 4499, 232, 10, 15, "Index",
      CellTags->"Combine"],
    Cell[498598, 17136, 232, 10, 23, "Index",
      CellTags->"Combine"],
    Cell[808238, 29646, 232, 10, 15, "Index",
      CellTags->"Combine"],
    Cell[1100697, 41469, 232, 10, 23, "Index",
      CellTags->"Combine"],
    Cell[1386979, 53033, 232, 10, 23, "Index",
      CellTags->"Combine"],
    Cell[1664834, 64238, 232, 10, 15, "Index",
      CellTags->"Combine"]},
  "CompareLogL"->{
    Cell[186118, 4511, 256, 10, 15, "Index",
      CellTags->"CompareLogL"],
    Cell[498833, 17148, 256, 10, 23, "Index",
      CellTags->"CompareLogL"],
    Cell[808473, 29658, 256, 10, 15, "Index",
      CellTags->"CompareLogL"],
    Cell[1100932, 41481, 256, 10, 23, "Index",
      CellTags->"CompareLogL"],
    Cell[1387214, 53045, 256, 10, 23, "Index",
      CellTags->"CompareLogL"],
    Cell[1665069, 64250, 256, 10, 15, "Index",
      CellTags->"CompareLogL"]},
  "Compiled"->{
    Cell[186377, 4523, 1075, 31, 30, "Index",
      CellTags->"Compiled"],
    Cell[499092, 17160, 1075, 31, 38, "Index",
      CellTags->"Compiled"],
    Cell[808732, 29670, 1075, 31, 30, "Index",
      CellTags->"Compiled"],
    Cell[1101191, 41493, 1075, 31, 38, "Index",
      CellTags->"Compiled"],
    Cell[1387473, 53057, 1075, 31, 38, "Index",
      CellTags->"Compiled"],
    Cell[1665328, 64262, 1075, 31, 30, "Index",
      CellTags->"Compiled"]},
  "Compiling"->{
    Cell[187455, 4556, 1073, 31, 30, "Index",
      CellTags->"Compiling"],
    Cell[500170, 17193, 1073, 31, 38, "Index",
      CellTags->"Compiling"],
    Cell[809810, 29703, 1073, 31, 30, "Index",
      CellTags->"Compiling"],
    Cell[1102269, 41526, 1073, 31, 38, "Index",
      CellTags->"Compiling"],
    Cell[1388551, 53090, 1073, 31, 38, "Index",
      CellTags->"Compiling"],
    Cell[1666406, 64295, 1073, 31, 30, "Index",
      CellTags->"Compiling"]},
  "CondenseGenealogy"->{
    Cell[188531, 4589, 286, 10, 15, "Index",
      CellTags->"CondenseGenealogy"],
    Cell[501246, 17226, 286, 10, 23, "Index",
      CellTags->"CondenseGenealogy"],
    Cell[810886, 29736, 286, 10, 15, "Index",
      CellTags->"CondenseGenealogy"],
    Cell[1103345, 41559, 286, 10, 23, "Index",
      CellTags->"CondenseGenealogy"],
    Cell[1389627, 53123, 286, 10, 23, "Index",
      CellTags->"CondenseGenealogy"],
    Cell[1667482, 64328, 286, 10, 15, "Index",
      CellTags->"CondenseGenealogy"]},
  "CondenseMatrix"->{
    Cell[188820, 4601, 271, 10, 15, "Index",
      CellTags->"CondenseMatrix"],
    Cell[501535, 17238, 271, 10, 23, "Index",
      CellTags->"CondenseMatrix"],
    Cell[811175, 29748, 271, 10, 15, "Index",
      CellTags->"CondenseMatrix"]},
  "ConfigurationSet"->{
    Cell[189094, 4613, 267, 10, 15, "Index",
      CellTags->"ConfigurationSet"],
    Cell[501809, 17250, 267, 10, 23, "Index",
      CellTags->"ConfigurationSet"]},
  "ConstrainedIntervals"->{
    Cell[189364, 4625, 289, 10, 15, "Index",
      CellTags->"ConstrainedIntervals"],
    Cell[502079, 17262, 289, 10, 23, "Index",
      CellTags->"ConstrainedIntervals"],
    Cell[811449, 29760, 289, 10, 15, "Index",
      CellTags->"ConstrainedIntervals"],
    Cell[1103634, 41571, 289, 10, 23, "Index",
      CellTags->"ConstrainedIntervals"],
    Cell[1389916, 53135, 289, 10, 23, "Index",
      CellTags->"ConstrainedIntervals"],
    Cell[1667771, 64340, 289, 10, 15, "Index",
      CellTags->"ConstrainedIntervals"]},
  "ConstructMutateList"->{
    Cell[189656, 4637, 754, 22, 15, "Index",
      CellTags->"ConstructMutateList"],
    Cell[502371, 17274, 754, 22, 23, "Index",
      CellTags->"ConstructMutateList"],
    Cell[811741, 29772, 754, 22, 15, "Index",
      CellTags->"ConstructMutateList"],
    Cell[1103926, 41583, 754, 22, 23, "Index",
      CellTags->"ConstructMutateList"],
    Cell[1390208, 53147, 754, 22, 23, "Index",
      CellTags->"ConstructMutateList"]},
  "ConstructMutateMatrix"->{
    Cell[190413, 4661, 442, 14, 15, "Index",
      CellTags->"ConstructMutateMatrix"],
    Cell[503128, 17298, 442, 14, 23, "Index",
      CellTags->"ConstructMutateMatrix"],
    Cell[812498, 29796, 442, 14, 15, "Index",
      CellTags->"ConstructMutateMatrix"],
    Cell[1104683, 41607, 442, 14, 23, "Index",
      CellTags->"ConstructMutateMatrix"],
    Cell[1390965, 53171, 442, 14, 23, "Index",
      CellTags->"ConstructMutateMatrix"]},
  "ContextComponentQ"->{
    Cell[190858, 4677, 286, 10, 15, "Index",
      CellTags->"ContextComponentQ"],
    Cell[503573, 17314, 286, 10, 23, "Index",
      CellTags->"ContextComponentQ"],
    Cell[812943, 29812, 286, 10, 15, "Index",
      CellTags->"ContextComponentQ"],
    Cell[1105128, 41623, 286, 10, 23, "Index",
      CellTags->"ContextComponentQ"],
    Cell[1391410, 53187, 286, 10, 23, "Index",
      CellTags->"ContextComponentQ"],
    Cell[1668063, 64352, 286, 10, 15, "Index",
      CellTags->"ContextComponentQ"]},
  "ContextPosition"->{
    Cell[191147, 4689, 280, 10, 15, "Index",
      CellTags->"ContextPosition"],
    Cell[503862, 17326, 280, 10, 23, "Index",
      CellTags->"ContextPosition"],
    Cell[813232, 29824, 280, 10, 15, "Index",
      CellTags->"ContextPosition"],
    Cell[1105417, 41635, 280, 10, 23, "Index",
      CellTags->"ContextPosition"],
    Cell[1391699, 53199, 280, 10, 23, "Index",
      CellTags->"ContextPosition"],
    Cell[1668352, 64364, 280, 10, 15, "Index",
      CellTags->"ContextPosition"]},
  "ContextStageQ"->{
    Cell[191430, 4701, 274, 10, 15, "Index",
      CellTags->"ContextStageQ"],
    Cell[504145, 17338, 274, 10, 23, "Index",
      CellTags->"ContextStageQ"],
    Cell[813515, 29836, 274, 10, 15, "Index",
      CellTags->"ContextStageQ"],
    Cell[1105700, 41647, 274, 10, 23, "Index",
      CellTags->"ContextStageQ"],
    Cell[1391982, 53211, 274, 10, 23, "Index",
      CellTags->"ContextStageQ"],
    Cell[1668635, 64376, 274, 10, 15, "Index",
      CellTags->"ContextStageQ"]},
  "ContextStructure"->{
    Cell[191707, 4713, 283, 10, 15, "Index",
      CellTags->"ContextStructure"],
    Cell[504422, 17350, 283, 10, 23, "Index",
      CellTags->"ContextStructure"],
    Cell[813792, 29848, 283, 10, 15, "Index",
      CellTags->"ContextStructure"],
    Cell[1105977, 41659, 283, 10, 23, "Index",
      CellTags->"ContextStructure"],
    Cell[1392259, 53223, 283, 10, 23, "Index",
      CellTags->"ContextStructure"],
    Cell[1668912, 64388, 283, 10, 15, "Index",
      CellTags->"ContextStructure"]},
  "Continuous populations"->{
    Cell[191993, 4725, 312, 11, 15, "Index",
      CellTags->"Continuous populations"],
    Cell[192308, 4738, 665, 27, 60, "IndexSubentry",
      CellTags->"Continuous populations"],
    Cell[504708, 17362, 312, 11, 23, "Index",
      CellTags->"Continuous populations"],
    Cell[505023, 17375, 665, 27, 68, "IndexSubentry",
      CellTags->"Continuous populations"],
    Cell[814078, 29860, 312, 11, 15, "Index",
      CellTags->"Continuous populations"],
    Cell[814393, 29873, 665, 27, 60, "IndexSubentry",
      CellTags->"Continuous populations"],
    Cell[1106263, 41671, 312, 11, 23, "Index",
      CellTags->"Continuous populations"],
    Cell[1106578, 41684, 665, 27, 68, "IndexSubentry",
      CellTags->"Continuous populations"],
    Cell[1392545, 53235, 312, 11, 23, "Index",
      CellTags->"Continuous populations"],
    Cell[1392860, 53248, 508, 21, 53, "IndexSubentry",
      CellTags->"Continuous populations"],
    Cell[1669198, 64400, 312, 11, 15, "Index",
      CellTags->"Continuous populations"],
    Cell[1669513, 64413, 508, 21, 45, "IndexSubentry",
      CellTags->"Continuous populations"]},
  "ContinuumVariables"->{
    Cell[192976, 4767, 273, 10, 15, "Index",
      CellTags->"ContinuumVariables"],
    Cell[505691, 17404, 273, 10, 23, "Index",
      CellTags->"ContinuumVariables"],
    Cell[815061, 29902, 273, 10, 15, "Index",
      CellTags->"ContinuumVariables"],
    Cell[1107246, 41713, 273, 10, 23, "Index",
      CellTags->"ContinuumVariables"]},
  "ConvertData"->{
    Cell[193252, 4779, 260, 10, 15, "Index",
      CellTags->"ConvertData"],
    Cell[505967, 17416, 260, 10, 23, "Index",
      CellTags->"ConvertData"],
    Cell[815337, 29914, 260, 10, 15, "Index",
      CellTags->"ConvertData"],
    Cell[1107522, 41725, 260, 10, 23, "Index",
      CellTags->"ConvertData"],
    Cell[1393371, 53271, 260, 10, 23, "Index",
      CellTags->"ConvertData"],
    Cell[1670024, 64436, 260, 10, 15, "Index",
      CellTags->"ConvertData"]},
  "ConvertHyperlinkToAddOnsLink"->{
    Cell[193515, 4791, 291, 10, 15, "Index",
      CellTags->"ConvertHyperlinkToAddOnsLink"],
    Cell[506230, 17428, 291, 10, 23, "Index",
      CellTags->"ConvertHyperlinkToAddOnsLink"],
    Cell[815600, 29926, 291, 10, 15, "Index",
      CellTags->"ConvertHyperlinkToAddOnsLink"],
    Cell[1107785, 41737, 291, 10, 23, "Index",
      CellTags->"ConvertHyperlinkToAddOnsLink"],
    Cell[1393634, 53283, 291, 10, 23, "Index",
      CellTags->"ConvertHyperlinkToAddOnsLink"],
    Cell[1670287, 64448, 291, 10, 15, "Index",
      CellTags->"ConvertHyperlinkToAddOnsLink"]},
  "Converting"->{
    Cell[193809, 4803, 427, 15, 15, "Index",
      CellTags->"Converting"],
    Cell[506524, 17440, 427, 15, 23, "Index",
      CellTags->"Converting"],
    Cell[815894, 29938, 427, 15, 15, "Index",
      CellTags->"Converting"],
    Cell[1108079, 41749, 427, 15, 23, "Index",
      CellTags->"Converting"],
    Cell[1393928, 53295, 427, 15, 23, "Index",
      CellTags->"Converting"],
    Cell[1670581, 64460, 427, 15, 15, "Index",
      CellTags->"Converting"]},
  "CountHeterozygotes"->{
    Cell[194239, 4820, 287, 10, 15, "Index",
      CellTags->"CountHeterozygotes"],
    Cell[506954, 17457, 287, 10, 23, "Index",
      CellTags->"CountHeterozygotes"],
    Cell[816324, 29955, 287, 10, 15, "Index",
      CellTags->"CountHeterozygotes"],
    Cell[1108509, 41766, 287, 10, 23, "Index",
      CellTags->"CountHeterozygotes"],
    Cell[1394358, 53312, 287, 10, 23, "Index",
      CellTags->"CountHeterozygotes"],
    Cell[1671011, 64477, 287, 10, 15, "Index",
      CellTags->"CountHeterozygotes"]},
  "Covariance"->{
    Cell[194529, 4832, 292, 11, 15, "Index",
      CellTags->"Covariance"],
    Cell[507244, 17469, 292, 11, 23, "Index",
      CellTags->"Covariance"],
    Cell[816614, 29967, 292, 11, 15, "Index",
      CellTags->"Covariance"],
    Cell[1108799, 41778, 292, 11, 23, "Index",
      CellTags->"Covariance"],
    Cell[1394648, 53324, 292, 11, 23, "Index",
      CellTags->"Covariance"],
    Cell[1671301, 64489, 292, 11, 15, "Index",
      CellTags->"Covariance"]},
  "CovarianceMidPoints"->{
    Cell[194824, 4845, 260, 10, 15, "Index",
      CellTags->"CovarianceMidPoints"],
    Cell[507539, 17482, 260, 10, 23, "Index",
      CellTags->"CovarianceMidPoints"],
    Cell[816909, 29980, 260, 10, 15, "Index",
      CellTags->"CovarianceMidPoints"],
    Cell[1109094, 41791, 260, 10, 23, "Index",
      CellTags->"CovarianceMidPoints"],
    Cell[1394943, 53337, 260, 10, 23, "Index",
      CellTags->"CovarianceMidPoints"],
    Cell[1671596, 64502, 260, 10, 15, "Index",
      CellTags->"CovarianceMidPoints"]},
  "Crow and Kimura 1970"->{
    Cell[195087, 4857, 289, 10, 15, "Index",
      CellTags->"Crow and Kimura 1970"],
    Cell[507802, 17494, 289, 10, 23, "Index",
      CellTags->"Crow and Kimura 1970"],
    Cell[817172, 29992, 289, 10, 15, "Index",
      CellTags->"Crow and Kimura 1970"],
    Cell[1109357, 41803, 289, 10, 23, "Index",
      CellTags->"Crow and Kimura 1970"],
    Cell[1395206, 53349, 289, 10, 23, "Index",
      CellTags->"Crow and Kimura 1970"],
    Cell[1671859, 64514, 289, 10, 15, "Index",
      CellTags->"Crow and Kimura 1970"]},
  "Cumulant"->{
    Cell[195379, 4869, 253, 10, 15, "Index",
      CellTags->"Cumulant"],
    Cell[508094, 17506, 253, 10, 23, "Index",
      CellTags->"Cumulant"],
    Cell[817464, 30004, 253, 10, 15, "Index",
      CellTags->"Cumulant"],
    Cell[1109649, 41815, 253, 10, 23, "Index",
      CellTags->"Cumulant"],
    Cell[1395498, 53361, 253, 10, 23, "Index",
      CellTags->"Cumulant"],
    Cell[1672151, 64526, 253, 10, 15, "Index",
      CellTags->"Cumulant"]},
  "CumulantDisequilibrium"->{
    Cell[195635, 4881, 332, 11, 15, "Index",
      CellTags->"CumulantDisequilibrium"],
    Cell[508350, 17518, 332, 11, 23, "Index",
      CellTags->"CumulantDisequilibrium"],
    Cell[817720, 30016, 332, 11, 15, "Index",
      CellTags->"CumulantDisequilibrium"],
    Cell[1109905, 41827, 332, 11, 23, "Index",
      CellTags->"CumulantDisequilibrium"],
    Cell[1395754, 53373, 332, 11, 23, "Index",
      CellTags->"CumulantDisequilibrium"],
    Cell[1672407, 64538, 332, 11, 15, "Index",
      CellTags->"CumulantDisequilibrium"]},
  "CumulantEquilibrium"->{
    Cell[195970, 4894, 264, 10, 15, "Index",
      CellTags->"CumulantEquilibrium"],
    Cell[508685, 17531, 264, 10, 23, "Index",
      CellTags->"CumulantEquilibrium"],
    Cell[818055, 30029, 264, 10, 15, "Index",
      CellTags->"CumulantEquilibrium"],
    Cell[1110240, 41840, 264, 10, 23, "Index",
      CellTags->"CumulantEquilibrium"],
    Cell[1396089, 53386, 264, 10, 23, "Index",
      CellTags->"CumulantEquilibrium"],
    Cell[1672742, 64551, 264, 10, 15, "Index",
      CellTags->"CumulantEquilibrium"]},
  "CumulantPopulationDisequilibrium"->{
    Cell[196237, 4906, 392, 11, 15, "Index",
      CellTags->"CumulantPopulationDisequilibrium"],
    Cell[508952, 17543, 392, 11, 23, "Index",
      CellTags->"CumulantPopulationDisequilibrium"],
    Cell[818322, 30041, 392, 11, 15, "Index",
      CellTags->"CumulantPopulationDisequilibrium"],
    Cell[1110507, 41852, 392, 11, 23, "Index",
      CellTags->"CumulantPopulationDisequilibrium"],
    Cell[1396356, 53398, 392, 11, 23, "Index",
      CellTags->"CumulantPopulationDisequilibrium"],
    Cell[1673009, 64563, 392, 11, 15, "Index",
      CellTags->"CumulantPopulationDisequilibrium"]},
  "CumulantReduced"->{
    Cell[196632, 4919, 268, 10, 15, "Index",
      CellTags->"CumulantReduced"],
    Cell[509347, 17556, 268, 10, 23, "Index",
      CellTags->"CumulantReduced"],
    Cell[818717, 30054, 268, 10, 15, "Index",
      CellTags->"CumulantReduced"],
    Cell[1110902, 41865, 268, 10, 23, "Index",
      CellTags->"CumulantReduced"],
    Cell[1396751, 53411, 268, 10, 23, "Index",
      CellTags->"CumulantReduced"],
    Cell[1673404, 64576, 268, 10, 15, "Index",
      CellTags->"CumulantReduced"]},
  "Cumulants"->{
    Cell[196903, 4931, 333, 14, 15, "Index",
      CellTags->"Cumulants"],
    Cell[509618, 17568, 333, 14, 23, "Index",
      CellTags->"Cumulants"],
    Cell[818988, 30066, 333, 14, 15, "Index",
      CellTags->"Cumulants"],
    Cell[1111173, 41877, 333, 14, 23, "Index",
      CellTags->"Cumulants"],
    Cell[1397022, 53423, 333, 14, 23, "Index",
      CellTags->"Cumulants"],
    Cell[1673675, 64588, 333, 14, 15, "Index",
      CellTags->"Cumulants"]},
  "Cytoplasmic inheritance"->{
    Cell[197239, 4947, 426, 14, 15, "Index",
      CellTags->"Cytoplasmic inheritance"],
    Cell[197668, 4963, 440, 15, 30, "IndexSubentry",
      CellTags->"Cytoplasmic inheritance"],
    Cell[509954, 17584, 426, 14, 23, "Index",
      CellTags->"Cytoplasmic inheritance"],
    Cell[510383, 17600, 440, 15, 38, "IndexSubentry",
      CellTags->"Cytoplasmic inheritance"],
    Cell[819324, 30082, 426, 14, 15, "Index",
      CellTags->"Cytoplasmic inheritance"],
    Cell[819753, 30098, 440, 15, 30, "IndexSubentry",
      CellTags->"Cytoplasmic inheritance"],
    Cell[1111509, 41893, 426, 14, 23, "Index",
      CellTags->"Cytoplasmic inheritance"],
    Cell[1111938, 41909, 440, 15, 38, "IndexSubentry",
      CellTags->"Cytoplasmic inheritance"],
    Cell[1397358, 53439, 426, 14, 23, "Index",
      CellTags->"Cytoplasmic inheritance"],
    Cell[1397787, 53455, 440, 15, 38, "IndexSubentry",
      CellTags->"Cytoplasmic inheritance"],
    Cell[1674011, 64604, 426, 14, 15, "Index",
      CellTags->"Cytoplasmic inheritance"],
    Cell[1674440, 64620, 440, 15, 30, "IndexSubentry",
      CellTags->"Cytoplasmic inheritance"]},
  "CytoplasmicLoci"->{
    Cell[198111, 4980, 283, 11, 15, "Index",
      CellTags->"CytoplasmicLoci"],
    Cell[198397, 4993, 453, 15, 30, "IndexSubentry",
      CellTags->"CytoplasmicLoci"],
    Cell[510826, 17617, 283, 11, 23, "Index",
      CellTags->"CytoplasmicLoci"],
    Cell[511112, 17630, 453, 15, 38, "IndexSubentry",
      CellTags->"CytoplasmicLoci"],
    Cell[820196, 30115, 283, 11, 15, "Index",
      CellTags->"CytoplasmicLoci"],
    Cell[820482, 30128, 453, 15, 30, "IndexSubentry",
      CellTags->"CytoplasmicLoci"],
    Cell[1112381, 41926, 283, 11, 23, "Index",
      CellTags->"CytoplasmicLoci"],
    Cell[1112667, 41939, 453, 15, 38, "IndexSubentry",
      CellTags->"CytoplasmicLoci"],
    Cell[1398230, 53472, 283, 11, 23, "Index",
      CellTags->"CytoplasmicLoci"],
    Cell[1398516, 53485, 453, 15, 38, "IndexSubentry",
      CellTags->"CytoplasmicLoci"],
    Cell[1674883, 64637, 283, 11, 15, "Index",
      CellTags->"CytoplasmicLoci"],
    Cell[1675169, 64650, 453, 15, 30, "IndexSubentry",
      CellTags->"CytoplasmicLoci"]},
  "dAlleleFrequencyPermutations"->{
    Cell[198853, 5010, 307, 10, 15, "Index",
      CellTags->"dAlleleFrequencyPermutations"],
    Cell[511568, 17647, 307, 10, 23, "Index",
      CellTags->"dAlleleFrequencyPermutations"],
    Cell[820938, 30145, 307, 10, 15, "Index",
      CellTags->"dAlleleFrequencyPermutations"],
    Cell[1113123, 41956, 307, 10, 23, "Index",
      CellTags->"dAlleleFrequencyPermutations"],
    Cell[1398972, 53502, 307, 10, 23, "Index",
      CellTags->"dAlleleFrequencyPermutations"],
    Cell[1675625, 64667, 307, 10, 15, "Index",
      CellTags->"dAlleleFrequencyPermutations"]},
  "Data"->{
    Cell[199163, 5022, 235, 10, 15, "Index",
      CellTags->"Data"],
    Cell[199401, 5034, 423, 15, 30, "IndexSubentry",
      CellTags->"Data"],
    Cell[511878, 17659, 235, 10, 23, "Index",
      CellTags->"Data"],
    Cell[512116, 17671, 423, 15, 38, "IndexSubentry",
      CellTags->"Data"],
    Cell[821248, 30157, 235, 10, 15, "Index",
      CellTags->"Data"],
    Cell[821486, 30169, 423, 15, 30, "IndexSubentry",
      CellTags->"Data"],
    Cell[1113433, 41968, 235, 10, 23, "Index",
      CellTags->"Data"],
    Cell[1113671, 41980, 423, 15, 38, "IndexSubentry",
      CellTags->"Data"],
    Cell[1399282, 53514, 235, 10, 23, "Index",
      CellTags->"Data"],
    Cell[1399520, 53526, 423, 15, 38, "IndexSubentry",
      CellTags->"Data"],
    Cell[1675935, 64679, 235, 10, 15, "Index",
      CellTags->"Data"],
    Cell[1676173, 64691, 423, 15, 30, "IndexSubentry",
      CellTags->"Data"]},
  "Datasets"->{
    Cell[199827, 5051, 259, 11, 15, "Index",
      CellTags->"Datasets"],
    Cell[512542, 17688, 259, 11, 23, "Index",
      CellTags->"Datasets"],
    Cell[821912, 30186, 259, 11, 15, "Index",
      CellTags->"Datasets"],
    Cell[1114097, 41997, 259, 11, 23, "Index",
      CellTags->"Datasets"],
    Cell[1399946, 53543, 259, 11, 23, "Index",
      CellTags->"Datasets"],
    Cell[1676599, 64708, 259, 11, 15, "Index",
      CellTags->"Datasets"]},
  "Dawson 2000"->{
    Cell[200089, 5064, 368, 14, 15, "Index",
      CellTags->"Dawson 2000"],
    Cell[512804, 17701, 368, 14, 23, "Index",
      CellTags->"Dawson 2000"],
    Cell[822174, 30199, 368, 14, 15, "Index",
      CellTags->"Dawson 2000"],
    Cell[1114359, 42010, 368, 14, 23, "Index",
      CellTags->"Dawson 2000"]},
  "Death"->{
    Cell[200460, 5080, 262, 10, 15, "Index",
      CellTags->"Death"],
    Cell[513175, 17717, 262, 10, 23, "Index",
      CellTags->"Death"],
    Cell[822545, 30215, 262, 10, 15, "Index",
      CellTags->"Death"],
    Cell[1114730, 42026, 262, 10, 23, "Index",
      CellTags->"Death"],
    Cell[1400208, 53556, 262, 10, 23, "Index",
      CellTags->"Death"],
    Cell[1676861, 64721, 262, 10, 15, "Index",
      CellTags->"Death"]},
  "DeathTime"->{
    Cell[200725, 5092, 258, 10, 15, "Index",
      CellTags->"DeathTime"],
    Cell[513440, 17729, 258, 10, 23, "Index",
      CellTags->"DeathTime"],
    Cell[822810, 30227, 258, 10, 15, "Index",
      CellTags->"DeathTime"],
    Cell[1114995, 42038, 258, 10, 23, "Index",
      CellTags->"DeathTime"],
    Cell[1400473, 53568, 258, 10, 23, "Index",
      CellTags->"DeathTime"],
    Cell[1677126, 64733, 258, 10, 15, "Index",
      CellTags->"DeathTime"]},
  "DefineContext"->{
    Cell[200986, 5104, 274, 10, 15, "Index",
      CellTags->"DefineContext"],
    Cell[513701, 17741, 274, 10, 23, "Index",
      CellTags->"DefineContext"],
    Cell[823071, 30239, 274, 10, 15, "Index",
      CellTags->"DefineContext"],
    Cell[1115256, 42050, 274, 10, 23, "Index",
      CellTags->"DefineContext"],
    Cell[1400734, 53580, 274, 10, 23, "Index",
      CellTags->"DefineContext"],
    Cell[1677387, 64745, 274, 10, 15, "Index",
      CellTags->"DefineContext"]},
  "DegreesOfFreedom"->{
    Cell[201263, 5116, 271, 10, 15, "Index",
      CellTags->"DegreesOfFreedom"],
    Cell[513978, 17753, 271, 10, 23, "Index",
      CellTags->"DegreesOfFreedom"],
    Cell[823348, 30251, 271, 10, 15, "Index",
      CellTags->"DegreesOfFreedom"],
    Cell[1115533, 42062, 271, 10, 23, "Index",
      CellTags->"DegreesOfFreedom"],
    Cell[1401011, 53592, 271, 10, 23, "Index",
      CellTags->"DegreesOfFreedom"],
    Cell[1677664, 64757, 271, 10, 15, "Index",
      CellTags->"DegreesOfFreedom"]},
  "DeletedMutations"->{
    Cell[201537, 5128, 279, 10, 15, "Index",
      CellTags->"DeletedMutations"],
    Cell[514252, 17765, 279, 10, 23, "Index",
      CellTags->"DeletedMutations"],
    Cell[823622, 30263, 279, 10, 15, "Index",
      CellTags->"DeletedMutations"],
    Cell[1115807, 42074, 279, 10, 23, "Index",
      CellTags->"DeletedMutations"],
    Cell[1401285, 53604, 279, 10, 23, "Index",
      CellTags->"DeletedMutations"],
    Cell[1677938, 64769, 279, 10, 15, "Index",
      CellTags->"DeletedMutations"]},
  "DeleteGenealogy"->{
    Cell[201819, 5140, 280, 10, 15, "Index",
      CellTags->"DeleteGenealogy"],
    Cell[514534, 17777, 280, 10, 23, "Index",
      CellTags->"DeleteGenealogy"],
    Cell[823904, 30275, 280, 10, 15, "Index",
      CellTags->"DeleteGenealogy"],
    Cell[1116089, 42086, 280, 10, 23, "Index",
      CellTags->"DeleteGenealogy"],
    Cell[1401567, 53616, 280, 10, 23, "Index",
      CellTags->"DeleteGenealogy"],
    Cell[1678220, 64781, 280, 10, 15, "Index",
      CellTags->"DeleteGenealogy"]},
  "DeleteNullLineages"->{
    Cell[202102, 5152, 321, 11, 15, "Index",
      CellTags->"DeleteNullLineages"],
    Cell[202426, 5165, 311, 9, 15, "IndexSubentry",
      CellTags->"DeleteNullLineages"],
    Cell[514817, 17789, 321, 11, 23, "Index",
      CellTags->"DeleteNullLineages"],
    Cell[515141, 17802, 311, 9, 23, "IndexSubentry",
      CellTags->"DeleteNullLineages"]},
  "Deme"->{
    Cell[202740, 5176, 322, 14, 15, "Index",
      CellTags->"Deme"],
    Cell[515455, 17813, 322, 14, 23, "Index",
      CellTags->"Deme"],
    Cell[824187, 30287, 322, 14, 15, "Index",
      CellTags->"Deme"],
    Cell[1116372, 42098, 322, 14, 23, "Index",
      CellTags->"Deme"],
    Cell[1401850, 53628, 322, 14, 23, "Index",
      CellTags->"Deme"],
    Cell[1678503, 64793, 322, 14, 15, "Index",
      CellTags->"Deme"]},
  "DemeSize"->{
    Cell[203065, 5192, 614, 20, 15, "Index",
      CellTags->"DemeSize"],
    Cell[203682, 5214, 3024, 86, 149, "IndexSubentry",
      CellTags->"DemeSize"],
    Cell[515780, 17829, 614, 20, 23, "Index",
      CellTags->"DemeSize"],
    Cell[516397, 17851, 3026, 86, 142, "IndexSubentry",
      CellTags->"DemeSize"],
    Cell[824512, 30303, 614, 20, 15, "Index",
      CellTags->"DemeSize"],
    Cell[825129, 30325, 3024, 86, 134, "IndexSubentry",
      CellTags->"DemeSize"],
    Cell[1116697, 42114, 614, 20, 23, "Index",
      CellTags->"DemeSize"],
    Cell[1117314, 42136, 3024, 86, 142, "IndexSubentry",
      CellTags->"DemeSize"],
    Cell[1402175, 53644, 614, 20, 23, "Index",
      CellTags->"DemeSize"],
    Cell[1402792, 53666, 3024, 86, 142, "IndexSubentry",
      CellTags->"DemeSize"],
    Cell[1678828, 64809, 614, 20, 15, "Index",
      CellTags->"DemeSize"],
    Cell[1679445, 64831, 3024, 86, 134, "IndexSubentry",
      CellTags->"DemeSize"]},
  "Dempster et al 1977"->{
    Cell[206709, 5302, 264, 10, 15, "Index",
      CellTags->"Dempster et al 1977"],
    Cell[519426, 17939, 264, 10, 23, "Index",
      CellTags->"Dempster et al 1977"],
    Cell[828156, 30413, 264, 10, 15, "Index",
      CellTags->"Dempster et al 1977"],
    Cell[1120341, 42224, 264, 10, 23, "Index",
      CellTags->"Dempster et al 1977"],
    Cell[1405819, 53754, 264, 10, 23, "Index",
      CellTags->"Dempster et al 1977"],
    Cell[1682472, 64919, 264, 10, 15, "Index",
      CellTags->"Dempster et al 1977"]},
  "Density"->{
    Cell[206976, 5314, 252, 10, 15, "Index",
      CellTags->"Density"],
    Cell[519693, 17951, 252, 10, 23, "Index",
      CellTags->"Density"],
    Cell[828423, 30425, 252, 10, 15, "Index",
      CellTags->"Density"],
    Cell[1120608, 42236, 252, 10, 23, "Index",
      CellTags->"Density"],
    Cell[1406086, 53766, 252, 10, 23, "Index",
      CellTags->"Density"],
    Cell[1682739, 64931, 252, 10, 15, "Index",
      CellTags->"Density"]},
  "Descendants"->{
    Cell[207231, 5326, 270, 10, 15, "Index",
      CellTags->"Descendants"],
    Cell[207504, 5338, 436, 15, 30, "IndexSubentry",
      CellTags->"Descendants"],
    Cell[519948, 17963, 270, 10, 23, "Index",
      CellTags->"Descendants"],
    Cell[520221, 17975, 436, 15, 38, "IndexSubentry",
      CellTags->"Descendants"],
    Cell[828678, 30437, 270, 10, 15, "Index",
      CellTags->"Descendants"],
    Cell[828951, 30449, 263, 9, 15, "IndexSubentry",
      CellTags->"Descendants"],
    Cell[1120863, 42248, 270, 10, 23, "Index",
      CellTags->"Descendants"],
    Cell[1121136, 42260, 263, 9, 23, "IndexSubentry",
      CellTags->"Descendants"],
    Cell[1406341, 53778, 270, 10, 23, "Index",
      CellTags->"Descendants"],
    Cell[1406614, 53790, 263, 9, 23, "IndexSubentry",
      CellTags->"Descendants"],
    Cell[1682994, 64943, 270, 10, 15, "Index",
      CellTags->"Descendants"],
    Cell[1683267, 64955, 263, 9, 15, "IndexSubentry",
      CellTags->"Descendants"]},
  "Dicytonuclear associations"->{
    Cell[207943, 5355, 296, 10, 15, "Index",
      CellTags->"Dicytonuclear associations"],
    Cell[520660, 17992, 296, 10, 23, "Index",
      CellTags->"Dicytonuclear associations"],
    Cell[829217, 30460, 296, 10, 15, "Index",
      CellTags->"Dicytonuclear associations"],
    Cell[1121402, 42271, 296, 10, 23, "Index",
      CellTags->"Dicytonuclear associations"],
    Cell[1406880, 53801, 296, 10, 23, "Index",
      CellTags->"Dicytonuclear associations"],
    Cell[1683533, 64966, 296, 10, 15, "Index",
      CellTags->"Dicytonuclear associations"]},
  "Diploid"->{
    Cell[208242, 5367, 304, 11, 15, "Index",
      CellTags->"Diploid"],
    Cell[520959, 18004, 304, 11, 23, "Index",
      CellTags->"Diploid"],
    Cell[829516, 30472, 304, 11, 15, "Index",
      CellTags->"Diploid"],
    Cell[1121701, 42283, 304, 11, 23, "Index",
      CellTags->"Diploid"],
    Cell[1407179, 53813, 304, 11, 23, "Index",
      CellTags->"Diploid"],
    Cell[1683832, 64978, 304, 11, 15, "Index",
      CellTags->"Diploid"]},
  "DiploidConstraints"->{
    Cell[208549, 5380, 277, 10, 15, "Index",
      CellTags->"DiploidConstraints"],
    Cell[521266, 18017, 277, 10, 23, "Index",
      CellTags->"DiploidConstraints"],
    Cell[829823, 30485, 277, 10, 15, "Index",
      CellTags->"DiploidConstraints"],
    Cell[1122008, 42296, 277, 10, 23, "Index",
      CellTags->"DiploidConstraints"],
    Cell[1407486, 53826, 277, 10, 23, "Index",
      CellTags->"DiploidConstraints"],
    Cell[1684139, 64991, 277, 10, 15, "Index",
      CellTags->"DiploidConstraints"]},
  "DiploidFrequencies"->{
    Cell[208829, 5392, 297, 10, 15, "Index",
      CellTags->"DiploidFrequencies"],
    Cell[521546, 18029, 297, 10, 23, "Index",
      CellTags->"DiploidFrequencies"],
    Cell[830103, 30497, 297, 10, 15, "Index",
      CellTags->"DiploidFrequencies"],
    Cell[1122288, 42308, 297, 10, 23, "Index",
      CellTags->"DiploidFrequencies"],
    Cell[1407766, 53838, 297, 10, 23, "Index",
      CellTags->"DiploidFrequencies"],
    Cell[1684419, 65003, 297, 10, 15, "Index",
      CellTags->"DiploidFrequencies"]},
  "DiploidGenotypeFrequency"->{
    Cell[209129, 5404, 332, 11, 15, "Index",
      CellTags->"DiploidGenotypeFrequency"],
    Cell[521846, 18041, 332, 11, 23, "Index",
      CellTags->"DiploidGenotypeFrequency"],
    Cell[830403, 30509, 332, 11, 15, "Index",
      CellTags->"DiploidGenotypeFrequency"],
    Cell[1122588, 42320, 332, 11, 23, "Index",
      CellTags->"DiploidGenotypeFrequency"],
    Cell[1408066, 53850, 332, 11, 23, "Index",
      CellTags->"DiploidGenotypeFrequency"],
    Cell[1684719, 65015, 332, 11, 15, "Index",
      CellTags->"DiploidGenotypeFrequency"]},
  "DiploidGenotypeFrequencyList"->{
    Cell[209464, 5417, 305, 10, 15, "Index",
      CellTags->"DiploidGenotypeFrequencyList"],
    Cell[522181, 18054, 305, 10, 23, "Index",
      CellTags->"DiploidGenotypeFrequencyList"],
    Cell[830738, 30522, 305, 10, 15, "Index",
      CellTags->"DiploidGenotypeFrequencyList"],
    Cell[1122923, 42333, 305, 10, 23, "Index",
      CellTags->"DiploidGenotypeFrequencyList"],
    Cell[1408401, 53863, 305, 10, 23, "Index",
      CellTags->"DiploidGenotypeFrequencyList"],
    Cell[1685054, 65028, 305, 10, 15, "Index",
      CellTags->"DiploidGenotypeFrequencyList"]},
  "DiploidGenotypeFrequencyReduced"->{
    Cell[209772, 5429, 316, 10, 15, "Index",
      CellTags->"DiploidGenotypeFrequencyReduced"],
    Cell[522489, 18066, 316, 10, 23, "Index",
      CellTags->"DiploidGenotypeFrequencyReduced"],
    Cell[831046, 30534, 316, 10, 15, "Index",
      CellTags->"DiploidGenotypeFrequencyReduced"],
    Cell[1123231, 42345, 316, 10, 23, "Index",
      CellTags->"DiploidGenotypeFrequencyReduced"],
    Cell[1408709, 53875, 316, 10, 23, "Index",
      CellTags->"DiploidGenotypeFrequencyReduced"],
    Cell[1685362, 65040, 316, 10, 15, "Index",
      CellTags->"DiploidGenotypeFrequencyReduced"]},
  "DiploidGenotypeFrequencyTable"->{
    Cell[210091, 5441, 310, 10, 15, "Index",
      CellTags->"DiploidGenotypeFrequencyTable"],
    Cell[522808, 18078, 310, 10, 23, "Index",
      CellTags->"DiploidGenotypeFrequencyTable"],
    Cell[831365, 30546, 310, 10, 15, "Index",
      CellTags->"DiploidGenotypeFrequencyTable"],
    Cell[1123550, 42357, 310, 10, 23, "Index",
      CellTags->"DiploidGenotypeFrequencyTable"],
    Cell[1409028, 53887, 310, 10, 23, "Index",
      CellTags->"DiploidGenotypeFrequencyTable"],
    Cell[1685681, 65052, 310, 10, 15, "Index",
      CellTags->"DiploidGenotypeFrequencyTable"]},
  "DiploidIndividuals"->{
    Cell[210404, 5453, 297, 10, 15, "Index",
      CellTags->"DiploidIndividuals"],
    Cell[523121, 18090, 297, 10, 23, "Index",
      CellTags->"DiploidIndividuals"],
    Cell[831678, 30558, 297, 10, 15, "Index",
      CellTags->"DiploidIndividuals"],
    Cell[1123863, 42369, 297, 10, 23, "Index",
      CellTags->"DiploidIndividuals"],
    Cell[1409341, 53899, 297, 10, 23, "Index",
      CellTags->"DiploidIndividuals"],
    Cell[1685994, 65064, 297, 10, 15, "Index",
      CellTags->"DiploidIndividuals"]},
  "DiploidPhenotype"->{
    Cell[210704, 5465, 275, 10, 15, "Index",
      CellTags->"DiploidPhenotype"],
    Cell[523421, 18102, 275, 10, 23, "Index",
      CellTags->"DiploidPhenotype"],
    Cell[831978, 30570, 275, 10, 15, "Index",
      CellTags->"DiploidPhenotype"],
    Cell[1124163, 42381, 275, 10, 23, "Index",
      CellTags->"DiploidPhenotype"],
    Cell[1409641, 53911, 275, 10, 23, "Index",
      CellTags->"DiploidPhenotype"],
    Cell[1686294, 65076, 275, 10, 15, "Index",
      CellTags->"DiploidPhenotype"]},
  "DiploidPsi"->{
    Cell[210982, 5477, 402, 14, 15, "Index",
      CellTags->"DiploidPsi"],
    Cell[523699, 18114, 402, 14, 23, "Index",
      CellTags->"DiploidPsi"],
    Cell[832256, 30582, 402, 14, 15, "Index",
      CellTags->"DiploidPsi"],
    Cell[1124441, 42393, 402, 14, 23, "Index",
      CellTags->"DiploidPsi"],
    Cell[1409919, 53923, 402, 14, 23, "Index",
      CellTags->"DiploidPsi"],
    Cell[1686572, 65088, 402, 14, 15, "Index",
      CellTags->"DiploidPsi"]},
  "DiploidRepresentations"->{
    Cell[211387, 5493, 309, 10, 15, "Index",
      CellTags->"DiploidRepresentations"],
    Cell[524104, 18130, 309, 10, 23, "Index",
      CellTags->"DiploidRepresentations"],
    Cell[832661, 30598, 309, 10, 15, "Index",
      CellTags->"DiploidRepresentations"],
    Cell[1124846, 42409, 309, 10, 23, "Index",
      CellTags->"DiploidRepresentations"],
    Cell[1410324, 53939, 309, 10, 23, "Index",
      CellTags->"DiploidRepresentations"],
    Cell[1686977, 65104, 309, 10, 15, "Index",
      CellTags->"DiploidRepresentations"]},
  "DiploidSource"->{
    Cell[211699, 5505, 414, 14, 15, "Index",
      CellTags->"DiploidSource"],
    Cell[524416, 18142, 414, 14, 23, "Index",
      CellTags->"DiploidSource"],
    Cell[832973, 30610, 414, 14, 15, "Index",
      CellTags->"DiploidSource"],
    Cell[1125158, 42421, 414, 14, 23, "Index",
      CellTags->"DiploidSource"],
    Cell[1410636, 53951, 414, 14, 23, "Index",
      CellTags->"DiploidSource"],
    Cell[1687289, 65116, 414, 14, 15, "Index",
      CellTags->"DiploidSource"]},
  "DiploidSubsets"->{
    Cell[212116, 5521, 259, 10, 15, "Index",
      CellTags->"DiploidSubsets"],
    Cell[524833, 18158, 259, 10, 23, "Index",
      CellTags->"DiploidSubsets"],
    Cell[833390, 30626, 259, 10, 15, "Index",
      CellTags->"DiploidSubsets"],
    Cell[1125575, 42437, 259, 10, 23, "Index",
      CellTags->"DiploidSubsets"],
    Cell[1411053, 53967, 259, 10, 23, "Index",
      CellTags->"DiploidSubsets"],
    Cell[1687706, 65132, 259, 10, 15, "Index",
      CellTags->"DiploidSubsets"]},
  "DiploidTypes"->{
    Cell[212378, 5533, 257, 10, 15, "Index",
      CellTags->"DiploidTypes"],
    Cell[525095, 18170, 257, 10, 23, "Index",
      CellTags->"DiploidTypes"],
    Cell[833652, 30638, 257, 10, 15, "Index",
      CellTags->"DiploidTypes"],
    Cell[1125837, 42449, 257, 10, 23, "Index",
      CellTags->"DiploidTypes"],
    Cell[1411315, 53979, 257, 10, 23, "Index",
      CellTags->"DiploidTypes"],
    Cell[1687968, 65144, 257, 10, 15, "Index",
      CellTags->"DiploidTypes"]},
  "Disequilibrium"->{
    Cell[212638, 5545, 283, 11, 15, "Index",
      CellTags->"Disequilibrium"],
    Cell[212924, 5558, 919, 29, 45, "IndexSubentry",
      CellTags->"Disequilibrium"],
    Cell[525355, 18182, 283, 11, 23, "Index",
      CellTags->"Disequilibrium"],
    Cell[525641, 18195, 919, 29, 53, "IndexSubentry",
      CellTags->"Disequilibrium"],
    Cell[833912, 30650, 283, 11, 15, "Index",
      CellTags->"Disequilibrium"],
    Cell[834198, 30663, 919, 29, 45, "IndexSubentry",
      CellTags->"Disequilibrium"],
    Cell[1126097, 42461, 283, 11, 23, "Index",
      CellTags->"Disequilibrium"],
    Cell[1126383, 42474, 919, 29, 53, "IndexSubentry",
      CellTags->"Disequilibrium"],
    Cell[1411575, 53991, 281, 11, 23, "Index",
      CellTags->"Disequilibrium"],
    Cell[1411859, 54004, 590, 17, 23, "IndexSubentry",
      CellTags->"Disequilibrium"],
    Cell[1688228, 65156, 281, 11, 15, "Index",
      CellTags->"Disequilibrium"],
    Cell[1688512, 65169, 590, 17, 15, "IndexSubentry",
      CellTags->"Disequilibrium"]},
  "DisequilibriumMean"->{
    Cell[213846, 5589, 337, 11, 15, "Index",
      CellTags->"DisequilibriumMean"],
    Cell[214186, 5602, 744, 23, 45, "IndexSubentry",
      CellTags->"DisequilibriumMean"],
    Cell[526563, 18226, 339, 11, 23, "Index",
      CellTags->"DisequilibriumMean"],
    Cell[526905, 18239, 744, 23, 53, "IndexSubentry",
      CellTags->"DisequilibriumMean"],
    Cell[835120, 30694, 337, 11, 15, "Index",
      CellTags->"DisequilibriumMean"],
    Cell[835460, 30707, 744, 23, 45, "IndexSubentry",
      CellTags->"DisequilibriumMean"],
    Cell[1127305, 42505, 337, 11, 23, "Index",
      CellTags->"DisequilibriumMean"],
    Cell[1127645, 42518, 744, 23, 53, "IndexSubentry",
      CellTags->"DisequilibriumMean"],
    Cell[1412452, 54023, 337, 11, 23, "Index",
      CellTags->"DisequilibriumMean"],
    Cell[1412792, 54036, 744, 23, 53, "IndexSubentry",
      CellTags->"DisequilibriumMean"],
    Cell[1689105, 65188, 337, 11, 15, "Index",
      CellTags->"DisequilibriumMean"],
    Cell[1689445, 65201, 744, 23, 45, "IndexSubentry",
      CellTags->"DisequilibriumMean"]},
  "DisequilibriumTable"->{
    Cell[214933, 5627, 340, 11, 15, "Index",
      CellTags->"DisequilibriumTable"],
    Cell[215276, 5640, 748, 23, 45, "IndexSubentry",
      CellTags->"DisequilibriumTable"],
    Cell[527652, 18264, 347, 12, 23, "Index",
      CellTags->"DisequilibriumTable"],
    Cell[528002, 18278, 748, 23, 53, "IndexSubentry",
      CellTags->"DisequilibriumTable"],
    Cell[836207, 30732, 340, 11, 15, "Index",
      CellTags->"DisequilibriumTable"],
    Cell[836550, 30745, 748, 23, 45, "IndexSubentry",
      CellTags->"DisequilibriumTable"],
    Cell[1128392, 42543, 340, 11, 23, "Index",
      CellTags->"DisequilibriumTable"],
    Cell[1128735, 42556, 748, 23, 53, "IndexSubentry",
      CellTags->"DisequilibriumTable"],
    Cell[1413539, 54061, 340, 11, 23, "Index",
      CellTags->"DisequilibriumTable"],
    Cell[1413882, 54074, 748, 23, 53, "IndexSubentry",
      CellTags->"DisequilibriumTable"],
    Cell[1690192, 65226, 340, 11, 15, "Index",
      CellTags->"DisequilibriumTable"],
    Cell[1690535, 65239, 748, 23, 45, "IndexSubentry",
      CellTags->"DisequilibriumTable"]},
  "Dispersal"->{
    Cell[216027, 5665, 299, 11, 15, "Index",
      CellTags->"Dispersal"],
    Cell[528753, 18303, 299, 11, 23, "Index",
      CellTags->"Dispersal"],
    Cell[837301, 30770, 299, 11, 15, "Index",
      CellTags->"Dispersal"],
    Cell[1129486, 42581, 299, 11, 23, "Index",
      CellTags->"Dispersal"]},
  "DistanceSquared"->{
    Cell[216329, 5678, 276, 10, 15, "Index",
      CellTags->"DistanceSquared"],
    Cell[529055, 18316, 276, 10, 23, "Index",
      CellTags->"DistanceSquared"],
    Cell[837603, 30783, 276, 10, 15, "Index",
      CellTags->"DistanceSquared"],
    Cell[1129788, 42594, 276, 10, 23, "Index",
      CellTags->"DistanceSquared"],
    Cell[1414633, 54099, 276, 10, 23, "Index",
      CellTags->"DistanceSquared"],
    Cell[1691286, 65264, 276, 10, 15, "Index",
      CellTags->"DistanceSquared"]},
  "Distribution"->{
    Cell[216608, 5690, 241, 10, 15, "Index",
      CellTags->"Distribution"],
    Cell[529334, 18328, 241, 10, 23, "Index",
      CellTags->"Distribution"],
    Cell[837882, 30795, 241, 10, 15, "Index",
      CellTags->"Distribution"],
    Cell[1130067, 42606, 241, 10, 23, "Index",
      CellTags->"Distribution"],
    Cell[1414912, 54111, 241, 10, 23, "Index",
      CellTags->"Distribution"],
    Cell[1691565, 65276, 241, 10, 15, "Index",
      CellTags->"Distribution"]},
  "DivideZero"->{
    Cell[216852, 5702, 237, 10, 15, "Index",
      CellTags->"DivideZero"],
    Cell[529578, 18340, 237, 10, 23, "Index",
      CellTags->"DivideZero"],
    Cell[838126, 30807, 237, 10, 15, "Index",
      CellTags->"DivideZero"],
    Cell[1130311, 42618, 237, 10, 23, "Index",
      CellTags->"DivideZero"],
    Cell[1415156, 54123, 237, 10, 23, "Index",
      CellTags->"DivideZero"],
    Cell[1691809, 65288, 237, 10, 15, "Index",
      CellTags->"DivideZero"]},
  "DoReplicates"->{
    Cell[217092, 5714, 277, 10, 15, "Index",
      CellTags->"DoReplicates"],
    Cell[529818, 18352, 277, 10, 23, "Index",
      CellTags->"DoReplicates"],
    Cell[838366, 30819, 277, 10, 15, "Index",
      CellTags->"DoReplicates"],
    Cell[1130551, 42630, 277, 10, 23, "Index",
      CellTags->"DoReplicates"],
    Cell[1415396, 54135, 277, 10, 23, "Index",
      CellTags->"DoReplicates"],
    Cell[1692049, 65300, 277, 10, 15, "Index",
      CellTags->"DoReplicates"]},
  "DoubleCline"->{
    Cell[217372, 5726, 353, 12, 15, "Index",
      CellTags->"DoubleCline"],
    Cell[217728, 5740, 772, 23, 45, "IndexSubentry",
      CellTags->"DoubleCline"],
    Cell[530098, 18364, 353, 12, 23, "Index",
      CellTags->"DoubleCline"],
    Cell[530454, 18378, 772, 23, 53, "IndexSubentry",
      CellTags->"DoubleCline"],
    Cell[838646, 30831, 353, 12, 15, "Index",
      CellTags->"DoubleCline"],
    Cell[839002, 30845, 772, 23, 45, "IndexSubentry",
      CellTags->"DoubleCline"],
    Cell[1130831, 42642, 353, 12, 23, "Index",
      CellTags->"DoubleCline"],
    Cell[1131187, 42656, 772, 23, 53, "IndexSubentry",
      CellTags->"DoubleCline"],
    Cell[1415676, 54147, 353, 12, 23, "Index",
      CellTags->"DoubleCline"],
    Cell[1416032, 54161, 772, 23, 53, "IndexSubentry",
      CellTags->"DoubleCline"],
    Cell[1692329, 65312, 353, 12, 15, "Index",
      CellTags->"DoubleCline"],
    Cell[1692685, 65326, 772, 23, 45, "IndexSubentry",
      CellTags->"DoubleCline"]},
  "DrawSamples"->{
    Cell[218503, 5765, 262, 10, 15, "Index",
      CellTags->"DrawSamples"],
    Cell[531229, 18403, 262, 10, 23, "Index",
      CellTags->"DrawSamples"],
    Cell[839777, 30870, 262, 10, 15, "Index",
      CellTags->"DrawSamples"],
    Cell[1131962, 42681, 262, 10, 23, "Index",
      CellTags->"DrawSamples"],
    Cell[1416807, 54186, 262, 10, 23, "Index",
      CellTags->"DrawSamples"],
    Cell[1693460, 65351, 262, 10, 15, "Index",
      CellTags->"DrawSamples"]},
  "DropOptions"->{
    Cell[218768, 5777, 260, 10, 15, "Index",
      CellTags->"DropOptions"],
    Cell[531494, 18415, 260, 10, 23, "Index",
      CellTags->"DropOptions"],
    Cell[840042, 30882, 260, 10, 15, "Index",
      CellTags->"DropOptions"],
    Cell[1132227, 42693, 260, 10, 23, "Index",
      CellTags->"DropOptions"],
    Cell[1417072, 54198, 260, 10, 23, "Index",
      CellTags->"DropOptions"],
    Cell[1693725, 65363, 260, 10, 15, "Index",
      CellTags->"DropOptions"]},
  "Edwards 1972"->{
    Cell[219031, 5789, 243, 10, 15, "Index",
      CellTags->"Edwards 1972"],
    Cell[531757, 18427, 243, 10, 23, "Index",
      CellTags->"Edwards 1972"],
    Cell[840305, 30894, 243, 10, 15, "Index",
      CellTags->"Edwards 1972"],
    Cell[1132490, 42705, 243, 10, 23, "Index",
      CellTags->"Edwards 1972"],
    Cell[1417335, 54210, 243, 10, 23, "Index",
      CellTags->"Edwards 1972"],
    Cell[1693988, 65375, 243, 10, 15, "Index",
      CellTags->"Edwards 1972"]},
  "EmptySets"->{
    Cell[219277, 5801, 272, 11, 15, "Index",
      CellTags->"EmptySets"],
    Cell[532003, 18439, 272, 11, 23, "Index",
      CellTags->"EmptySets"],
    Cell[840551, 30906, 272, 11, 15, "Index",
      CellTags->"EmptySets"],
    Cell[1132736, 42717, 272, 11, 23, "Index",
      CellTags->"EmptySets"]},
  "Epistasis"->{
    Cell[219552, 5814, 270, 11, 15, "Index",
      CellTags->"Epistasis"],
    Cell[532278, 18452, 270, 11, 23, "Index",
      CellTags->"Epistasis"],
    Cell[840826, 30919, 270, 11, 15, "Index",
      CellTags->"Epistasis"],
    Cell[1133011, 42730, 270, 11, 23, "Index",
      CellTags->"Epistasis"],
    Cell[1417581, 54222, 270, 11, 23, "Index",
      CellTags->"Epistasis"],
    Cell[1694234, 65387, 270, 11, 15, "Index",
      CellTags->"Epistasis"]},
  "EquivalentSexes"->{
    Cell[219825, 5827, 300, 11, 15, "Index",
      CellTags->"EquivalentSexes"],
    Cell[532551, 18465, 300, 11, 23, "Index",
      CellTags->"EquivalentSexes"],
    Cell[841099, 30932, 300, 11, 15, "Index",
      CellTags->"EquivalentSexes"],
    Cell[1133284, 42743, 300, 11, 23, "Index",
      CellTags->"EquivalentSexes"],
    Cell[1417854, 54235, 300, 11, 23, "Index",
      CellTags->"EquivalentSexes"],
    Cell[1694507, 65400, 300, 11, 15, "Index",
      CellTags->"EquivalentSexes"]},
  "ErrorBound"->{
    Cell[220128, 5840, 267, 10, 15, "Index",
      CellTags->"ErrorBound"],
    Cell[532854, 18478, 267, 10, 23, "Index",
      CellTags->"ErrorBound"],
    Cell[841402, 30945, 267, 10, 15, "Index",
      CellTags->"ErrorBound"],
    Cell[1133587, 42756, 267, 10, 23, "Index",
      CellTags->"ErrorBound"],
    Cell[1418157, 54248, 267, 10, 23, "Index",
      CellTags->"ErrorBound"],
    Cell[1694810, 65413, 267, 10, 15, "Index",
      CellTags->"ErrorBound"]},
  "EstimateFamilyMoments"->{
    Cell[220398, 5852, 298, 10, 15, "Index",
      CellTags->"EstimateFamilyMoments"],
    Cell[533124, 18490, 298, 10, 23, "Index",
      CellTags->"EstimateFamilyMoments"],
    Cell[841672, 30957, 298, 10, 15, "Index",
      CellTags->"EstimateFamilyMoments"],
    Cell[1133857, 42768, 298, 10, 23, "Index",
      CellTags->"EstimateFamilyMoments"],
    Cell[1418427, 54260, 298, 10, 23, "Index",
      CellTags->"EstimateFamilyMoments"],
    Cell[1695080, 65425, 298, 10, 15, "Index",
      CellTags->"EstimateFamilyMoments"]},
  "EstimateMoments"->{
    Cell[220699, 5864, 274, 10, 15, "Index",
      CellTags->"EstimateMoments"],
    Cell[533425, 18502, 274, 10, 23, "Index",
      CellTags->"EstimateMoments"],
    Cell[841973, 30969, 274, 10, 15, "Index",
      CellTags->"EstimateMoments"],
    Cell[1134158, 42780, 274, 10, 23, "Index",
      CellTags->"EstimateMoments"],
    Cell[1418728, 54272, 274, 10, 23, "Index",
      CellTags->"EstimateMoments"],
    Cell[1695381, 65437, 274, 10, 15, "Index",
      CellTags->"EstimateMoments"]},
  "Estimating D"->{
    Cell[220976, 5876, 269, 11, 15, "Index",
      CellTags->"Estimating D"],
    Cell[221248, 5889, 2407, 92, 210, "IndexSubentry",
      CellTags->"Estimating D"],
    Cell[533702, 18514, 269, 11, 23, "Index",
      CellTags->"Estimating D"],
    Cell[533974, 18527, 2407, 92, 218, "IndexSubentry",
      CellTags->"Estimating D"],
    Cell[842250, 30981, 269, 11, 15, "Index",
      CellTags->"Estimating D"],
    Cell[842522, 30994, 2407, 92, 210, "IndexSubentry",
      CellTags->"Estimating D"],
    Cell[1134435, 42792, 269, 11, 23, "Index",
      CellTags->"Estimating D"],
    Cell[1134707, 42805, 2407, 92, 218, "IndexSubentry",
      CellTags->"Estimating D"],
    Cell[1419005, 54284, 269, 11, 23, "Index",
      CellTags->"Estimating D"],
    Cell[1419277, 54297, 2407, 92, 218, "IndexSubentry",
      CellTags->"Estimating D"],
    Cell[1695658, 65449, 269, 11, 15, "Index",
      CellTags->"Estimating D"],
    Cell[1695930, 65462, 2407, 92, 210, "IndexSubentry",
      CellTags->"Estimating D"]},
  "ExactEigenvalues"->{
    Cell[223658, 5983, 293, 10, 15, "Index",
      CellTags->"ExactEigenvalues"],
    Cell[536384, 18621, 293, 10, 23, "Index",
      CellTags->"ExactEigenvalues"],
    Cell[844932, 31088, 293, 10, 15, "Index",
      CellTags->"ExactEigenvalues"],
    Cell[1137117, 42899, 293, 10, 23, "Index",
      CellTags->"ExactEigenvalues"],
    Cell[1421687, 54391, 293, 10, 23, "Index",
      CellTags->"ExactEigenvalues"],
    Cell[1698340, 65556, 293, 10, 15, "Index",
      CellTags->"ExactEigenvalues"]},
  "ExactIntersection"->{
    Cell[223954, 5995, 459, 15, 15, "Index",
      CellTags->"ExactIntersection"],
    Cell[536680, 18633, 459, 15, 23, "Index",
      CellTags->"ExactIntersection"],
    Cell[845228, 31100, 459, 15, 15, "Index",
      CellTags->"ExactIntersection"],
    Cell[1137413, 42911, 459, 15, 23, "Index",
      CellTags->"ExactIntersection"],
    Cell[1421983, 54403, 459, 15, 23, "Index",
      CellTags->"ExactIntersection"],
    Cell[1698636, 65568, 459, 15, 15, "Index",
      CellTags->"ExactIntersection"]},
  "ExactProbability"->{
    Cell[224416, 6012, 269, 10, 15, "Index",
      CellTags->"ExactProbability"],
    Cell[537142, 18650, 269, 10, 23, "Index",
      CellTags->"ExactProbability"],
    Cell[845690, 31117, 269, 10, 15, "Index",
      CellTags->"ExactProbability"],
    Cell[1137875, 42928, 269, 10, 23, "Index",
      CellTags->"ExactProbability"],
    Cell[1422445, 54420, 269, 10, 23, "Index",
      CellTags->"ExactProbability"]},
  "Expectation"->{
    Cell[224688, 6024, 252, 11, 15, "Index",
      CellTags->"Expectation"],
    Cell[224943, 6037, 572, 16, 30, "IndexSubentry",
      CellTags->"Expectation"],
    Cell[537414, 18662, 252, 11, 23, "Index",
      CellTags->"Expectation"],
    Cell[537669, 18675, 572, 16, 38, "IndexSubentry",
      CellTags->"Expectation"],
    Cell[845962, 31129, 252, 11, 15, "Index",
      CellTags->"Expectation"],
    Cell[846217, 31142, 572, 16, 30, "IndexSubentry",
      CellTags->"Expectation"],
    Cell[1138147, 42940, 252, 11, 23, "Index",
      CellTags->"Expectation"],
    Cell[1138402, 42953, 572, 16, 38, "IndexSubentry",
      CellTags->"Expectation"],
    Cell[1422717, 54432, 252, 11, 23, "Index",
      CellTags->"Expectation"],
    Cell[1422972, 54445, 572, 16, 38, "IndexSubentry",
      CellTags->"Expectation"],
    Cell[1699098, 65585, 252, 11, 15, "Index",
      CellTags->"Expectation"],
    Cell[1699353, 65598, 550, 16, 30, "IndexSubentry",
      CellTags->"Expectation"]},
  "ExponentialF"->{
    Cell[225518, 6055, 329, 11, 15, "Index",
      CellTags->"ExponentialF"],
    Cell[225850, 6068, 877, 26, 45, "IndexSubentry",
      CellTags->"ExponentialF"],
    Cell[538244, 18693, 329, 11, 23, "Index",
      CellTags->"ExponentialF"],
    Cell[538576, 18706, 877, 26, 53, "IndexSubentry",
      CellTags->"ExponentialF"],
    Cell[846792, 31160, 329, 11, 15, "Index",
      CellTags->"ExponentialF"],
    Cell[847124, 31173, 877, 26, 45, "IndexSubentry",
      CellTags->"ExponentialF"],
    Cell[1138977, 42971, 329, 11, 23, "Index",
      CellTags->"ExponentialF"],
    Cell[1139309, 42984, 877, 26, 53, "IndexSubentry",
      CellTags->"ExponentialF"],
    Cell[1423547, 54463, 329, 11, 23, "Index",
      CellTags->"ExponentialF"],
    Cell[1423879, 54476, 877, 26, 53, "IndexSubentry",
      CellTags->"ExponentialF"],
    Cell[1699906, 65616, 329, 11, 15, "Index",
      CellTags->"ExponentialF"],
    Cell[1700238, 65629, 877, 26, 45, "IndexSubentry",
      CellTags->"ExponentialF"]},
  "ExtantIndividuals"->{
    Cell[226730, 6096, 270, 10, 15, "Index",
      CellTags->"ExtantIndividuals"],
    Cell[539456, 18734, 270, 10, 23, "Index",
      CellTags->"ExtantIndividuals"],
    Cell[848004, 31201, 270, 10, 15, "Index",
      CellTags->"ExtantIndividuals"],
    Cell[1140189, 43012, 270, 10, 23, "Index",
      CellTags->"ExtantIndividuals"],
    Cell[1424759, 54504, 270, 10, 23, "Index",
      CellTags->"ExtantIndividuals"],
    Cell[1701118, 65657, 270, 10, 15, "Index",
      CellTags->"ExtantIndividuals"]},
  "ExtractContexts"->{
    Cell[227003, 6108, 321, 11, 15, "Index",
      CellTags->"ExtractContexts"],
    Cell[539729, 18746, 321, 11, 23, "Index",
      CellTags->"ExtractContexts"],
    Cell[848277, 31213, 321, 11, 15, "Index",
      CellTags->"ExtractContexts"],
    Cell[1140462, 43024, 321, 11, 23, "Index",
      CellTags->"ExtractContexts"],
    Cell[1425032, 54516, 321, 11, 23, "Index",
      CellTags->"ExtractContexts"],
    Cell[1701391, 65669, 321, 11, 15, "Index",
      CellTags->"ExtractContexts"]},
  "ExtractExtant"->{
    Cell[227327, 6121, 242, 10, 15, "Index",
      CellTags->"ExtractExtant"],
    Cell[540053, 18759, 242, 10, 23, "Index",
      CellTags->"ExtractExtant"],
    Cell[848601, 31226, 242, 10, 15, "Index",
      CellTags->"ExtractExtant"],
    Cell[1140786, 43037, 242, 10, 23, "Index",
      CellTags->"ExtractExtant"],
    Cell[1425356, 54529, 254, 10, 23, "Index",
      CellTags->"ExtractExtant"],
    Cell[1701715, 65682, 254, 10, 15, "Index",
      CellTags->"ExtractExtant"]},
  "ExtractGenealogy"->{
    Cell[227572, 6133, 424, 14, 15, "Index",
      CellTags->"ExtractGenealogy"],
    Cell[540298, 18771, 424, 14, 23, "Index",
      CellTags->"ExtractGenealogy"],
    Cell[848846, 31238, 283, 10, 15, "Index",
      CellTags->"ExtractGenealogy"],
    Cell[1141031, 43049, 283, 10, 23, "Index",
      CellTags->"ExtractGenealogy"],
    Cell[1425613, 54541, 283, 10, 23, "Index",
      CellTags->"ExtractGenealogy"],
    Cell[1701972, 65694, 283, 10, 15, "Index",
      CellTags->"ExtractGenealogy"]},
  "ExtractGenes"->{
    Cell[227999, 6149, 314, 11, 15, "Index",
      CellTags->"ExtractGenes"],
    Cell[540725, 18787, 314, 11, 23, "Index",
      CellTags->"ExtractGenes"],
    Cell[849132, 31250, 314, 11, 15, "Index",
      CellTags->"ExtractGenes"],
    Cell[1141317, 43061, 314, 11, 23, "Index",
      CellTags->"ExtractGenes"],
    Cell[1425899, 54553, 314, 11, 23, "Index",
      CellTags->"ExtractGenes"],
    Cell[1702258, 65706, 278, 11, 15, "Index",
      CellTags->"ExtractGenes"],
    Cell[1702539, 65719, 297, 9, 15, "IndexSubentry",
      CellTags->"ExtractGenes"]},
  "ExtractInformation"->{
    Cell[228316, 6162, 285, 10, 15, "Index",
      CellTags->"ExtractInformation"],
    Cell[228604, 6174, 301, 9, 15, "IndexSubentry",
      CellTags->"ExtractInformation"],
    Cell[541042, 18800, 285, 10, 23, "Index",
      CellTags->"ExtractInformation"],
    Cell[541330, 18812, 301, 9, 23, "IndexSubentry",
      CellTags->"ExtractInformation"],
    Cell[849449, 31263, 285, 10, 15, "Index",
      CellTags->"ExtractInformation"],
    Cell[1141634, 43074, 285, 10, 23, "Index",
      CellTags->"ExtractInformation"],
    Cell[1426216, 54566, 285, 10, 23, "Index",
      CellTags->"ExtractInformation"],
    Cell[1702839, 65730, 285, 10, 15, "Index",
      CellTags->"ExtractInformation"]},
  "ExtractLabel"->{
    Cell[228908, 6185, 306, 11, 15, "Index",
      CellTags->"ExtractLabel"],
    Cell[541634, 18823, 306, 11, 23, "Index",
      CellTags->"ExtractLabel"]},
  "ExtractLineagesEndingAtT"->{
    Cell[229217, 6198, 342, 11, 15, "Index",
      CellTags->"ExtractLineagesEndingAtT"],
    Cell[541943, 18836, 342, 11, 23, "Index",
      CellTags->"ExtractLineagesEndingAtT"]},
  "ExtractLineagesStartingAtT"->{
    Cell[229562, 6211, 353, 12, 15, "Index",
      CellTags->"ExtractLineagesStartingAtT"],
    Cell[542288, 18849, 353, 12, 23, "Index",
      CellTags->"ExtractLineagesStartingAtT"]},
  "ExtractRepeat"->{
    Cell[229918, 6225, 260, 10, 15, "Index",
      CellTags->"ExtractRepeat"],
    Cell[542644, 18863, 260, 10, 23, "Index",
      CellTags->"ExtractRepeat"],
    Cell[849737, 31275, 260, 10, 15, "Index",
      CellTags->"ExtractRepeat"],
    Cell[1141922, 43086, 260, 10, 23, "Index",
      CellTags->"ExtractRepeat"],
    Cell[1426504, 54578, 260, 10, 23, "Index",
      CellTags->"ExtractRepeat"],
    Cell[1703127, 65742, 260, 10, 15, "Index",
      CellTags->"ExtractRepeat"]},
  "ExtractSubMatrix"->{
    Cell[230181, 6237, 279, 10, 15, "Index",
      CellTags->"ExtractSubMatrix"],
    Cell[542907, 18875, 279, 10, 23, "Index",
      CellTags->"ExtractSubMatrix"],
    Cell[850000, 31287, 279, 10, 15, "Index",
      CellTags->"ExtractSubMatrix"],
    Cell[1142185, 43098, 279, 10, 23, "Index",
      CellTags->"ExtractSubMatrix"],
    Cell[1426767, 54590, 279, 10, 23, "Index",
      CellTags->"ExtractSubMatrix"],
    Cell[1703390, 65754, 279, 10, 15, "Index",
      CellTags->"ExtractSubMatrix"]},
  "FamilyAlleleFrequencyEstimate"->{
    Cell[230463, 6249, 327, 11, 15, "Index",
      CellTags->"FamilyAlleleFrequencyEstimate"],
    Cell[543189, 18887, 327, 11, 23, "Index",
      CellTags->"FamilyAlleleFrequencyEstimate"],
    Cell[850282, 31299, 327, 11, 15, "Index",
      CellTags->"FamilyAlleleFrequencyEstimate"],
    Cell[1142467, 43110, 327, 11, 23, "Index",
      CellTags->"FamilyAlleleFrequencyEstimate"],
    Cell[1427049, 54602, 327, 11, 23, "Index",
      CellTags->"FamilyAlleleFrequencyEstimate"],
    Cell[1703672, 65766, 327, 11, 15, "Index",
      CellTags->"FamilyAlleleFrequencyEstimate"]},
  "FamilyEffects"->{
    Cell[230793, 6262, 274, 10, 15, "Index",
      CellTags->"FamilyEffects"],
    Cell[543519, 18900, 274, 10, 23, "Index",
      CellTags->"FamilyEffects"],
    Cell[850612, 31312, 274, 10, 15, "Index",
      CellTags->"FamilyEffects"],
    Cell[1142797, 43123, 274, 10, 23, "Index",
      CellTags->"FamilyEffects"],
    Cell[1427379, 54615, 274, 10, 23, "Index",
      CellTags->"FamilyEffects"],
    Cell[1704002, 65779, 274, 10, 15, "Index",
      CellTags->"FamilyEffects"]},
  "FamilyM"->{
    Cell[231070, 6274, 256, 10, 15, "Index",
      CellTags->"FamilyM"],
    Cell[543796, 18912, 256, 10, 23, "Index",
      CellTags->"FamilyM"],
    Cell[850889, 31324, 256, 10, 15, "Index",
      CellTags->"FamilyM"],
    Cell[1143074, 43135, 256, 10, 23, "Index",
      CellTags->"FamilyM"],
    Cell[1427656, 54627, 256, 10, 23, "Index",
      CellTags->"FamilyM"],
    Cell[1704279, 65791, 256, 10, 15, "Index",
      CellTags->"FamilyM"]},
  "FamilyProbability"->{
    Cell[231329, 6286, 264, 10, 15, "Index",
      CellTags->"FamilyProbability"],
    Cell[544055, 18924, 264, 10, 23, "Index",
      CellTags->"FamilyProbability"],
    Cell[851148, 31336, 264, 10, 15, "Index",
      CellTags->"FamilyProbability"],
    Cell[1143333, 43147, 264, 10, 23, "Index",
      CellTags->"FamilyProbability"],
    Cell[1427915, 54639, 264, 10, 23, "Index",
      CellTags->"FamilyProbability"],
    Cell[1704538, 65803, 264, 10, 15, "Index",
      CellTags->"FamilyProbability"]},
  "Family structure"->{
    Cell[231596, 6298, 291, 11, 15, "Index",
      CellTags->"Family structure"],
    Cell[544322, 18936, 291, 11, 23, "Index",
      CellTags->"Family structure"],
    Cell[851415, 31348, 291, 11, 15, "Index",
      CellTags->"Family structure"],
    Cell[1143600, 43159, 291, 11, 23, "Index",
      CellTags->"Family structure"],
    Cell[1428182, 54651, 291, 11, 23, "Index",
      CellTags->"Family structure"],
    Cell[1704805, 65815, 291, 11, 15, "Index",
      CellTags->"Family structure"]},
  "Fecundity"->{
    Cell[231890, 6311, 258, 10, 15, "Index",
      CellTags->"Fecundity"],
    Cell[544616, 18949, 258, 10, 23, "Index",
      CellTags->"Fecundity"],
    Cell[851709, 31361, 258, 10, 15, "Index",
      CellTags->"Fecundity"],
    Cell[1143894, 43172, 258, 10, 23, "Index",
      CellTags->"Fecundity"],
    Cell[1428476, 54664, 258, 10, 23, "Index",
      CellTags->"Fecundity"],
    Cell[1705099, 65828, 258, 10, 15, "Index",
      CellTags->"Fecundity"]},
  "FindHyperlinks"->{
    Cell[232151, 6323, 249, 10, 15, "Index",
      CellTags->"FindHyperlinks"],
    Cell[544877, 18961, 249, 10, 23, "Index",
      CellTags->"FindHyperlinks"],
    Cell[851970, 31373, 249, 10, 15, "Index",
      CellTags->"FindHyperlinks"],
    Cell[1144155, 43184, 249, 10, 23, "Index",
      CellTags->"FindHyperlinks"],
    Cell[1428737, 54676, 249, 10, 23, "Index",
      CellTags->"FindHyperlinks"],
    Cell[1705360, 65840, 249, 10, 15, "Index",
      CellTags->"FindHyperlinks"]},
  "FindIndexTag"->{
    Cell[232403, 6335, 243, 10, 15, "Index",
      CellTags->"FindIndexTag"],
    Cell[545129, 18973, 243, 10, 23, "Index",
      CellTags->"FindIndexTag"],
    Cell[852222, 31385, 243, 10, 15, "Index",
      CellTags->"FindIndexTag"],
    Cell[1144407, 43196, 243, 10, 23, "Index",
      CellTags->"FindIndexTag"],
    Cell[1428989, 54688, 243, 10, 23, "Index",
      CellTags->"FindIndexTag"],
    Cell[1705612, 65852, 243, 10, 15, "Index",
      CellTags->"FindIndexTag"]},
  "FindMLE"->{
    Cell[232649, 6347, 238, 10, 15, "Index",
      CellTags->"FindMLE"],
    Cell[545375, 18985, 238, 10, 23, "Index",
      CellTags->"FindMLE"],
    Cell[852468, 31397, 238, 10, 15, "Index",
      CellTags->"FindMLE"],
    Cell[1144653, 43208, 238, 10, 23, "Index",
      CellTags->"FindMLE"],
    Cell[1429235, 54700, 238, 10, 23, "Index",
      CellTags->"FindMLE"],
    Cell[1705858, 65864, 238, 10, 15, "Index",
      CellTags->"FindMLE"]},
  "FindNode"->{
    Cell[232890, 6359, 253, 10, 15, "Index",
      CellTags->"FindNode"],
    Cell[545616, 18997, 253, 10, 23, "Index",
      CellTags->"FindNode"],
    Cell[852709, 31409, 253, 10, 15, "Index",
      CellTags->"FindNode"],
    Cell[1144894, 43220, 253, 10, 23, "Index",
      CellTags->"FindNode"],
    Cell[1429476, 54712, 253, 10, 23, "Index",
      CellTags->"FindNode"],
    Cell[1706099, 65876, 253, 10, 15, "Index",
      CellTags->"FindNode"]},
  "FindPosition"->{
    Cell[233146, 6371, 239, 10, 15, "Index",
      CellTags->"FindPosition"],
    Cell[545872, 19009, 239, 10, 23, "Index",
      CellTags->"FindPosition"],
    Cell[852965, 31421, 239, 10, 15, "Index",
      CellTags->"FindPosition"],
    Cell[1145150, 43232, 239, 10, 23, "Index",
      CellTags->"FindPosition"],
    Cell[1429732, 54724, 251, 10, 23, "Index",
      CellTags->"FindPosition"],
    Cell[1706355, 65888, 251, 10, 15, "Index",
      CellTags->"FindPosition"]},
  "FindTags"->{
    Cell[233388, 6383, 249, 10, 15, "Index",
      CellTags->"FindTags"],
    Cell[546114, 19021, 249, 10, 23, "Index",
      CellTags->"FindTags"],
    Cell[853207, 31433, 249, 10, 15, "Index",
      CellTags->"FindTags"],
    Cell[1145392, 43244, 249, 10, 23, "Index",
      CellTags->"FindTags"],
    Cell[1429986, 54736, 249, 10, 23, "Index",
      CellTags->"FindTags"],
    Cell[1706609, 65900, 249, 10, 15, "Index",
      CellTags->"FindTags"]},
  "Fitness"->{
    Cell[233640, 6395, 316, 11, 15, "Index",
      CellTags->"Fitness"],
    Cell[233959, 6408, 618, 21, 45, "IndexSubentry",
      CellTags->"Fitness"],
    Cell[546366, 19033, 316, 11, 23, "Index",
      CellTags->"Fitness"],
    Cell[546685, 19046, 618, 21, 53, "IndexSubentry",
      CellTags->"Fitness"],
    Cell[853459, 31445, 316, 11, 15, "Index",
      CellTags->"Fitness"],
    Cell[853778, 31458, 618, 21, 45, "IndexSubentry",
      CellTags->"Fitness"],
    Cell[1145644, 43256, 316, 11, 23, "Index",
      CellTags->"Fitness"],
    Cell[1145963, 43269, 618, 21, 53, "IndexSubentry",
      CellTags->"Fitness"],
    Cell[1430238, 54748, 316, 11, 23, "Index",
      CellTags->"Fitness"],
    Cell[1430557, 54761, 618, 21, 53, "IndexSubentry",
      CellTags->"Fitness"],
    Cell[1706861, 65912, 316, 11, 15, "Index",
      CellTags->"Fitness"],
    Cell[1707180, 65925, 618, 21, 45, "IndexSubentry",
      CellTags->"Fitness"]},
  "FitnessSet"->{
    Cell[234580, 6431, 305, 11, 15, "Index",
      CellTags->"FitnessSet"],
    Cell[547306, 19069, 305, 11, 23, "Index",
      CellTags->"FitnessSet"],
    Cell[854399, 31481, 305, 11, 15, "Index",
      CellTags->"FitnessSet"],
    Cell[1146584, 43292, 305, 11, 23, "Index",
      CellTags->"FitnessSet"],
    Cell[1431178, 54784, 305, 11, 23, "Index",
      CellTags->"FitnessSet"],
    Cell[1707801, 65948, 305, 11, 15, "Index",
      CellTags->"FitnessSet"]},
  "FitnessTable"->{
    Cell[234888, 6444, 295, 11, 15, "Index",
      CellTags->"FitnessTable"],
    Cell[235186, 6457, 475, 15, 30, "IndexSubentry",
      CellTags->"FitnessTable"],
    Cell[547614, 19082, 295, 11, 23, "Index",
      CellTags->"FitnessTable"],
    Cell[547912, 19095, 475, 15, 38, "IndexSubentry",
      CellTags->"FitnessTable"],
    Cell[854707, 31494, 295, 11, 15, "Index",
      CellTags->"FitnessTable"],
    Cell[855005, 31507, 475, 15, 30, "IndexSubentry",
      CellTags->"FitnessTable"],
    Cell[1146892, 43305, 295, 11, 23, "Index",
      CellTags->"FitnessTable"],
    Cell[1147190, 43318, 475, 15, 38, "IndexSubentry",
      CellTags->"FitnessTable"],
    Cell[1431486, 54797, 295, 11, 23, "Index",
      CellTags->"FitnessTable"],
    Cell[1431784, 54810, 475, 15, 38, "IndexSubentry",
      CellTags->"FitnessTable"],
    Cell[1708109, 65961, 295, 11, 15, "Index",
      CellTags->"FitnessTable"],
    Cell[1708407, 65974, 475, 15, 30, "IndexSubentry",
      CellTags->"FitnessTable"]},
  "FixedEnds"->{
    Cell[235664, 6474, 300, 11, 15, "Index",
      CellTags->"FixedEnds"],
    Cell[235967, 6487, 1296, 37, 60, "IndexSubentry",
      CellTags->"FixedEnds"],
    Cell[548390, 19112, 300, 11, 23, "Index",
      CellTags->"FixedEnds"],
    Cell[548693, 19125, 1296, 37, 67, "IndexSubentry",
      CellTags->"FixedEnds"],
    Cell[855483, 31524, 300, 11, 15, "Index",
      CellTags->"FixedEnds"],
    Cell[855786, 31537, 1296, 37, 59, "IndexSubentry",
      CellTags->"FixedEnds"],
    Cell[1147668, 43335, 300, 11, 23, "Index",
      CellTags->"FixedEnds"],
    Cell[1147971, 43348, 1296, 37, 67, "IndexSubentry",
      CellTags->"FixedEnds"],
    Cell[1432262, 54827, 300, 11, 23, "Index",
      CellTags->"FixedEnds"],
    Cell[1432565, 54840, 1296, 37, 67, "IndexSubentry",
      CellTags->"FixedEnds"],
    Cell[1708885, 65991, 300, 11, 15, "Index",
      CellTags->"FixedEnds"],
    Cell[1709188, 66004, 1296, 37, 59, "IndexSubentry",
      CellTags->"FixedEnds"]},
  "Flatten"->{
    Cell[237266, 6526, 278, 10, 15, "Index",
      CellTags->"Flatten"],
    Cell[549992, 19164, 278, 10, 23, "Index",
      CellTags->"Flatten"],
    Cell[857085, 31576, 278, 10, 15, "Index",
      CellTags->"Flatten"],
    Cell[1149270, 43387, 278, 10, 23, "Index",
      CellTags->"Flatten"],
    Cell[1433864, 54879, 278, 10, 23, "Index",
      CellTags->"Flatten"],
    Cell[1710487, 66043, 278, 10, 15, "Index",
      CellTags->"Flatten"]},
  "FlattenList"->{
    Cell[237547, 6538, 274, 10, 15, "Index",
      CellTags->"FlattenList"],
    Cell[237824, 6550, 277, 9, 15, "IndexSubentry",
      CellTags->"FlattenList"],
    Cell[550273, 19176, 274, 10, 23, "Index",
      CellTags->"FlattenList"],
    Cell[550550, 19188, 277, 9, 23, "IndexSubentry",
      CellTags->"FlattenList"],
    Cell[857366, 31588, 274, 10, 15, "Index",
      CellTags->"FlattenList"],
    Cell[857643, 31600, 277, 9, 15, "IndexSubentry",
      CellTags->"FlattenList"],
    Cell[1149551, 43399, 274, 10, 23, "Index",
      CellTags->"FlattenList"],
    Cell[1149828, 43411, 277, 9, 23, "IndexSubentry",
      CellTags->"FlattenList"],
    Cell[1434145, 54891, 274, 10, 23, "Index",
      CellTags->"FlattenList"],
    Cell[1434422, 54903, 277, 9, 23, "IndexSubentry",
      CellTags->"FlattenList"],
    Cell[1710768, 66055, 274, 10, 15, "Index",
      CellTags->"FlattenList"],
    Cell[1711045, 66067, 277, 9, 15, "IndexSubentry",
      CellTags->"FlattenList"]},
  "FourierNormalised"->{
    Cell[238104, 6561, 274, 10, 15, "Index",
      CellTags->"FourierNormalised"],
    Cell[550830, 19199, 274, 10, 23, "Index",
      CellTags->"FourierNormalised"],
    Cell[857923, 31611, 274, 10, 15, "Index",
      CellTags->"FourierNormalised"],
    Cell[1150108, 43422, 274, 10, 23, "Index",
      CellTags->"FourierNormalised"],
    Cell[1434702, 54914, 274, 10, 23, "Index",
      CellTags->"FourierNormalised"],
    Cell[1711325, 66078, 274, 10, 15, "Index",
      CellTags->"FourierNormalised"]},
  "FourierNormalisedTable"->{
    Cell[238381, 6573, 289, 10, 15, "Index",
      CellTags->"FourierNormalisedTable"],
    Cell[551107, 19211, 289, 10, 23, "Index",
      CellTags->"FourierNormalisedTable"],
    Cell[858200, 31623, 289, 10, 15, "Index",
      CellTags->"FourierNormalisedTable"],
    Cell[1150385, 43434, 289, 10, 23, "Index",
      CellTags->"FourierNormalisedTable"],
    Cell[1434979, 54926, 289, 10, 23, "Index",
      CellTags->"FourierNormalisedTable"],
    Cell[1711602, 66090, 289, 10, 15, "Index",
      CellTags->"FourierNormalisedTable"]},
  "FrequencyRepresentations"->{
    Cell[238673, 6585, 315, 10, 15, "Index",
      CellTags->"FrequencyRepresentations"],
    Cell[551399, 19223, 315, 10, 23, "Index",
      CellTags->"FrequencyRepresentations"],
    Cell[858492, 31635, 315, 10, 15, "Index",
      CellTags->"FrequencyRepresentations"],
    Cell[1150677, 43446, 315, 10, 23, "Index",
      CellTags->"FrequencyRepresentations"],
    Cell[1435271, 54938, 315, 10, 23, "Index",
      CellTags->"FrequencyRepresentations"],
    Cell[1711894, 66102, 315, 10, 15, "Index",
      CellTags->"FrequencyRepresentations"]},
  "FromBaake"->{
    Cell[238991, 6597, 254, 10, 15, "Index",
      CellTags->"FromBaake"],
    Cell[551717, 19235, 254, 10, 23, "Index",
      CellTags->"FromBaake"],
    Cell[858810, 31647, 254, 10, 15, "Index",
      CellTags->"FromBaake"],
    Cell[1150995, 43458, 254, 10, 23, "Index",
      CellTags->"FromBaake"]},
  "FromBennett"->{
    Cell[239248, 6609, 260, 10, 15, "Index",
      CellTags->"FromBennett"],
    Cell[551974, 19247, 260, 10, 23, "Index",
      CellTags->"FromBennett"],
    Cell[859067, 31659, 260, 10, 15, "Index",
      CellTags->"FromBennett"],
    Cell[1151252, 43470, 260, 10, 23, "Index",
      CellTags->"FromBennett"]},
  "FromBennettExpression"->{
    Cell[239511, 6621, 290, 10, 15, "Index",
      CellTags->"FromBennettExpression"],
    Cell[552237, 19259, 290, 10, 23, "Index",
      CellTags->"FromBennettExpression"],
    Cell[859330, 31671, 290, 10, 15, "Index",
      CellTags->"FromBennettExpression"],
    Cell[1151515, 43482, 290, 10, 23, "Index",
      CellTags->"FromBennettExpression"]},
  "FullContext"->{
    Cell[239804, 6633, 262, 10, 15, "Index",
      CellTags->"FullContext"],
    Cell[552530, 19271, 262, 10, 23, "Index",
      CellTags->"FullContext"],
    Cell[859623, 31683, 262, 10, 15, "Index",
      CellTags->"FullContext"],
    Cell[1151808, 43494, 262, 10, 23, "Index",
      CellTags->"FullContext"],
    Cell[1435589, 54950, 262, 10, 23, "Index",
      CellTags->"FullContext"],
    Cell[1712212, 66114, 262, 10, 15, "Index",
      CellTags->"FullContext"]},
  "FullGenotypeFrequencyReduced"->{
    Cell[240069, 6645, 307, 10, 15, "Index",
      CellTags->"FullGenotypeFrequencyReduced"],
    Cell[552795, 19283, 307, 10, 23, "Index",
      CellTags->"FullGenotypeFrequencyReduced"],
    Cell[859888, 31695, 307, 10, 15, "Index",
      CellTags->"FullGenotypeFrequencyReduced"],
    Cell[1152073, 43506, 307, 10, 23, "Index",
      CellTags->"FullGenotypeFrequencyReduced"],
    Cell[1435854, 54962, 307, 10, 23, "Index",
      CellTags->"FullGenotypeFrequencyReduced"],
    Cell[1712477, 66126, 307, 10, 15, "Index",
      CellTags->"FullGenotypeFrequencyReduced"]},
  "FullGenotypeFrequencyTable"->{
    Cell[240379, 6657, 301, 10, 15, "Index",
      CellTags->"FullGenotypeFrequencyTable"],
    Cell[553105, 19295, 301, 10, 23, "Index",
      CellTags->"FullGenotypeFrequencyTable"],
    Cell[860198, 31707, 301, 10, 15, "Index",
      CellTags->"FullGenotypeFrequencyTable"],
    Cell[1152383, 43518, 301, 10, 23, "Index",
      CellTags->"FullGenotypeFrequencyTable"],
    Cell[1436164, 54974, 301, 10, 23, "Index",
      CellTags->"FullGenotypeFrequencyTable"],
    Cell[1712787, 66138, 301, 10, 15, "Index",
      CellTags->"FullGenotypeFrequencyTable"]},
  "FullOutput"->{
    Cell[240683, 6669, 257, 10, 15, "Index",
      CellTags->"FullOutput"],
    Cell[553409, 19307, 257, 10, 23, "Index",
      CellTags->"FullOutput"],
    Cell[860502, 31719, 257, 10, 15, "Index",
      CellTags->"FullOutput"],
    Cell[1152687, 43530, 257, 10, 23, "Index",
      CellTags->"FullOutput"],
    Cell[1436468, 54986, 257, 10, 23, "Index",
      CellTags->"FullOutput"],
    Cell[1713091, 66150, 257, 10, 15, "Index",
      CellTags->"FullOutput"]},
  "Function"->{
    Cell[240943, 6681, 241, 10, 15, "Index",
      CellTags->"Function"],
    Cell[553669, 19319, 241, 10, 23, "Index",
      CellTags->"Function"],
    Cell[860762, 31731, 241, 10, 15, "Index",
      CellTags->"Function"],
    Cell[1152947, 43542, 241, 10, 23, "Index",
      CellTags->"Function"],
    Cell[1436728, 54998, 241, 10, 23, "Index",
      CellTags->"Function"],
    Cell[1713351, 66162, 241, 10, 15, "Index",
      CellTags->"Function"]},
  "Gametes"->{
    Cell[241187, 6693, 286, 11, 15, "Index",
      CellTags->"Gametes"],
    Cell[241476, 6706, 1087, 36, 60, "IndexSubentry",
      CellTags->"Gametes"],
    Cell[553913, 19331, 286, 11, 23, "Index",
      CellTags->"Gametes"],
    Cell[554202, 19344, 1087, 36, 68, "IndexSubentry",
      CellTags->"Gametes"],
    Cell[861006, 31743, 286, 11, 15, "Index",
      CellTags->"Gametes"],
    Cell[861295, 31756, 1087, 36, 60, "IndexSubentry",
      CellTags->"Gametes"],
    Cell[1153191, 43554, 286, 11, 23, "Index",
      CellTags->"Gametes"],
    Cell[1153480, 43567, 1087, 36, 68, "IndexSubentry",
      CellTags->"Gametes"],
    Cell[1436972, 55010, 286, 11, 23, "Index",
      CellTags->"Gametes"],
    Cell[1437261, 55023, 1087, 36, 68, "IndexSubentry",
      CellTags->"Gametes"],
    Cell[1713595, 66174, 286, 11, 15, "Index",
      CellTags->"Gametes"],
    Cell[1713884, 66187, 1087, 36, 60, "IndexSubentry",
      CellTags->"Gametes"]},
  "GameteTable"->{
    Cell[242566, 6744, 298, 11, 15, "Index",
      CellTags->"GameteTable"],
    Cell[242867, 6757, 440, 15, 30, "IndexSubentry",
      CellTags->"GameteTable"],
    Cell[555292, 19382, 298, 11, 23, "Index",
      CellTags->"GameteTable"],
    Cell[555593, 19395, 440, 15, 38, "IndexSubentry",
      CellTags->"GameteTable"],
    Cell[862385, 31794, 298, 11, 15, "Index",
      CellTags->"GameteTable"],
    Cell[862686, 31807, 440, 15, 30, "IndexSubentry",
      CellTags->"GameteTable"],
    Cell[1154570, 43605, 298, 11, 23, "Index",
      CellTags->"GameteTable"],
    Cell[1154871, 43618, 440, 15, 38, "IndexSubentry",
      CellTags->"GameteTable"],
    Cell[1438351, 55061, 298, 11, 23, "Index",
      CellTags->"GameteTable"],
    Cell[1438652, 55074, 440, 15, 38, "IndexSubentry",
      CellTags->"GameteTable"],
    Cell[1714974, 66225, 298, 11, 15, "Index",
      CellTags->"GameteTable"],
    Cell[1715275, 66238, 440, 15, 30, "IndexSubentry",
      CellTags->"GameteTable"]},
  "GaussianLogLikelihood"->{
    Cell[243310, 6774, 290, 10, 15, "Index",
      CellTags->"GaussianLogLikelihood"],
    Cell[556036, 19412, 290, 10, 23, "Index",
      CellTags->"GaussianLogLikelihood"],
    Cell[863129, 31824, 290, 10, 15, "Index",
      CellTags->"GaussianLogLikelihood"],
    Cell[1155314, 43635, 290, 10, 23, "Index",
      CellTags->"GaussianLogLikelihood"],
    Cell[1439095, 55091, 290, 10, 23, "Index",
      CellTags->"GaussianLogLikelihood"],
    Cell[1715718, 66255, 290, 10, 15, "Index",
      CellTags->"GaussianLogLikelihood"]},
  "GaussianMLE"->{
    Cell[243603, 6786, 260, 10, 15, "Index",
      CellTags->"GaussianMLE"],
    Cell[556329, 19424, 260, 10, 23, "Index",
      CellTags->"GaussianMLE"],
    Cell[863422, 31836, 260, 10, 15, "Index",
      CellTags->"GaussianMLE"],
    Cell[1155607, 43647, 260, 10, 23, "Index",
      CellTags->"GaussianMLE"],
    Cell[1439388, 55103, 260, 10, 23, "Index",
      CellTags->"GaussianMLE"],
    Cell[1716011, 66267, 260, 10, 15, "Index",
      CellTags->"GaussianMLE"]},
  "Genealogies"->{
    Cell[243866, 6798, 270, 11, 15, "Index",
      CellTags->"Genealogies"],
    Cell[244139, 6811, 929, 33, 75, "IndexSubentry",
      CellTags->"Genealogies"],
    Cell[556592, 19436, 270, 11, 23, "Index",
      CellTags->"Genealogies"],
    Cell[556865, 19449, 929, 33, 83, "IndexSubentry",
      CellTags->"Genealogies"],
    Cell[863685, 31848, 270, 11, 15, "Index",
      CellTags->"Genealogies"],
    Cell[863958, 31861, 740, 27, 60, "IndexSubentry",
      CellTags->"Genealogies"],
    Cell[1155870, 43659, 270, 11, 23, "Index",
      CellTags->"Genealogies"],
    Cell[1156143, 43672, 740, 27, 68, "IndexSubentry",
      CellTags->"Genealogies"],
    Cell[1439651, 55115, 270, 11, 23, "Index",
      CellTags->"Genealogies"],
    Cell[1439924, 55128, 740, 27, 68, "IndexSubentry",
      CellTags->"Genealogies"],
    Cell[1716274, 66279, 267, 11, 15, "Index",
      CellTags->"Genealogies"],
    Cell[1716544, 66292, 412, 15, 30, "IndexSubentry",
      CellTags->"Genealogies"]},
  "Genealogy"->{
    Cell[245071, 6846, 412, 15, 15, "Index",
      CellTags->"Genealogy"],
    Cell[557797, 19484, 412, 15, 23, "Index",
      CellTags->"Genealogy"],
    Cell[864701, 31890, 412, 15, 15, "Index",
      CellTags->"Genealogy"]},
  "GenealogyToMatrix"->{
    Cell[245486, 6863, 276, 10, 15, "Index",
      CellTags->"GenealogyToMatrix"],
    Cell[558212, 19501, 276, 10, 23, "Index",
      CellTags->"GenealogyToMatrix"],
    Cell[865116, 31907, 276, 10, 15, "Index",
      CellTags->"GenealogyToMatrix"],
    Cell[1156886, 43701, 276, 10, 23, "Index",
      CellTags->"GenealogyToMatrix"],
    Cell[1440667, 55157, 276, 10, 23, "Index",
      CellTags->"GenealogyToMatrix"],
    Cell[1716959, 66309, 276, 10, 15, "Index",
      CellTags->"GenealogyToMatrix"]},
  "GeneralizedTransform"->{
    Cell[245765, 6875, 265, 10, 15, "Index",
      CellTags->"GeneralizedTransform"],
    Cell[558491, 19513, 265, 10, 23, "Index",
      CellTags->"GeneralizedTransform"],
    Cell[865395, 31919, 265, 10, 15, "Index",
      CellTags->"GeneralizedTransform"],
    Cell[1157165, 43713, 265, 10, 23, "Index",
      CellTags->"GeneralizedTransform"],
    Cell[1440946, 55169, 265, 10, 23, "Index",
      CellTags->"GeneralizedTransform"],
    Cell[1717238, 66321, 265, 10, 15, "Index",
      CellTags->"GeneralizedTransform"]},
  "Generating functions"->{
    Cell[246033, 6887, 283, 11, 15, "Index",
      CellTags->"Generating functions"],
    Cell[246319, 6900, 437, 15, 30, "IndexSubentry",
      CellTags->"Generating functions"],
    Cell[558759, 19525, 283, 11, 23, "Index",
      CellTags->"Generating functions"],
    Cell[559045, 19538, 437, 15, 38, "IndexSubentry",
      CellTags->"Generating functions"],
    Cell[865663, 31931, 283, 11, 15, "Index",
      CellTags->"Generating functions"],
    Cell[865949, 31944, 437, 15, 30, "IndexSubentry",
      CellTags->"Generating functions"],
    Cell[1157433, 43725, 283, 11, 23, "Index",
      CellTags->"Generating functions"],
    Cell[1157719, 43738, 437, 15, 38, "IndexSubentry",
      CellTags->"Generating functions"],
    Cell[1441214, 55181, 283, 11, 23, "Index",
      CellTags->"Generating functions"],
    Cell[1441500, 55194, 437, 15, 38, "IndexSubentry",
      CellTags->"Generating functions"]},
  "Genes and contexts"->{
    Cell[246759, 6917, 277, 10, 15, "Index",
      CellTags->"Genes and contexts"],
    Cell[559485, 19555, 277, 10, 23, "Index",
      CellTags->"Genes and contexts"],
    Cell[866389, 31961, 277, 10, 15, "Index",
      CellTags->"Genes and contexts"],
    Cell[1158159, 43755, 277, 10, 23, "Index",
      CellTags->"Genes and contexts"],
    Cell[1441940, 55211, 277, 10, 23, "Index",
      CellTags->"Genes and contexts"],
    Cell[1717506, 66333, 277, 10, 15, "Index",
      CellTags->"Genes and contexts"]},
  "Genome"->{
    Cell[247039, 6929, 334, 12, 15, "Index",
      CellTags->"Genome"],
    Cell[559765, 19567, 334, 12, 23, "Index",
      CellTags->"Genome"],
    Cell[866669, 31973, 334, 12, 15, "Index",
      CellTags->"Genome"],
    Cell[1158439, 43767, 334, 12, 23, "Index",
      CellTags->"Genome"],
    Cell[1442220, 55223, 334, 12, 23, "Index",
      CellTags->"Genome"],
    Cell[1717786, 66345, 334, 12, 15, "Index",
      CellTags->"Genome"]},
  "Genotype"->{
    Cell[247376, 6943, 287, 11, 15, "Index",
      CellTags->"Genotype"],
    Cell[247666, 6956, 566, 19, 30, "IndexSubentry",
      CellTags->"Genotype"],
    Cell[560102, 19581, 287, 11, 23, "Index",
      CellTags->"Genotype"],
    Cell[560392, 19594, 566, 19, 38, "IndexSubentry",
      CellTags->"Genotype"],
    Cell[867006, 31987, 287, 11, 15, "Index",
      CellTags->"Genotype"],
    Cell[867296, 32000, 566, 19, 30, "IndexSubentry",
      CellTags->"Genotype"],
    Cell[1158776, 43781, 287, 11, 23, "Index",
      CellTags->"Genotype"],
    Cell[1159066, 43794, 566, 19, 38, "IndexSubentry",
      CellTags->"Genotype"],
    Cell[1442557, 55237, 416, 15, 23, "Index",
      CellTags->"Genotype"],
    Cell[1718123, 66359, 416, 15, 15, "Index",
      CellTags->"Genotype"]},
  "Genotype frequencies"->{
    Cell[248235, 6977, 299, 11, 15, "Index",
      CellTags->"Genotype frequencies"],
    Cell[560961, 19615, 299, 11, 23, "Index",
      CellTags->"Genotype frequencies"],
    Cell[867865, 32021, 299, 11, 15, "Index",
      CellTags->"Genotype frequencies"],
    Cell[1159635, 43815, 299, 11, 23, "Index",
      CellTags->"Genotype frequencies"],
    Cell[1442976, 55254, 299, 11, 23, "Index",
      CellTags->"Genotype frequencies"],
    Cell[1718542, 66376, 299, 11, 15, "Index",
      CellTags->"Genotype frequencies"]},
  "GenotypeFrequencyArguments"->{
    Cell[248537, 6990, 301, 10, 15, "Index",
      CellTags->"GenotypeFrequencyArguments"],
    Cell[561882, 19653, 301, 10, 23, "Index",
      CellTags->"GenotypeFrequencyArguments"],
    Cell[868167, 32034, 301, 10, 15, "Index",
      CellTags->"GenotypeFrequencyArguments"],
    Cell[1159937, 43828, 301, 10, 23, "Index",
      CellTags->"GenotypeFrequencyArguments"],
    Cell[1443278, 55267, 301, 10, 23, "Index",
      CellTags->"GenotypeFrequencyArguments"],
    Cell[1718844, 66389, 301, 10, 15, "Index",
      CellTags->"GenotypeFrequencyArguments"]},
  "GenotypeFrequencyConvert"->{
    Cell[248841, 7002, 303, 10, 15, "Index",
      CellTags->"GenotypeFrequencyConvert"],
    Cell[562186, 19665, 303, 10, 23, "Index",
      CellTags->"GenotypeFrequencyConvert"],
    Cell[868471, 32046, 303, 10, 15, "Index",
      CellTags->"GenotypeFrequencyConvert"],
    Cell[1160241, 43840, 303, 10, 23, "Index",
      CellTags->"GenotypeFrequencyConvert"],
    Cell[1443582, 55279, 303, 10, 23, "Index",
      CellTags->"GenotypeFrequencyConvert"],
    Cell[1719148, 66401, 303, 10, 15, "Index",
      CellTags->"GenotypeFrequencyConvert"]},
  "GenotypeFrequencyTable"->{
    Cell[249147, 7014, 307, 10, 15, "Index",
      CellTags->"GenotypeFrequencyTable"],
    Cell[562492, 19677, 307, 10, 23, "Index",
      CellTags->"GenotypeFrequencyTable"],
    Cell[868777, 32058, 307, 10, 15, "Index",
      CellTags->"GenotypeFrequencyTable"],
    Cell[1160547, 43852, 307, 10, 23, "Index",
      CellTags->"GenotypeFrequencyTable"],
    Cell[1443888, 55291, 307, 10, 23, "Index",
      CellTags->"GenotypeFrequencyTable"],
    Cell[1719454, 66413, 307, 10, 15, "Index",
      CellTags->"GenotypeFrequencyTable"]},
  "GenotypePosition"->{
    Cell[249457, 7026, 281, 10, 15, "Index",
      CellTags->"GenotypePosition"],
    Cell[562802, 19689, 281, 10, 23, "Index",
      CellTags->"GenotypePosition"],
    Cell[869087, 32070, 281, 10, 15, "Index",
      CellTags->"GenotypePosition"],
    Cell[1160857, 43864, 281, 10, 23, "Index",
      CellTags->"GenotypePosition"],
    Cell[1444198, 55303, 281, 10, 23, "Index",
      CellTags->"GenotypePosition"],
    Cell[1719764, 66425, 281, 10, 15, "Index",
      CellTags->"GenotypePosition"]},
  "GenotypeProbability"->{
    Cell[249741, 7038, 288, 10, 15, "Index",
      CellTags->"GenotypeProbability"],
    Cell[250032, 7050, 286, 9, 15, "IndexSubentry",
      CellTags->"GenotypeProbability"],
    Cell[563086, 19701, 288, 10, 23, "Index",
      CellTags->"GenotypeProbability"],
    Cell[563377, 19713, 286, 9, 23, "IndexSubentry",
      CellTags->"GenotypeProbability"],
    Cell[869371, 32082, 288, 10, 15, "Index",
      CellTags->"GenotypeProbability"],
    Cell[869662, 32094, 286, 9, 15, "IndexSubentry",
      CellTags->"GenotypeProbability"],
    Cell[1161141, 43876, 288, 10, 23, "Index",
      CellTags->"GenotypeProbability"],
    Cell[1161432, 43888, 286, 9, 23, "IndexSubentry",
      CellTags->"GenotypeProbability"],
    Cell[1444482, 55315, 288, 10, 23, "Index",
      CellTags->"GenotypeProbability"],
    Cell[1444773, 55327, 286, 9, 23, "IndexSubentry",
      CellTags->"GenotypeProbability"],
    Cell[1720048, 66437, 288, 10, 15, "Index",
      CellTags->"GenotypeProbability"],
    Cell[1720339, 66449, 286, 9, 15, "IndexSubentry",
      CellTags->"GenotypeProbability"]},
  "Genotypes"->{
    Cell[250321, 7061, 256, 11, 15, "Index",
      CellTags->"Genotypes"],
    Cell[563666, 19724, 256, 11, 23, "Index",
      CellTags->"Genotypes"],
    Cell[869951, 32105, 256, 11, 15, "Index",
      CellTags->"Genotypes"],
    Cell[1161721, 43899, 256, 11, 23, "Index",
      CellTags->"Genotypes"],
    Cell[1445062, 55338, 256, 11, 23, "Index",
      CellTags->"Genotypes"],
    Cell[1720628, 66460, 256, 11, 15, "Index",
      CellTags->"Genotypes"]},
  "GlobalContinuumVariables"->{
    Cell[250580, 7074, 291, 10, 15, "Index",
      CellTags->"GlobalContinuumVariables"],
    Cell[563925, 19737, 291, 10, 23, "Index",
      CellTags->"GlobalContinuumVariables"],
    Cell[870210, 32118, 291, 10, 15, "Index",
      CellTags->"GlobalContinuumVariables"],
    Cell[1161980, 43912, 291, 10, 23, "Index",
      CellTags->"GlobalContinuumVariables"]},
  "Gnew"->{
    Cell[250874, 7086, 452, 16, 15, "Index",
      CellTags->"Gnew"],
    Cell[564219, 19749, 452, 16, 23, "Index",
      CellTags->"Gnew"],
    Cell[870504, 32130, 452, 16, 15, "Index",
      CellTags->"Gnew"],
    Cell[1162274, 43924, 452, 16, 23, "Index",
      CellTags->"Gnew"],
    Cell[1445321, 55351, 452, 16, 23, "Index",
      CellTags->"Gnew"],
    Cell[1720887, 66473, 452, 16, 15, "Index",
      CellTags->"Gnew"]},
  "Goodman et al 1999"->{
    Cell[251329, 7104, 261, 10, 15, "Index",
      CellTags->"Goodman et al 1999"],
    Cell[564674, 19767, 261, 10, 23, "Index",
      CellTags->"Goodman et al 1999"],
    Cell[870959, 32148, 261, 10, 15, "Index",
      CellTags->"Goodman et al 1999"],
    Cell[1162729, 43942, 261, 10, 23, "Index",
      CellTags->"Goodman et al 1999"],
    Cell[1445776, 55369, 261, 10, 23, "Index",
      CellTags->"Goodman et al 1999"],
    Cell[1721342, 66491, 261, 10, 15, "Index",
      CellTags->"Goodman et al 1999"]},
  "Graphs"->{
    Cell[251593, 7116, 274, 11, 15, "Index",
      CellTags->"Graphs"],
    Cell[564938, 19779, 274, 11, 23, "Index",
      CellTags->"Graphs"]},
  "Griffiths-Tavare"->{
    Cell[251870, 7129, 399, 14, 15, "Index",
      CellTags->"Griffiths-Tavare"],
    Cell[252272, 7145, 833, 26, 45, "IndexSubentry",
      CellTags->"Griffiths-Tavare"],
    Cell[565215, 19792, 399, 14, 23, "Index",
      CellTags->"Griffiths-Tavare"],
    Cell[565617, 19808, 833, 26, 53, "IndexSubentry",
      CellTags->"Griffiths-Tavare"],
    Cell[871223, 32160, 399, 14, 15, "Index",
      CellTags->"Griffiths-Tavare"],
    Cell[871625, 32176, 833, 26, 45, "IndexSubentry",
      CellTags->"Griffiths-Tavare"],
    Cell[1162993, 43954, 399, 14, 23, "Index",
      CellTags->"Griffiths-Tavare"],
    Cell[1163395, 43970, 833, 26, 53, "IndexSubentry",
      CellTags->"Griffiths-Tavare"],
    Cell[1446040, 55381, 399, 14, 23, "Index",
      CellTags->"Griffiths-Tavare"],
    Cell[1446442, 55397, 833, 26, 53, "IndexSubentry",
      CellTags->"Griffiths-Tavare"],
    Cell[1721606, 66503, 399, 14, 15, "Index",
      CellTags->"Griffiths-Tavare"],
    Cell[1722008, 66519, 833, 26, 45, "IndexSubentry",
      CellTags->"Griffiths-Tavare"]},
  "Guiasu & Shenitzer 1985"->{
    Cell[253108, 7173, 276, 10, 15, "Index",
      CellTags->"Guiasu & Shenitzer 1985"],
    Cell[566453, 19836, 276, 10, 23, "Index",
      CellTags->"Guiasu & Shenitzer 1985"],
    Cell[872461, 32204, 276, 10, 15, "Index",
      CellTags->"Guiasu & Shenitzer 1985"],
    Cell[1164231, 43998, 276, 10, 23, "Index",
      CellTags->"Guiasu & Shenitzer 1985"],
    Cell[1447278, 55425, 276, 10, 23, "Index",
      CellTags->"Guiasu & Shenitzer 1985"],
    Cell[1722844, 66547, 276, 10, 15, "Index",
      CellTags->"Guiasu & Shenitzer 1985"]},
  "HaploidConstraints"->{
    Cell[253387, 7185, 277, 10, 15, "Index",
      CellTags->"HaploidConstraints"],
    Cell[566732, 19848, 277, 10, 23, "Index",
      CellTags->"HaploidConstraints"],
    Cell[872740, 32216, 277, 10, 15, "Index",
      CellTags->"HaploidConstraints"],
    Cell[1164510, 44010, 277, 10, 23, "Index",
      CellTags->"HaploidConstraints"],
    Cell[1447557, 55437, 277, 10, 23, "Index",
      CellTags->"HaploidConstraints"],
    Cell[1723123, 66559, 277, 10, 15, "Index",
      CellTags->"HaploidConstraints"]},
  "HaploidFrequencies"->{
    Cell[253667, 7197, 297, 10, 15, "Index",
      CellTags->"HaploidFrequencies"],
    Cell[567012, 19860, 297, 10, 23, "Index",
      CellTags->"HaploidFrequencies"],
    Cell[873020, 32228, 297, 10, 15, "Index",
      CellTags->"HaploidFrequencies"],
    Cell[1164790, 44022, 297, 10, 23, "Index",
      CellTags->"HaploidFrequencies"],
    Cell[1447837, 55449, 297, 10, 23, "Index",
      CellTags->"HaploidFrequencies"],
    Cell[1723403, 66571, 297, 10, 15, "Index",
      CellTags->"HaploidFrequencies"]},
  "HaploidGenotypeFrequency"->{
    Cell[253967, 7209, 332, 11, 15, "Index",
      CellTags->"HaploidGenotypeFrequency"],
    Cell[567312, 19872, 332, 11, 23, "Index",
      CellTags->"HaploidGenotypeFrequency"],
    Cell[873320, 32240, 332, 11, 15, "Index",
      CellTags->"HaploidGenotypeFrequency"],
    Cell[1165090, 44034, 332, 11, 23, "Index",
      CellTags->"HaploidGenotypeFrequency"],
    Cell[1448137, 55461, 332, 11, 23, "Index",
      CellTags->"HaploidGenotypeFrequency"],
    Cell[1723703, 66583, 332, 11, 15, "Index",
      CellTags->"HaploidGenotypeFrequency"]},
  "HaploidIndividuals"->{
    Cell[254302, 7222, 297, 10, 15, "Index",
      CellTags->"HaploidIndividuals"],
    Cell[567647, 19885, 297, 10, 23, "Index",
      CellTags->"HaploidIndividuals"],
    Cell[873655, 32253, 297, 10, 15, "Index",
      CellTags->"HaploidIndividuals"],
    Cell[1165425, 44047, 297, 10, 23, "Index",
      CellTags->"HaploidIndividuals"],
    Cell[1448472, 55474, 297, 10, 23, "Index",
      CellTags->"HaploidIndividuals"],
    Cell[1724038, 66596, 297, 10, 15, "Index",
      CellTags->"HaploidIndividuals"]},
  "HaploidRepresentations"->{
    Cell[254602, 7234, 309, 10, 15, "Index",
      CellTags->"HaploidRepresentations"],
    Cell[567947, 19897, 309, 10, 23, "Index",
      CellTags->"HaploidRepresentations"],
    Cell[873955, 32265, 309, 10, 15, "Index",
      CellTags->"HaploidRepresentations"],
    Cell[1165725, 44059, 309, 10, 23, "Index",
      CellTags->"HaploidRepresentations"],
    Cell[1448772, 55486, 309, 10, 23, "Index",
      CellTags->"HaploidRepresentations"],
    Cell[1724338, 66608, 309, 10, 15, "Index",
      CellTags->"HaploidRepresentations"]},
  "Haploids"->{
    Cell[254914, 7246, 259, 11, 15, "Index",
      CellTags->"Haploids"],
    Cell[568259, 19909, 259, 11, 23, "Index",
      CellTags->"Haploids"],
    Cell[874267, 32277, 259, 11, 15, "Index",
      CellTags->"Haploids"],
    Cell[1166037, 44071, 259, 11, 23, "Index",
      CellTags->"Haploids"],
    Cell[1449084, 55498, 259, 11, 23, "Index",
      CellTags->"Haploids"]},
  "HaploidSource"->{
    Cell[255176, 7259, 414, 14, 15, "Index",
      CellTags->"HaploidSource"],
    Cell[568521, 19922, 414, 14, 23, "Index",
      CellTags->"HaploidSource"],
    Cell[874529, 32290, 414, 14, 15, "Index",
      CellTags->"HaploidSource"],
    Cell[1166299, 44084, 414, 14, 23, "Index",
      CellTags->"HaploidSource"],
    Cell[1449346, 55511, 414, 14, 23, "Index",
      CellTags->"HaploidSource"],
    Cell[1724650, 66620, 414, 14, 15, "Index",
      CellTags->"HaploidSource"]},
  "HaploidSubsets"->{
    Cell[255593, 7275, 259, 10, 15, "Index",
      CellTags->"HaploidSubsets"],
    Cell[568938, 19938, 259, 10, 23, "Index",
      CellTags->"HaploidSubsets"],
    Cell[874946, 32306, 259, 10, 15, "Index",
      CellTags->"HaploidSubsets"],
    Cell[1166716, 44100, 259, 10, 23, "Index",
      CellTags->"HaploidSubsets"],
    Cell[1449763, 55527, 259, 10, 23, "Index",
      CellTags->"HaploidSubsets"],
    Cell[1725067, 66636, 259, 10, 15, "Index",
      CellTags->"HaploidSubsets"]},
  "HaploidTypes"->{
    Cell[255855, 7287, 257, 10, 15, "Index",
      CellTags->"HaploidTypes"],
    Cell[569200, 19950, 257, 10, 23, "Index",
      CellTags->"HaploidTypes"],
    Cell[875208, 32318, 257, 10, 15, "Index",
      CellTags->"HaploidTypes"],
    Cell[1166978, 44112, 257, 10, 23, "Index",
      CellTags->"HaploidTypes"],
    Cell[1450025, 55539, 257, 10, 23, "Index",
      CellTags->"HaploidTypes"],
    Cell[1725329, 66648, 257, 10, 15, "Index",
      CellTags->"HaploidTypes"]},
  "Help browser"->{
    Cell[256115, 7299, 314, 11, 15, "Index",
      CellTags->"Help browser"],
    Cell[569460, 19962, 314, 11, 23, "Index",
      CellTags->"Help browser"],
    Cell[875468, 32330, 314, 11, 15, "Index",
      CellTags->"Help browser"],
    Cell[1167238, 44124, 314, 11, 23, "Index",
      CellTags->"Help browser"],
    Cell[1450285, 55551, 314, 11, 23, "Index",
      CellTags->"Help browser"],
    Cell[1725589, 66660, 314, 11, 15, "Index",
      CellTags->"Help browser"]},
  "Help Browser"->{
    Cell[256432, 7312, 281, 10, 15, "Index",
      CellTags->"Help Browser"],
    Cell[256716, 7324, 291, 9, 15, "IndexSubentry",
      CellTags->"Help Browser"],
    Cell[569777, 19975, 281, 10, 23, "Index",
      CellTags->"Help Browser"],
    Cell[570061, 19987, 291, 9, 23, "IndexSubentry",
      CellTags->"Help Browser"],
    Cell[875785, 32343, 281, 10, 15, "Index",
      CellTags->"Help Browser"],
    Cell[876069, 32355, 291, 9, 15, "IndexSubentry",
      CellTags->"Help Browser"],
    Cell[1167555, 44137, 281, 10, 23, "Index",
      CellTags->"Help Browser"],
    Cell[1167839, 44149, 291, 9, 23, "IndexSubentry",
      CellTags->"Help Browser"],
    Cell[1450602, 55564, 281, 10, 23, "Index",
      CellTags->"Help Browser"],
    Cell[1450886, 55576, 291, 9, 23, "IndexSubentry",
      CellTags->"Help Browser"],
    Cell[1725906, 66673, 281, 10, 15, "Index",
      CellTags->"Help Browser"],
    Cell[1726190, 66685, 291, 9, 15, "IndexSubentry",
      CellTags->"Help Browser"]},
  "Hermaphrodites"->{
    Cell[257010, 7335, 432, 15, 15, "Index",
      CellTags->"Hermaphrodites"],
    Cell[570355, 19998, 432, 15, 23, "Index",
      CellTags->"Hermaphrodites"],
    Cell[876363, 32366, 432, 15, 15, "Index",
      CellTags->"Hermaphrodites"],
    Cell[1168133, 44160, 432, 15, 23, "Index",
      CellTags->"Hermaphrodites"],
    Cell[1451180, 55587, 432, 15, 23, "Index",
      CellTags->"Hermaphrodites"],
    Cell[1726484, 66696, 432, 15, 15, "Index",
      CellTags->"Hermaphrodites"]},
  "HeterozygoteB"->{
    Cell[257445, 7352, 284, 10, 15, "Index",
      CellTags->"HeterozygoteB"],
    Cell[570790, 20015, 284, 10, 23, "Index",
      CellTags->"HeterozygoteB"],
    Cell[876798, 32383, 284, 10, 15, "Index",
      CellTags->"HeterozygoteB"],
    Cell[1168568, 44177, 284, 10, 23, "Index",
      CellTags->"HeterozygoteB"],
    Cell[1451615, 55604, 284, 10, 23, "Index",
      CellTags->"HeterozygoteB"],
    Cell[1726919, 66713, 284, 10, 15, "Index",
      CellTags->"HeterozygoteB"]},
  "Hill 1974a"->{
    Cell[257732, 7364, 237, 10, 15, "Index",
      CellTags->"Hill 1974a"],
    Cell[571077, 20027, 237, 10, 23, "Index",
      CellTags->"Hill 1974a"],
    Cell[877085, 32395, 237, 10, 15, "Index",
      CellTags->"Hill 1974a"],
    Cell[1168855, 44189, 237, 10, 23, "Index",
      CellTags->"Hill 1974a"],
    Cell[1451902, 55616, 237, 10, 23, "Index",
      CellTags->"Hill 1974a"],
    Cell[1727206, 66725, 237, 10, 15, "Index",
      CellTags->"Hill 1974a"]},
  "Hill 1974b"->{
    Cell[257972, 7376, 237, 10, 15, "Index",
      CellTags->"Hill 1974b"],
    Cell[571317, 20039, 237, 10, 23, "Index",
      CellTags->"Hill 1974b"],
    Cell[877325, 32407, 237, 10, 15, "Index",
      CellTags->"Hill 1974b"],
    Cell[1169095, 44201, 237, 10, 23, "Index",
      CellTags->"Hill 1974b"],
    Cell[1452142, 55628, 237, 10, 23, "Index",
      CellTags->"Hill 1974b"],
    Cell[1727446, 66737, 237, 10, 15, "Index",
      CellTags->"Hill 1974b"]},
  "Hill 1974c"->{
    Cell[258212, 7388, 237, 10, 15, "Index",
      CellTags->"Hill 1974c"],
    Cell[571557, 20051, 237, 10, 23, "Index",
      CellTags->"Hill 1974c"],
    Cell[877565, 32419, 237, 10, 15, "Index",
      CellTags->"Hill 1974c"],
    Cell[1169335, 44213, 237, 10, 23, "Index",
      CellTags->"Hill 1974c"],
    Cell[1452382, 55640, 237, 10, 23, "Index",
      CellTags->"Hill 1974c"],
    Cell[1727686, 66749, 237, 10, 15, "Index",
      CellTags->"Hill 1974c"]},
  "Hudson 1990"->{
    Cell[258452, 7400, 411, 14, 15, "Index",
      CellTags->"Hudson 1990"],
    Cell[571797, 20063, 413, 14, 23, "Index",
      CellTags->"Hudson 1990"]},
  "Hypergeometric model"->{
    Cell[258866, 7416, 303, 10, 15, "Index",
      CellTags->"Hypergeometric model"],
    Cell[572213, 20079, 303, 10, 23, "Index",
      CellTags->"Hypergeometric model"],
    Cell[877805, 32431, 303, 10, 15, "Index",
      CellTags->"Hypergeometric model"],
    Cell[1169575, 44225, 303, 10, 23, "Index",
      CellTags->"Hypergeometric model"],
    Cell[1452622, 55652, 303, 10, 23, "Index",
      CellTags->"Hypergeometric model"],
    Cell[1727926, 66761, 303, 10, 15, "Index",
      CellTags->"Hypergeometric model"]},
  "Hyperlinks"->{
    Cell[259172, 7428, 256, 11, 15, "Index",
      CellTags->"Hyperlinks"],
    Cell[259431, 7441, 621, 22, 45, "IndexSubentry",
      CellTags->"Hyperlinks"],
    Cell[572519, 20091, 256, 11, 23, "Index",
      CellTags->"Hyperlinks"],
    Cell[572778, 20104, 621, 22, 53, "IndexSubentry",
      CellTags->"Hyperlinks"],
    Cell[878111, 32443, 256, 11, 15, "Index",
      CellTags->"Hyperlinks"],
    Cell[878370, 32456, 621, 22, 45, "IndexSubentry",
      CellTags->"Hyperlinks"],
    Cell[1169881, 44237, 256, 11, 23, "Index",
      CellTags->"Hyperlinks"],
    Cell[1170140, 44250, 621, 22, 53, "IndexSubentry",
      CellTags->"Hyperlinks"],
    Cell[1452928, 55664, 256, 11, 23, "Index",
      CellTags->"Hyperlinks"],
    Cell[1453187, 55677, 621, 22, 53, "IndexSubentry",
      CellTags->"Hyperlinks"],
    Cell[1728232, 66773, 256, 11, 15, "Index",
      CellTags->"Hyperlinks"],
    Cell[1728491, 66786, 621, 22, 45, "IndexSubentry",
      CellTags->"Hyperlinks"]},
  "IncidenceMatrix"->{
    Cell[260055, 7465, 270, 10, 15, "Index",
      CellTags->"IncidenceMatrix"],
    Cell[573402, 20128, 270, 10, 23, "Index",
      CellTags->"IncidenceMatrix"],
    Cell[878994, 32480, 270, 10, 15, "Index",
      CellTags->"IncidenceMatrix"],
    Cell[1170764, 44274, 270, 10, 23, "Index",
      CellTags->"IncidenceMatrix"],
    Cell[1453811, 55701, 270, 10, 23, "Index",
      CellTags->"IncidenceMatrix"],
    Cell[1729115, 66810, 270, 10, 15, "Index",
      CellTags->"IncidenceMatrix"]},
  "Index"->{
    Cell[260328, 7477, 290, 11, 15, "Index",
      CellTags->"Index"],
    Cell[573675, 20140, 290, 11, 23, "Index",
      CellTags->"Index"],
    Cell[879267, 32492, 290, 11, 15, "Index",
      CellTags->"Index"],
    Cell[1171037, 44286, 290, 11, 23, "Index",
      CellTags->"Index"],
    Cell[1454084, 55713, 290, 11, 23, "Index",
      CellTags->"Index"],
    Cell[1729388, 66822, 290, 11, 15, "Index",
      CellTags->"Index"]},
  "Individual"->{
    Cell[260621, 7490, 237, 10, 15, "Index",
      CellTags->"Individual"],
    Cell[573968, 20153, 237, 10, 23, "Index",
      CellTags->"Individual"],
    Cell[879560, 32505, 237, 10, 15, "Index",
      CellTags->"Individual"],
    Cell[1171330, 44299, 237, 10, 23, "Index",
      CellTags->"Individual"],
    Cell[1454377, 55726, 237, 10, 23, "Index",
      CellTags->"Individual"],
    Cell[1729681, 66835, 237, 10, 15, "Index",
      CellTags->"Individual"]},
  "IndividualContinuumVariables"->{
    Cell[260861, 7502, 303, 10, 15, "Index",
      CellTags->"IndividualContinuumVariables"],
    Cell[574208, 20165, 303, 10, 23, "Index",
      CellTags->"IndividualContinuumVariables"],
    Cell[879800, 32517, 303, 10, 15, "Index",
      CellTags->"IndividualContinuumVariables"],
    Cell[1171570, 44311, 303, 10, 23, "Index",
      CellTags->"IndividualContinuumVariables"]},
  "IndividualRepresentations"->{
    Cell[261167, 7514, 323, 11, 15, "Index",
      CellTags->"IndividualRepresentations"],
    Cell[574514, 20177, 323, 11, 23, "Index",
      CellTags->"IndividualRepresentations"],
    Cell[880106, 32529, 323, 11, 15, "Index",
      CellTags->"IndividualRepresentations"],
    Cell[1171876, 44323, 323, 11, 23, "Index",
      CellTags->"IndividualRepresentations"],
    Cell[1454617, 55738, 323, 11, 23, "Index",
      CellTags->"IndividualRepresentations"],
    Cell[1729921, 66847, 323, 11, 15, "Index",
      CellTags->"IndividualRepresentations"]},
  "Individuals"->{
    Cell[261493, 7527, 264, 10, 15, "Index",
      CellTags->"Individuals"],
    Cell[574840, 20190, 264, 10, 23, "Index",
      CellTags->"Individuals"],
    Cell[880432, 32542, 264, 10, 15, "Index",
      CellTags->"Individuals"],
    Cell[1172202, 44336, 264, 10, 23, "Index",
      CellTags->"Individuals"],
    Cell[1454943, 55751, 264, 10, 23, "Index",
      CellTags->"Individuals"],
    Cell[1730247, 66860, 264, 10, 15, "Index",
      CellTags->"Individuals"]},
  "Infinite sites mutation"->{
    Cell[261760, 7539, 275, 10, 15, "Index",
      CellTags->"Infinite sites mutation"],
    Cell[575411, 20214, 275, 10, 23, "Index",
      CellTags->"Infinite sites mutation"],
    Cell[880699, 32554, 275, 10, 15, "Index",
      CellTags->"Infinite sites mutation"]},
  "InformationFunction"->{
    Cell[262038, 7551, 338, 11, 15, "Index",
      CellTags->"InformationFunction"],
    Cell[262379, 7564, 501, 15, 30, "IndexSubentry",
      CellTags->"InformationFunction"],
    Cell[575689, 20226, 338, 11, 23, "Index",
      CellTags->"InformationFunction"],
    Cell[576030, 20239, 501, 15, 38, "IndexSubentry",
      CellTags->"InformationFunction"]},
  "InitialiseContinuum"->{
    Cell[262883, 7581, 272, 10, 15, "Index",
      CellTags->"InitialiseContinuum"],
    Cell[576534, 20256, 272, 10, 23, "Index",
      CellTags->"InitialiseContinuum"],
    Cell[880977, 32566, 272, 10, 15, "Index",
      CellTags->"InitialiseContinuum"],
    Cell[1172469, 44348, 272, 10, 23, "Index",
      CellTags->"InitialiseContinuum"],
    Cell[1455210, 55763, 272, 10, 23, "Index",
      CellTags->"InitialiseContinuum"],
    Cell[1730514, 66872, 272, 10, 15, "Index",
      CellTags->"InitialiseContinuum"]},
  "InitialiseCovariance"->{
    Cell[263158, 7593, 263, 10, 15, "Index",
      CellTags->"InitialiseCovariance"],
    Cell[576809, 20268, 263, 10, 23, "Index",
      CellTags->"InitialiseCovariance"],
    Cell[881252, 32578, 263, 10, 15, "Index",
      CellTags->"InitialiseCovariance"],
    Cell[1172744, 44360, 263, 10, 23, "Index",
      CellTags->"InitialiseCovariance"],
    Cell[1455485, 55775, 263, 10, 23, "Index",
      CellTags->"InitialiseCovariance"],
    Cell[1730789, 66884, 263, 10, 15, "Index",
      CellTags->"InitialiseCovariance"]},
  "InitialiseDemes"->{
    Cell[263424, 7605, 414, 14, 15, "Index",
      CellTags->"InitialiseDemes"],
    Cell[577075, 20280, 414, 14, 23, "Index",
      CellTags->"InitialiseDemes"],
    Cell[881518, 32590, 414, 14, 15, "Index",
      CellTags->"InitialiseDemes"],
    Cell[1173010, 44372, 414, 14, 23, "Index",
      CellTags->"InitialiseDemes"],
    Cell[1455751, 55787, 414, 14, 23, "Index",
      CellTags->"InitialiseDemes"],
    Cell[1731055, 66896, 414, 14, 15, "Index",
      CellTags->"InitialiseDemes"]},
  "InitialStep"->{
    Cell[263841, 7621, 254, 10, 15, "Index",
      CellTags->"InitialStep"],
    Cell[577492, 20296, 254, 10, 23, "Index",
      CellTags->"InitialStep"],
    Cell[881935, 32606, 254, 10, 15, "Index",
      CellTags->"InitialStep"],
    Cell[1173427, 44388, 254, 10, 23, "Index",
      CellTags->"InitialStep"],
    Cell[1456168, 55803, 254, 10, 23, "Index",
      CellTags->"InitialStep"],
    Cell[1731472, 66912, 254, 10, 15, "Index",
      CellTags->"InitialStep"]},
  "InitialStepReduced"->{
    Cell[264098, 7633, 277, 10, 15, "Index",
      CellTags->"InitialStepReduced"],
    Cell[577749, 20308, 277, 10, 23, "Index",
      CellTags->"InitialStepReduced"],
    Cell[882192, 32618, 277, 10, 15, "Index",
      CellTags->"InitialStepReduced"],
    Cell[1173684, 44400, 277, 10, 23, "Index",
      CellTags->"InitialStepReduced"],
    Cell[1456425, 55815, 277, 10, 23, "Index",
      CellTags->"InitialStepReduced"],
    Cell[1731729, 66924, 277, 10, 15, "Index",
      CellTags->"InitialStepReduced"]},
  "InternalNodes"->{
    Cell[264378, 7645, 270, 10, 15, "Index",
      CellTags->"InternalNodes"],
    Cell[578029, 20320, 270, 10, 23, "Index",
      CellTags->"InternalNodes"],
    Cell[882472, 32630, 270, 10, 15, "Index",
      CellTags->"InternalNodes"],
    Cell[1173964, 44412, 270, 10, 23, "Index",
      CellTags->"InternalNodes"],
    Cell[1456705, 55827, 270, 10, 23, "Index",
      CellTags->"InternalNodes"],
    Cell[1732009, 66936, 270, 10, 15, "Index",
      CellTags->"InternalNodes"]},
  "IntervalCombine"->{
    Cell[264651, 7657, 268, 10, 15, "Index",
      CellTags->"IntervalCombine"],
    Cell[578302, 20332, 268, 10, 23, "Index",
      CellTags->"IntervalCombine"],
    Cell[882745, 32642, 268, 10, 15, "Index",
      CellTags->"IntervalCombine"],
    Cell[1174237, 44424, 268, 10, 23, "Index",
      CellTags->"IntervalCombine"],
    Cell[1456978, 55839, 268, 10, 23, "Index",
      CellTags->"IntervalCombine"],
    Cell[1732282, 66948, 268, 10, 15, "Index",
      CellTags->"IntervalCombine"]},
  "IntervalPosition"->{
    Cell[264922, 7669, 271, 10, 15, "Index",
      CellTags->"IntervalPosition"],
    Cell[578573, 20344, 271, 10, 23, "Index",
      CellTags->"IntervalPosition"],
    Cell[883016, 32654, 271, 10, 15, "Index",
      CellTags->"IntervalPosition"],
    Cell[1174508, 44436, 271, 10, 23, "Index",
      CellTags->"IntervalPosition"],
    Cell[1457249, 55851, 271, 10, 23, "Index",
      CellTags->"IntervalPosition"],
    Cell[1732553, 66960, 271, 10, 15, "Index",
      CellTags->"IntervalPosition"]},
  "InverseFourierNormalised"->{
    Cell[265196, 7681, 295, 10, 15, "Index",
      CellTags->"InverseFourierNormalised"],
    Cell[578847, 20356, 295, 10, 23, "Index",
      CellTags->"InverseFourierNormalised"],
    Cell[883290, 32666, 295, 10, 15, "Index",
      CellTags->"InverseFourierNormalised"],
    Cell[1174782, 44448, 295, 10, 23, "Index",
      CellTags->"InverseFourierNormalised"],
    Cell[1457523, 55863, 295, 10, 23, "Index",
      CellTags->"InverseFourierNormalised"],
    Cell[1732827, 66972, 295, 10, 15, "Index",
      CellTags->"InverseFourierNormalised"]},
  "InverseFourierNormalisedTable"->{
    Cell[265494, 7693, 310, 10, 15, "Index",
      CellTags->"InverseFourierNormalisedTable"],
    Cell[579145, 20368, 310, 10, 23, "Index",
      CellTags->"InverseFourierNormalisedTable"],
    Cell[883588, 32678, 310, 10, 15, "Index",
      CellTags->"InverseFourierNormalisedTable"],
    Cell[1175080, 44460, 310, 10, 23, "Index",
      CellTags->"InverseFourierNormalisedTable"],
    Cell[1457821, 55875, 310, 10, 23, "Index",
      CellTags->"InverseFourierNormalisedTable"],
    Cell[1733125, 66984, 310, 10, 15, "Index",
      CellTags->"InverseFourierNormalisedTable"]},
  "Island model"->{
    Cell[265807, 7705, 476, 15, 15, "Index",
      CellTags->"Island model"],
    Cell[266286, 7722, 795, 25, 45, "IndexSubentry",
      CellTags->"Island model"],
    Cell[579458, 20380, 476, 15, 23, "Index",
      CellTags->"Island model"],
    Cell[579937, 20397, 795, 25, 53, "IndexSubentry",
      CellTags->"Island model"],
    Cell[883901, 32690, 476, 15, 15, "Index",
      CellTags->"Island model"],
    Cell[884380, 32707, 795, 25, 45, "IndexSubentry",
      CellTags->"Island model"],
    Cell[1175393, 44472, 476, 15, 23, "Index",
      CellTags->"Island model"],
    Cell[1175872, 44489, 795, 25, 53, "IndexSubentry",
      CellTags->"Island model"],
    Cell[1458134, 55887, 476, 15, 23, "Index",
      CellTags->"Island model"],
    Cell[1458613, 55904, 795, 25, 53, "IndexSubentry",
      CellTags->"Island model"],
    Cell[1733438, 66996, 476, 15, 15, "Index",
      CellTags->"Island model"],
    Cell[1733917, 67013, 795, 25, 45, "IndexSubentry",
      CellTags->"Island model"]},
  "IterateContinuum"->{
    Cell[267084, 7749, 295, 10, 15, "Index",
      CellTags->"IterateContinuum"],
    Cell[580735, 20424, 295, 10, 23, "Index",
      CellTags->"IterateContinuum"],
    Cell[885178, 32734, 295, 10, 15, "Index",
      CellTags->"IterateContinuum"],
    Cell[1176670, 44516, 295, 10, 23, "Index",
      CellTags->"IterateContinuum"],
    Cell[1459411, 55931, 295, 10, 23, "Index",
      CellTags->"IterateContinuum"],
    Cell[1734715, 67040, 295, 10, 15, "Index",
      CellTags->"IterateContinuum"]},
  "IterateExact"->{
    Cell[267382, 7761, 264, 11, 15, "Index",
      CellTags->"IterateExact"],
    Cell[267649, 7774, 1753, 53, 120, "IndexSubentry",
      CellTags->"IterateExact"],
    Cell[581033, 20436, 264, 11, 23, "Index",
      CellTags->"IterateExact"],
    Cell[581300, 20449, 1753, 53, 128, "IndexSubentry",
      CellTags->"IterateExact"],
    Cell[885476, 32746, 264, 11, 15, "Index",
      CellTags->"IterateExact"],
    Cell[885743, 32759, 1753, 53, 120, "IndexSubentry",
      CellTags->"IterateExact"],
    Cell[1176968, 44528, 264, 11, 23, "Index",
      CellTags->"IterateExact"],
    Cell[1177235, 44541, 1753, 53, 128, "IndexSubentry",
      CellTags->"IterateExact"],
    Cell[1459709, 55943, 264, 11, 23, "Index",
      CellTags->"IterateExact"],
    Cell[1459976, 55956, 1753, 53, 128, "IndexSubentry",
      CellTags->"IterateExact"],
    Cell[1735013, 67052, 264, 11, 15, "Index",
      CellTags->"IterateExact"],
    Cell[1735280, 67065, 1753, 53, 120, "IndexSubentry",
      CellTags->"IterateExact"]},
  "Join"->{
    Cell[269405, 7829, 328, 14, 15, "Index",
      CellTags->"Join"],
    Cell[583056, 20504, 328, 14, 23, "Index",
      CellTags->"Join"],
    Cell[887499, 32814, 328, 14, 15, "Index",
      CellTags->"Join"],
    Cell[1178991, 44596, 328, 14, 23, "Index",
      CellTags->"Join"],
    Cell[1461732, 56011, 328, 14, 23, "Index",
      CellTags->"Join"],
    Cell[1739657, 67223, 328, 14, 15, "Index",
      CellTags->"Join"]},
  "Junctions"->{
    Cell[269736, 7845, 295, 11, 15, "Index",
      CellTags->"Junctions"],
    Cell[583387, 20520, 295, 11, 23, "Index",
      CellTags->"Junctions"]},
  "JunctionStyle"->{
    Cell[270034, 7858, 307, 11, 15, "Index",
      CellTags->"JunctionStyle"],
    Cell[583685, 20533, 307, 11, 23, "Index",
      CellTags->"JunctionStyle"]},
  "Juveniles"->{
    Cell[270344, 7871, 417, 15, 15, "Index",
      CellTags->"Juveniles"],
    Cell[583995, 20546, 417, 15, 23, "Index",
      CellTags->"Juveniles"],
    Cell[887830, 32830, 417, 15, 15, "Index",
      CellTags->"Juveniles"],
    Cell[1179322, 44612, 417, 15, 23, "Index",
      CellTags->"Juveniles"],
    Cell[1462063, 56027, 417, 15, 23, "Index",
      CellTags->"Juveniles"],
    Cell[1739988, 67239, 417, 15, 15, "Index",
      CellTags->"Juveniles"]},
  "Kirkpatrick and Barton 1997"->{
    Cell[270764, 7888, 310, 10, 15, "Index",
      CellTags->"Kirkpatrick and Barton 1997"],
    Cell[584415, 20563, 310, 10, 23, "Index",
      CellTags->"Kirkpatrick and Barton 1997"],
    Cell[888250, 32847, 310, 10, 15, "Index",
      CellTags->"Kirkpatrick and Barton 1997"],
    Cell[1179742, 44629, 310, 10, 23, "Index",
      CellTags->"Kirkpatrick and Barton 1997"],
    Cell[1462483, 56044, 310, 10, 23, "Index",
      CellTags->"Kirkpatrick and Barton 1997"],
    Cell[1740408, 67256, 310, 10, 15, "Index",
      CellTags->"Kirkpatrick and Barton 1997"]},
  "Kirkpatrick and Servedio 1998"->{
    Cell[271077, 7900, 316, 10, 15, "Index",
      CellTags->"Kirkpatrick and Servedio 1998"],
    Cell[584728, 20575, 316, 10, 23, "Index",
      CellTags->"Kirkpatrick and Servedio 1998"],
    Cell[888563, 32859, 316, 10, 15, "Index",
      CellTags->"Kirkpatrick and Servedio 1998"],
    Cell[1180055, 44641, 316, 10, 23, "Index",
      CellTags->"Kirkpatrick and Servedio 1998"],
    Cell[1462796, 56056, 316, 10, 23, "Index",
      CellTags->"Kirkpatrick and Servedio 1998"],
    Cell[1740721, 67268, 316, 10, 15, "Index",
      CellTags->"Kirkpatrick and Servedio 1998"]},
  "Kirkpatrick et al."->{
    Cell[271396, 7912, 392, 14, 15, "Index",
      CellTags->"Kirkpatrick et al."],
    Cell[271791, 7928, 3891, 138, 285, "IndexSubentry",
      CellTags->"Kirkpatrick et al."],
    Cell[585047, 20587, 392, 14, 23, "Index",
      CellTags->"Kirkpatrick et al."],
    Cell[585442, 20603, 3891, 138, 293, "IndexSubentry",
      CellTags->"Kirkpatrick et al."],
    Cell[888882, 32871, 392, 14, 15, "Index",
      CellTags->"Kirkpatrick et al."],
    Cell[889277, 32887, 3891, 138, 285, "IndexSubentry",
      CellTags->"Kirkpatrick et al."],
    Cell[1180374, 44653, 392, 14, 23, "Index",
      CellTags->"Kirkpatrick et al."],
    Cell[1180769, 44669, 3891, 138, 293, "IndexSubentry",
      CellTags->"Kirkpatrick et al."],
    Cell[1463115, 56068, 392, 14, 23, "Index",
      CellTags->"Kirkpatrick et al."],
    Cell[1463510, 56084, 3891, 138, 293, "IndexSubentry",
      CellTags->"Kirkpatrick et al."]},
  "Kirkpatrick et al. 1983"->{
    Cell[275685, 8068, 275, 10, 15, "Index",
      CellTags->"Kirkpatrick et al. 1983"],
    Cell[589336, 20743, 275, 10, 23, "Index",
      CellTags->"Kirkpatrick et al. 1983"],
    Cell[893171, 33027, 275, 10, 15, "Index",
      CellTags->"Kirkpatrick et al. 1983"],
    Cell[1184663, 44809, 275, 10, 23, "Index",
      CellTags->"Kirkpatrick et al. 1983"],
    Cell[1467404, 56224, 275, 10, 23, "Index",
      CellTags->"Kirkpatrick et al. 1983"],
    Cell[1741040, 67280, 275, 10, 15, "Index",
      CellTags->"Kirkpatrick et al. 1983"]},
  "Kruuk 1997"->{
    Cell[275963, 8080, 237, 10, 15, "Index",
      CellTags->"Kruuk 1997"],
    Cell[589614, 20755, 237, 10, 23, "Index",
      CellTags->"Kruuk 1997"],
    Cell[893449, 33039, 237, 10, 15, "Index",
      CellTags->"Kruuk 1997"],
    Cell[1184941, 44821, 237, 10, 23, "Index",
      CellTags->"Kruuk 1997"],
    Cell[1467682, 56236, 237, 10, 23, "Index",
      CellTags->"Kruuk 1997"],
    Cell[1741318, 67292, 237, 10, 15, "Index",
      CellTags->"Kruuk 1997"]},
  "LeafEvents"->{
    Cell[276203, 8092, 298, 11, 15, "Index",
      CellTags->"LeafEvents"],
    Cell[589854, 20767, 298, 11, 23, "Index",
      CellTags->"LeafEvents"]},
  "LeafLabels"->{
    Cell[276504, 8105, 257, 10, 15, "Index",
      CellTags->"LeafLabels"],
    Cell[590155, 20780, 257, 10, 23, "Index",
      CellTags->"LeafLabels"],
    Cell[893689, 33051, 257, 10, 15, "Index",
      CellTags->"LeafLabels"],
    Cell[1185181, 44833, 257, 10, 23, "Index",
      CellTags->"LeafLabels"],
    Cell[1467922, 56248, 257, 10, 23, "Index",
      CellTags->"LeafLabels"],
    Cell[1741558, 67304, 257, 10, 15, "Index",
      CellTags->"LeafLabels"]},
  "LeafOffset"->{
    Cell[276764, 8117, 257, 10, 15, "Index",
      CellTags->"LeafOffset"],
    Cell[590415, 20792, 257, 10, 23, "Index",
      CellTags->"LeafOffset"],
    Cell[893949, 33063, 257, 10, 15, "Index",
      CellTags->"LeafOffset"],
    Cell[1185441, 44845, 257, 10, 23, "Index",
      CellTags->"LeafOffset"],
    Cell[1468182, 56260, 257, 10, 23, "Index",
      CellTags->"LeafOffset"],
    Cell[1741818, 67316, 257, 10, 15, "Index",
      CellTags->"LeafOffset"]},
  "Leaves"->{
    Cell[277024, 8129, 249, 10, 15, "Index",
      CellTags->"Leaves"],
    Cell[277276, 8141, 275, 9, 15, "IndexSubentry",
      CellTags->"Leaves"],
    Cell[590675, 20804, 249, 10, 23, "Index",
      CellTags->"Leaves"],
    Cell[590927, 20816, 275, 9, 23, "IndexSubentry",
      CellTags->"Leaves"],
    Cell[894209, 33075, 249, 10, 15, "Index",
      CellTags->"Leaves"],
    Cell[1185701, 44857, 249, 10, 23, "Index",
      CellTags->"Leaves"],
    Cell[1468442, 56272, 249, 10, 23, "Index",
      CellTags->"Leaves"],
    Cell[1742078, 67328, 249, 10, 15, "Index",
      CellTags->"Leaves"]},
  "Life cycle"->{
    Cell[277554, 8152, 229, 10, 15, "Index",
      CellTags->"Life cycle"],
    Cell[277786, 8164, 3070, 111, 180, "IndexSubentry",
      CellTags->"Life cycle"],
    Cell[591205, 20827, 229, 10, 23, "Index",
      CellTags->"Life cycle"],
    Cell[591437, 20839, 3070, 111, 188, "IndexSubentry",
      CellTags->"Life cycle"],
    Cell[894461, 33087, 229, 10, 15, "Index",
      CellTags->"Life cycle"],
    Cell[894693, 33099, 3070, 111, 180, "IndexSubentry",
      CellTags->"Life cycle"],
    Cell[1185953, 44869, 229, 10, 23, "Index",
      CellTags->"Life cycle"],
    Cell[1186185, 44881, 3070, 111, 188, "IndexSubentry",
      CellTags->"Life cycle"],
    Cell[1468694, 56284, 229, 10, 23, "Index",
      CellTags->"Life cycle"],
    Cell[1468926, 56296, 3070, 111, 188, "IndexSubentry",
      CellTags->"Life cycle"],
    Cell[1742330, 67340, 229, 10, 15, "Index",
      CellTags->"Life cycle"],
    Cell[1742562, 67352, 3070, 111, 180, "IndexSubentry",
      CellTags->"Life cycle"]},
  "LineagesPresent"->{
    Cell[280859, 8277, 313, 11, 15, "Index",
      CellTags->"LineagesPresent"],
    Cell[594510, 20952, 313, 11, 23, "Index",
      CellTags->"LineagesPresent"]},
  "Li & Nei 1974"->{
    Cell[281175, 8290, 246, 10, 15, "Index",
      CellTags->"Li & Nei 1974"],
    Cell[594826, 20965, 246, 10, 23, "Index",
      CellTags->"Li & Nei 1974"],
    Cell[897766, 33212, 246, 10, 15, "Index",
      CellTags->"Li & Nei 1974"],
    Cell[1189258, 44994, 246, 10, 23, "Index",
      CellTags->"Li & Nei 1974"],
    Cell[1471999, 56409, 246, 10, 23, "Index",
      CellTags->"Li & Nei 1974"],
    Cell[1745635, 67465, 246, 10, 15, "Index",
      CellTags->"Li & Nei 1974"]},
  "Linkage"->{
    Cell[281424, 8302, 480, 18, 15, "Index",
      CellTags->"Linkage"],
    Cell[281907, 8322, 451, 15, 30, "IndexSubentry",
      CellTags->"Linkage"],
    Cell[595075, 20977, 480, 18, 23, "Index",
      CellTags->"Linkage"],
    Cell[595558, 20997, 451, 15, 38, "IndexSubentry",
      CellTags->"Linkage"],
    Cell[898015, 33224, 480, 18, 15, "Index",
      CellTags->"Linkage"],
    Cell[898498, 33244, 451, 15, 30, "IndexSubentry",
      CellTags->"Linkage"],
    Cell[1189507, 45006, 480, 18, 23, "Index",
      CellTags->"Linkage"],
    Cell[1189990, 45026, 451, 15, 38, "IndexSubentry",
      CellTags->"Linkage"],
    Cell[1472248, 56421, 480, 18, 23, "Index",
      CellTags->"Linkage"],
    Cell[1472731, 56441, 451, 15, 38, "IndexSubentry",
      CellTags->"Linkage"],
    Cell[1745884, 67477, 480, 18, 15, "Index",
      CellTags->"Linkage"],
    Cell[1746367, 67497, 451, 15, 30, "IndexSubentry",
      CellTags->"Linkage"]},
  "Linkage disequilibrium"->{
    Cell[282361, 8339, 307, 10, 15, "Index",
      CellTags->"Linkage disequilibrium"],
    Cell[596012, 21014, 307, 10, 23, "Index",
      CellTags->"Linkage disequilibrium"],
    Cell[898952, 33261, 307, 10, 15, "Index",
      CellTags->"Linkage disequilibrium"],
    Cell[1190444, 45043, 307, 10, 23, "Index",
      CellTags->"Linkage disequilibrium"],
    Cell[1473185, 56458, 307, 10, 23, "Index",
      CellTags->"Linkage disequilibrium"],
    Cell[1746821, 67514, 307, 10, 15, "Index",
      CellTags->"Linkage disequilibrium"]},
  "LinkedRecombination"->{
    Cell[282671, 8351, 270, 10, 15, "Index",
      CellTags->"LinkedRecombination"],
    Cell[596322, 21026, 270, 10, 23, "Index",
      CellTags->"LinkedRecombination"],
    Cell[899262, 33273, 270, 10, 15, "Index",
      CellTags->"LinkedRecombination"],
    Cell[1190754, 45055, 270, 10, 23, "Index",
      CellTags->"LinkedRecombination"]},
  "ListToGenealogy"->{
    Cell[282944, 8363, 280, 10, 15, "Index",
      CellTags->"ListToGenealogy"],
    Cell[596595, 21038, 280, 10, 23, "Index",
      CellTags->"ListToGenealogy"],
    Cell[899535, 33285, 280, 10, 15, "Index",
      CellTags->"ListToGenealogy"],
    Cell[1191027, 45067, 280, 10, 23, "Index",
      CellTags->"ListToGenealogy"],
    Cell[1473495, 56470, 280, 10, 23, "Index",
      CellTags->"ListToGenealogy"],
    Cell[1747131, 67526, 280, 10, 15, "Index",
      CellTags->"ListToGenealogy"]},
  "ListToMatrix"->{
    Cell[283227, 8375, 291, 10, 15, "Index",
      CellTags->"ListToMatrix"],
    Cell[596878, 21050, 291, 10, 23, "Index",
      CellTags->"ListToMatrix"],
    Cell[899818, 33297, 291, 10, 15, "Index",
      CellTags->"ListToMatrix"],
    Cell[1191310, 45079, 291, 10, 23, "Index",
      CellTags->"ListToMatrix"],
    Cell[1473778, 56482, 291, 10, 23, "Index",
      CellTags->"ListToMatrix"],
    Cell[1747414, 67538, 291, 10, 15, "Index",
      CellTags->"ListToMatrix"]},
  "Location"->{
    Cell[283521, 8387, 255, 10, 15, "Index",
      CellTags->"Location"],
    Cell[597172, 21062, 255, 10, 23, "Index",
      CellTags->"Location"],
    Cell[900112, 33309, 255, 10, 15, "Index",
      CellTags->"Location"],
    Cell[1191604, 45091, 255, 10, 23, "Index",
      CellTags->"Location"],
    Cell[1474072, 56494, 255, 10, 23, "Index",
      CellTags->"Location"],
    Cell[1747708, 67550, 255, 10, 15, "Index",
      CellTags->"Location"]},
  "Locations"->{
    Cell[283779, 8399, 232, 10, 15, "Index",
      CellTags->"Locations"],
    Cell[597430, 21074, 232, 10, 23, "Index",
      CellTags->"Locations"],
    Cell[900370, 33321, 232, 10, 15, "Index",
      CellTags->"Locations"],
    Cell[1191862, 45103, 232, 10, 23, "Index",
      CellTags->"Locations"],
    Cell[1474330, 56506, 232, 10, 23, "Index",
      CellTags->"Locations"],
    Cell[1747966, 67562, 232, 10, 15, "Index",
      CellTags->"Locations"]},
  "LocusNames"->{
    Cell[284014, 8411, 253, 10, 15, "Index",
      CellTags->"LocusNames"],
    Cell[597665, 21086, 253, 10, 23, "Index",
      CellTags->"LocusNames"],
    Cell[900605, 33333, 253, 10, 15, "Index",
      CellTags->"LocusNames"],
    Cell[1192097, 45115, 253, 10, 23, "Index",
      CellTags->"LocusNames"],
    Cell[1474565, 56518, 253, 10, 23, "Index",
      CellTags->"LocusNames"],
    Cell[1748201, 67574, 253, 10, 15, "Index",
      CellTags->"LocusNames"]},
  "LogLikelihoodDisequilibrium"->{
    Cell[284270, 8423, 288, 10, 15, "Index",
      CellTags->"LogLikelihoodDisequilibrium"],
    Cell[597921, 21098, 288, 10, 23, "Index",
      CellTags->"LogLikelihoodDisequilibrium"],
    Cell[900861, 33345, 288, 10, 15, "Index",
      CellTags->"LogLikelihoodDisequilibrium"],
    Cell[1192353, 45127, 288, 10, 23, "Index",
      CellTags->"LogLikelihoodDisequilibrium"],
    Cell[1474821, 56530, 288, 10, 23, "Index",
      CellTags->"LogLikelihoodDisequilibrium"],
    Cell[1748457, 67586, 288, 10, 15, "Index",
      CellTags->"LogLikelihoodDisequilibrium"]},
  "LogLikelihoodDisequilibriumReduced"->{
    Cell[284561, 8435, 325, 10, 15, "Index",
      CellTags->"LogLikelihoodDisequilibriumReduced"],
    Cell[598212, 21110, 325, 10, 23, "Index",
      CellTags->"LogLikelihoodDisequilibriumReduced"],
    Cell[901152, 33357, 325, 10, 15, "Index",
      CellTags->"LogLikelihoodDisequilibriumReduced"],
    Cell[1192644, 45139, 325, 10, 23, "Index",
      CellTags->"LogLikelihoodDisequilibriumReduced"],
    Cell[1475112, 56542, 325, 10, 23, "Index",
      CellTags->"LogLikelihoodDisequilibriumReduced"],
    Cell[1748748, 67598, 325, 10, 15, "Index",
      CellTags->"LogLikelihoodDisequilibriumReduced"]},
  "LogLikelihoodTest"->{
    Cell[284889, 8447, 270, 10, 15, "Index",
      CellTags->"LogLikelihoodTest"],
    Cell[598540, 21122, 270, 10, 23, "Index",
      CellTags->"LogLikelihoodTest"],
    Cell[901480, 33369, 270, 10, 15, "Index",
      CellTags->"LogLikelihoodTest"],
    Cell[1192972, 45151, 270, 10, 23, "Index",
      CellTags->"LogLikelihoodTest"],
    Cell[1475440, 56554, 270, 10, 23, "Index",
      CellTags->"LogLikelihoodTest"],
    Cell[1749076, 67610, 270, 10, 15, "Index",
      CellTags->"LogLikelihoodTest"]},
  "Log-linear models"->{
    Cell[285162, 8459, 397, 14, 15, "Index",
      CellTags->"Log-linear models"],
    Cell[598813, 21134, 397, 14, 23, "Index",
      CellTags->"Log-linear models"],
    Cell[901753, 33381, 397, 14, 15, "Index",
      CellTags->"Log-linear models"],
    Cell[1193245, 45163, 397, 14, 23, "Index",
      CellTags->"Log-linear models"],
    Cell[1475713, 56566, 397, 14, 23, "Index",
      CellTags->"Log-linear models"],
    Cell[1749349, 67622, 397, 14, 15, "Index",
      CellTags->"Log-linear models"]},
  "Long et al 1995"->{
    Cell[285562, 8475, 252, 10, 15, "Index",
      CellTags->"Long et al 1995"],
    Cell[599213, 21150, 252, 10, 23, "Index",
      CellTags->"Long et al 1995"],
    Cell[902153, 33397, 252, 10, 15, "Index",
      CellTags->"Long et al 1995"],
    Cell[1193645, 45179, 252, 10, 23, "Index",
      CellTags->"Long et al 1995"],
    Cell[1476113, 56582, 252, 10, 23, "Index",
      CellTags->"Long et al 1995"],
    Cell[1749749, 67638, 252, 10, 15, "Index",
      CellTags->"Long et al 1995"]},
  "LowerOffDiagonal"->{
    Cell[285817, 8487, 269, 10, 15, "Index",
      CellTags->"LowerOffDiagonal"],
    Cell[599468, 21162, 269, 10, 23, "Index",
      CellTags->"LowerOffDiagonal"],
    Cell[902408, 33409, 269, 10, 15, "Index",
      CellTags->"LowerOffDiagonal"],
    Cell[1193900, 45191, 269, 10, 23, "Index",
      CellTags->"LowerOffDiagonal"],
    Cell[1476368, 56594, 269, 10, 23, "Index",
      CellTags->"LowerOffDiagonal"],
    Cell[1750004, 67650, 269, 10, 15, "Index",
      CellTags->"LowerOffDiagonal"]},
  "MacCallum 1994"->{
    Cell[286089, 8499, 249, 10, 15, "Index",
      CellTags->"MacCallum 1994"],
    Cell[599740, 21174, 249, 10, 23, "Index",
      CellTags->"MacCallum 1994"],
    Cell[902680, 33421, 249, 10, 15, "Index",
      CellTags->"MacCallum 1994"],
    Cell[1194172, 45203, 249, 10, 23, "Index",
      CellTags->"MacCallum 1994"],
    Cell[1476640, 56606, 249, 10, 23, "Index",
      CellTags->"MacCallum 1994"],
    Cell[1750276, 67662, 249, 10, 15, "Index",
      CellTags->"MacCallum 1994"]},
  "MacCallum et al. 1998"->{
    Cell[286341, 8511, 269, 10, 15, "Index",
      CellTags->"MacCallum et al. 1998"],
    Cell[599992, 21186, 269, 10, 23, "Index",
      CellTags->"MacCallum et al. 1998"],
    Cell[902932, 33433, 269, 10, 15, "Index",
      CellTags->"MacCallum et al. 1998"],
    Cell[1194424, 45215, 269, 10, 23, "Index",
      CellTags->"MacCallum et al. 1998"],
    Cell[1476892, 56618, 269, 10, 23, "Index",
      CellTags->"MacCallum et al. 1998"],
    Cell[1750528, 67674, 269, 10, 15, "Index",
      CellTags->"MacCallum et al. 1998"]},
  "MakeCline"->{
    Cell[286613, 8523, 320, 11, 15, "Index",
      CellTags->"MakeCline"],
    Cell[286936, 8536, 691, 21, 45, "IndexSubentry",
      CellTags->"MakeCline"],
    Cell[600264, 21198, 320, 11, 23, "Index",
      CellTags->"MakeCline"],
    Cell[600587, 21211, 691, 21, 53, "IndexSubentry",
      CellTags->"MakeCline"],
    Cell[903204, 33445, 320, 11, 15, "Index",
      CellTags->"MakeCline"],
    Cell[903527, 33458, 691, 21, 45, "IndexSubentry",
      CellTags->"MakeCline"],
    Cell[1194696, 45227, 320, 11, 23, "Index",
      CellTags->"MakeCline"],
    Cell[1195019, 45240, 691, 21, 53, "IndexSubentry",
      CellTags->"MakeCline"],
    Cell[1477164, 56630, 320, 11, 23, "Index",
      CellTags->"MakeCline"],
    Cell[1477487, 56643, 691, 21, 53, "IndexSubentry",
      CellTags->"MakeCline"],
    Cell[1750800, 67686, 320, 11, 15, "Index",
      CellTags->"MakeCline"],
    Cell[1751123, 67699, 691, 21, 45, "IndexSubentry",
      CellTags->"MakeCline"]},
  "MakeDiploid"->{
    Cell[287630, 8559, 296, 11, 15, "Index",
      CellTags->"MakeDiploid"],
    Cell[287929, 8572, 474, 15, 30, "IndexSubentry",
      CellTags->"MakeDiploid"],
    Cell[601281, 21234, 296, 11, 23, "Index",
      CellTags->"MakeDiploid"],
    Cell[601580, 21247, 474, 15, 38, "IndexSubentry",
      CellTags->"MakeDiploid"],
    Cell[904221, 33481, 296, 11, 15, "Index",
      CellTags->"MakeDiploid"],
    Cell[904520, 33494, 474, 15, 30, "IndexSubentry",
      CellTags->"MakeDiploid"],
    Cell[1195713, 45263, 296, 11, 23, "Index",
      CellTags->"MakeDiploid"],
    Cell[1196012, 45276, 474, 15, 38, "IndexSubentry",
      CellTags->"MakeDiploid"],
    Cell[1478181, 56666, 296, 11, 23, "Index",
      CellTags->"MakeDiploid"],
    Cell[1478480, 56679, 474, 15, 38, "IndexSubentry",
      CellTags->"MakeDiploid"],
    Cell[1751817, 67722, 296, 11, 15, "Index",
      CellTags->"MakeDiploid"],
    Cell[1752116, 67735, 474, 15, 30, "IndexSubentry",
      CellTags->"MakeDiploid"]},
  "MakeDistanceList"->{
    Cell[288406, 8589, 279, 10, 15, "Index",
      CellTags->"MakeDistanceList"],
    Cell[602057, 21264, 279, 10, 23, "Index",
      CellTags->"MakeDistanceList"],
    Cell[904997, 33511, 279, 10, 15, "Index",
      CellTags->"MakeDistanceList"],
    Cell[1196489, 45293, 279, 10, 23, "Index",
      CellTags->"MakeDistanceList"],
    Cell[1478957, 56696, 279, 10, 23, "Index",
      CellTags->"MakeDistanceList"],
    Cell[1752593, 67752, 279, 10, 15, "Index",
      CellTags->"MakeDistanceList"]},
  "MakeDistances"->{
    Cell[288688, 8601, 270, 10, 15, "Index",
      CellTags->"MakeDistances"],
    Cell[602339, 21276, 270, 10, 23, "Index",
      CellTags->"MakeDistances"],
    Cell[905279, 33523, 270, 10, 15, "Index",
      CellTags->"MakeDistances"],
    Cell[1196771, 45305, 270, 10, 23, "Index",
      CellTags->"MakeDistances"],
    Cell[1479239, 56708, 270, 10, 23, "Index",
      CellTags->"MakeDistances"],
    Cell[1752875, 67764, 270, 10, 15, "Index",
      CellTags->"MakeDistances"]},
  "MakeFitnessSet"->{
    Cell[288961, 8613, 243, 10, 15, "Index",
      CellTags->"MakeFitnessSet"],
    Cell[289207, 8625, 255, 9, 15, "IndexSubentry",
      CellTags->"MakeFitnessSet"],
    Cell[602612, 21288, 243, 10, 23, "Index",
      CellTags->"MakeFitnessSet"],
    Cell[602858, 21300, 255, 9, 23, "IndexSubentry",
      CellTags->"MakeFitnessSet"],
    Cell[905552, 33535, 243, 10, 15, "Index",
      CellTags->"MakeFitnessSet"],
    Cell[905798, 33547, 255, 9, 15, "IndexSubentry",
      CellTags->"MakeFitnessSet"],
    Cell[1197044, 45317, 243, 10, 23, "Index",
      CellTags->"MakeFitnessSet"],
    Cell[1197290, 45329, 255, 9, 23, "IndexSubentry",
      CellTags->"MakeFitnessSet"],
    Cell[1479512, 56720, 243, 10, 23, "Index",
      CellTags->"MakeFitnessSet"],
    Cell[1479758, 56732, 255, 9, 23, "IndexSubentry",
      CellTags->"MakeFitnessSet"],
    Cell[1753148, 67776, 243, 10, 15, "Index",
      CellTags->"MakeFitnessSet"],
    Cell[1753394, 67788, 255, 9, 15, "IndexSubentry",
      CellTags->"MakeFitnessSet"]},
  "MakeGenealogy"->{
    Cell[289465, 8636, 262, 10, 15, "Index",
      CellTags->"MakeGenealogy"],
    Cell[603116, 21311, 262, 10, 23, "Index",
      CellTags->"MakeGenealogy"],
    Cell[906056, 33558, 262, 10, 15, "Index",
      CellTags->"MakeGenealogy"],
    Cell[1197548, 45340, 262, 10, 23, "Index",
      CellTags->"MakeGenealogy"],
    Cell[1480016, 56743, 262, 10, 23, "Index",
      CellTags->"MakeGenealogy"],
    Cell[1753652, 67799, 262, 10, 15, "Index",
      CellTags->"MakeGenealogy"]},
  "MakeGenealogyPlot"->{
    Cell[289730, 8648, 278, 10, 15, "Index",
      CellTags->"MakeGenealogyPlot"],
    Cell[603381, 21323, 278, 10, 23, "Index",
      CellTags->"MakeGenealogyPlot"],
    Cell[906321, 33570, 278, 10, 15, "Index",
      CellTags->"MakeGenealogyPlot"],
    Cell[1197813, 45352, 278, 10, 23, "Index",
      CellTags->"MakeGenealogyPlot"],
    Cell[1480281, 56755, 278, 10, 23, "Index",
      CellTags->"MakeGenealogyPlot"],
    Cell[1753917, 67811, 278, 10, 15, "Index",
      CellTags->"MakeGenealogyPlot"]},
  "MakeHaploid"->{
    Cell[290011, 8660, 296, 11, 15, "Index",
      CellTags->"MakeHaploid"],
    Cell[290310, 8673, 474, 15, 30, "IndexSubentry",
      CellTags->"MakeHaploid"],
    Cell[603662, 21335, 296, 11, 23, "Index",
      CellTags->"MakeHaploid"],
    Cell[603961, 21348, 474, 15, 38, "IndexSubentry",
      CellTags->"MakeHaploid"],
    Cell[906602, 33582, 296, 11, 15, "Index",
      CellTags->"MakeHaploid"],
    Cell[906901, 33595, 474, 15, 30, "IndexSubentry",
      CellTags->"MakeHaploid"],
    Cell[1198094, 45364, 296, 11, 23, "Index",
      CellTags->"MakeHaploid"],
    Cell[1198393, 45377, 474, 15, 38, "IndexSubentry",
      CellTags->"MakeHaploid"],
    Cell[1480562, 56767, 296, 11, 23, "Index",
      CellTags->"MakeHaploid"],
    Cell[1480861, 56780, 474, 15, 38, "IndexSubentry",
      CellTags->"MakeHaploid"],
    Cell[1754198, 67823, 296, 11, 15, "Index",
      CellTags->"MakeHaploid"],
    Cell[1754497, 67836, 474, 15, 30, "IndexSubentry",
      CellTags->"MakeHaploid"]},
  "MakeIndividuals"->{
    Cell[290787, 8690, 322, 11, 15, "Index",
      CellTags->"MakeIndividuals"],
    Cell[291112, 8703, 666, 21, 45, "IndexSubentry",
      CellTags->"MakeIndividuals"],
    Cell[604438, 21365, 322, 11, 23, "Index",
      CellTags->"MakeIndividuals"],
    Cell[604763, 21378, 666, 21, 53, "IndexSubentry",
      CellTags->"MakeIndividuals"],
    Cell[907378, 33612, 322, 11, 15, "Index",
      CellTags->"MakeIndividuals"],
    Cell[907703, 33625, 666, 21, 45, "IndexSubentry",
      CellTags->"MakeIndividuals"],
    Cell[1198870, 45394, 322, 11, 23, "Index",
      CellTags->"MakeIndividuals"],
    Cell[1199195, 45407, 666, 21, 53, "IndexSubentry",
      CellTags->"MakeIndividuals"],
    Cell[1481338, 56797, 322, 11, 23, "Index",
      CellTags->"MakeIndividuals"],
    Cell[1481663, 56810, 666, 21, 53, "IndexSubentry",
      CellTags->"MakeIndividuals"],
    Cell[1754974, 67853, 322, 11, 15, "Index",
      CellTags->"MakeIndividuals"],
    Cell[1755299, 67866, 666, 21, 45, "IndexSubentry",
      CellTags->"MakeIndividuals"]},
  "MakeOneWayTable"->{
    Cell[291781, 8726, 270, 10, 15, "Index",
      CellTags->"MakeOneWayTable"],
    Cell[605432, 21401, 270, 10, 23, "Index",
      CellTags->"MakeOneWayTable"],
    Cell[908372, 33648, 270, 10, 15, "Index",
      CellTags->"MakeOneWayTable"],
    Cell[1199864, 45430, 270, 10, 23, "Index",
      CellTags->"MakeOneWayTable"],
    Cell[1482332, 56833, 270, 10, 23, "Index",
      CellTags->"MakeOneWayTable"],
    Cell[1755968, 67889, 270, 10, 15, "Index",
      CellTags->"MakeOneWayTable"]},
  "MakePairwiseTable"->{
    Cell[292054, 8738, 268, 10, 15, "Index",
      CellTags->"MakePairwiseTable"],
    Cell[605705, 21413, 268, 10, 23, "Index",
      CellTags->"MakePairwiseTable"],
    Cell[908645, 33660, 268, 10, 15, "Index",
      CellTags->"MakePairwiseTable"],
    Cell[1200137, 45442, 268, 10, 23, "Index",
      CellTags->"MakePairwiseTable"],
    Cell[1482605, 56845, 268, 10, 23, "Index",
      CellTags->"MakePairwiseTable"],
    Cell[1756241, 67901, 268, 10, 15, "Index",
      CellTags->"MakePairwiseTable"]},
  "MakePopulation"->{
    Cell[292325, 8750, 325, 11, 15, "Index",
      CellTags->"MakePopulation"],
    Cell[292653, 8763, 711, 22, 45, "IndexSubentry",
      CellTags->"MakePopulation"],
    Cell[605976, 21425, 327, 11, 23, "Index",
      CellTags->"MakePopulation"],
    Cell[606306, 21438, 711, 22, 53, "IndexSubentry",
      CellTags->"MakePopulation"],
    Cell[908916, 33672, 325, 11, 15, "Index",
      CellTags->"MakePopulation"],
    Cell[909244, 33685, 711, 22, 45, "IndexSubentry",
      CellTags->"MakePopulation"],
    Cell[1200408, 45454, 325, 11, 23, "Index",
      CellTags->"MakePopulation"],
    Cell[1200736, 45467, 711, 22, 53, "IndexSubentry",
      CellTags->"MakePopulation"],
    Cell[1482876, 56857, 325, 11, 23, "Index",
      CellTags->"MakePopulation"],
    Cell[1483204, 56870, 711, 22, 53, "IndexSubentry",
      CellTags->"MakePopulation"],
    Cell[1756512, 67913, 325, 11, 15, "Index",
      CellTags->"MakePopulation"],
    Cell[1756840, 67926, 711, 22, 45, "IndexSubentry",
      CellTags->"MakePopulation"]},
  "MakeSelectionCoefficient"->{
    Cell[293367, 8787, 398, 14, 15, "Index",
      CellTags->"MakeSelectionCoefficient"],
    Cell[293768, 8803, 423, 15, 30, "IndexSubentry",
      CellTags->"MakeSelectionCoefficient"],
    Cell[607020, 21462, 398, 14, 23, "Index",
      CellTags->"MakeSelectionCoefficient"],
    Cell[607421, 21478, 423, 15, 38, "IndexSubentry",
      CellTags->"MakeSelectionCoefficient"],
    Cell[909958, 33709, 398, 14, 15, "Index",
      CellTags->"MakeSelectionCoefficient"],
    Cell[910359, 33725, 423, 15, 30, "IndexSubentry",
      CellTags->"MakeSelectionCoefficient"],
    Cell[1201450, 45491, 398, 14, 23, "Index",
      CellTags->"MakeSelectionCoefficient"],
    Cell[1201851, 45507, 423, 15, 38, "IndexSubentry",
      CellTags->"MakeSelectionCoefficient"],
    Cell[1483918, 56894, 398, 14, 23, "Index",
      CellTags->"MakeSelectionCoefficient"],
    Cell[1484319, 56910, 423, 15, 38, "IndexSubentry",
      CellTags->"MakeSelectionCoefficient"],
    Cell[1757554, 67950, 398, 14, 15, "Index",
      CellTags->"MakeSelectionCoefficient"],
    Cell[1757955, 67966, 423, 15, 30, "IndexSubentry",
      CellTags->"MakeSelectionCoefficient"]},
  "Mangel & Hilborn 1996"->{
    Cell[294194, 8820, 270, 10, 15, "Index",
      CellTags->"Mangel & Hilborn 1996"],
    Cell[607847, 21495, 270, 10, 23, "Index",
      CellTags->"Mangel & Hilborn 1996"],
    Cell[910785, 33742, 270, 10, 15, "Index",
      CellTags->"Mangel & Hilborn 1996"],
    Cell[1202277, 45524, 270, 10, 23, "Index",
      CellTags->"Mangel & Hilborn 1996"],
    Cell[1484745, 56927, 270, 10, 23, "Index",
      CellTags->"Mangel & Hilborn 1996"],
    Cell[1758381, 67983, 270, 10, 15, "Index",
      CellTags->"Mangel & Hilborn 1996"]},
  "MapLength"->{
    Cell[294467, 8832, 295, 11, 15, "Index",
      CellTags->"MapLength"],
    Cell[608120, 21507, 295, 11, 23, "Index",
      CellTags->"MapLength"]},
  "MapPosition"->{
    Cell[294765, 8845, 298, 11, 15, "Index",
      CellTags->"MapPosition"],
    Cell[295066, 8858, 284, 9, 15, "IndexSubentry",
      CellTags->"MapPosition"],
    Cell[608418, 21520, 298, 11, 23, "Index",
      CellTags->"MapPosition"],
    Cell[608719, 21533, 284, 9, 23, "IndexSubentry",
      CellTags->"MapPosition"]},
  "Marginal fitness"->{
    Cell[295353, 8869, 316, 11, 15, "Index",
      CellTags->"Marginal fitness"],
    Cell[295672, 8882, 642, 21, 45, "IndexSubentry",
      CellTags->"Marginal fitness"],
    Cell[609006, 21544, 316, 11, 23, "Index",
      CellTags->"Marginal fitness"],
    Cell[609325, 21557, 642, 21, 53, "IndexSubentry",
      CellTags->"Marginal fitness"],
    Cell[911058, 33754, 316, 11, 15, "Index",
      CellTags->"Marginal fitness"],
    Cell[911377, 33767, 642, 21, 45, "IndexSubentry",
      CellTags->"Marginal fitness"],
    Cell[1202550, 45536, 316, 11, 23, "Index",
      CellTags->"Marginal fitness"],
    Cell[1202869, 45549, 642, 21, 53, "IndexSubentry",
      CellTags->"Marginal fitness"],
    Cell[1485018, 56939, 316, 11, 23, "Index",
      CellTags->"Marginal fitness"],
    Cell[1485337, 56952, 642, 21, 53, "IndexSubentry",
      CellTags->"Marginal fitness"],
    Cell[1758654, 67995, 316, 11, 15, "Index",
      CellTags->"Marginal fitness"],
    Cell[1758973, 68008, 642, 21, 45, "IndexSubentry",
      CellTags->"Marginal fitness"]},
  "MarginalTable"->{
    Cell[296317, 8905, 256, 10, 15, "Index",
      CellTags->"MarginalTable"],
    Cell[609970, 21580, 256, 10, 23, "Index",
      CellTags->"MarginalTable"],
    Cell[912022, 33790, 256, 10, 15, "Index",
      CellTags->"MarginalTable"],
    Cell[1203514, 45572, 256, 10, 23, "Index",
      CellTags->"MarginalTable"],
    Cell[1485982, 56975, 256, 10, 23, "Index",
      CellTags->"MarginalTable"],
    Cell[1759618, 68031, 256, 10, 15, "Index",
      CellTags->"MarginalTable"]},
  "MarginalW"->{
    Cell[296576, 8917, 302, 11, 15, "Index",
      CellTags->"MarginalW"],
    Cell[296881, 8930, 636, 21, 45, "IndexSubentry",
      CellTags->"MarginalW"],
    Cell[610229, 21592, 302, 11, 23, "Index",
      CellTags->"MarginalW"],
    Cell[610534, 21605, 636, 21, 53, "IndexSubentry",
      CellTags->"MarginalW"],
    Cell[912281, 33802, 302, 11, 15, "Index",
      CellTags->"MarginalW"],
    Cell[912586, 33815, 636, 21, 45, "IndexSubentry",
      CellTags->"MarginalW"],
    Cell[1203773, 45584, 302, 11, 23, "Index",
      CellTags->"MarginalW"],
    Cell[1204078, 45597, 636, 21, 53, "IndexSubentry",
      CellTags->"MarginalW"],
    Cell[1486241, 56987, 302, 11, 23, "Index",
      CellTags->"MarginalW"],
    Cell[1486546, 57000, 636, 21, 53, "IndexSubentry",
      CellTags->"MarginalW"],
    Cell[1759877, 68043, 302, 11, 15, "Index",
      CellTags->"MarginalW"],
    Cell[1760182, 68056, 636, 21, 45, "IndexSubentry",
      CellTags->"MarginalW"]},
  "MaternalLoci"->{
    Cell[297520, 8953, 277, 11, 15, "Index",
      CellTags->"MaternalLoci"],
    Cell[297800, 8966, 450, 15, 30, "IndexSubentry",
      CellTags->"MaternalLoci"],
    Cell[611173, 21628, 277, 11, 23, "Index",
      CellTags->"MaternalLoci"],
    Cell[611453, 21641, 450, 15, 38, "IndexSubentry",
      CellTags->"MaternalLoci"],
    Cell[913225, 33838, 277, 11, 15, "Index",
      CellTags->"MaternalLoci"],
    Cell[913505, 33851, 450, 15, 30, "IndexSubentry",
      CellTags->"MaternalLoci"],
    Cell[1204717, 45620, 277, 11, 23, "Index",
      CellTags->"MaternalLoci"],
    Cell[1204997, 45633, 450, 15, 38, "IndexSubentry",
      CellTags->"MaternalLoci"],
    Cell[1487185, 57023, 277, 11, 23, "Index",
      CellTags->"MaternalLoci"],
    Cell[1487465, 57036, 450, 15, 38, "IndexSubentry",
      CellTags->"MaternalLoci"]},
  "MatrixGamma"->{
    Cell[298253, 8983, 254, 10, 15, "Index",
      CellTags->"MatrixGamma"],
    Cell[611906, 21658, 254, 10, 23, "Index",
      CellTags->"MatrixGamma"],
    Cell[913958, 33868, 254, 10, 15, "Index",
      CellTags->"MatrixGamma"],
    Cell[1205450, 45650, 254, 10, 23, "Index",
      CellTags->"MatrixGamma"],
    Cell[1487918, 57053, 254, 10, 23, "Index",
      CellTags->"MatrixGamma"],
    Cell[1760821, 68079, 254, 10, 15, "Index",
      CellTags->"MatrixGamma"]},
  "MatrixToGenealogy"->{
    Cell[298510, 8995, 280, 10, 15, "Index",
      CellTags->"MatrixToGenealogy"],
    Cell[612163, 21670, 280, 10, 23, "Index",
      CellTags->"MatrixToGenealogy"],
    Cell[914215, 33880, 280, 10, 15, "Index",
      CellTags->"MatrixToGenealogy"],
    Cell[1205707, 45662, 280, 10, 23, "Index",
      CellTags->"MatrixToGenealogy"],
    Cell[1488175, 57065, 280, 10, 23, "Index",
      CellTags->"MatrixToGenealogy"],
    Cell[1761078, 68091, 280, 10, 15, "Index",
      CellTags->"MatrixToGenealogy"]},
  "MatrixToList"->{
    Cell[298793, 9007, 291, 10, 15, "Index",
      CellTags->"MatrixToList"],
    Cell[612446, 21682, 291, 10, 23, "Index",
      CellTags->"MatrixToList"],
    Cell[914498, 33892, 291, 10, 15, "Index",
      CellTags->"MatrixToList"],
    Cell[1205990, 45674, 291, 10, 23, "Index",
      CellTags->"MatrixToList"],
    Cell[1488458, 57077, 291, 10, 23, "Index",
      CellTags->"MatrixToList"],
    Cell[1761361, 68103, 291, 10, 15, "Index",
      CellTags->"MatrixToList"]},
  "MeanContribution"->{
    Cell[299087, 9019, 314, 11, 15, "Index",
      CellTags->"MeanContribution"],
    Cell[612740, 21694, 314, 11, 23, "Index",
      CellTags->"MeanContribution"],
    Cell[914792, 33904, 314, 11, 15, "Index",
      CellTags->"MeanContribution"],
    Cell[1206284, 45686, 314, 11, 23, "Index",
      CellTags->"MeanContribution"],
    Cell[1488752, 57089, 314, 11, 23, "Index",
      CellTags->"MeanContribution"],
    Cell[1761655, 68115, 314, 11, 15, "Index",
      CellTags->"MeanContribution"]},
  "Mean fitness"->{
    Cell[299404, 9032, 400, 14, 15, "Index",
      CellTags->"Mean fitness"],
    Cell[299807, 9048, 461, 15, 30, "IndexSubentry",
      CellTags->"Mean fitness"],
    Cell[613057, 21707, 400, 14, 23, "Index",
      CellTags->"Mean fitness"],
    Cell[613460, 21723, 461, 15, 38, "IndexSubentry",
      CellTags->"Mean fitness"],
    Cell[915109, 33917, 400, 14, 15, "Index",
      CellTags->"Mean fitness"],
    Cell[915512, 33933, 461, 15, 30, "IndexSubentry",
      CellTags->"Mean fitness"],
    Cell[1206601, 45699, 400, 14, 23, "Index",
      CellTags->"Mean fitness"],
    Cell[1207004, 45715, 461, 15, 38, "IndexSubentry",
      CellTags->"Mean fitness"],
    Cell[1489069, 57102, 400, 14, 23, "Index",
      CellTags->"Mean fitness"],
    Cell[1489472, 57118, 461, 15, 38, "IndexSubentry",
      CellTags->"Mean fitness"],
    Cell[1761972, 68128, 400, 14, 15, "Index",
      CellTags->"Mean fitness"],
    Cell[1762375, 68144, 461, 15, 30, "IndexSubentry",
      CellTags->"Mean fitness"]},
  "MeanW"->{
    Cell[300271, 9065, 290, 11, 15, "Index",
      CellTags->"MeanW"],
    Cell[300564, 9078, 620, 21, 45, "IndexSubentry",
      CellTags->"MeanW"],
    Cell[613924, 21740, 290, 11, 23, "Index",
      CellTags->"MeanW"],
    Cell[614217, 21753, 620, 21, 53, "IndexSubentry",
      CellTags->"MeanW"],
    Cell[915976, 33950, 290, 11, 15, "Index",
      CellTags->"MeanW"],
    Cell[916269, 33963, 620, 21, 45, "IndexSubentry",
      CellTags->"MeanW"],
    Cell[1207468, 45732, 290, 11, 23, "Index",
      CellTags->"MeanW"],
    Cell[1207761, 45745, 620, 21, 53, "IndexSubentry",
      CellTags->"MeanW"],
    Cell[1489936, 57135, 290, 11, 23, "Index",
      CellTags->"MeanW"],
    Cell[1490229, 57148, 620, 21, 53, "IndexSubentry",
      CellTags->"MeanW"],
    Cell[1762839, 68161, 290, 11, 15, "Index",
      CellTags->"MeanW"],
    Cell[1763132, 68174, 620, 21, 45, "IndexSubentry",
      CellTags->"MeanW"]},
  "Meiosis"->{
    Cell[301187, 9101, 234, 10, 15, "Index",
      CellTags->"Meiosis"],
    Cell[301424, 9113, 264, 9, 15, "IndexSubentry",
      CellTags->"Meiosis"],
    Cell[614840, 21776, 234, 10, 23, "Index",
      CellTags->"Meiosis"],
    Cell[615077, 21788, 264, 9, 23, "IndexSubentry",
      CellTags->"Meiosis"],
    Cell[916892, 33986, 234, 10, 15, "Index",
      CellTags->"Meiosis"],
    Cell[917129, 33998, 264, 9, 15, "IndexSubentry",
      CellTags->"Meiosis"],
    Cell[1208384, 45768, 234, 10, 23, "Index",
      CellTags->"Meiosis"],
    Cell[1208621, 45780, 264, 9, 23, "IndexSubentry",
      CellTags->"Meiosis"],
    Cell[1490852, 57171, 234, 10, 23, "Index",
      CellTags->"Meiosis"],
    Cell[1491089, 57183, 264, 9, 23, "IndexSubentry",
      CellTags->"Meiosis"],
    Cell[1763755, 68197, 234, 10, 15, "Index",
      CellTags->"Meiosis"],
    Cell[1763992, 68209, 264, 9, 15, "IndexSubentry",
      CellTags->"Meiosis"]},
  "MethodC"->{
    Cell[301691, 9124, 256, 10, 15, "Index",
      CellTags->"MethodC"],
    Cell[615344, 21799, 256, 10, 23, "Index",
      CellTags->"MethodC"],
    Cell[917396, 34009, 256, 10, 15, "Index",
      CellTags->"MethodC"],
    Cell[1208888, 45791, 256, 10, 23, "Index",
      CellTags->"MethodC"],
    Cell[1491356, 57194, 256, 10, 23, "Index",
      CellTags->"MethodC"],
    Cell[1764259, 68220, 256, 10, 15, "Index",
      CellTags->"MethodC"]},
  "MethodP"->{
    Cell[301950, 9136, 256, 10, 15, "Index",
      CellTags->"MethodP"],
    Cell[615603, 21811, 256, 10, 23, "Index",
      CellTags->"MethodP"],
    Cell[917655, 34021, 256, 10, 15, "Index",
      CellTags->"MethodP"],
    Cell[1209147, 45803, 256, 10, 23, "Index",
      CellTags->"MethodP"],
    Cell[1491615, 57206, 256, 10, 23, "Index",
      CellTags->"MethodP"],
    Cell[1764518, 68232, 256, 10, 15, "Index",
      CellTags->"MethodP"]},
  "Metropolis algorithm"->{
    Cell[302209, 9148, 271, 11, 15, "Index",
      CellTags->"Metropolis algorithm"],
    Cell[615862, 21823, 271, 11, 23, "Index",
      CellTags->"Metropolis algorithm"],
    Cell[917914, 34033, 271, 11, 15, "Index",
      CellTags->"Metropolis algorithm"],
    Cell[1209406, 45815, 271, 11, 23, "Index",
      CellTags->"Metropolis algorithm"],
    Cell[1491874, 57218, 271, 11, 23, "Index",
      CellTags->"Metropolis algorithm"],
    Cell[1764777, 68244, 271, 11, 15, "Index",
      CellTags->"Metropolis algorithm"]},
  "MetropolisDisequilibrium"->{
    Cell[302483, 9161, 295, 10, 15, "Index",
      CellTags->"MetropolisDisequilibrium"],
    Cell[616136, 21836, 295, 10, 23, "Index",
      CellTags->"MetropolisDisequilibrium"],
    Cell[918188, 34046, 295, 10, 15, "Index",
      CellTags->"MetropolisDisequilibrium"],
    Cell[1209680, 45828, 295, 10, 23, "Index",
      CellTags->"MetropolisDisequilibrium"],
    Cell[1492148, 57231, 295, 10, 23, "Index",
      CellTags->"MetropolisDisequilibrium"],
    Cell[1765051, 68257, 295, 10, 15, "Index",
      CellTags->"MetropolisDisequilibrium"]},
  "MetropolisDisequilibriumReduced"->{
    Cell[302781, 9173, 316, 10, 15, "Index",
      CellTags->"MetropolisDisequilibriumReduced"],
    Cell[616434, 21848, 316, 10, 23, "Index",
      CellTags->"MetropolisDisequilibriumReduced"],
    Cell[918486, 34058, 316, 10, 15, "Index",
      CellTags->"MetropolisDisequilibriumReduced"],
    Cell[1209978, 45840, 316, 10, 23, "Index",
      CellTags->"MetropolisDisequilibriumReduced"],
    Cell[1492446, 57243, 316, 10, 23, "Index",
      CellTags->"MetropolisDisequilibriumReduced"],
    Cell[1765349, 68269, 316, 10, 15, "Index",
      CellTags->"MetropolisDisequilibriumReduced"]},
  "Metropolis et al. 1954"->{
    Cell[303100, 9185, 272, 10, 15, "Index",
      CellTags->"Metropolis et al. 1954"],
    Cell[616753, 21860, 272, 10, 23, "Index",
      CellTags->"Metropolis et al. 1954"],
    Cell[918805, 34070, 272, 10, 15, "Index",
      CellTags->"Metropolis et al. 1954"],
    Cell[1210297, 45852, 272, 10, 23, "Index",
      CellTags->"Metropolis et al. 1954"],
    Cell[1492765, 57255, 272, 10, 23, "Index",
      CellTags->"Metropolis et al. 1954"],
    Cell[1765668, 68281, 272, 10, 15, "Index",
      CellTags->"Metropolis et al. 1954"]},
  "MFromC"->{
    Cell[303375, 9197, 382, 14, 15, "Index",
      CellTags->"MFromC"],
    Cell[617028, 21872, 382, 14, 23, "Index",
      CellTags->"MFromC"],
    Cell[919080, 34082, 382, 14, 15, "Index",
      CellTags->"MFromC"],
    Cell[1210572, 45864, 382, 14, 23, "Index",
      CellTags->"MFromC"],
    Cell[1493040, 57267, 382, 14, 23, "Index",
      CellTags->"MFromC"],
    Cell[1765943, 68293, 382, 14, 15, "Index",
      CellTags->"MFromC"]},
  "Migrate"->{
    Cell[303760, 9213, 226, 10, 15, "Index",
      CellTags->"Migrate"],
    Cell[617413, 21888, 226, 10, 23, "Index",
      CellTags->"Migrate"],
    Cell[919465, 34098, 226, 10, 15, "Index",
      CellTags->"Migrate"],
    Cell[1210957, 45880, 226, 10, 23, "Index",
      CellTags->"Migrate"],
    Cell[1493425, 57283, 226, 10, 23, "Index",
      CellTags->"Migrate"],
    Cell[1766328, 68309, 226, 10, 15, "Index",
      CellTags->"Migrate"]},
  "MigrateExact"->{
    Cell[303989, 9225, 311, 11, 15, "Index",
      CellTags->"MigrateExact"],
    Cell[304303, 9238, 646, 21, 45, "IndexSubentry",
      CellTags->"MigrateExact"],
    Cell[617642, 21900, 311, 11, 23, "Index",
      CellTags->"MigrateExact"],
    Cell[617956, 21913, 646, 21, 53, "IndexSubentry",
      CellTags->"MigrateExact"],
    Cell[919694, 34110, 311, 11, 15, "Index",
      CellTags->"MigrateExact"],
    Cell[920008, 34123, 646, 21, 45, "IndexSubentry",
      CellTags->"MigrateExact"],
    Cell[1211186, 45892, 311, 11, 23, "Index",
      CellTags->"MigrateExact"],
    Cell[1211500, 45905, 646, 21, 53, "IndexSubentry",
      CellTags->"MigrateExact"],
    Cell[1493654, 57295, 311, 11, 23, "Index",
      CellTags->"MigrateExact"],
    Cell[1493968, 57308, 646, 21, 53, "IndexSubentry",
      CellTags->"MigrateExact"],
    Cell[1766557, 68321, 311, 11, 15, "Index",
      CellTags->"MigrateExact"],
    Cell[1766871, 68334, 646, 21, 45, "IndexSubentry",
      CellTags->"MigrateExact"]},
  "Migration"->{
    Cell[304952, 9261, 298, 11, 15, "Index",
      CellTags->"Migration"],
    Cell[305253, 9274, 2405, 85, 195, "IndexSubentry",
      CellTags->"Migration"],
    Cell[618605, 21936, 298, 11, 23, "Index",
      CellTags->"Migration"],
    Cell[618906, 21949, 2405, 85, 203, "IndexSubentry",
      CellTags->"Migration"],
    Cell[920657, 34146, 298, 11, 15, "Index",
      CellTags->"Migration"],
    Cell[920958, 34159, 2405, 85, 195, "IndexSubentry",
      CellTags->"Migration"],
    Cell[1212149, 45928, 298, 11, 23, "Index",
      CellTags->"Migration"],
    Cell[1212450, 45941, 2215, 79, 188, "IndexSubentry",
      CellTags->"Migration"],
    Cell[1494617, 57331, 298, 11, 23, "Index",
      CellTags->"Migration"],
    Cell[1494918, 57344, 2215, 79, 188, "IndexSubentry",
      CellTags->"Migration"],
    Cell[1767520, 68357, 298, 11, 15, "Index",
      CellTags->"Migration"],
    Cell[1767821, 68370, 2065, 73, 165, "IndexSubentry",
      CellTags->"Migration"]},
  "MigrationOrder"->{
    Cell[307661, 9361, 491, 15, 15, "Index",
      CellTags->"MigrationOrder"],
    Cell[308155, 9378, 524, 16, 30, "IndexSubentry",
      CellTags->"MigrationOrder"],
    Cell[621314, 22036, 491, 15, 23, "Index",
      CellTags->"MigrationOrder"],
    Cell[621808, 22053, 524, 16, 38, "IndexSubentry",
      CellTags->"MigrationOrder"],
    Cell[923366, 34246, 491, 15, 15, "Index",
      CellTags->"MigrationOrder"],
    Cell[923860, 34263, 524, 16, 30, "IndexSubentry",
      CellTags->"MigrationOrder"],
    Cell[1214668, 46022, 491, 15, 23, "Index",
      CellTags->"MigrationOrder"],
    Cell[1215162, 46039, 524, 16, 38, "IndexSubentry",
      CellTags->"MigrationOrder"],
    Cell[1497136, 57425, 491, 15, 23, "Index",
      CellTags->"MigrationOrder"],
    Cell[1497630, 57442, 524, 16, 38, "IndexSubentry",
      CellTags->"MigrationOrder"],
    Cell[1769889, 68445, 491, 15, 15, "Index",
      CellTags->"MigrationOrder"],
    Cell[1770383, 68462, 524, 16, 30, "IndexSubentry",
      CellTags->"MigrationOrder"]},
  "MigrationRate"->{
    Cell[308682, 9396, 308, 11, 15, "Index",
      CellTags->"MigrationRate"],
    Cell[622335, 22071, 308, 11, 23, "Index",
      CellTags->"MigrationRate"],
    Cell[924387, 34281, 308, 11, 15, "Index",
      CellTags->"MigrationRate"],
    Cell[1215689, 46057, 308, 11, 23, "Index",
      CellTags->"MigrationRate"],
    Cell[1498157, 57460, 308, 11, 23, "Index",
      CellTags->"MigrationRate"],
    Cell[1770910, 68480, 308, 11, 15, "Index",
      CellTags->"MigrationRate"]},
  "MigrationSet"->{
    Cell[308993, 9409, 311, 11, 15, "Index",
      CellTags->"MigrationSet"],
    Cell[622646, 22084, 311, 11, 23, "Index",
      CellTags->"MigrationSet"],
    Cell[924698, 34294, 311, 11, 15, "Index",
      CellTags->"MigrationSet"],
    Cell[1216000, 46070, 311, 11, 23, "Index",
      CellTags->"MigrationSet"],
    Cell[1498468, 57473, 311, 11, 23, "Index",
      CellTags->"MigrationSet"],
    Cell[1771221, 68493, 311, 11, 15, "Index",
      CellTags->"MigrationSet"]},
  "MissingCombination"->{
    Cell[309307, 9422, 299, 10, 15, "Index",
      CellTags->"MissingCombination"],
    Cell[622960, 22097, 299, 10, 23, "Index",
      CellTags->"MissingCombination"],
    Cell[925012, 34307, 299, 10, 15, "Index",
      CellTags->"MissingCombination"]},
  "Missing data"->{
    Cell[309609, 9434, 259, 10, 15, "Index",
      CellTags->"Missing data"],
    Cell[623262, 22109, 323, 11, 23, "Index",
      CellTags->"Missing data"],
    Cell[623588, 22122, 468, 15, 38, "IndexSubentry",
      CellTags->"Missing data"],
    Cell[925314, 34319, 259, 10, 15, "Index",
      CellTags->"Missing data"],
    Cell[1216314, 46083, 259, 10, 23, "Index",
      CellTags->"Missing data"],
    Cell[1498782, 57486, 259, 10, 23, "Index",
      CellTags->"Missing data"],
    Cell[1771535, 68506, 259, 10, 15, "Index",
      CellTags->"Missing data"]},
  "Moment"->{
    Cell[309871, 9446, 352, 14, 15, "Index",
      CellTags->"Moment"],
    Cell[624677, 22163, 352, 14, 23, "Index",
      CellTags->"Moment"],
    Cell[925576, 34331, 352, 14, 15, "Index",
      CellTags->"Moment"],
    Cell[1216576, 46095, 352, 14, 23, "Index",
      CellTags->"Moment"],
    Cell[1499044, 57498, 352, 14, 23, "Index",
      CellTags->"Moment"],
    Cell[1771797, 68518, 352, 14, 15, "Index",
      CellTags->"Moment"]},
  "MomentAfterMigration"->{
    Cell[310226, 9462, 305, 10, 15, "Index",
      CellTags->"MomentAfterMigration"],
    Cell[625032, 22179, 305, 10, 23, "Index",
      CellTags->"MomentAfterMigration"],
    Cell[925931, 34347, 305, 10, 15, "Index",
      CellTags->"MomentAfterMigration"],
    Cell[1216931, 46111, 305, 10, 23, "Index",
      CellTags->"MomentAfterMigration"],
    Cell[1499399, 57514, 305, 10, 23, "Index",
      CellTags->"MomentAfterMigration"],
    Cell[1772152, 68534, 305, 10, 15, "Index",
      CellTags->"MomentAfterMigration"]},
  "MomentAfterRecombination"->{
    Cell[310534, 9474, 332, 11, 15, "Index",
      CellTags->"MomentAfterRecombination"],
    Cell[625340, 22191, 332, 11, 23, "Index",
      CellTags->"MomentAfterRecombination"],
    Cell[926239, 34359, 332, 11, 15, "Index",
      CellTags->"MomentAfterRecombination"],
    Cell[1217239, 46123, 332, 11, 23, "Index",
      CellTags->"MomentAfterRecombination"],
    Cell[1499707, 57526, 332, 11, 23, "Index",
      CellTags->"MomentAfterRecombination"],
    Cell[1772460, 68546, 332, 11, 15, "Index",
      CellTags->"MomentAfterRecombination"]},
  "MomentEquilibrium"->{
    Cell[310869, 9487, 258, 10, 15, "Index",
      CellTags->"MomentEquilibrium"],
    Cell[625675, 22204, 258, 10, 23, "Index",
      CellTags->"MomentEquilibrium"],
    Cell[926574, 34372, 258, 10, 15, "Index",
      CellTags->"MomentEquilibrium"],
    Cell[1217574, 46136, 258, 10, 23, "Index",
      CellTags->"MomentEquilibrium"],
    Cell[1500042, 57539, 258, 10, 23, "Index",
      CellTags->"MomentEquilibrium"],
    Cell[1772795, 68559, 258, 10, 15, "Index",
      CellTags->"MomentEquilibrium"]},
  "MomentGeneratingFunction"->{
    Cell[311130, 9499, 315, 11, 15, "Index",
      CellTags->"MomentGeneratingFunction"],
    Cell[311448, 9512, 582, 21, 45, "IndexSubentry",
      CellTags->"MomentGeneratingFunction"],
    Cell[625936, 22216, 315, 11, 23, "Index",
      CellTags->"MomentGeneratingFunction"],
    Cell[626254, 22229, 582, 21, 53, "IndexSubentry",
      CellTags->"MomentGeneratingFunction"],
    Cell[926835, 34384, 315, 11, 15, "Index",
      CellTags->"MomentGeneratingFunction"],
    Cell[927153, 34397, 582, 21, 45, "IndexSubentry",
      CellTags->"MomentGeneratingFunction"],
    Cell[1217835, 46148, 315, 11, 23, "Index",
      CellTags->"MomentGeneratingFunction"],
    Cell[1218153, 46161, 582, 21, 53, "IndexSubentry",
      CellTags->"MomentGeneratingFunction"],
    Cell[1500303, 57551, 315, 11, 23, "Index",
      CellTags->"MomentGeneratingFunction"],
    Cell[1500621, 57564, 582, 21, 53, "IndexSubentry",
      CellTags->"MomentGeneratingFunction"]},
  "MomentLimits"->{
    Cell[312033, 9535, 267, 10, 15, "Index",
      CellTags->"MomentLimits"],
    Cell[626839, 22252, 267, 10, 23, "Index",
      CellTags->"MomentLimits"],
    Cell[927738, 34420, 267, 10, 15, "Index",
      CellTags->"MomentLimits"],
    Cell[1218738, 46184, 267, 10, 23, "Index",
      CellTags->"MomentLimits"],
    Cell[1501206, 57587, 267, 10, 23, "Index",
      CellTags->"MomentLimits"],
    Cell[1773056, 68571, 267, 10, 15, "Index",
      CellTags->"MomentLimits"]},
  "MomentNew"->{
    Cell[312303, 9547, 232, 10, 15, "Index",
      CellTags->"MomentNew"],
    Cell[627109, 22264, 232, 10, 23, "Index",
      CellTags->"MomentNew"],
    Cell[928008, 34432, 232, 10, 15, "Index",
      CellTags->"MomentNew"],
    Cell[1219008, 46196, 232, 10, 23, "Index",
      CellTags->"MomentNew"],
    Cell[1501476, 57599, 232, 10, 23, "Index",
      CellTags->"MomentNew"],
    Cell[1773326, 68583, 232, 10, 15, "Index",
      CellTags->"MomentNew"]},
  "MomentReduced"->{
    Cell[312538, 9559, 262, 10, 15, "Index",
      CellTags->"MomentReduced"],
    Cell[627344, 22276, 262, 10, 23, "Index",
      CellTags->"MomentReduced"],
    Cell[928243, 34444, 262, 10, 15, "Index",
      CellTags->"MomentReduced"],
    Cell[1219243, 46208, 262, 10, 23, "Index",
      CellTags->"MomentReduced"],
    Cell[1501711, 57611, 262, 10, 23, "Index",
      CellTags->"MomentReduced"],
    Cell[1773561, 68595, 262, 10, 15, "Index",
      CellTags->"MomentReduced"]},
  "Moments"->{
    Cell[312803, 9571, 222, 10, 15, "Index",
      CellTags->"Moments"],
    Cell[313028, 9583, 1552, 53, 120, "IndexSubentry",
      CellTags->"Moments"],
    Cell[627609, 22288, 222, 10, 23, "Index",
      CellTags->"Moments"],
    Cell[627834, 22300, 1552, 53, 128, "IndexSubentry",
      CellTags->"Moments"],
    Cell[928508, 34456, 222, 10, 15, "Index",
      CellTags->"Moments"],
    Cell[928733, 34468, 1552, 53, 120, "IndexSubentry",
      CellTags->"Moments"],
    Cell[1219508, 46220, 222, 10, 23, "Index",
      CellTags->"Moments"],
    Cell[1219733, 46232, 1552, 53, 128, "IndexSubentry",
      CellTags->"Moments"],
    Cell[1501976, 57623, 222, 10, 23, "Index",
      CellTags->"Moments"],
    Cell[1502201, 57635, 1552, 53, 128, "IndexSubentry",
      CellTags->"Moments"],
    Cell[1773826, 68607, 222, 10, 15, "Index",
      CellTags->"Moments"],
    Cell[1774051, 68619, 1552, 53, 120, "IndexSubentry",
      CellTags->"Moments"]},
  "MomentsFromG"->{
    Cell[314583, 9638, 289, 10, 15, "Index",
      CellTags->"MomentsFromG"],
    Cell[629389, 22355, 289, 10, 23, "Index",
      CellTags->"MomentsFromG"],
    Cell[930288, 34523, 289, 10, 15, "Index",
      CellTags->"MomentsFromG"],
    Cell[1221288, 46287, 289, 10, 23, "Index",
      CellTags->"MomentsFromG"],
    Cell[1503756, 57690, 289, 10, 23, "Index",
      CellTags->"MomentsFromG"],
    Cell[1775606, 68674, 289, 10, 15, "Index",
      CellTags->"MomentsFromG"]},
  "MomentSimple"->{
    Cell[314875, 9650, 269, 10, 15, "Index",
      CellTags->"MomentSimple"],
    Cell[629681, 22367, 269, 10, 23, "Index",
      CellTags->"MomentSimple"],
    Cell[930580, 34535, 269, 10, 15, "Index",
      CellTags->"MomentSimple"],
    Cell[1221580, 46299, 269, 10, 23, "Index",
      CellTags->"MomentSimple"],
    Cell[1504048, 57702, 269, 10, 23, "Index",
      CellTags->"MomentSimple"],
    Cell[1775898, 68686, 269, 10, 15, "Index",
      CellTags->"MomentSimple"]},
  "MonteCarloGriffithsTavare"->{
    Cell[315147, 9662, 302, 10, 15, "Index",
      CellTags->"MonteCarloGriffithsTavare"],
    Cell[629953, 22379, 302, 10, 23, "Index",
      CellTags->"MonteCarloGriffithsTavare"],
    Cell[930852, 34547, 302, 10, 15, "Index",
      CellTags->"MonteCarloGriffithsTavare"],
    Cell[1221852, 46311, 302, 10, 23, "Index",
      CellTags->"MonteCarloGriffithsTavare"],
    Cell[1504320, 57714, 302, 10, 23, "Index",
      CellTags->"MonteCarloGriffithsTavare"],
    Cell[1776170, 68698, 302, 10, 15, "Index",
      CellTags->"MonteCarloGriffithsTavare"]},
  "MonteCarloProbability"->{
    Cell[315452, 9674, 302, 10, 15, "Index",
      CellTags->"MonteCarloProbability"],
    Cell[630258, 22391, 302, 10, 23, "Index",
      CellTags->"MonteCarloProbability"],
    Cell[931157, 34559, 302, 10, 15, "Index",
      CellTags->"MonteCarloProbability"],
    Cell[1222157, 46323, 302, 10, 23, "Index",
      CellTags->"MonteCarloProbability"],
    Cell[1504625, 57726, 302, 10, 23, "Index",
      CellTags->"MonteCarloProbability"],
    Cell[1776475, 68710, 302, 10, 15, "Index",
      CellTags->"MonteCarloProbability"]},
  "Mortality"->{
    Cell[315757, 9686, 258, 10, 15, "Index",
      CellTags->"Mortality"],
    Cell[630563, 22403, 258, 10, 23, "Index",
      CellTags->"Mortality"],
    Cell[931462, 34571, 258, 10, 15, "Index",
      CellTags->"Mortality"],
    Cell[1222462, 46335, 258, 10, 23, "Index",
      CellTags->"Mortality"],
    Cell[1504930, 57738, 258, 10, 23, "Index",
      CellTags->"Mortality"],
    Cell[1776780, 68722, 258, 10, 15, "Index",
      CellTags->"Mortality"]},
  "MostRecentCommonAncestor"->{
    Cell[316018, 9698, 299, 10, 15, "Index",
      CellTags->"MostRecentCommonAncestor"],
    Cell[630824, 22415, 299, 10, 23, "Index",
      CellTags->"MostRecentCommonAncestor"],
    Cell[931723, 34583, 299, 10, 15, "Index",
      CellTags->"MostRecentCommonAncestor"],
    Cell[1222723, 46347, 299, 10, 23, "Index",
      CellTags->"MostRecentCommonAncestor"],
    Cell[1505191, 57750, 299, 10, 23, "Index",
      CellTags->"MostRecentCommonAncestor"],
    Cell[1777041, 68734, 299, 10, 15, "Index",
      CellTags->"MostRecentCommonAncestor"]},
  "MToC"->{
    Cell[316320, 9710, 374, 14, 15, "Index",
      CellTags->"MToC"],
    Cell[631126, 22427, 374, 14, 23, "Index",
      CellTags->"MToC"],
    Cell[932025, 34595, 374, 14, 15, "Index",
      CellTags->"MToC"],
    Cell[1223025, 46359, 374, 14, 23, "Index",
      CellTags->"MToC"],
    Cell[1505493, 57762, 374, 14, 23, "Index",
      CellTags->"MToC"],
    Cell[1777343, 68746, 374, 14, 15, "Index",
      CellTags->"MToC"]},
  "MToCEquations"->{
    Cell[316697, 9726, 410, 14, 15, "Index",
      CellTags->"MToCEquations"],
    Cell[631503, 22443, 410, 14, 23, "Index",
      CellTags->"MToCEquations"],
    Cell[932402, 34611, 410, 14, 15, "Index",
      CellTags->"MToCEquations"],
    Cell[1223402, 46375, 410, 14, 23, "Index",
      CellTags->"MToCEquations"],
    Cell[1505870, 57778, 410, 14, 23, "Index",
      CellTags->"MToCEquations"],
    Cell[1777720, 68762, 410, 14, 15, "Index",
      CellTags->"MToCEquations"]},
  "Muddle"->{
    Cell[317110, 9742, 263, 10, 15, "Index",
      CellTags->"Muddle"],
    Cell[631916, 22459, 263, 10, 23, "Index",
      CellTags->"Muddle"],
    Cell[932815, 34627, 263, 10, 15, "Index",
      CellTags->"Muddle"],
    Cell[1223815, 46391, 263, 10, 23, "Index",
      CellTags->"Muddle"],
    Cell[1506283, 57794, 263, 10, 23, "Index",
      CellTags->"Muddle"],
    Cell[1778133, 68778, 263, 10, 15, "Index",
      CellTags->"Muddle"]},
  "Multilocus algebra"->{
    Cell[317376, 9754, 295, 11, 15, "Index",
      CellTags->"Multilocus algebra"],
    Cell[317674, 9767, 1010, 36, 60, "IndexSubentry",
      CellTags->"Multilocus algebra"],
    Cell[632182, 22471, 295, 11, 23, "Index",
      CellTags->"Multilocus algebra"],
    Cell[632480, 22484, 1010, 36, 68, "IndexSubentry",
      CellTags->"Multilocus algebra"],
    Cell[933081, 34639, 295, 11, 15, "Index",
      CellTags->"Multilocus algebra"],
    Cell[933379, 34652, 1010, 36, 60, "IndexSubentry",
      CellTags->"Multilocus algebra"],
    Cell[1224081, 46403, 295, 11, 23, "Index",
      CellTags->"Multilocus algebra"],
    Cell[1224379, 46416, 1010, 36, 68, "IndexSubentry",
      CellTags->"Multilocus algebra"],
    Cell[1506549, 57806, 295, 11, 23, "Index",
      CellTags->"Multilocus algebra"],
    Cell[1506847, 57819, 1010, 36, 68, "IndexSubentry",
      CellTags->"Multilocus algebra"],
    Cell[1778399, 68790, 295, 11, 15, "Index",
      CellTags->"Multilocus algebra"],
    Cell[1778697, 68803, 1010, 36, 60, "IndexSubentry",
      CellTags->"Multilocus algebra"]},
  "Multilocus MS"->{
    Cell[318687, 9805, 408, 15, 15, "Index",
      CellTags->"Multilocus MS"],
    Cell[633493, 22522, 408, 15, 23, "Index",
      CellTags->"Multilocus MS"],
    Cell[934392, 34690, 408, 15, 15, "Index",
      CellTags->"Multilocus MS"],
    Cell[1225392, 46454, 408, 15, 23, "Index",
      CellTags->"Multilocus MS"],
    Cell[1507860, 57857, 408, 15, 23, "Index",
      CellTags->"Multilocus MS"],
    Cell[1779710, 68841, 390, 15, 15, "Index",
      CellTags->"Multilocus MS"]},
  "Multilocus notation"->{
    Cell[319098, 9822, 264, 11, 15, "Index",
      CellTags->"Multilocus notation"],
    Cell[633904, 22539, 264, 11, 23, "Index",
      CellTags->"Multilocus notation"],
    Cell[934803, 34707, 264, 11, 15, "Index",
      CellTags->"Multilocus notation"],
    Cell[1225803, 46471, 264, 11, 23, "Index",
      CellTags->"Multilocus notation"],
    Cell[1508271, 57874, 264, 11, 23, "Index",
      CellTags->"Multilocus notation"],
    Cell[1780103, 68858, 264, 11, 15, "Index",
      CellTags->"Multilocus notation"]},
  "Multinomial sampling"->{
    Cell[319365, 9835, 344, 12, 15, "Index",
      CellTags->"Multinomial sampling"],
    Cell[634171, 22552, 344, 12, 23, "Index",
      CellTags->"Multinomial sampling"],
    Cell[935070, 34720, 344, 12, 15, "Index",
      CellTags->"Multinomial sampling"],
    Cell[1226070, 46484, 344, 12, 23, "Index",
      CellTags->"Multinomial sampling"],
    Cell[1508538, 57887, 344, 12, 23, "Index",
      CellTags->"Multinomial sampling"],
    Cell[1780370, 68871, 344, 12, 15, "Index",
      CellTags->"Multinomial sampling"]},
  "MultinomialSamplingProbability"->{
    Cell[319712, 9849, 332, 11, 15, "Index",
      CellTags->"MultinomialSamplingProbability"],
    Cell[634518, 22566, 332, 11, 23, "Index",
      CellTags->"MultinomialSamplingProbability"],
    Cell[935417, 34734, 332, 11, 15, "Index",
      CellTags->"MultinomialSamplingProbability"],
    Cell[1226417, 46498, 332, 11, 23, "Index",
      CellTags->"MultinomialSamplingProbability"],
    Cell[1508885, 57901, 332, 11, 23, "Index",
      CellTags->"MultinomialSamplingProbability"],
    Cell[1780717, 68885, 332, 11, 15, "Index",
      CellTags->"MultinomialSamplingProbability"]},
  "Multiple alleles"->{
    Cell[320047, 9862, 289, 11, 15, "Index",
      CellTags->"Multiple alleles"],
    Cell[320339, 9875, 694, 27, 60, "IndexSubentry",
      CellTags->"Multiple alleles"],
    Cell[634853, 22579, 289, 11, 23, "Index",
      CellTags->"Multiple alleles"],
    Cell[635145, 22592, 694, 27, 68, "IndexSubentry",
      CellTags->"Multiple alleles"],
    Cell[935752, 34747, 289, 11, 15, "Index",
      CellTags->"Multiple alleles"],
    Cell[936044, 34760, 694, 27, 60, "IndexSubentry",
      CellTags->"Multiple alleles"],
    Cell[1226752, 46511, 289, 11, 23, "Index",
      CellTags->"Multiple alleles"],
    Cell[1227044, 46524, 694, 27, 68, "IndexSubentry",
      CellTags->"Multiple alleles"],
    Cell[1509220, 57914, 289, 11, 23, "Index",
      CellTags->"Multiple alleles"],
    Cell[1509512, 57927, 535, 21, 53, "IndexSubentry",
      CellTags->"Multiple alleles"],
    Cell[1781052, 68898, 289, 11, 15, "Index",
      CellTags->"Multiple alleles"],
    Cell[1781344, 68911, 535, 21, 45, "IndexSubentry",
      CellTags->"Multiple alleles"]},
  "Multiple arguments"->{
    Cell[321036, 9904, 297, 11, 15, "Index",
      CellTags->"Multiple arguments"],
    Cell[635842, 22621, 297, 11, 23, "Index",
      CellTags->"Multiple arguments"],
    Cell[936741, 34789, 297, 11, 15, "Index",
      CellTags->"Multiple arguments"],
    Cell[1227741, 46553, 297, 11, 23, "Index",
      CellTags->"Multiple arguments"],
    Cell[1510050, 57950, 297, 11, 23, "Index",
      CellTags->"Multiple arguments"],
    Cell[1781882, 68934, 297, 11, 15, "Index",
      CellTags->"Multiple arguments"]},
  "Multiplicative models"->{
    Cell[321336, 9917, 336, 11, 15, "Index",
      CellTags->"Multiplicative models"],
    Cell[636142, 22634, 336, 11, 23, "Index",
      CellTags->"Multiplicative models"],
    Cell[937041, 34802, 336, 11, 15, "Index",
      CellTags->"Multiplicative models"],
    Cell[1228041, 46566, 336, 11, 23, "Index",
      CellTags->"Multiplicative models"],
    Cell[1510350, 57963, 336, 11, 23, "Index",
      CellTags->"Multiplicative models"],
    Cell[1782182, 68947, 336, 11, 15, "Index",
      CellTags->"Multiplicative models"]},
  "MUS"->{
    Cell[321675, 9930, 302, 11, 15, "Index",
      CellTags->"MUS"],
    Cell[321980, 9943, 667, 21, 45, "IndexSubentry",
      CellTags->"MUS"],
    Cell[636481, 22647, 302, 11, 23, "Index",
      CellTags->"MUS"],
    Cell[636786, 22660, 667, 21, 53, "IndexSubentry",
      CellTags->"MUS"],
    Cell[937380, 34815, 302, 11, 15, "Index",
      CellTags->"MUS"],
    Cell[937685, 34828, 667, 21, 45, "IndexSubentry",
      CellTags->"MUS"],
    Cell[1228380, 46579, 302, 11, 23, "Index",
      CellTags->"MUS"],
    Cell[1228685, 46592, 667, 21, 53, "IndexSubentry",
      CellTags->"MUS"],
    Cell[1510689, 57976, 302, 11, 23, "Index",
      CellTags->"MUS"],
    Cell[1510994, 57989, 667, 21, 53, "IndexSubentry",
      CellTags->"MUS"],
    Cell[1782521, 68960, 302, 11, 15, "Index",
      CellTags->"MUS"],
    Cell[1782826, 68973, 667, 21, 45, "IndexSubentry",
      CellTags->"MUS"]},
  "Mutate"->{
    Cell[322650, 9966, 287, 11, 15, "Index",
      CellTags->"Mutate"],
    Cell[322940, 9979, 607, 21, 45, "IndexSubentry",
      CellTags->"Mutate"],
    Cell[637456, 22683, 287, 11, 23, "Index",
      CellTags->"Mutate"],
    Cell[637746, 22696, 607, 21, 53, "IndexSubentry",
      CellTags->"Mutate"],
    Cell[938355, 34851, 287, 11, 15, "Index",
      CellTags->"Mutate"],
    Cell[938645, 34864, 607, 21, 45, "IndexSubentry",
      CellTags->"Mutate"],
    Cell[1229355, 46615, 287, 11, 23, "Index",
      CellTags->"Mutate"],
    Cell[1229645, 46628, 607, 21, 53, "IndexSubentry",
      CellTags->"Mutate"],
    Cell[1511664, 58012, 287, 11, 23, "Index",
      CellTags->"Mutate"],
    Cell[1511954, 58025, 607, 21, 53, "IndexSubentry",
      CellTags->"Mutate"]},
  "MutateCompiled"->{
    Cell[323550, 10002, 724, 22, 15, "Index",
      CellTags->"MutateCompiled"],
    Cell[638356, 22719, 724, 22, 23, "Index",
      CellTags->"MutateCompiled"],
    Cell[939255, 34887, 724, 22, 15, "Index",
      CellTags->"MutateCompiled"],
    Cell[1230255, 46651, 724, 22, 23, "Index",
      CellTags->"MutateCompiled"],
    Cell[1512564, 58048, 724, 22, 23, "Index",
      CellTags->"MutateCompiled"]},
  "Mutation"->{
    Cell[324277, 10026, 263, 11, 15, "Index",
      CellTags->"Mutation"],
    Cell[324543, 10039, 1083, 33, 59, "IndexSubentry",
      CellTags->"Mutation"],
    Cell[639083, 22743, 263, 11, 23, "Index",
      CellTags->"Mutation"],
    Cell[639349, 22756, 1083, 33, 53, "IndexSubentry",
      CellTags->"Mutation"],
    Cell[939982, 34911, 263, 11, 15, "Index",
      CellTags->"Mutation"],
    Cell[940248, 34924, 1083, 33, 45, "IndexSubentry",
      CellTags->"Mutation"],
    Cell[1230982, 46675, 263, 11, 23, "Index",
      CellTags->"Mutation"],
    Cell[1231248, 46688, 1083, 33, 53, "IndexSubentry",
      CellTags->"Mutation"],
    Cell[1513291, 58072, 263, 11, 23, "Index",
      CellTags->"Mutation"],
    Cell[1513557, 58085, 736, 21, 23, "IndexSubentry",
      CellTags->"Mutation"]},
  "MutationInterval"->{
    Cell[325629, 10074, 275, 10, 15, "Index",
      CellTags->"MutationInterval"],
    Cell[640435, 22791, 275, 10, 23, "Index",
      CellTags->"MutationInterval"],
    Cell[941334, 34959, 275, 10, 15, "Index",
      CellTags->"MutationInterval"],
    Cell[1232334, 46723, 275, 10, 23, "Index",
      CellTags->"MutationInterval"],
    Cell[1514296, 58108, 275, 10, 23, "Index",
      CellTags->"MutationInterval"],
    Cell[1783496, 68996, 275, 10, 15, "Index",
      CellTags->"MutationInterval"]},
  "MutationLabels"->{
    Cell[325907, 10086, 297, 10, 15, "Index",
      CellTags->"MutationLabels"],
    Cell[640713, 22803, 297, 10, 23, "Index",
      CellTags->"MutationLabels"],
    Cell[941612, 34971, 297, 10, 15, "Index",
      CellTags->"MutationLabels"],
    Cell[1232612, 46735, 297, 10, 23, "Index",
      CellTags->"MutationLabels"],
    Cell[1514574, 58120, 297, 10, 23, "Index",
      CellTags->"MutationLabels"],
    Cell[1783774, 69008, 297, 10, 15, "Index",
      CellTags->"MutationLabels"]},
  "MutationOrigin"->{
    Cell[326207, 10098, 269, 10, 15, "Index",
      CellTags->"MutationOrigin"],
    Cell[641013, 22815, 269, 10, 23, "Index",
      CellTags->"MutationOrigin"],
    Cell[941912, 34983, 269, 10, 15, "Index",
      CellTags->"MutationOrigin"],
    Cell[1232912, 46747, 269, 10, 23, "Index",
      CellTags->"MutationOrigin"],
    Cell[1514874, 58132, 269, 10, 23, "Index",
      CellTags->"MutationOrigin"],
    Cell[1784074, 69020, 269, 10, 15, "Index",
      CellTags->"MutationOrigin"]},
  "MutationRate"->{
    Cell[326479, 10110, 261, 10, 15, "Index",
      CellTags->"MutationRate"],
    Cell[641285, 22827, 261, 10, 23, "Index",
      CellTags->"MutationRate"],
    Cell[942184, 34995, 261, 10, 15, "Index",
      CellTags->"MutationRate"],
    Cell[1233184, 46759, 261, 10, 23, "Index",
      CellTags->"MutationRate"],
    Cell[1515146, 58144, 261, 10, 23, "Index",
      CellTags->"MutationRate"],
    Cell[1784346, 69032, 261, 10, 15, "Index",
      CellTags->"MutationRate"]},
  "Mutations"->{
    Cell[326743, 10122, 293, 11, 15, "Index",
      CellTags->"Mutations"],
    Cell[327039, 10135, 772, 27, 60, "IndexSubentry",
      CellTags->"Mutations"],
    Cell[641549, 22839, 293, 11, 23, "Index",
      CellTags->"Mutations"],
    Cell[641845, 22852, 772, 27, 68, "IndexSubentry",
      CellTags->"Mutations"],
    Cell[942448, 35007, 293, 11, 15, "Index",
      CellTags->"Mutations"],
    Cell[942744, 35020, 772, 27, 60, "IndexSubentry",
      CellTags->"Mutations"],
    Cell[1233448, 46771, 276, 11, 23, "Index",
      CellTags->"Mutations"],
    Cell[1515410, 58156, 254, 10, 23, "Index",
      CellTags->"Mutations"],
    Cell[1784610, 69044, 254, 10, 15, "Index",
      CellTags->"Mutations"]},
  "MVariables"->{
    Cell[327814, 10164, 398, 14, 15, "Index",
      CellTags->"MVariables"],
    Cell[642620, 22881, 398, 14, 23, "Index",
      CellTags->"MVariables"],
    Cell[943519, 35049, 398, 14, 15, "Index",
      CellTags->"MVariables"],
    Cell[1233727, 46784, 398, 14, 23, "Index",
      CellTags->"MVariables"],
    Cell[1515667, 58168, 398, 14, 23, "Index",
      CellTags->"MVariables"],
    Cell[1784867, 69056, 398, 14, 15, "Index",
      CellTags->"MVariables"]},
  "Negative binomial"->{
    Cell[328215, 10180, 293, 11, 15, "Index",
      CellTags->"Negative binomial"],
    Cell[328511, 10193, 828, 27, 60, "IndexSubentry",
      CellTags->"Negative binomial"],
    Cell[643021, 22897, 293, 11, 23, "Index",
      CellTags->"Negative binomial"],
    Cell[643317, 22910, 828, 27, 68, "IndexSubentry",
      CellTags->"Negative binomial"],
    Cell[943920, 35065, 293, 11, 15, "Index",
      CellTags->"Negative binomial"],
    Cell[944216, 35078, 828, 27, 60, "IndexSubentry",
      CellTags->"Negative binomial"],
    Cell[1234128, 46800, 293, 11, 23, "Index",
      CellTags->"Negative binomial"],
    Cell[1234424, 46813, 828, 27, 68, "IndexSubentry",
      CellTags->"Negative binomial"],
    Cell[1516068, 58184, 293, 11, 23, "Index",
      CellTags->"Negative binomial"],
    Cell[1516364, 58197, 828, 27, 68, "IndexSubentry",
      CellTags->"Negative binomial"],
    Cell[1785268, 69072, 293, 11, 15, "Index",
      CellTags->"Negative binomial"],
    Cell[1785564, 69085, 828, 27, 60, "IndexSubentry",
      CellTags->"Negative binomial"]},
  "NegativeBinomialLogLikelihood"->{
    Cell[329342, 10222, 339, 11, 15, "Index",
      CellTags->"NegativeBinomialLogLikelihood"],
    Cell[644148, 22939, 339, 11, 23, "Index",
      CellTags->"NegativeBinomialLogLikelihood"],
    Cell[945047, 35107, 339, 11, 15, "Index",
      CellTags->"NegativeBinomialLogLikelihood"],
    Cell[1235255, 46842, 339, 11, 23, "Index",
      CellTags->"NegativeBinomialLogLikelihood"],
    Cell[1517195, 58226, 339, 11, 23, "Index",
      CellTags->"NegativeBinomialLogLikelihood"],
    Cell[1786395, 69114, 339, 11, 15, "Index",
      CellTags->"NegativeBinomialLogLikelihood"]},
  "NegativeBinomialMLE"->{
    Cell[329684, 10235, 302, 10, 15, "Index",
      CellTags->"NegativeBinomialMLE"],
    Cell[644490, 22952, 302, 10, 23, "Index",
      CellTags->"NegativeBinomialMLE"],
    Cell[945389, 35120, 302, 10, 15, "Index",
      CellTags->"NegativeBinomialMLE"],
    Cell[1235597, 46855, 302, 10, 23, "Index",
      CellTags->"NegativeBinomialMLE"],
    Cell[1517537, 58239, 302, 10, 23, "Index",
      CellTags->"NegativeBinomialMLE"],
    Cell[1786737, 69127, 302, 10, 15, "Index",
      CellTags->"NegativeBinomialMLE"]},
  "NegativeHypergeometricDistribution"->{
    Cell[329989, 10247, 368, 11, 15, "Index",
      CellTags->"NegativeHypergeometricDistribution"],
    Cell[644795, 22964, 368, 11, 23, "Index",
      CellTags->"NegativeHypergeometricDistribution"],
    Cell[945694, 35132, 368, 11, 15, "Index",
      CellTags->"NegativeHypergeometricDistribution"],
    Cell[1235902, 46867, 368, 11, 23, "Index",
      CellTags->"NegativeHypergeometricDistribution"],
    Cell[1517842, 58251, 368, 11, 23, "Index",
      CellTags->"NegativeHypergeometricDistribution"],
    Cell[1787042, 69139, 368, 11, 15, "Index",
      CellTags->"NegativeHypergeometricDistribution"]},
  "NeighbourArray"->{
    Cell[330360, 10260, 273, 10, 15, "Index",
      CellTags->"NeighbourArray"],
    Cell[645166, 22977, 273, 10, 23, "Index",
      CellTags->"NeighbourArray"],
    Cell[946065, 35145, 273, 10, 15, "Index",
      CellTags->"NeighbourArray"],
    Cell[1236273, 46880, 273, 10, 23, "Index",
      CellTags->"NeighbourArray"],
    Cell[1518213, 58264, 273, 10, 23, "Index",
      CellTags->"NeighbourArray"],
    Cell[1787413, 69152, 273, 10, 15, "Index",
      CellTags->"NeighbourArray"]},
  "Neighbours"->{
    Cell[330636, 10272, 261, 10, 15, "Index",
      CellTags->"Neighbours"],
    Cell[645442, 22989, 261, 10, 23, "Index",
      CellTags->"Neighbours"],
    Cell[946341, 35157, 261, 10, 15, "Index",
      CellTags->"Neighbours"],
    Cell[1236549, 46892, 261, 10, 23, "Index",
      CellTags->"Neighbours"],
    Cell[1518489, 58276, 261, 10, 23, "Index",
      CellTags->"Neighbours"],
    Cell[1787689, 69164, 261, 10, 15, "Index",
      CellTags->"Neighbours"]},
  "NetCovariance"->{
    Cell[330900, 10284, 280, 10, 15, "Index",
      CellTags->"NetCovariance"],
    Cell[645706, 23001, 280, 10, 23, "Index",
      CellTags->"NetCovariance"],
    Cell[946605, 35169, 280, 10, 15, "Index",
      CellTags->"NetCovariance"],
    Cell[1236813, 46904, 280, 10, 23, "Index",
      CellTags->"NetCovariance"],
    Cell[1518753, 58288, 280, 10, 23, "Index",
      CellTags->"NetCovariance"],
    Cell[1787953, 69176, 280, 10, 15, "Index",
      CellTags->"NetCovariance"]},
  "NetFecundity"->{
    Cell[331183, 10296, 255, 10, 15, "Index",
      CellTags->"NetFecundity"],
    Cell[645989, 23013, 255, 10, 23, "Index",
      CellTags->"NetFecundity"],
    Cell[946888, 35181, 255, 10, 15, "Index",
      CellTags->"NetFecundity"],
    Cell[1237096, 46916, 255, 10, 23, "Index",
      CellTags->"NetFecundity"],
    Cell[1519036, 58300, 255, 10, 23, "Index",
      CellTags->"NetFecundity"],
    Cell[1788236, 69188, 255, 10, 15, "Index",
      CellTags->"NetFecundity"]},
  "NetMortality"->{
    Cell[331441, 10308, 255, 10, 15, "Index",
      CellTags->"NetMortality"],
    Cell[646247, 23025, 255, 10, 23, "Index",
      CellTags->"NetMortality"],
    Cell[947146, 35193, 255, 10, 15, "Index",
      CellTags->"NetMortality"],
    Cell[1237354, 46928, 255, 10, 23, "Index",
      CellTags->"NetMortality"],
    Cell[1519294, 58312, 255, 10, 23, "Index",
      CellTags->"NetMortality"],
    Cell[1788494, 69200, 255, 10, 15, "Index",
      CellTags->"NetMortality"]},
  "NetRecombination"->{
    Cell[331699, 10320, 384, 14, 15, "Index",
      CellTags->"NetRecombination"],
    Cell[332086, 10336, 438, 15, 30, "IndexSubentry",
      CellTags->"NetRecombination"],
    Cell[646505, 23037, 384, 14, 23, "Index",
      CellTags->"NetRecombination"],
    Cell[646892, 23053, 438, 15, 38, "IndexSubentry",
      CellTags->"NetRecombination"],
    Cell[947404, 35205, 384, 14, 15, "Index",
      CellTags->"NetRecombination"],
    Cell[947791, 35221, 438, 15, 30, "IndexSubentry",
      CellTags->"NetRecombination"],
    Cell[1237612, 46940, 384, 14, 23, "Index",
      CellTags->"NetRecombination"],
    Cell[1237999, 46956, 438, 15, 38, "IndexSubentry",
      CellTags->"NetRecombination"],
    Cell[1519552, 58324, 384, 14, 23, "Index",
      CellTags->"NetRecombination"],
    Cell[1519939, 58340, 277, 9, 23, "IndexSubentry",
      CellTags->"NetRecombination"],
    Cell[1788752, 69212, 384, 14, 15, "Index",
      CellTags->"NetRecombination"],
    Cell[1789139, 69228, 277, 9, 15, "IndexSubentry",
      CellTags->"NetRecombination"]},
  "Neutral marker"->{
    Cell[332527, 10353, 285, 11, 15, "Index",
      CellTags->"Neutral marker"],
    Cell[647333, 23070, 285, 11, 23, "Index",
      CellTags->"Neutral marker"],
    Cell[948232, 35238, 285, 11, 15, "Index",
      CellTags->"Neutral marker"],
    Cell[1238440, 46973, 285, 11, 23, "Index",
      CellTags->"Neutral marker"],
    Cell[1520219, 58351, 285, 11, 23, "Index",
      CellTags->"Neutral marker"],
    Cell[1789419, 69239, 285, 11, 15, "Index",
      CellTags->"Neutral marker"]},
  "NeutralRepresentations"->{
    Cell[332815, 10366, 309, 10, 15, "Index",
      CellTags->"NeutralRepresentations"],
    Cell[647621, 23083, 309, 10, 23, "Index",
      CellTags->"NeutralRepresentations"],
    Cell[948520, 35251, 309, 10, 15, "Index",
      CellTags->"NeutralRepresentations"],
    Cell[1238728, 46986, 309, 10, 23, "Index",
      CellTags->"NeutralRepresentations"],
    Cell[1520507, 58364, 309, 10, 23, "Index",
      CellTags->"NeutralRepresentations"],
    Cell[1789707, 69252, 309, 10, 15, "Index",
      CellTags->"NeutralRepresentations"]},
  "NewGametes"->{
    Cell[333127, 10378, 309, 11, 15, "Index",
      CellTags->"NewGametes"],
    Cell[333439, 10391, 1653, 52, 104, "IndexSubentry",
      CellTags->"NewGametes"],
    Cell[647933, 23095, 309, 11, 23, "Index",
      CellTags->"NewGametes"],
    Cell[648245, 23108, 1653, 52, 98, "IndexSubentry",
      CellTags->"NewGametes"],
    Cell[948832, 35263, 309, 11, 15, "Index",
      CellTags->"NewGametes"],
    Cell[949144, 35276, 1653, 52, 90, "IndexSubentry",
      CellTags->"NewGametes"],
    Cell[1239040, 46998, 309, 11, 23, "Index",
      CellTags->"NewGametes"],
    Cell[1239352, 47011, 1653, 52, 98, "IndexSubentry",
      CellTags->"NewGametes"],
    Cell[1520819, 58376, 309, 11, 23, "Index",
      CellTags->"NewGametes"],
    Cell[1521131, 58389, 1653, 52, 98, "IndexSubentry",
      CellTags->"NewGametes"],
    Cell[1790019, 69264, 309, 11, 15, "Index",
      CellTags->"NewGametes"],
    Cell[1790331, 69277, 809, 27, 60, "IndexSubentry",
      CellTags->"NewGametes"]},
  "NewS"->{
    Cell[335095, 10445, 249, 10, 15, "Index",
      CellTags->"NewS"],
    Cell[649901, 23162, 249, 10, 23, "Index",
      CellTags->"NewS"],
    Cell[950800, 35330, 249, 10, 15, "Index",
      CellTags->"NewS"],
    Cell[1241008, 47065, 249, 10, 23, "Index",
      CellTags->"NewS"],
    Cell[1522787, 58443, 249, 10, 23, "Index",
      CellTags->"NewS"],
    Cell[1791143, 69306, 249, 10, 15, "Index",
      CellTags->"NewS"]},
  "Node"->{
    Cell[335347, 10457, 380, 14, 15, "Index",
      CellTags->"Node"],
    Cell[650153, 23174, 380, 14, 23, "Index",
      CellTags->"Node"],
    Cell[951052, 35342, 380, 14, 15, "Index",
      CellTags->"Node"],
    Cell[1241260, 47077, 380, 14, 23, "Index",
      CellTags->"Node"],
    Cell[1523039, 58455, 380, 14, 23, "Index",
      CellTags->"Node"],
    Cell[1791395, 69318, 380, 14, 15, "Index",
      CellTags->"Node"]},
  "NodeFunction"->{
    Cell[335730, 10473, 404, 14, 15, "Index",
      CellTags->"NodeFunction"],
    Cell[336137, 10489, 275, 9, 15, "IndexSubentry",
      CellTags->"NodeFunction"],
    Cell[650536, 23190, 404, 14, 23, "Index",
      CellTags->"NodeFunction"],
    Cell[650943, 23206, 275, 9, 23, "IndexSubentry",
      CellTags->"NodeFunction"],
    Cell[951435, 35358, 404, 14, 15, "Index",
      CellTags->"NodeFunction"],
    Cell[951842, 35374, 275, 9, 15, "IndexSubentry",
      CellTags->"NodeFunction"],
    Cell[1241643, 47093, 404, 14, 23, "Index",
      CellTags->"NodeFunction"],
    Cell[1242050, 47109, 275, 9, 23, "IndexSubentry",
      CellTags->"NodeFunction"],
    Cell[1523422, 58471, 404, 14, 23, "Index",
      CellTags->"NodeFunction"],
    Cell[1523829, 58487, 275, 9, 23, "IndexSubentry",
      CellTags->"NodeFunction"],
    Cell[1791778, 69334, 404, 14, 15, "Index",
      CellTags->"NodeFunction"]},
  "NodeLabels"->{
    Cell[336415, 10500, 257, 10, 15, "Index",
      CellTags->"NodeLabels"],
    Cell[651221, 23217, 257, 10, 23, "Index",
      CellTags->"NodeLabels"],
    Cell[952120, 35385, 257, 10, 15, "Index",
      CellTags->"NodeLabels"],
    Cell[1242328, 47120, 257, 10, 23, "Index",
      CellTags->"NodeLabels"],
    Cell[1524107, 58498, 257, 10, 23, "Index",
      CellTags->"NodeLabels"],
    Cell[1792185, 69350, 257, 10, 15, "Index",
      CellTags->"NodeLabels"]},
  "NodeOffset"->{
    Cell[336675, 10512, 257, 10, 15, "Index",
      CellTags->"NodeOffset"],
    Cell[651481, 23229, 257, 10, 23, "Index",
      CellTags->"NodeOffset"],
    Cell[952380, 35397, 257, 10, 15, "Index",
      CellTags->"NodeOffset"],
    Cell[1242588, 47132, 257, 10, 23, "Index",
      CellTags->"NodeOffset"],
    Cell[1524367, 58510, 257, 10, 23, "Index",
      CellTags->"NodeOffset"],
    Cell[1792445, 69362, 257, 10, 15, "Index",
      CellTags->"NodeOffset"]},
  "Nodes"->{
    Cell[336935, 10524, 246, 10, 15, "Index",
      CellTags->"Nodes"],
    Cell[651741, 23241, 246, 10, 23, "Index",
      CellTags->"Nodes"],
    Cell[952640, 35409, 246, 10, 15, "Index",
      CellTags->"Nodes"],
    Cell[1242848, 47144, 246, 10, 23, "Index",
      CellTags->"Nodes"],
    Cell[1524627, 58522, 246, 10, 23, "Index",
      CellTags->"Nodes"],
    Cell[1792705, 69374, 246, 10, 15, "Index",
      CellTags->"Nodes"]},
  "NonMendelian"->{
    Cell[337184, 10536, 263, 10, 15, "Index",
      CellTags->"NonMendelian"],
    Cell[337450, 10548, 366, 13, 15, "IndexSubentry",
      CellTags->"NonMendelian"],
    Cell[651990, 23253, 263, 10, 23, "Index",
      CellTags->"NonMendelian"],
    Cell[652256, 23265, 366, 13, 23, "IndexSubentry",
      CellTags->"NonMendelian"],
    Cell[952889, 35421, 263, 10, 15, "Index",
      CellTags->"NonMendelian"],
    Cell[953155, 35433, 366, 13, 15, "IndexSubentry",
      CellTags->"NonMendelian"],
    Cell[1243097, 47156, 263, 10, 23, "Index",
      CellTags->"NonMendelian"],
    Cell[1243363, 47168, 366, 13, 23, "IndexSubentry",
      CellTags->"NonMendelian"],
    Cell[1524876, 58534, 263, 10, 23, "Index",
      CellTags->"NonMendelian"],
    Cell[1525142, 58546, 366, 13, 23, "IndexSubentry",
      CellTags->"NonMendelian"],
    Cell[1792954, 69386, 263, 10, 15, "Index",
      CellTags->"NonMendelian"],
    Cell[1793220, 69398, 366, 13, 15, "IndexSubentry",
      CellTags->"NonMendelian"]},
  "NonNeutralRepresentations"->{
    Cell[337819, 10563, 323, 11, 15, "Index",
      CellTags->"NonNeutralRepresentations"],
    Cell[652625, 23280, 323, 11, 23, "Index",
      CellTags->"NonNeutralRepresentations"],
    Cell[953524, 35448, 323, 11, 15, "Index",
      CellTags->"NonNeutralRepresentations"],
    Cell[1243732, 47183, 323, 11, 23, "Index",
      CellTags->"NonNeutralRepresentations"],
    Cell[1525511, 58561, 323, 11, 23, "Index",
      CellTags->"NonNeutralRepresentations"],
    Cell[1793589, 69413, 323, 11, 15, "Index",
      CellTags->"NonNeutralRepresentations"]},
  "NonSymmetricRepresentations"->{
    Cell[338145, 10576, 331, 11, 15, "Index",
      CellTags->"NonSymmetricRepresentations"],
    Cell[652951, 23293, 331, 11, 23, "Index",
      CellTags->"NonSymmetricRepresentations"],
    Cell[953850, 35461, 331, 11, 15, "Index",
      CellTags->"NonSymmetricRepresentations"],
    Cell[1244058, 47196, 331, 11, 23, "Index",
      CellTags->"NonSymmetricRepresentations"],
    Cell[1525837, 58574, 331, 11, 23, "Index",
      CellTags->"NonSymmetricRepresentations"],
    Cell[1793915, 69426, 331, 11, 15, "Index",
      CellTags->"NonSymmetricRepresentations"]},
  "Normalisation"->{
    Cell[338479, 10589, 284, 10, 15, "Index",
      CellTags->"Normalisation"],
    Cell[653285, 23306, 284, 10, 23, "Index",
      CellTags->"Normalisation"],
    Cell[954184, 35474, 284, 10, 15, "Index",
      CellTags->"Normalisation"],
    Cell[1244392, 47209, 284, 10, 23, "Index",
      CellTags->"Normalisation"],
    Cell[1526171, 58587, 284, 10, 23, "Index",
      CellTags->"Normalisation"],
    Cell[1794249, 69439, 284, 10, 15, "Index",
      CellTags->"Normalisation"]},
  "Normalised"->{
    Cell[338766, 10601, 275, 10, 15, "Index",
      CellTags->"Normalised"],
    Cell[653572, 23318, 275, 10, 23, "Index",
      CellTags->"Normalised"],
    Cell[954471, 35486, 275, 10, 15, "Index",
      CellTags->"Normalised"],
    Cell[1244679, 47221, 275, 10, 23, "Index",
      CellTags->"Normalised"],
    Cell[1526458, 58599, 275, 10, 23, "Index",
      CellTags->"Normalised"],
    Cell[1794536, 69451, 275, 10, 15, "Index",
      CellTags->"Normalised"]},
  "Notation"->{
    Cell[339044, 10613, 287, 11, 15, "Index",
      CellTags->"Notation"],
    Cell[339334, 10626, 727, 27, 60, "IndexSubentry",
      CellTags->"Notation"],
    Cell[653850, 23330, 287, 11, 23, "Index",
      CellTags->"Notation"],
    Cell[654140, 23343, 727, 27, 68, "IndexSubentry",
      CellTags->"Notation"],
    Cell[954749, 35498, 287, 11, 15, "Index",
      CellTags->"Notation"],
    Cell[955039, 35511, 727, 27, 60, "IndexSubentry",
      CellTags->"Notation"],
    Cell[1244957, 47233, 287, 11, 23, "Index",
      CellTags->"Notation"],
    Cell[1245247, 47246, 727, 27, 68, "IndexSubentry",
      CellTags->"Notation"],
    Cell[1526736, 58611, 287, 11, 23, "Index",
      CellTags->"Notation"],
    Cell[1527026, 58624, 727, 27, 68, "IndexSubentry",
      CellTags->"Notation"],
    Cell[1794814, 69463, 280, 11, 15, "Index",
      CellTags->"Notation"],
    Cell[1795097, 69476, 395, 15, 30, "IndexSubentry",
      CellTags->"Notation"]},
  "Notation Package"->{
    Cell[340064, 10655, 253, 10, 15, "Index",
      CellTags->"Notation Package"],
    Cell[654870, 23372, 253, 10, 23, "Index",
      CellTags->"Notation Package"],
    Cell[955769, 35540, 253, 10, 15, "Index",
      CellTags->"Notation Package"],
    Cell[1245977, 47275, 253, 10, 23, "Index",
      CellTags->"Notation Package"],
    Cell[1527756, 58653, 253, 10, 23, "Index",
      CellTags->"Notation Package"]},
  "Null lineages"->{
    Cell[340320, 10667, 304, 11, 15, "Index",
      CellTags->"Null lineages"],
    Cell[656363, 23432, 304, 11, 23, "Index",
      CellTags->"Null lineages"]},
  "NullLineages"->{
    Cell[340627, 10680, 304, 11, 15, "Index",
      CellTags->"NullLineages"],
    Cell[656670, 23445, 304, 11, 23, "Index",
      CellTags->"NullLineages"]},
  "NullRecombinationEvents"->{
    Cell[340934, 10693, 337, 11, 15, "Index",
      CellTags->"NullRecombinationEvents"],
    Cell[656977, 23458, 337, 11, 23, "Index",
      CellTags->"NullRecombinationEvents"]},
  "NumberedLink"->{
    Cell[341274, 10706, 261, 10, 15, "Index",
      CellTags->"NumberedLink"],
    Cell[657317, 23471, 261, 10, 23, "Index",
      CellTags->"NumberedLink"],
    Cell[956025, 35552, 261, 10, 15, "Index",
      CellTags->"NumberedLink"],
    Cell[1246233, 47287, 261, 10, 23, "Index",
      CellTags->"NumberedLink"],
    Cell[1528012, 58665, 261, 10, 23, "Index",
      CellTags->"NumberedLink"],
    Cell[1795751, 69505, 261, 10, 15, "Index",
      CellTags->"NumberedLink"]},
  "Numbering"->{
    Cell[341538, 10718, 271, 11, 15, "Index",
      CellTags->"Numbering"],
    Cell[341812, 10731, 560, 21, 45, "IndexSubentry",
      CellTags->"Numbering"],
    Cell[657581, 23483, 271, 11, 23, "Index",
      CellTags->"Numbering"],
    Cell[657855, 23496, 560, 21, 53, "IndexSubentry",
      CellTags->"Numbering"],
    Cell[956289, 35564, 271, 11, 15, "Index",
      CellTags->"Numbering"],
    Cell[956563, 35577, 560, 21, 45, "IndexSubentry",
      CellTags->"Numbering"],
    Cell[1246497, 47299, 271, 11, 23, "Index",
      CellTags->"Numbering"],
    Cell[1246771, 47312, 560, 21, 53, "IndexSubentry",
      CellTags->"Numbering"],
    Cell[1528276, 58677, 271, 11, 23, "Index",
      CellTags->"Numbering"],
    Cell[1528550, 58690, 560, 21, 53, "IndexSubentry",
      CellTags->"Numbering"],
    Cell[1796015, 69517, 271, 11, 15, "Index",
      CellTags->"Numbering"],
    Cell[1796289, 69530, 560, 21, 45, "IndexSubentry",
      CellTags->"Numbering"]},
  "NumberOfCoalescences"->{
    Cell[342375, 10754, 318, 11, 15, "Index",
      CellTags->"NumberOfCoalescences"],
    Cell[658418, 23519, 318, 11, 23, "Index",
      CellTags->"NumberOfCoalescences"],
    Cell[957126, 35600, 318, 11, 15, "Index",
      CellTags->"NumberOfCoalescences"],
    Cell[1247334, 47335, 318, 11, 23, "Index",
      CellTags->"NumberOfCoalescences"],
    Cell[1529113, 58713, 318, 11, 23, "Index",
      CellTags->"NumberOfCoalescences"],
    Cell[1796852, 69553, 318, 11, 15, "Index",
      CellTags->"NumberOfCoalescences"]},
  "NumberOfGenes"->{
    Cell[342696, 10767, 266, 10, 15, "Index",
      CellTags->"NumberOfGenes"],
    Cell[342965, 10779, 915, 28, 60, "IndexSubentry",
      CellTags->"NumberOfGenes"],
    Cell[658739, 23532, 266, 10, 23, "Index",
      CellTags->"NumberOfGenes"],
    Cell[659008, 23544, 917, 28, 68, "IndexSubentry",
      CellTags->"NumberOfGenes"],
    Cell[957447, 35613, 266, 10, 15, "Index",
      CellTags->"NumberOfGenes"],
    Cell[957716, 35625, 915, 28, 60, "IndexSubentry",
      CellTags->"NumberOfGenes"],
    Cell[1247655, 47348, 266, 10, 23, "Index",
      CellTags->"NumberOfGenes"],
    Cell[1247924, 47360, 915, 28, 68, "IndexSubentry",
      CellTags->"NumberOfGenes"],
    Cell[1529434, 58726, 266, 10, 23, "Index",
      CellTags->"NumberOfGenes"],
    Cell[1529703, 58738, 915, 28, 68, "IndexSubentry",
      CellTags->"NumberOfGenes"],
    Cell[1797173, 69566, 266, 10, 15, "Index",
      CellTags->"NumberOfGenes"],
    Cell[1797442, 69578, 915, 28, 60, "IndexSubentry",
      CellTags->"NumberOfGenes"]},
  "NumberOfGenesTable"->{
    Cell[343883, 10809, 281, 10, 15, "Index",
      CellTags->"NumberOfGenesTable"],
    Cell[659928, 23574, 281, 10, 23, "Index",
      CellTags->"NumberOfGenesTable"],
    Cell[958634, 35655, 281, 10, 15, "Index",
      CellTags->"NumberOfGenesTable"],
    Cell[1248842, 47390, 281, 10, 23, "Index",
      CellTags->"NumberOfGenesTable"],
    Cell[1530621, 58768, 281, 10, 23, "Index",
      CellTags->"NumberOfGenesTable"],
    Cell[1798360, 69608, 281, 10, 15, "Index",
      CellTags->"NumberOfGenesTable"]},
  "NumberOfIndividuals"->{
    Cell[344167, 10821, 416, 14, 15, "Index",
      CellTags->"NumberOfIndividuals"],
    Cell[660212, 23586, 416, 14, 23, "Index",
      CellTags->"NumberOfIndividuals"],
    Cell[958918, 35667, 416, 14, 15, "Index",
      CellTags->"NumberOfIndividuals"],
    Cell[1249126, 47402, 416, 14, 23, "Index",
      CellTags->"NumberOfIndividuals"],
    Cell[1530905, 58780, 416, 14, 23, "Index",
      CellTags->"NumberOfIndividuals"],
    Cell[1798644, 69620, 416, 14, 15, "Index",
      CellTags->"NumberOfIndividuals"]},
  "NumberOfIndividualsTable"->{
    Cell[344586, 10837, 299, 10, 15, "Index",
      CellTags->"NumberOfIndividualsTable"],
    Cell[660631, 23602, 299, 10, 23, "Index",
      CellTags->"NumberOfIndividualsTable"],
    Cell[959337, 35683, 299, 10, 15, "Index",
      CellTags->"NumberOfIndividualsTable"],
    Cell[1249545, 47418, 299, 10, 23, "Index",
      CellTags->"NumberOfIndividualsTable"],
    Cell[1531324, 58796, 299, 10, 23, "Index",
      CellTags->"NumberOfIndividualsTable"],
    Cell[1799063, 69636, 299, 10, 15, "Index",
      CellTags->"NumberOfIndividualsTable"]},
  "NumberOfLineages"->{
    Cell[344888, 10849, 279, 10, 15, "Index",
      CellTags->"NumberOfLineages"],
    Cell[660933, 23614, 279, 10, 23, "Index",
      CellTags->"NumberOfLineages"],
    Cell[959639, 35695, 279, 10, 15, "Index",
      CellTags->"NumberOfLineages"],
    Cell[1249847, 47430, 279, 10, 23, "Index",
      CellTags->"NumberOfLineages"],
    Cell[1531626, 58808, 279, 10, 23, "Index",
      CellTags->"NumberOfLineages"],
    Cell[1799365, 69648, 279, 10, 15, "Index",
      CellTags->"NumberOfLineages"]},
  "NumberOfLoci"->{
    Cell[345170, 10861, 263, 10, 15, "Index",
      CellTags->"NumberOfLoci"],
    Cell[661215, 23626, 263, 10, 23, "Index",
      CellTags->"NumberOfLoci"],
    Cell[959921, 35707, 263, 10, 15, "Index",
      CellTags->"NumberOfLoci"],
    Cell[1250129, 47442, 263, 10, 23, "Index",
      CellTags->"NumberOfLoci"],
    Cell[1531908, 58820, 263, 10, 23, "Index",
      CellTags->"NumberOfLoci"],
    Cell[1799647, 69660, 263, 10, 15, "Index",
      CellTags->"NumberOfLoci"]},
  "NumberOfMutations"->{
    Cell[345436, 10873, 278, 10, 15, "Index",
      CellTags->"NumberOfMutations"],
    Cell[661481, 23638, 278, 10, 23, "Index",
      CellTags->"NumberOfMutations"],
    Cell[960187, 35719, 278, 10, 15, "Index",
      CellTags->"NumberOfMutations"],
    Cell[1250395, 47454, 278, 10, 23, "Index",
      CellTags->"NumberOfMutations"],
    Cell[1532174, 58832, 278, 10, 23, "Index",
      CellTags->"NumberOfMutations"],
    Cell[1799913, 69672, 278, 10, 15, "Index",
      CellTags->"NumberOfMutations"]},
  "NumberOfPossibleCoalescences"->{
    Cell[345717, 10885, 317, 10, 15, "Index",
      CellTags->"NumberOfPossibleCoalescences"],
    Cell[661762, 23650, 317, 10, 23, "Index",
      CellTags->"NumberOfPossibleCoalescences"],
    Cell[960468, 35731, 317, 10, 15, "Index",
      CellTags->"NumberOfPossibleCoalescences"],
    Cell[1250676, 47466, 317, 10, 23, "Index",
      CellTags->"NumberOfPossibleCoalescences"],
    Cell[1532455, 58844, 317, 10, 23, "Index",
      CellTags->"NumberOfPossibleCoalescences"],
    Cell[1800194, 69684, 317, 10, 15, "Index",
      CellTags->"NumberOfPossibleCoalescences"]},
  "NumberOfSamplePartitions"->{
    Cell[346037, 10897, 287, 10, 15, "Index",
      CellTags->"NumberOfSamplePartitions"],
    Cell[662082, 23662, 287, 10, 23, "Index",
      CellTags->"NumberOfSamplePartitions"],
    Cell[960788, 35743, 287, 10, 15, "Index",
      CellTags->"NumberOfSamplePartitions"],
    Cell[1250996, 47478, 287, 10, 23, "Index",
      CellTags->"NumberOfSamplePartitions"],
    Cell[1532775, 58856, 287, 10, 23, "Index",
      CellTags->"NumberOfSamplePartitions"],
    Cell[1800514, 69696, 287, 10, 15, "Index",
      CellTags->"NumberOfSamplePartitions"]},
  "NumberOfSetPartitions"->{
    Cell[346327, 10909, 278, 10, 15, "Index",
      CellTags->"NumberOfSetPartitions"],
    Cell[662372, 23674, 278, 10, 23, "Index",
      CellTags->"NumberOfSetPartitions"],
    Cell[961078, 35755, 278, 10, 15, "Index",
      CellTags->"NumberOfSetPartitions"],
    Cell[1251286, 47490, 278, 10, 23, "Index",
      CellTags->"NumberOfSetPartitions"],
    Cell[1533065, 58868, 278, 10, 23, "Index",
      CellTags->"NumberOfSetPartitions"],
    Cell[1800804, 69708, 278, 10, 15, "Index",
      CellTags->"NumberOfSetPartitions"]},
  "NumericalModel"->{
    Cell[346608, 10921, 325, 11, 15, "Index",
      CellTags->"NumericalModel"],
    Cell[346936, 10934, 294, 9, 15, "IndexSubentry",
      CellTags->"NumericalModel"],
    Cell[662653, 23686, 327, 11, 23, "Index",
      CellTags->"NumericalModel"],
    Cell[662983, 23699, 294, 9, 23, "IndexSubentry",
      CellTags->"NumericalModel"],
    Cell[961359, 35767, 325, 11, 15, "Index",
      CellTags->"NumericalModel"],
    Cell[961687, 35780, 294, 9, 15, "IndexSubentry",
      CellTags->"NumericalModel"],
    Cell[1251567, 47502, 325, 11, 23, "Index",
      CellTags->"NumericalModel"],
    Cell[1251895, 47515, 294, 9, 23, "IndexSubentry",
      CellTags->"NumericalModel"],
    Cell[1533346, 58880, 325, 11, 23, "Index",
      CellTags->"NumericalModel"],
    Cell[1533674, 58893, 294, 9, 23, "IndexSubentry",
      CellTags->"NumericalModel"],
    Cell[1801085, 69720, 325, 11, 15, "Index",
      CellTags->"NumericalModel"],
    Cell[1801413, 69733, 294, 9, 15, "IndexSubentry",
      CellTags->"NumericalModel"]},
  "Numerical models"->{
    Cell[347233, 10945, 301, 11, 15, "Index",
      CellTags->"Numerical models"],
    Cell[347537, 10958, 1265, 43, 90, "IndexSubentry",
      CellTags->"Numerical models"],
    Cell[663280, 23710, 301, 11, 23, "Index",
      CellTags->"Numerical models"],
    Cell[663584, 23723, 1267, 43, 98, "IndexSubentry",
      CellTags->"Numerical models"],
    Cell[961984, 35791, 301, 11, 15, "Index",
      CellTags->"Numerical models"],
    Cell[962288, 35804, 1265, 43, 90, "IndexSubentry",
      CellTags->"Numerical models"],
    Cell[1252192, 47526, 301, 11, 23, "Index",
      CellTags->"Numerical models"],
    Cell[1252496, 47539, 1071, 37, 83, "IndexSubentry",
      CellTags->"Numerical models"],
    Cell[1533971, 58904, 301, 11, 23, "Index",
      CellTags->"Numerical models"],
    Cell[1534275, 58917, 1071, 37, 83, "IndexSubentry",
      CellTags->"Numerical models"],
    Cell[1801710, 69744, 301, 11, 15, "Index",
      CellTags->"Numerical models"],
    Cell[1802014, 69757, 1071, 37, 75, "IndexSubentry",
      CellTags->"Numerical models"]},
  "Observable genotype"->{
    Cell[348805, 11003, 420, 14, 15, "Index",
      CellTags->"Observable genotype"],
    Cell[664854, 23768, 420, 14, 23, "Index",
      CellTags->"Observable genotype"],
    Cell[963556, 35849, 420, 14, 15, "Index",
      CellTags->"Observable genotype"],
    Cell[1253570, 47578, 420, 14, 23, "Index",
      CellTags->"Observable genotype"],
    Cell[1535349, 58956, 420, 14, 23, "Index",
      CellTags->"Observable genotype"],
    Cell[1803088, 69796, 420, 14, 15, "Index",
      CellTags->"Observable genotype"]},
  "Obsolete"->{
    Cell[349228, 11019, 250, 11, 15, "Index",
      CellTags->"Obsolete"],
    Cell[349481, 11032, 3402, 121, 285, "IndexSubentry",
      CellTags->"Obsolete"],
    Cell[665277, 23784, 250, 11, 23, "Index",
      CellTags->"Obsolete"],
    Cell[665530, 23797, 3402, 121, 293, "IndexSubentry",
      CellTags->"Obsolete"],
    Cell[963979, 35865, 250, 11, 15, "Index",
      CellTags->"Obsolete"],
    Cell[964232, 35878, 3402, 121, 285, "IndexSubentry",
      CellTags->"Obsolete"],
    Cell[1253993, 47594, 250, 11, 23, "Index",
      CellTags->"Obsolete"],
    Cell[1254246, 47607, 3402, 121, 293, "IndexSubentry",
      CellTags->"Obsolete"],
    Cell[1535772, 58972, 250, 11, 23, "Index",
      CellTags->"Obsolete"],
    Cell[1536025, 58985, 3253, 115, 278, "IndexSubentry",
      CellTags->"Obsolete"],
    Cell[1803511, 69812, 250, 11, 15, "Index",
      CellTags->"Obsolete"],
    Cell[1803764, 69825, 3253, 115, 270, "IndexSubentry",
      CellTags->"Obsolete"]},
  "Offspring"->{
    Cell[352886, 11155, 258, 10, 15, "Index",
      CellTags->"Offspring"],
    Cell[668935, 23920, 258, 10, 23, "Index",
      CellTags->"Offspring"],
    Cell[967637, 36001, 258, 10, 15, "Index",
      CellTags->"Offspring"],
    Cell[1257651, 47730, 258, 10, 23, "Index",
      CellTags->"Offspring"],
    Cell[1539281, 59102, 258, 10, 23, "Index",
      CellTags->"Offspring"],
    Cell[1807020, 69942, 258, 10, 15, "Index",
      CellTags->"Offspring"]},
  "Ordered"->{
    Cell[353147, 11167, 266, 11, 15, "Index",
      CellTags->"Ordered"],
    Cell[669196, 23932, 266, 11, 23, "Index",
      CellTags->"Ordered"],
    Cell[967898, 36013, 266, 11, 15, "Index",
      CellTags->"Ordered"],
    Cell[1257912, 47742, 266, 11, 23, "Index",
      CellTags->"Ordered"]},
  "Orive & Barton 1999"->{
    Cell[353416, 11180, 264, 10, 15, "Index",
      CellTags->"Orive & Barton 1999"],
    Cell[669465, 23945, 264, 10, 23, "Index",
      CellTags->"Orive & Barton 1999"],
    Cell[968167, 36026, 264, 10, 15, "Index",
      CellTags->"Orive & Barton 1999"],
    Cell[1258181, 47755, 264, 10, 23, "Index",
      CellTags->"Orive & Barton 1999"],
    Cell[1539542, 59114, 264, 10, 23, "Index",
      CellTags->"Orive & Barton 1999"],
    Cell[1807281, 69954, 264, 10, 15, "Index",
      CellTags->"Orive & Barton 1999"]},
  "OtherSex"->{
    Cell[353683, 11192, 247, 10, 15, "Index",
      CellTags->"OtherSex"],
    Cell[669732, 23957, 247, 10, 23, "Index",
      CellTags->"OtherSex"],
    Cell[968434, 36038, 247, 10, 15, "Index",
      CellTags->"OtherSex"],
    Cell[1258448, 47767, 247, 10, 23, "Index",
      CellTags->"OtherSex"],
    Cell[1539809, 59126, 247, 10, 23, "Index",
      CellTags->"OtherSex"],
    Cell[1807548, 69966, 247, 10, 15, "Index",
      CellTags->"OtherSex"]},
  "Packages"->{
    Cell[353933, 11204, 275, 11, 15, "Index",
      CellTags->"Packages"],
    Cell[354211, 11217, 839, 31, 60, "IndexSubentry",
      CellTags->"Packages"],
    Cell[669982, 23969, 275, 11, 23, "Index",
      CellTags->"Packages"],
    Cell[670260, 23982, 839, 31, 68, "IndexSubentry",
      CellTags->"Packages"],
    Cell[968684, 36050, 275, 11, 15, "Index",
      CellTags->"Packages"],
    Cell[968962, 36063, 839, 31, 60, "IndexSubentry",
      CellTags->"Packages"],
    Cell[1258698, 47779, 275, 11, 23, "Index",
      CellTags->"Packages"],
    Cell[1258976, 47792, 839, 31, 68, "IndexSubentry",
      CellTags->"Packages"],
    Cell[1540059, 59138, 275, 11, 23, "Index",
      CellTags->"Packages"],
    Cell[1540337, 59151, 839, 31, 68, "IndexSubentry",
      CellTags->"Packages"],
    Cell[1807798, 69978, 275, 11, 15, "Index",
      CellTags->"Packages"],
    Cell[1808076, 69991, 839, 31, 60, "IndexSubentry",
      CellTags->"Packages"]},
  "PackageSaver"->{
    Cell[355053, 11250, 235, 10, 15, "Index",
      CellTags->"PackageSaver"],
    Cell[671102, 24015, 235, 10, 23, "Index",
      CellTags->"PackageSaver"],
    Cell[969804, 36096, 235, 10, 15, "Index",
      CellTags->"PackageSaver"],
    Cell[1259818, 47825, 235, 10, 23, "Index",
      CellTags->"PackageSaver"],
    Cell[1541179, 59184, 235, 10, 23, "Index",
      CellTags->"PackageSaver"],
    Cell[1808918, 70024, 235, 10, 15, "Index",
      CellTags->"PackageSaver"]},
  "Partitions"->{
    Cell[355291, 11262, 262, 11, 15, "Index",
      CellTags->"Partitions"],
    Cell[355556, 11275, 426, 15, 30, "IndexSubentry",
      CellTags->"Partitions"],
    Cell[671615, 24039, 262, 11, 23, "Index",
      CellTags->"Partitions"],
    Cell[671880, 24052, 426, 15, 38, "IndexSubentry",
      CellTags->"Partitions"],
    Cell[970042, 36108, 262, 11, 15, "Index",
      CellTags->"Partitions"],
    Cell[970307, 36121, 426, 15, 30, "IndexSubentry",
      CellTags->"Partitions"],
    Cell[1260056, 47837, 262, 11, 23, "Index",
      CellTags->"Partitions"],
    Cell[1260321, 47850, 426, 15, 38, "IndexSubentry",
      CellTags->"Partitions"]},
  "PartitionSet"->{
    Cell[355985, 11292, 251, 10, 15, "Index",
      CellTags->"PartitionSet"],
    Cell[672309, 24069, 251, 10, 23, "Index",
      CellTags->"PartitionSet"],
    Cell[970736, 36138, 251, 10, 15, "Index",
      CellTags->"PartitionSet"],
    Cell[1260750, 47867, 251, 10, 23, "Index",
      CellTags->"PartitionSet"]},
  "Paternal inheritance"->{
    Cell[356239, 11304, 414, 14, 15, "Index",
      CellTags->"Paternal inheritance"],
    Cell[672563, 24081, 414, 14, 23, "Index",
      CellTags->"Paternal inheritance"],
    Cell[970990, 36150, 414, 14, 15, "Index",
      CellTags->"Paternal inheritance"],
    Cell[1261004, 47879, 414, 14, 23, "Index",
      CellTags->"Paternal inheritance"],
    Cell[1541417, 59196, 414, 14, 23, "Index",
      CellTags->"Paternal inheritance"]},
  "PaternalLoci"->{
    Cell[356656, 11320, 277, 11, 15, "Index",
      CellTags->"PaternalLoci"],
    Cell[356936, 11333, 444, 15, 30, "IndexSubentry",
      CellTags->"PaternalLoci"],
    Cell[672980, 24097, 277, 11, 23, "Index",
      CellTags->"PaternalLoci"],
    Cell[673260, 24110, 444, 15, 38, "IndexSubentry",
      CellTags->"PaternalLoci"],
    Cell[971407, 36166, 277, 11, 15, "Index",
      CellTags->"PaternalLoci"],
    Cell[971687, 36179, 444, 15, 30, "IndexSubentry",
      CellTags->"PaternalLoci"],
    Cell[1261421, 47895, 277, 11, 23, "Index",
      CellTags->"PaternalLoci"],
    Cell[1261701, 47908, 444, 15, 38, "IndexSubentry",
      CellTags->"PaternalLoci"],
    Cell[1541834, 59212, 277, 11, 23, "Index",
      CellTags->"PaternalLoci"],
    Cell[1542114, 59225, 444, 15, 38, "IndexSubentry",
      CellTags->"PaternalLoci"]},
  "PatternFree"->{
    Cell[357383, 11350, 274, 10, 15, "Index",
      CellTags->"PatternFree"],
    Cell[673707, 24127, 274, 10, 23, "Index",
      CellTags->"PatternFree"],
    Cell[972134, 36196, 274, 10, 15, "Index",
      CellTags->"PatternFree"],
    Cell[1262148, 47925, 274, 10, 23, "Index",
      CellTags->"PatternFree"],
    Cell[1542561, 59242, 274, 10, 23, "Index",
      CellTags->"PatternFree"],
    Cell[1809156, 70036, 274, 10, 15, "Index",
      CellTags->"PatternFree"]},
  "Permutations"->{
    Cell[357660, 11362, 281, 11, 15, "Index",
      CellTags->"Permutations"],
    Cell[673984, 24139, 281, 11, 23, "Index",
      CellTags->"Permutations"],
    Cell[972411, 36208, 281, 11, 15, "Index",
      CellTags->"Permutations"],
    Cell[1262425, 47937, 281, 11, 23, "Index",
      CellTags->"Permutations"]},
  "Permutations in defining coefficients"->{
    Cell[357944, 11375, 325, 11, 15, "Index",
      CellTags->"Permutations in defining coefficients"],
    Cell[674268, 24152, 325, 11, 23, "Index",
      CellTags->"Permutations in defining coefficients"],
    Cell[972695, 36221, 325, 11, 15, "Index",
      CellTags->"Permutations in defining coefficients"],
    Cell[1262709, 47950, 325, 11, 23, "Index",
      CellTags->"Permutations in defining coefficients"],
    Cell[1542838, 59254, 325, 11, 23, "Index",
      CellTags->"Permutations in defining coefficients"]},
  "Phenotypes"->{
    Cell[358272, 11388, 269, 11, 15, "Index",
      CellTags->"Phenotypes"],
    Cell[674596, 24165, 269, 11, 23, "Index",
      CellTags->"Phenotypes"],
    Cell[973023, 36234, 269, 11, 15, "Index",
      CellTags->"Phenotypes"],
    Cell[1263037, 47963, 269, 11, 23, "Index",
      CellTags->"Phenotypes"],
    Cell[1543166, 59267, 269, 11, 23, "Index",
      CellTags->"Phenotypes"]},
  "Phipps & Brill 1995"->{
    Cell[358544, 11401, 264, 10, 15, "Index",
      CellTags->"Phipps & Brill 1995"],
    Cell[674868, 24178, 264, 10, 23, "Index",
      CellTags->"Phipps & Brill 1995"],
    Cell[973295, 36247, 264, 10, 15, "Index",
      CellTags->"Phipps & Brill 1995"],
    Cell[1263309, 47976, 264, 10, 23, "Index",
      CellTags->"Phipps & Brill 1995"],
    Cell[1543438, 59280, 264, 10, 23, "Index",
      CellTags->"Phipps & Brill 1995"],
    Cell[1809433, 70048, 264, 10, 15, "Index",
      CellTags->"Phipps & Brill 1995"]},
  "Ploidy"->{
    Cell[358811, 11413, 245, 10, 15, "Index",
      CellTags->"Ploidy"],
    Cell[675135, 24190, 245, 10, 23, "Index",
      CellTags->"Ploidy"],
    Cell[973562, 36259, 245, 10, 15, "Index",
      CellTags->"Ploidy"],
    Cell[1263576, 47988, 245, 10, 23, "Index",
      CellTags->"Ploidy"],
    Cell[1543705, 59292, 245, 10, 23, "Index",
      CellTags->"Ploidy"],
    Cell[1809700, 70060, 245, 10, 15, "Index",
      CellTags->"Ploidy"]},
  "PloidyWeightList"->{
    Cell[359059, 11425, 271, 10, 15, "Index",
      CellTags->"PloidyWeightList"],
    Cell[675383, 24202, 271, 10, 23, "Index",
      CellTags->"PloidyWeightList"],
    Cell[973810, 36271, 271, 10, 15, "Index",
      CellTags->"PloidyWeightList"],
    Cell[1263824, 48000, 271, 10, 23, "Index",
      CellTags->"PloidyWeightList"],
    Cell[1543953, 59304, 271, 10, 23, "Index",
      CellTags->"PloidyWeightList"],
    Cell[1809948, 70072, 271, 10, 15, "Index",
      CellTags->"PloidyWeightList"]},
  "PlotGenealogy"->{
    Cell[359333, 11437, 266, 10, 15, "Index",
      CellTags->"PlotGenealogy"],
    Cell[675657, 24214, 266, 10, 23, "Index",
      CellTags->"PlotGenealogy"],
    Cell[974084, 36283, 266, 10, 15, "Index",
      CellTags->"PlotGenealogy"],
    Cell[1264098, 48012, 266, 10, 23, "Index",
      CellTags->"PlotGenealogy"],
    Cell[1544227, 59316, 266, 10, 23, "Index",
      CellTags->"PlotGenealogy"],
    Cell[1810222, 70084, 266, 10, 15, "Index",
      CellTags->"PlotGenealogy"]},
  "PlotLogL"->{
    Cell[359602, 11449, 247, 10, 15, "Index",
      CellTags->"PlotLogL"],
    Cell[675926, 24226, 247, 10, 23, "Index",
      CellTags->"PlotLogL"],
    Cell[974353, 36295, 247, 10, 15, "Index",
      CellTags->"PlotLogL"],
    Cell[1264367, 48024, 247, 10, 23, "Index",
      CellTags->"PlotLogL"],
    Cell[1544496, 59328, 247, 10, 23, "Index",
      CellTags->"PlotLogL"],
    Cell[1810491, 70096, 247, 10, 15, "Index",
      CellTags->"PlotLogL"]},
  "PlotSegments"->{
    Cell[359852, 11461, 300, 11, 15, "Index",
      CellTags->"PlotSegments"],
    Cell[676176, 24238, 300, 11, 23, "Index",
      CellTags->"PlotSegments"]},
  "Plotting"->{
    Cell[360155, 11474, 279, 11, 15, "Index",
      CellTags->"Plotting"],
    Cell[676479, 24251, 279, 11, 23, "Index",
      CellTags->"Plotting"]},
  "PopulationDisequilibrium"->{
    Cell[360437, 11487, 346, 11, 15, "Index",
      CellTags->"PopulationDisequilibrium"],
    Cell[676761, 24264, 346, 11, 23, "Index",
      CellTags->"PopulationDisequilibrium"],
    Cell[974603, 36307, 346, 11, 15, "Index",
      CellTags->"PopulationDisequilibrium"],
    Cell[1264617, 48036, 346, 11, 23, "Index",
      CellTags->"PopulationDisequilibrium"],
    Cell[1544746, 59340, 346, 11, 23, "Index",
      CellTags->"PopulationDisequilibrium"],
    Cell[1810741, 70108, 346, 11, 15, "Index",
      CellTags->"PopulationDisequilibrium"]},
  "PopulationExpectation"->{
    Cell[360786, 11500, 274, 10, 15, "Index",
      CellTags->"PopulationExpectation"],
    Cell[361063, 11512, 271, 9, 15, "IndexSubentry",
      CellTags->"PopulationExpectation"],
    Cell[677110, 24277, 274, 10, 23, "Index",
      CellTags->"PopulationExpectation"],
    Cell[677387, 24289, 271, 9, 23, "IndexSubentry",
      CellTags->"PopulationExpectation"],
    Cell[974952, 36320, 274, 10, 15, "Index",
      CellTags->"PopulationExpectation"],
    Cell[975229, 36332, 271, 9, 15, "IndexSubentry",
      CellTags->"PopulationExpectation"],
    Cell[1264966, 48049, 274, 10, 23, "Index",
      CellTags->"PopulationExpectation"],
    Cell[1265243, 48061, 271, 9, 23, "IndexSubentry",
      CellTags->"PopulationExpectation"],
    Cell[1545095, 59353, 274, 10, 23, "Index",
      CellTags->"PopulationExpectation"],
    Cell[1545372, 59365, 271, 9, 23, "IndexSubentry",
      CellTags->"PopulationExpectation"],
    Cell[1811090, 70121, 274, 10, 15, "Index",
      CellTags->"PopulationExpectation"],
    Cell[1811367, 70133, 271, 9, 15, "IndexSubentry",
      CellTags->"PopulationExpectation"]},
  "PopulationRepresentations"->{
    Cell[361337, 11523, 323, 11, 15, "Index",
      CellTags->"PopulationRepresentations"],
    Cell[677661, 24300, 323, 11, 23, "Index",
      CellTags->"PopulationRepresentations"],
    Cell[975503, 36343, 323, 11, 15, "Index",
      CellTags->"PopulationRepresentations"],
    Cell[1265517, 48072, 323, 11, 23, "Index",
      CellTags->"PopulationRepresentations"],
    Cell[1545646, 59376, 323, 11, 23, "Index",
      CellTags->"PopulationRepresentations"],
    Cell[1811641, 70144, 323, 11, 15, "Index",
      CellTags->"PopulationRepresentations"]},
  "Position"->{
    Cell[361663, 11536, 380, 14, 15, "Index",
      CellTags->"Position"],
    Cell[362046, 11552, 442, 15, 30, "IndexSubentry",
      CellTags->"Position"],
    Cell[677987, 24313, 380, 14, 23, "Index",
      CellTags->"Position"],
    Cell[678370, 24329, 442, 15, 38, "IndexSubentry",
      CellTags->"Position"],
    Cell[975829, 36356, 380, 14, 15, "Index",
      CellTags->"Position"],
    Cell[976212, 36372, 442, 15, 30, "IndexSubentry",
      CellTags->"Position"],
    Cell[1265843, 48085, 380, 14, 23, "Index",
      CellTags->"Position"],
    Cell[1266226, 48101, 442, 15, 38, "IndexSubentry",
      CellTags->"Position"],
    Cell[1545972, 59389, 380, 14, 23, "Index",
      CellTags->"Position"],
    Cell[1546355, 59405, 442, 15, 38, "IndexSubentry",
      CellTags->"Position"],
    Cell[1811967, 70157, 362, 14, 15, "Index",
      CellTags->"Position"],
    Cell[1812332, 70173, 257, 9, 15, "IndexSubentry",
      CellTags->"Position"]},
  "PositionsList"->{
    Cell[362491, 11569, 270, 10, 15, "Index",
      CellTags->"PositionsList"],
    Cell[678815, 24346, 270, 10, 23, "Index",
      CellTags->"PositionsList"],
    Cell[976657, 36389, 270, 10, 15, "Index",
      CellTags->"PositionsList"],
    Cell[1266671, 48118, 270, 10, 23, "Index",
      CellTags->"PositionsList"],
    Cell[1546800, 59422, 270, 10, 23, "Index",
      CellTags->"PositionsList"],
    Cell[1812592, 70184, 270, 10, 15, "Index",
      CellTags->"PositionsList"]},
  "PositionsMatrix"->{
    Cell[362764, 11581, 276, 10, 15, "Index",
      CellTags->"PositionsMatrix"],
    Cell[679088, 24358, 276, 10, 23, "Index",
      CellTags->"PositionsMatrix"],
    Cell[976930, 36401, 276, 10, 15, "Index",
      CellTags->"PositionsMatrix"],
    Cell[1266944, 48130, 276, 10, 23, "Index",
      CellTags->"PositionsMatrix"],
    Cell[1547073, 59434, 276, 10, 23, "Index",
      CellTags->"PositionsMatrix"],
    Cell[1812865, 70196, 276, 10, 15, "Index",
      CellTags->"PositionsMatrix"]},
  "PossibleCoalescenceOrder"->{
    Cell[363043, 11593, 305, 10, 15, "Index",
      CellTags->"PossibleCoalescenceOrder"],
    Cell[679367, 24370, 305, 10, 23, "Index",
      CellTags->"PossibleCoalescenceOrder"],
    Cell[977209, 36413, 305, 10, 15, "Index",
      CellTags->"PossibleCoalescenceOrder"],
    Cell[1267223, 48142, 305, 10, 23, "Index",
      CellTags->"PossibleCoalescenceOrder"],
    Cell[1547352, 59446, 305, 10, 23, "Index",
      CellTags->"PossibleCoalescenceOrder"],
    Cell[1813144, 70208, 305, 10, 15, "Index",
      CellTags->"PossibleCoalescenceOrder"]},
  "PossibleDiploidGenotypes"->{
    Cell[363351, 11605, 303, 10, 15, "Index",
      CellTags->"PossibleDiploidGenotypes"],
    Cell[679675, 24382, 303, 10, 23, "Index",
      CellTags->"PossibleDiploidGenotypes"],
    Cell[977517, 36425, 303, 10, 15, "Index",
      CellTags->"PossibleDiploidGenotypes"],
    Cell[1267531, 48154, 303, 10, 23, "Index",
      CellTags->"PossibleDiploidGenotypes"],
    Cell[1547660, 59458, 303, 10, 23, "Index",
      CellTags->"PossibleDiploidGenotypes"],
    Cell[1813452, 70220, 303, 10, 15, "Index",
      CellTags->"PossibleDiploidGenotypes"]},
  "PossibleGenotypes"->{
    Cell[363657, 11617, 272, 10, 15, "Index",
      CellTags->"PossibleGenotypes"],
    Cell[679981, 24394, 272, 10, 23, "Index",
      CellTags->"PossibleGenotypes"],
    Cell[977823, 36437, 272, 10, 15, "Index",
      CellTags->"PossibleGenotypes"],
    Cell[1267837, 48166, 272, 10, 23, "Index",
      CellTags->"PossibleGenotypes"],
    Cell[1547966, 59470, 272, 10, 23, "Index",
      CellTags->"PossibleGenotypes"],
    Cell[1813758, 70232, 272, 10, 15, "Index",
      CellTags->"PossibleGenotypes"]},
  "PossibleRootings"->{
    Cell[363932, 11629, 273, 10, 15, "Index",
      CellTags->"PossibleRootings"],
    Cell[680256, 24406, 273, 10, 23, "Index",
      CellTags->"PossibleRootings"],
    Cell[978098, 36449, 273, 10, 15, "Index",
      CellTags->"PossibleRootings"]},
  "PowerF"->{
    Cell[364208, 11641, 311, 11, 15, "Index",
      CellTags->"PowerF"],
    Cell[364522, 11654, 871, 27, 60, "IndexSubentry",
      CellTags->"PowerF"],
    Cell[680532, 24418, 311, 11, 23, "Index",
      CellTags->"PowerF"],
    Cell[680846, 24431, 871, 27, 68, "IndexSubentry",
      CellTags->"PowerF"],
    Cell[978374, 36461, 311, 11, 15, "Index",
      CellTags->"PowerF"],
    Cell[978688, 36474, 871, 27, 60, "IndexSubentry",
      CellTags->"PowerF"],
    Cell[1268112, 48178, 311, 11, 23, "Index",
      CellTags->"PowerF"],
    Cell[1268426, 48191, 871, 27, 68, "IndexSubentry",
      CellTags->"PowerF"],
    Cell[1548241, 59482, 311, 11, 23, "Index",
      CellTags->"PowerF"],
    Cell[1548555, 59495, 871, 27, 68, "IndexSubentry",
      CellTags->"PowerF"],
    Cell[1814033, 70244, 311, 11, 15, "Index",
      CellTags->"PowerF"],
    Cell[1814347, 70257, 871, 27, 60, "IndexSubentry",
      CellTags->"PowerF"]},
  "PresentOneWayTable"->{
    Cell[365396, 11683, 279, 10, 15, "Index",
      CellTags->"PresentOneWayTable"],
    Cell[681720, 24460, 279, 10, 23, "Index",
      CellTags->"PresentOneWayTable"],
    Cell[979562, 36503, 279, 10, 15, "Index",
      CellTags->"PresentOneWayTable"],
    Cell[1269300, 48220, 279, 10, 23, "Index",
      CellTags->"PresentOneWayTable"],
    Cell[1549429, 59524, 279, 10, 23, "Index",
      CellTags->"PresentOneWayTable"],
    Cell[1815221, 70286, 279, 10, 15, "Index",
      CellTags->"PresentOneWayTable"]},
  "PresentPairwiseTable"->{
    Cell[365678, 11695, 277, 10, 15, "Index",
      CellTags->"PresentPairwiseTable"],
    Cell[682002, 24472, 277, 10, 23, "Index",
      CellTags->"PresentPairwiseTable"],
    Cell[979844, 36515, 277, 10, 15, "Index",
      CellTags->"PresentPairwiseTable"],
    Cell[1269582, 48232, 277, 10, 23, "Index",
      CellTags->"PresentPairwiseTable"],
    Cell[1549711, 59536, 277, 10, 23, "Index",
      CellTags->"PresentPairwiseTable"],
    Cell[1815503, 70298, 277, 10, 15, "Index",
      CellTags->"PresentPairwiseTable"]},
  "PresentResults"->{
    Cell[365958, 11707, 265, 10, 15, "Index",
      CellTags->"PresentResults"],
    Cell[682282, 24484, 265, 10, 23, "Index",
      CellTags->"PresentResults"],
    Cell[980124, 36527, 265, 10, 15, "Index",
      CellTags->"PresentResults"],
    Cell[1269862, 48244, 265, 10, 23, "Index",
      CellTags->"PresentResults"],
    Cell[1549991, 59548, 265, 10, 23, "Index",
      CellTags->"PresentResults"],
    Cell[1815783, 70310, 265, 10, 15, "Index",
      CellTags->"PresentResults"]},
  "Principal components"->{
    Cell[366226, 11719, 317, 11, 15, "Index",
      CellTags->"Principal components"],
    Cell[682550, 24496, 317, 11, 23, "Index",
      CellTags->"Principal components"],
    Cell[980392, 36539, 317, 11, 15, "Index",
      CellTags->"Principal components"],
    Cell[1270130, 48256, 317, 11, 23, "Index",
      CellTags->"Principal components"]},
  "PrintDetails"->{
    Cell[366546, 11732, 273, 10, 15, "Index",
      CellTags->"PrintDetails"],
    Cell[366822, 11744, 321, 10, 15, "IndexSubentry",
      CellTags->"PrintDetails"],
    Cell[682870, 24509, 273, 10, 23, "Index",
      CellTags->"PrintDetails"],
    Cell[683146, 24521, 321, 10, 23, "IndexSubentry",
      CellTags->"PrintDetails"],
    Cell[980712, 36552, 273, 10, 15, "Index",
      CellTags->"PrintDetails"],
    Cell[1270450, 48269, 273, 10, 23, "Index",
      CellTags->"PrintDetails"],
    Cell[1550259, 59560, 273, 10, 23, "Index",
      CellTags->"PrintDetails"],
    Cell[1816051, 70322, 273, 10, 15, "Index",
      CellTags->"PrintDetails"]},
  "Problems"->{
    Cell[367146, 11756, 275, 11, 15, "Index",
      CellTags->"Problems"],
    Cell[367424, 11769, 587, 18, 15, "IndexSubentry",
      CellTags->"Problems"],
    Cell[683470, 24533, 275, 11, 23, "Index",
      CellTags->"Problems"],
    Cell[683748, 24546, 587, 18, 23, "IndexSubentry",
      CellTags->"Problems"],
    Cell[980988, 36564, 275, 11, 15, "Index",
      CellTags->"Problems"],
    Cell[981266, 36577, 587, 18, 15, "IndexSubentry",
      CellTags->"Problems"],
    Cell[1270726, 48281, 275, 11, 23, "Index",
      CellTags->"Problems"],
    Cell[1271004, 48294, 587, 18, 23, "IndexSubentry",
      CellTags->"Problems"],
    Cell[1550535, 59572, 275, 11, 23, "Index",
      CellTags->"Problems"],
    Cell[1550813, 59585, 587, 18, 23, "IndexSubentry",
      CellTags->"Problems"],
    Cell[1816327, 70334, 275, 11, 15, "Index",
      CellTags->"Problems"],
    Cell[1816605, 70347, 587, 18, 15, "IndexSubentry",
      CellTags->"Problems"]},
  "Products"->{
    Cell[368014, 11789, 250, 11, 15, "Index",
      CellTags->"Products"],
    Cell[684338, 24566, 250, 11, 23, "Index",
      CellTags->"Products"],
    Cell[981856, 36597, 250, 11, 15, "Index",
      CellTags->"Products"],
    Cell[1271594, 48314, 250, 11, 23, "Index",
      CellTags->"Products"],
    Cell[1551403, 59605, 250, 11, 23, "Index",
      CellTags->"Products"],
    Cell[1817195, 70367, 250, 11, 15, "Index",
      CellTags->"Products"]},
  "ProductSum"->{
    Cell[368267, 11802, 237, 10, 15, "Index",
      CellTags->"ProductSum"],
    Cell[368507, 11814, 249, 9, 15, "IndexSubentry",
      CellTags->"ProductSum"],
    Cell[684591, 24579, 237, 10, 23, "Index",
      CellTags->"ProductSum"],
    Cell[684831, 24591, 249, 9, 23, "IndexSubentry",
      CellTags->"ProductSum"],
    Cell[982109, 36610, 237, 10, 15, "Index",
      CellTags->"ProductSum"],
    Cell[982349, 36622, 249, 9, 15, "IndexSubentry",
      CellTags->"ProductSum"],
    Cell[1271847, 48327, 237, 10, 23, "Index",
      CellTags->"ProductSum"],
    Cell[1272087, 48339, 249, 9, 23, "IndexSubentry",
      CellTags->"ProductSum"],
    Cell[1551656, 59618, 237, 10, 23, "Index",
      CellTags->"ProductSum"],
    Cell[1551896, 59630, 249, 9, 23, "IndexSubentry",
      CellTags->"ProductSum"],
    Cell[1817448, 70380, 237, 10, 15, "Index",
      CellTags->"ProductSum"]},
  "QLE"->{
    Cell[368759, 11825, 263, 11, 15, "Index",
      CellTags->"QLE"],
    Cell[369025, 11838, 258, 9, 15, "IndexSubentry",
      CellTags->"QLE"],
    Cell[685083, 24602, 263, 11, 23, "Index",
      CellTags->"QLE"],
    Cell[685349, 24615, 258, 9, 23, "IndexSubentry",
      CellTags->"QLE"],
    Cell[982601, 36633, 263, 11, 15, "Index",
      CellTags->"QLE"],
    Cell[982867, 36646, 258, 9, 15, "IndexSubentry",
      CellTags->"QLE"],
    Cell[1272339, 48350, 263, 11, 23, "Index",
      CellTags->"QLE"],
    Cell[1272605, 48363, 258, 9, 23, "IndexSubentry",
      CellTags->"QLE"],
    Cell[1552148, 59641, 263, 11, 23, "Index",
      CellTags->"QLE"],
    Cell[1552414, 59654, 258, 9, 23, "IndexSubentry",
      CellTags->"QLE"]},
  "Quasi-linkage equilibrium"->{
    Cell[369286, 11849, 310, 11, 15, "Index",
      CellTags->"Quasi-linkage equilibrium"],
    Cell[685610, 24626, 310, 11, 23, "Index",
      CellTags->"Quasi-linkage equilibrium"],
    Cell[983128, 36657, 310, 11, 15, "Index",
      CellTags->"Quasi-linkage equilibrium"],
    Cell[1272866, 48374, 310, 11, 23, "Index",
      CellTags->"Quasi-linkage equilibrium"],
    Cell[1552675, 59665, 310, 11, 23, "Index",
      CellTags->"Quasi-linkage equilibrium"]},
  "RandomBottleneckedGenealogy"->{
    Cell[369599, 11862, 312, 10, 15, "Index",
      CellTags->"RandomBottleneckedGenealogy"],
    Cell[685923, 24639, 312, 10, 23, "Index",
      CellTags->"RandomBottleneckedGenealogy"],
    Cell[983441, 36670, 312, 10, 15, "Index",
      CellTags->"RandomBottleneckedGenealogy"],
    Cell[1273179, 48387, 312, 10, 23, "Index",
      CellTags->"RandomBottleneckedGenealogy"],
    Cell[1552988, 59678, 312, 10, 23, "Index",
      CellTags->"RandomBottleneckedGenealogy"],
    Cell[1817958, 70404, 312, 10, 15, "Index",
      CellTags->"RandomBottleneckedGenealogy"]},
  "RandomCoalescenceOrder"->{
    Cell[369914, 11874, 299, 10, 15, "Index",
      CellTags->"RandomCoalescenceOrder"],
    Cell[686238, 24651, 299, 10, 23, "Index",
      CellTags->"RandomCoalescenceOrder"],
    Cell[983756, 36682, 299, 10, 15, "Index",
      CellTags->"RandomCoalescenceOrder"],
    Cell[1273494, 48399, 299, 10, 23, "Index",
      CellTags->"RandomCoalescenceOrder"],
    Cell[1553303, 59690, 299, 10, 23, "Index",
      CellTags->"RandomCoalescenceOrder"],
    Cell[1818273, 70416, 299, 10, 15, "Index",
      CellTags->"RandomCoalescenceOrder"]},
  "RandomCoalescenceTimes"->{
    Cell[370216, 11886, 326, 11, 15, "Index",
      CellTags->"RandomCoalescenceTimes"],
    Cell[370545, 11899, 300, 9, 15, "IndexSubentry",
      CellTags->"RandomCoalescenceTimes"],
    Cell[686540, 24663, 326, 11, 23, "Index",
      CellTags->"RandomCoalescenceTimes"],
    Cell[686869, 24676, 300, 9, 23, "IndexSubentry",
      CellTags->"RandomCoalescenceTimes"],
    Cell[984058, 36694, 326, 11, 15, "Index",
      CellTags->"RandomCoalescenceTimes"],
    Cell[1273796, 48411, 326, 11, 23, "Index",
      CellTags->"RandomCoalescenceTimes"],
    Cell[1553605, 59702, 326, 11, 23, "Index",
      CellTags->"RandomCoalescenceTimes"],
    Cell[1818575, 70428, 326, 11, 15, "Index",
      CellTags->"RandomCoalescenceTimes"]},
  "RandomCum"->{
    Cell[370848, 11910, 288, 10, 15, "Index",
      CellTags->"RandomCum"],
    Cell[687172, 24687, 288, 10, 23, "Index",
      CellTags->"RandomCum"],
    Cell[984387, 36707, 288, 10, 15, "Index",
      CellTags->"RandomCum"],
    Cell[1274125, 48424, 288, 10, 23, "Index",
      CellTags->"RandomCum"],
    Cell[1553934, 59715, 288, 10, 23, "Index",
      CellTags->"RandomCum"],
    Cell[1818904, 70441, 288, 10, 15, "Index",
      CellTags->"RandomCum"]},
  "Random drift"->{
    Cell[371139, 11922, 330, 12, 15, "Index",
      CellTags->"Random drift"],
    Cell[371472, 11936, 2349, 77, 150, "IndexSubentry",
      CellTags->"Random drift"],
    Cell[687463, 24699, 330, 12, 23, "Index",
      CellTags->"Random drift"],
    Cell[687796, 24713, 2349, 77, 158, "IndexSubentry",
      CellTags->"Random drift"],
    Cell[984678, 36719, 330, 12, 15, "Index",
      CellTags->"Random drift"],
    Cell[985011, 36733, 2349, 77, 150, "IndexSubentry",
      CellTags->"Random drift"],
    Cell[1274416, 48436, 330, 12, 23, "Index",
      CellTags->"Random drift"],
    Cell[1274749, 48450, 2349, 77, 158, "IndexSubentry",
      CellTags->"Random drift"],
    Cell[1554225, 59727, 330, 12, 23, "Index",
      CellTags->"Random drift"],
    Cell[1554558, 59741, 2349, 77, 158, "IndexSubentry",
      CellTags->"Random drift"],
    Cell[1819195, 70453, 330, 12, 15, "Index",
      CellTags->"Random drift"],
    Cell[1819528, 70467, 2349, 77, 150, "IndexSubentry",
      CellTags->"Random drift"]},
  "RandomDrift"->{
    Cell[373824, 12015, 286, 11, 15, "Index",
      CellTags->"RandomDrift"],
    Cell[374113, 12028, 956, 27, 30, "IndexSubentry",
      CellTags->"RandomDrift"],
    Cell[690148, 24792, 286, 11, 23, "Index",
      CellTags->"RandomDrift"],
    Cell[690437, 24805, 956, 27, 38, "IndexSubentry",
      CellTags->"RandomDrift"],
    Cell[987363, 36812, 286, 11, 15, "Index",
      CellTags->"RandomDrift"],
    Cell[987652, 36825, 956, 27, 30, "IndexSubentry",
      CellTags->"RandomDrift"],
    Cell[1277101, 48529, 286, 11, 23, "Index",
      CellTags->"RandomDrift"],
    Cell[1277390, 48542, 956, 27, 38, "IndexSubentry",
      CellTags->"RandomDrift"],
    Cell[1556910, 59820, 286, 11, 23, "Index",
      CellTags->"RandomDrift"],
    Cell[1557199, 59833, 956, 27, 38, "IndexSubentry",
      CellTags->"RandomDrift"],
    Cell[1821880, 70546, 286, 11, 15, "Index",
      CellTags->"RandomDrift"],
    Cell[1822169, 70559, 956, 27, 30, "IndexSubentry",
      CellTags->"RandomDrift"]},
  "RandomFamilies"->{
    Cell[375072, 12057, 259, 10, 15, "Index",
      CellTags->"RandomFamilies"],
    Cell[691396, 24834, 259, 10, 23, "Index",
      CellTags->"RandomFamilies"],
    Cell[988611, 36854, 259, 10, 15, "Index",
      CellTags->"RandomFamilies"],
    Cell[1278349, 48571, 259, 10, 23, "Index",
      CellTags->"RandomFamilies"],
    Cell[1558158, 59862, 259, 10, 23, "Index",
      CellTags->"RandomFamilies"],
    Cell[1823128, 70588, 259, 10, 15, "Index",
      CellTags->"RandomFamilies"]},
  "RandomFamily"->{
    Cell[375334, 12069, 261, 10, 15, "Index",
      CellTags->"RandomFamily"],
    Cell[375598, 12081, 273, 9, 15, "IndexSubentry",
      CellTags->"RandomFamily"],
    Cell[691658, 24846, 261, 10, 23, "Index",
      CellTags->"RandomFamily"],
    Cell[691922, 24858, 273, 9, 23, "IndexSubentry",
      CellTags->"RandomFamily"],
    Cell[988873, 36866, 261, 10, 15, "Index",
      CellTags->"RandomFamily"],
    Cell[989137, 36878, 273, 9, 15, "IndexSubentry",
      CellTags->"RandomFamily"],
    Cell[1278611, 48583, 261, 10, 23, "Index",
      CellTags->"RandomFamily"],
    Cell[1278875, 48595, 273, 9, 23, "IndexSubentry",
      CellTags->"RandomFamily"],
    Cell[1558420, 59874, 261, 10, 23, "Index",
      CellTags->"RandomFamily"],
    Cell[1558684, 59886, 273, 9, 23, "IndexSubentry",
      CellTags->"RandomFamily"],
    Cell[1823390, 70600, 261, 10, 15, "Index",
      CellTags->"RandomFamily"],
    Cell[1823654, 70612, 273, 9, 15, "IndexSubentry",
      CellTags->"RandomFamily"]},
  "Random genealogies"->{
    Cell[375874, 12092, 299, 11, 15, "Index",
      CellTags->"Random genealogies"],
    Cell[692198, 24869, 299, 11, 23, "Index",
      CellTags->"Random genealogies"],
    Cell[989413, 36889, 299, 11, 15, "Index",
      CellTags->"Random genealogies"],
    Cell[1279151, 48606, 299, 11, 23, "Index",
      CellTags->"Random genealogies"],
    Cell[1558960, 59897, 299, 11, 23, "Index",
      CellTags->"Random genealogies"],
    Cell[1823930, 70623, 299, 11, 15, "Index",
      CellTags->"Random genealogies"]},
  "RandomGenealogy"->{
    Cell[376176, 12105, 270, 10, 15, "Index",
      CellTags->"RandomGenealogy"],
    Cell[376449, 12117, 286, 9, 15, "IndexSubentry",
      CellTags->"RandomGenealogy"],
    Cell[692500, 24882, 270, 10, 23, "Index",
      CellTags->"RandomGenealogy"],
    Cell[692773, 24894, 286, 9, 23, "IndexSubentry",
      CellTags->"RandomGenealogy"],
    Cell[989715, 36902, 270, 10, 15, "Index",
      CellTags->"RandomGenealogy"],
    Cell[1279453, 48619, 270, 10, 23, "Index",
      CellTags->"RandomGenealogy"],
    Cell[1559262, 59910, 270, 10, 23, "Index",
      CellTags->"RandomGenealogy"],
    Cell[1824232, 70636, 270, 10, 15, "Index",
      CellTags->"RandomGenealogy"]},
  "RandomList"->{
    Cell[376738, 12128, 241, 10, 15, "Index",
      CellTags->"RandomList"],
    Cell[376982, 12140, 259, 9, 15, "IndexSubentry",
      CellTags->"RandomList"],
    Cell[693062, 24905, 241, 10, 23, "Index",
      CellTags->"RandomList"],
    Cell[693306, 24917, 259, 9, 23, "IndexSubentry",
      CellTags->"RandomList"],
    Cell[989988, 36914, 241, 10, 15, "Index",
      CellTags->"RandomList"],
    Cell[990232, 36926, 259, 9, 15, "IndexSubentry",
      CellTags->"RandomList"],
    Cell[1279726, 48631, 241, 10, 23, "Index",
      CellTags->"RandomList"],
    Cell[1279970, 48643, 259, 9, 23, "IndexSubentry",
      CellTags->"RandomList"],
    Cell[1559535, 59922, 241, 10, 23, "Index",
      CellTags->"RandomList"],
    Cell[1559779, 59934, 259, 9, 23, "IndexSubentry",
      CellTags->"RandomList"],
    Cell[1824505, 70648, 241, 10, 15, "Index",
      CellTags->"RandomList"],
    Cell[1824749, 70660, 259, 9, 15, "IndexSubentry",
      CellTags->"RandomList"]},
  "Random lists"->{
    Cell[377244, 12151, 259, 11, 15, "Index",
      CellTags->"Random lists"],
    Cell[693568, 24928, 259, 11, 23, "Index",
      CellTags->"Random lists"],
    Cell[990494, 36937, 259, 11, 15, "Index",
      CellTags->"Random lists"],
    Cell[1280232, 48654, 259, 11, 23, "Index",
      CellTags->"Random lists"],
    Cell[1560041, 59945, 259, 11, 23, "Index",
      CellTags->"Random lists"],
    Cell[1825011, 70671, 259, 11, 15, "Index",
      CellTags->"Random lists"]},
  "RandomMating"->{
    Cell[377506, 12164, 289, 10, 15, "Index",
      CellTags->"RandomMating"],
    Cell[693830, 24941, 289, 10, 23, "Index",
      CellTags->"RandomMating"],
    Cell[990756, 36950, 289, 10, 15, "Index",
      CellTags->"RandomMating"],
    Cell[1280494, 48667, 289, 10, 23, "Index",
      CellTags->"RandomMating"],
    Cell[1560303, 59958, 289, 10, 23, "Index",
      CellTags->"RandomMating"],
    Cell[1825273, 70684, 289, 10, 15, "Index",
      CellTags->"RandomMating"]},
  "RandomMultinomial"->{
    Cell[377798, 12176, 286, 10, 15, "Index",
      CellTags->"RandomMultinomial"],
    Cell[694122, 24953, 286, 10, 23, "Index",
      CellTags->"RandomMultinomial"],
    Cell[991048, 36962, 286, 10, 15, "Index",
      CellTags->"RandomMultinomial"],
    Cell[1280786, 48679, 286, 10, 23, "Index",
      CellTags->"RandomMultinomial"],
    Cell[1560595, 59970, 286, 10, 23, "Index",
      CellTags->"RandomMultinomial"],
    Cell[1825565, 70696, 286, 10, 15, "Index",
      CellTags->"RandomMultinomial"]},
  "RandomPreviousFamily"->{
    Cell[378087, 12188, 277, 10, 15, "Index",
      CellTags->"RandomPreviousFamily"],
    Cell[694411, 24965, 277, 10, 23, "Index",
      CellTags->"RandomPreviousFamily"],
    Cell[991337, 36974, 277, 10, 15, "Index",
      CellTags->"RandomPreviousFamily"],
    Cell[1281075, 48691, 277, 10, 23, "Index",
      CellTags->"RandomPreviousFamily"],
    Cell[1560884, 59982, 277, 10, 23, "Index",
      CellTags->"RandomPreviousFamily"],
    Cell[1825854, 70708, 277, 10, 15, "Index",
      CellTags->"RandomPreviousFamily"]},
  "Random sampling"->{
    Cell[378367, 12200, 288, 10, 15, "Index",
      CellTags->"Random sampling"],
    Cell[378658, 12212, 415, 15, 30, "IndexSubentry",
      CellTags->"Random sampling"],
    Cell[694691, 24977, 288, 10, 23, "Index",
      CellTags->"Random sampling"],
    Cell[694982, 24989, 415, 15, 38, "IndexSubentry",
      CellTags->"Random sampling"],
    Cell[991617, 36986, 288, 10, 15, "Index",
      CellTags->"Random sampling"],
    Cell[991908, 36998, 415, 15, 30, "IndexSubentry",
      CellTags->"Random sampling"],
    Cell[1281355, 48703, 288, 10, 23, "Index",
      CellTags->"Random sampling"],
    Cell[1281646, 48715, 415, 15, 38, "IndexSubentry",
      CellTags->"Random sampling"],
    Cell[1561164, 59994, 288, 10, 23, "Index",
      CellTags->"Random sampling"],
    Cell[1561455, 60006, 415, 15, 38, "IndexSubentry",
      CellTags->"Random sampling"],
    Cell[1826134, 70720, 288, 10, 15, "Index",
      CellTags->"Random sampling"],
    Cell[1826425, 70732, 415, 15, 30, "IndexSubentry",
      CellTags->"Random sampling"]},
  "RandomSet"->{
    Cell[379076, 12229, 236, 10, 15, "Index",
      CellTags->"RandomSet"],
    Cell[695400, 25006, 236, 10, 23, "Index",
      CellTags->"RandomSet"],
    Cell[992326, 37015, 236, 10, 15, "Index",
      CellTags->"RandomSet"],
    Cell[1282064, 48732, 236, 10, 23, "Index",
      CellTags->"RandomSet"],
    Cell[1561873, 60023, 236, 10, 23, "Index",
      CellTags->"RandomSet"],
    Cell[1826843, 70749, 236, 10, 15, "Index",
      CellTags->"RandomSet"]},
  "Random union"->{
    Cell[379315, 12241, 371, 14, 15, "Index",
      CellTags->"Random union"],
    Cell[379689, 12257, 306, 9, 15, "IndexSubentry",
      CellTags->"Random union"],
    Cell[695639, 25018, 371, 14, 23, "Index",
      CellTags->"Random union"],
    Cell[696013, 25034, 306, 9, 23, "IndexSubentry",
      CellTags->"Random union"],
    Cell[992565, 37027, 371, 14, 15, "Index",
      CellTags->"Random union"],
    Cell[992939, 37043, 306, 9, 15, "IndexSubentry",
      CellTags->"Random union"],
    Cell[1282303, 48744, 371, 14, 23, "Index",
      CellTags->"Random union"],
    Cell[1282677, 48760, 306, 9, 23, "IndexSubentry",
      CellTags->"Random union"],
    Cell[1562112, 60035, 371, 14, 23, "Index",
      CellTags->"Random union"],
    Cell[1562486, 60051, 306, 9, 23, "IndexSubentry",
      CellTags->"Random union"],
    Cell[1827082, 70761, 371, 14, 15, "Index",
      CellTags->"Random union"],
    Cell[1827456, 70777, 306, 9, 15, "IndexSubentry",
      CellTags->"Random union"]},
  "RandomUnion"->{
    Cell[379998, 12268, 244, 10, 15, "Index",
      CellTags->"RandomUnion"],
    Cell[696322, 25045, 244, 10, 23, "Index",
      CellTags->"RandomUnion"],
    Cell[993248, 37054, 244, 10, 15, "Index",
      CellTags->"RandomUnion"],
    Cell[1282986, 48771, 244, 10, 23, "Index",
      CellTags->"RandomUnion"],
    Cell[1562795, 60062, 244, 10, 23, "Index",
      CellTags->"RandomUnion"],
    Cell[1827765, 70788, 244, 10, 15, "Index",
      CellTags->"RandomUnion"]},
  "RandomUnionMethod"->{
    Cell[380245, 12280, 276, 10, 15, "Index",
      CellTags->"RandomUnionMethod"],
    Cell[696569, 25057, 276, 10, 23, "Index",
      CellTags->"RandomUnionMethod"],
    Cell[993495, 37066, 276, 10, 15, "Index",
      CellTags->"RandomUnionMethod"],
    Cell[1283233, 48783, 276, 10, 23, "Index",
      CellTags->"RandomUnionMethod"],
    Cell[1563042, 60074, 276, 10, 23, "Index",
      CellTags->"RandomUnionMethod"],
    Cell[1828012, 70800, 276, 10, 15, "Index",
      CellTags->"RandomUnionMethod"]},
  "RandomUnionObsolete"->{
    Cell[380524, 12292, 260, 10, 15, "Index",
      CellTags->"RandomUnionObsolete"],
    Cell[696848, 25069, 260, 10, 23, "Index",
      CellTags->"RandomUnionObsolete"],
    Cell[993774, 37078, 260, 10, 15, "Index",
      CellTags->"RandomUnionObsolete"],
    Cell[1283512, 48795, 260, 10, 23, "Index",
      CellTags->"RandomUnionObsolete"],
    Cell[1563321, 60086, 260, 10, 23, "Index",
      CellTags->"RandomUnionObsolete"],
    Cell[1828291, 70812, 260, 10, 15, "Index",
      CellTags->"RandomUnionObsolete"]},
  "Random walk"->{
    Cell[380787, 12304, 256, 11, 15, "Index",
      CellTags->"Random walk"],
    Cell[697111, 25081, 256, 11, 23, "Index",
      CellTags->"Random walk"],
    Cell[994037, 37090, 256, 11, 15, "Index",
      CellTags->"Random walk"],
    Cell[1283775, 48807, 256, 11, 23, "Index",
      CellTags->"Random walk"],
    Cell[1563584, 60098, 256, 11, 23, "Index",
      CellTags->"Random walk"],
    Cell[1828554, 70824, 256, 11, 15, "Index",
      CellTags->"Random walk"]},
  "RecombinantLineages"->{
    Cell[381046, 12317, 325, 11, 15, "Index",
      CellTags->"RecombinantLineages"],
    Cell[697370, 25094, 325, 11, 23, "Index",
      CellTags->"RecombinantLineages"]},
  "Recombination"->{
    Cell[381374, 12330, 378, 14, 15, "Index",
      CellTags->"Recombination"],
    Cell[381755, 12346, 1122, 39, 90, "IndexSubentry",
      CellTags->"Recombination"],
    Cell[697698, 25107, 378, 14, 23, "Index",
      CellTags->"Recombination"],
    Cell[698079, 25123, 1122, 39, 98, "IndexSubentry",
      CellTags->"Recombination"],
    Cell[994296, 37103, 378, 14, 15, "Index",
      CellTags->"Recombination"],
    Cell[994677, 37119, 1122, 39, 90, "IndexSubentry",
      CellTags->"Recombination"],
    Cell[1284034, 48820, 378, 14, 23, "Index",
      CellTags->"Recombination"],
    Cell[1284415, 48836, 1122, 39, 98, "IndexSubentry",
      CellTags->"Recombination"],
    Cell[1563843, 60111, 378, 14, 23, "Index",
      CellTags->"Recombination"],
    Cell[1564224, 60127, 796, 27, 68, "IndexSubentry",
      CellTags->"Recombination"],
    Cell[1828813, 70837, 378, 14, 15, "Index",
      CellTags->"Recombination"],
    Cell[1829194, 70853, 796, 27, 60, "IndexSubentry",
      CellTags->"Recombination"]},
  "RecombinationEvents"->{
    Cell[382880, 12387, 325, 11, 15, "Index",
      CellTags->"RecombinationEvents"],
    Cell[699204, 25164, 325, 11, 23, "Index",
      CellTags->"RecombinationEvents"]},
  "RecombinationRate"->{
    Cell[383208, 12400, 321, 11, 15, "Index",
      CellTags->"RecombinationRate"],
    Cell[699532, 25177, 321, 11, 23, "Index",
      CellTags->"RecombinationRate"],
    Cell[995802, 37160, 321, 11, 15, "Index",
      CellTags->"RecombinationRate"],
    Cell[1285540, 48877, 321, 11, 23, "Index",
      CellTags->"RecombinationRate"],
    Cell[1565023, 60156, 321, 11, 23, "Index",
      CellTags->"RecombinationRate"],
    Cell[1829993, 70882, 321, 11, 15, "Index",
      CellTags->"RecombinationRate"]},
  "RecombinationSet"->{
    Cell[383532, 12413, 450, 15, 15, "Index",
      CellTags->"RecombinationSet"],
    Cell[699856, 25190, 450, 15, 23, "Index",
      CellTags->"RecombinationSet"],
    Cell[996126, 37173, 450, 15, 15, "Index",
      CellTags->"RecombinationSet"],
    Cell[1285864, 48890, 450, 15, 23, "Index",
      CellTags->"RecombinationSet"],
    Cell[1565347, 60169, 450, 15, 23, "Index",
      CellTags->"RecombinationSet"],
    Cell[1830317, 70895, 450, 15, 15, "Index",
      CellTags->"RecombinationSet"]},
  "Recombined"->{
    Cell[383985, 12430, 283, 10, 15, "Index",
      CellTags->"Recombined"],
    Cell[700309, 25207, 283, 10, 23, "Index",
      CellTags->"Recombined"],
    Cell[996579, 37190, 283, 10, 15, "Index",
      CellTags->"Recombined"],
    Cell[1286317, 48907, 283, 10, 23, "Index",
      CellTags->"Recombined"],
    Cell[1565800, 60186, 283, 10, 23, "Index",
      CellTags->"Recombined"],
    Cell[1830770, 70912, 283, 10, 15, "Index",
      CellTags->"Recombined"]},
  "RecombineLineage"->{
    Cell[384271, 12442, 293, 10, 15, "Index",
      CellTags->"RecombineLineage"],
    Cell[700595, 25219, 293, 10, 23, "Index",
      CellTags->"RecombineLineage"]},
  "ReducedData"->{
    Cell[384567, 12454, 262, 10, 15, "Index",
      CellTags->"ReducedData"],
    Cell[700891, 25231, 262, 10, 23, "Index",
      CellTags->"ReducedData"],
    Cell[996865, 37202, 262, 10, 15, "Index",
      CellTags->"ReducedData"],
    Cell[1286603, 48919, 262, 10, 23, "Index",
      CellTags->"ReducedData"],
    Cell[1566086, 60198, 262, 10, 23, "Index",
      CellTags->"ReducedData"],
    Cell[1831056, 70924, 262, 10, 15, "Index",
      CellTags->"ReducedData"]},
  "ReferencePoint"->{
    Cell[384832, 12466, 316, 11, 15, "Index",
      CellTags->"ReferencePoint"],
    Cell[701156, 25243, 316, 11, 23, "Index",
      CellTags->"ReferencePoint"],
    Cell[997130, 37214, 316, 11, 15, "Index",
      CellTags->"ReferencePoint"],
    Cell[1286868, 48931, 316, 11, 23, "Index",
      CellTags->"ReferencePoint"],
    Cell[1566351, 60210, 316, 11, 23, "Index",
      CellTags->"ReferencePoint"],
    Cell[1831321, 70936, 316, 11, 15, "Index",
      CellTags->"ReferencePoint"]},
  "ReferencePointMean"->{
    Cell[385151, 12479, 273, 10, 15, "Index",
      CellTags->"ReferencePointMean"],
    Cell[385427, 12491, 1125, 37, 45, "IndexSubentry",
      CellTags->"ReferencePointMean"],
    Cell[701475, 25256, 273, 10, 23, "Index",
      CellTags->"ReferencePointMean"],
    Cell[701751, 25268, 1125, 37, 53, "IndexSubentry",
      CellTags->"ReferencePointMean"],
    Cell[997449, 37227, 273, 10, 15, "Index",
      CellTags->"ReferencePointMean"],
    Cell[997725, 37239, 1125, 37, 45, "IndexSubentry",
      CellTags->"ReferencePointMean"],
    Cell[1287187, 48944, 273, 10, 23, "Index",
      CellTags->"ReferencePointMean"],
    Cell[1287463, 48956, 1125, 37, 53, "IndexSubentry",
      CellTags->"ReferencePointMean"],
    Cell[1566670, 60223, 273, 10, 23, "Index",
      CellTags->"ReferencePointMean"],
    Cell[1566946, 60235, 1125, 37, 53, "IndexSubentry",
      CellTags->"ReferencePointMean"],
    Cell[1831640, 70949, 273, 10, 15, "Index",
      CellTags->"ReferencePointMean"],
    Cell[1831916, 70961, 819, 27, 30, "IndexSubentry",
      CellTags->"ReferencePointMean"]},
  "ReferencePointSame"->{
    Cell[386555, 12530, 273, 10, 15, "Index",
      CellTags->"ReferencePointSame"],
    Cell[702879, 25307, 273, 10, 23, "Index",
      CellTags->"ReferencePointSame"],
    Cell[998853, 37278, 273, 10, 15, "Index",
      CellTags->"ReferencePointSame"],
    Cell[1288591, 48995, 273, 10, 23, "Index",
      CellTags->"ReferencePointSame"],
    Cell[1568074, 60274, 273, 10, 23, "Index",
      CellTags->"ReferencePointSame"],
    Cell[1832738, 70990, 273, 10, 15, "Index",
      CellTags->"ReferencePointSame"]},
  "ReferencePointZero"->{
    Cell[386831, 12542, 273, 10, 15, "Index",
      CellTags->"ReferencePointZero"],
    Cell[703155, 25319, 273, 10, 23, "Index",
      CellTags->"ReferencePointZero"],
    Cell[999129, 37290, 273, 10, 15, "Index",
      CellTags->"ReferencePointZero"],
    Cell[1288867, 49007, 273, 10, 23, "Index",
      CellTags->"ReferencePointZero"],
    Cell[1568350, 60286, 273, 10, 23, "Index",
      CellTags->"ReferencePointZero"],
    Cell[1833014, 71002, 273, 10, 15, "Index",
      CellTags->"ReferencePointZero"]},
  "References"->{
    Cell[387107, 12554, 289, 11, 15, "Index",
      CellTags->"References"],
    Cell[703431, 25331, 289, 11, 23, "Index",
      CellTags->"References"]},
  "Reference values"->{
    Cell[387399, 12567, 400, 14, 15, "Index",
      CellTags->"Reference values"],
    Cell[387802, 12583, 472, 15, 30, "IndexSubentry",
      CellTags->"Reference values"],
    Cell[703723, 25344, 400, 14, 23, "Index",
      CellTags->"Reference values"],
    Cell[704126, 25360, 472, 15, 38, "IndexSubentry",
      CellTags->"Reference values"],
    Cell[999405, 37302, 400, 14, 15, "Index",
      CellTags->"Reference values"],
    Cell[999808, 37318, 472, 15, 30, "IndexSubentry",
      CellTags->"Reference values"],
    Cell[1289143, 49019, 400, 14, 23, "Index",
      CellTags->"Reference values"],
    Cell[1289546, 49035, 472, 15, 38, "IndexSubentry",
      CellTags->"Reference values"],
    Cell[1568626, 60298, 400, 14, 23, "Index",
      CellTags->"Reference values"],
    Cell[1569029, 60314, 472, 15, 38, "IndexSubentry",
      CellTags->"Reference values"],
    Cell[1833290, 71014, 382, 14, 15, "Index",
      CellTags->"Reference values"],
    Cell[1833675, 71030, 273, 9, 15, "IndexSubentry",
      CellTags->"Reference values"]},
  "RemoveTag"->{
    Cell[388277, 12600, 238, 10, 15, "Index",
      CellTags->"RemoveTag"],
    Cell[704601, 25377, 238, 10, 23, "Index",
      CellTags->"RemoveTag"],
    Cell[1000283, 37335, 238, 10, 15, "Index",
      CellTags->"RemoveTag"],
    Cell[1290021, 49052, 238, 10, 23, "Index",
      CellTags->"RemoveTag"],
    Cell[1569504, 60331, 238, 10, 23, "Index",
      CellTags->"RemoveTag"],
    Cell[1833951, 71041, 238, 10, 15, "Index",
      CellTags->"RemoveTag"]},
  "Repeat"->{
    Cell[388518, 12612, 239, 10, 15, "Index",
      CellTags->"Repeat"],
    Cell[704842, 25389, 239, 10, 23, "Index",
      CellTags->"Repeat"],
    Cell[1000524, 37347, 239, 10, 15, "Index",
      CellTags->"Repeat"],
    Cell[1290262, 49064, 239, 10, 23, "Index",
      CellTags->"Repeat"],
    Cell[1569745, 60343, 239, 10, 23, "Index",
      CellTags->"Repeat"],
    Cell[1834192, 71053, 239, 10, 15, "Index",
      CellTags->"Repeat"]},
  "Replace"->{
    Cell[388760, 12624, 232, 10, 15, "Index",
      CellTags->"Replace"],
    Cell[705084, 25401, 232, 10, 23, "Index",
      CellTags->"Replace"],
    Cell[1000766, 37359, 232, 10, 15, "Index",
      CellTags->"Replace"],
    Cell[1290504, 49076, 232, 10, 23, "Index",
      CellTags->"Replace"],
    Cell[1569987, 60355, 232, 10, 23, "Index",
      CellTags->"Replace"],
    Cell[1834434, 71065, 232, 10, 15, "Index",
      CellTags->"Replace"]},
  "ReplaceAllSpecial"->{
    Cell[388995, 12636, 262, 11, 15, "Index",
      CellTags->"ReplaceAllSpecial"],
    Cell[705319, 25413, 262, 11, 23, "Index",
      CellTags->"ReplaceAllSpecial"],
    Cell[1001001, 37371, 262, 11, 15, "Index",
      CellTags->"ReplaceAllSpecial"],
    Cell[1290739, 49088, 262, 11, 23, "Index",
      CellTags->"ReplaceAllSpecial"],
    Cell[1570222, 60367, 262, 11, 23, "Index",
      CellTags->"ReplaceAllSpecial"],
    Cell[1834669, 71077, 262, 11, 15, "Index",
      CellTags->"ReplaceAllSpecial"]},
  "ReplaceRepeatedSpecial"->{
    Cell[389260, 12649, 278, 11, 15, "Index",
      CellTags->"ReplaceRepeatedSpecial"],
    Cell[705584, 25426, 278, 11, 23, "Index",
      CellTags->"ReplaceRepeatedSpecial"],
    Cell[1001266, 37384, 278, 11, 15, "Index",
      CellTags->"ReplaceRepeatedSpecial"],
    Cell[1291004, 49101, 278, 11, 23, "Index",
      CellTags->"ReplaceRepeatedSpecial"],
    Cell[1570487, 60380, 278, 11, 23, "Index",
      CellTags->"ReplaceRepeatedSpecial"],
    Cell[1834934, 71090, 278, 11, 15, "Index",
      CellTags->"ReplaceRepeatedSpecial"]},
  "Representations"->{
    Cell[389541, 12662, 311, 11, 15, "Index",
      CellTags->"Representations"],
    Cell[389855, 12675, 308, 10, 15, "IndexSubentry",
      CellTags->"Representations"],
    Cell[705865, 25439, 311, 11, 23, "Index",
      CellTags->"Representations"],
    Cell[706179, 25452, 308, 10, 23, "IndexSubentry",
      CellTags->"Representations"],
    Cell[1001547, 37397, 311, 11, 15, "Index",
      CellTags->"Representations"],
    Cell[1001861, 37410, 308, 10, 15, "IndexSubentry",
      CellTags->"Representations"],
    Cell[1291285, 49114, 311, 11, 23, "Index",
      CellTags->"Representations"],
    Cell[1291599, 49127, 308, 10, 23, "IndexSubentry",
      CellTags->"Representations"],
    Cell[1570768, 60393, 311, 11, 23, "Index",
      CellTags->"Representations"],
    Cell[1571082, 60406, 308, 10, 23, "IndexSubentry",
      CellTags->"Representations"],
    Cell[1835215, 71103, 311, 11, 15, "Index",
      CellTags->"Representations"],
    Cell[1835529, 71116, 308, 10, 15, "IndexSubentry",
      CellTags->"Representations"]},
  "Reproduction"->{
    Cell[390166, 12687, 286, 11, 15, "Index",
      CellTags->"Reproduction"],
    Cell[706490, 25464, 286, 11, 23, "Index",
      CellTags->"Reproduction"],
    Cell[1002172, 37422, 286, 11, 15, "Index",
      CellTags->"Reproduction"],
    Cell[1291910, 49139, 286, 11, 23, "Index",
      CellTags->"Reproduction"],
    Cell[1571393, 60418, 286, 11, 23, "Index",
      CellTags->"Reproduction"],
    Cell[1835840, 71128, 286, 11, 15, "Index",
      CellTags->"Reproduction"]},
  "Reverse"->{
    Cell[390455, 12700, 222, 10, 15, "Index",
      CellTags->"Reverse"],
    Cell[706779, 25477, 222, 10, 23, "Index",
      CellTags->"Reverse"],
    Cell[1002461, 37435, 222, 10, 15, "Index",
      CellTags->"Reverse"],
    Cell[1292199, 49152, 222, 10, 23, "Index",
      CellTags->"Reverse"],
    Cell[1571682, 60431, 222, 10, 23, "Index",
      CellTags->"Reverse"],
    Cell[1836129, 71141, 222, 10, 15, "Index",
      CellTags->"Reverse"]},
  "Root"->{
    Cell[390680, 12712, 401, 15, 15, "Index",
      CellTags->"Root"],
    Cell[707004, 25489, 401, 15, 23, "Index",
      CellTags->"Root"],
    Cell[1002686, 37447, 401, 15, 15, "Index",
      CellTags->"Root"]},
  "RootedGenealogy"->{
    Cell[391084, 12729, 280, 10, 15, "Index",
      CellTags->"RootedGenealogy"],
    Cell[707408, 25506, 280, 10, 23, "Index",
      CellTags->"RootedGenealogy"],
    Cell[1003090, 37464, 280, 10, 15, "Index",
      CellTags->"RootedGenealogy"],
    Cell[1292424, 49164, 280, 10, 23, "Index",
      CellTags->"RootedGenealogy"],
    Cell[1571907, 60443, 280, 10, 23, "Index",
      CellTags->"RootedGenealogy"],
    Cell[1836354, 71153, 280, 10, 15, "Index",
      CellTags->"RootedGenealogy"]},
  "RootEvents"->{
    Cell[391367, 12741, 298, 11, 15, "Index",
      CellTags->"RootEvents"],
    Cell[707691, 25518, 298, 11, 23, "Index",
      CellTags->"RootEvents"]},
  "Rootings"->{
    Cell[391668, 12754, 289, 11, 15, "Index",
      CellTags->"Rootings"],
    Cell[707992, 25531, 289, 11, 23, "Index",
      CellTags->"Rootings"],
    Cell[1003373, 37476, 289, 11, 15, "Index",
      CellTags->"Rootings"]},
  "Rules"->{
    Cell[391960, 12767, 244, 10, 15, "Index",
      CellTags->"Rules"],
    Cell[392207, 12779, 234, 9, 15, "IndexSubentry",
      CellTags->"Rules"],
    Cell[708284, 25544, 244, 10, 23, "Index",
      CellTags->"Rules"],
    Cell[708531, 25556, 234, 9, 23, "IndexSubentry",
      CellTags->"Rules"],
    Cell[1003665, 37489, 244, 10, 15, "Index",
      CellTags->"Rules"],
    Cell[1003912, 37501, 234, 9, 15, "IndexSubentry",
      CellTags->"Rules"],
    Cell[1292707, 49176, 244, 10, 23, "Index",
      CellTags->"Rules"],
    Cell[1292954, 49188, 234, 9, 23, "IndexSubentry",
      CellTags->"Rules"],
    Cell[1572190, 60455, 244, 10, 23, "Index",
      CellTags->"Rules"],
    Cell[1572437, 60467, 234, 9, 23, "IndexSubentry",
      CellTags->"Rules"],
    Cell[1836637, 71165, 244, 10, 15, "Index",
      CellTags->"Rules"],
    Cell[1836884, 71177, 234, 9, 15, "IndexSubentry",
      CellTags->"Rules"]},
  "SampleCovariance"->{
    Cell[392444, 12790, 251, 10, 15, "Index",
      CellTags->"SampleCovariance"],
    Cell[708768, 25567, 251, 10, 23, "Index",
      CellTags->"SampleCovariance"],
    Cell[1004149, 37512, 251, 10, 15, "Index",
      CellTags->"SampleCovariance"],
    Cell[1293191, 49199, 251, 10, 23, "Index",
      CellTags->"SampleCovariance"],
    Cell[1572674, 60478, 251, 10, 23, "Index",
      CellTags->"SampleCovariance"],
    Cell[1837121, 71188, 251, 10, 15, "Index",
      CellTags->"SampleCovariance"]},
  "SampleIndividuals"->{
    Cell[392698, 12802, 278, 10, 15, "Index",
      CellTags->"SampleIndividuals"],
    Cell[709022, 25579, 278, 10, 23, "Index",
      CellTags->"SampleIndividuals"],
    Cell[1004403, 37524, 278, 10, 15, "Index",
      CellTags->"SampleIndividuals"],
    Cell[1293445, 49211, 278, 10, 23, "Index",
      CellTags->"SampleIndividuals"],
    Cell[1572928, 60490, 278, 10, 23, "Index",
      CellTags->"SampleIndividuals"],
    Cell[1837375, 71200, 278, 10, 15, "Index",
      CellTags->"SampleIndividuals"]},
  "SamplePartition"->{
    Cell[392979, 12814, 260, 10, 15, "Index",
      CellTags->"SamplePartition"],
    Cell[709303, 25591, 260, 10, 23, "Index",
      CellTags->"SamplePartition"],
    Cell[1004684, 37536, 260, 10, 15, "Index",
      CellTags->"SamplePartition"],
    Cell[1293726, 49223, 260, 10, 23, "Index",
      CellTags->"SamplePartition"],
    Cell[1573209, 60502, 260, 10, 23, "Index",
      CellTags->"SamplePartition"],
    Cell[1837656, 71212, 260, 10, 15, "Index",
      CellTags->"SamplePartition"]},
  "Sampling"->{
    Cell[393242, 12826, 261, 11, 15, "Index",
      CellTags->"Sampling"],
    Cell[709566, 25603, 261, 11, 23, "Index",
      CellTags->"Sampling"],
    Cell[1004947, 37548, 261, 11, 15, "Index",
      CellTags->"Sampling"],
    Cell[1293989, 49235, 261, 11, 23, "Index",
      CellTags->"Sampling"],
    Cell[1573472, 60514, 261, 11, 23, "Index",
      CellTags->"Sampling"],
    Cell[1837919, 71224, 261, 11, 15, "Index",
      CellTags->"Sampling"]},
  "Scripts and faces"->{
    Cell[393506, 12839, 319, 11, 15, "Index",
      CellTags->"Scripts and faces"],
    Cell[709830, 25616, 319, 11, 23, "Index",
      CellTags->"Scripts and faces"],
    Cell[1005211, 37561, 319, 11, 15, "Index",
      CellTags->"Scripts and faces"],
    Cell[1294253, 49248, 319, 11, 23, "Index",
      CellTags->"Scripts and faces"],
    Cell[1573736, 60527, 319, 11, 23, "Index",
      CellTags->"Scripts and faces"],
    Cell[1838183, 71237, 297, 11, 15, "Index",
      CellTags->"Scripts and faces"]},
  "Segments"->{
    Cell[393828, 12852, 292, 11, 15, "Index",
      CellTags->"Segments"],
    Cell[710152, 25629, 292, 11, 23, "Index",
      CellTags->"Segments"]},
  "SegmentStyle"->{
    Cell[394123, 12865, 304, 11, 15, "Index",
      CellTags->"SegmentStyle"],
    Cell[710447, 25642, 304, 11, 23, "Index",
      CellTags->"SegmentStyle"]},
  "SegregationRatio"->{
    Cell[394430, 12878, 414, 14, 15, "Index",
      CellTags->"SegregationRatio"],
    Cell[710754, 25655, 414, 14, 23, "Index",
      CellTags->"SegregationRatio"],
    Cell[1005533, 37574, 414, 14, 15, "Index",
      CellTags->"SegregationRatio"],
    Cell[1294575, 49261, 414, 14, 23, "Index",
      CellTags->"SegregationRatio"],
    Cell[1574058, 60540, 414, 14, 23, "Index",
      CellTags->"SegregationRatio"],
    Cell[1838483, 71250, 414, 14, 15, "Index",
      CellTags->"SegregationRatio"]},
  "SelectContext"->{
    Cell[394847, 12894, 321, 11, 15, "Index",
      CellTags->"SelectContext"],
    Cell[711171, 25671, 321, 11, 23, "Index",
      CellTags->"SelectContext"],
    Cell[1005950, 37590, 321, 11, 15, "Index",
      CellTags->"SelectContext"],
    Cell[1294992, 49277, 321, 11, 23, "Index",
      CellTags->"SelectContext"],
    Cell[1574475, 60556, 321, 11, 23, "Index",
      CellTags->"SelectContext"],
    Cell[1838900, 71266, 321, 11, 15, "Index",
      CellTags->"SelectContext"]},
  "SelectIndividuals"->{
    Cell[395171, 12907, 272, 10, 15, "Index",
      CellTags->"SelectIndividuals"],
    Cell[711495, 25684, 272, 10, 23, "Index",
      CellTags->"SelectIndividuals"],
    Cell[1006274, 37603, 272, 10, 15, "Index",
      CellTags->"SelectIndividuals"],
    Cell[1295316, 49290, 272, 10, 23, "Index",
      CellTags->"SelectIndividuals"],
    Cell[1574799, 60569, 272, 10, 23, "Index",
      CellTags->"SelectIndividuals"],
    Cell[1839224, 71279, 272, 10, 15, "Index",
      CellTags->"SelectIndividuals"]},
  "Selection"->{
    Cell[395446, 12919, 232, 10, 15, "Index",
      CellTags->"Selection"],
    Cell[395681, 12931, 1704, 61, 135, "IndexSubentry",
      CellTags->"Selection"],
    Cell[711770, 25696, 232, 10, 23, "Index",
      CellTags->"Selection"],
    Cell[712005, 25708, 1704, 61, 143, "IndexSubentry",
      CellTags->"Selection"],
    Cell[1006549, 37615, 232, 10, 15, "Index",
      CellTags->"Selection"],
    Cell[1006784, 37627, 1704, 61, 135, "IndexSubentry",
      CellTags->"Selection"],
    Cell[1295591, 49302, 232, 10, 23, "Index",
      CellTags->"Selection"],
    Cell[1295826, 49314, 1704, 61, 143, "IndexSubentry",
      CellTags->"Selection"],
    Cell[1575074, 60581, 232, 10, 23, "Index",
      CellTags->"Selection"],
    Cell[1575309, 60593, 1704, 61, 143, "IndexSubentry",
      CellTags->"Selection"],
    Cell[1839499, 71291, 232, 10, 15, "Index",
      CellTags->"Selection"],
    Cell[1839734, 71303, 1361, 49, 105, "IndexSubentry",
      CellTags->"Selection"]},
  "SelectionCoefficient"->{
    Cell[397388, 12994, 437, 15, 15, "Index",
      CellTags->"SelectionCoefficient"],
    Cell[713712, 25771, 437, 15, 23, "Index",
      CellTags->"SelectionCoefficient"],
    Cell[1008491, 37690, 437, 15, 15, "Index",
      CellTags->"SelectionCoefficient"],
    Cell[1297533, 49377, 437, 15, 23, "Index",
      CellTags->"SelectionCoefficient"],
    Cell[1577016, 60656, 437, 15, 23, "Index",
      CellTags->"SelectionCoefficient"],
    Cell[1841098, 71354, 437, 15, 15, "Index",
      CellTags->"SelectionCoefficient"]},
  "Selection coefficients"->{
    Cell[397828, 13011, 327, 11, 15, "Index",
      CellTags->"Selection coefficients"],
    Cell[398158, 13024, 519, 19, 30, "IndexSubentry",
      CellTags->"Selection coefficients"],
    Cell[714152, 25788, 327, 11, 23, "Index",
      CellTags->"Selection coefficients"],
    Cell[714482, 25801, 519, 19, 38, "IndexSubentry",
      CellTags->"Selection coefficients"],
    Cell[1008931, 37707, 327, 11, 15, "Index",
      CellTags->"Selection coefficients"],
    Cell[1009261, 37720, 519, 19, 30, "IndexSubentry",
      CellTags->"Selection coefficients"],
    Cell[1297973, 49394, 327, 11, 23, "Index",
      CellTags->"Selection coefficients"],
    Cell[1298303, 49407, 519, 19, 38, "IndexSubentry",
      CellTags->"Selection coefficients"],
    Cell[1577456, 60673, 327, 11, 23, "Index",
      CellTags->"Selection coefficients"],
    Cell[1577786, 60686, 519, 19, 38, "IndexSubentry",
      CellTags->"Selection coefficients"],
    Cell[1841538, 71371, 305, 11, 15, "Index",
      CellTags->"Selection coefficients"],
    Cell[1841846, 71384, 519, 19, 30, "IndexSubentry",
      CellTags->"Selection coefficients"]},
  "SelectionExact"->{
    Cell[398680, 13045, 317, 11, 15, "Index",
      CellTags->"SelectionExact"],
    Cell[399000, 13058, 658, 21, 45, "IndexSubentry",
      CellTags->"SelectionExact"],
    Cell[715004, 25822, 317, 11, 23, "Index",
      CellTags->"SelectionExact"],
    Cell[715324, 25835, 658, 21, 53, "IndexSubentry",
      CellTags->"SelectionExact"],
    Cell[1009783, 37741, 317, 11, 15, "Index",
      CellTags->"SelectionExact"],
    Cell[1010103, 37754, 658, 21, 45, "IndexSubentry",
      CellTags->"SelectionExact"],
    Cell[1298825, 49428, 317, 11, 23, "Index",
      CellTags->"SelectionExact"],
    Cell[1299145, 49441, 658, 21, 53, "IndexSubentry",
      CellTags->"SelectionExact"],
    Cell[1578308, 60707, 317, 11, 23, "Index",
      CellTags->"SelectionExact"],
    Cell[1578628, 60720, 658, 21, 53, "IndexSubentry",
      CellTags->"SelectionExact"],
    Cell[1842368, 71405, 317, 11, 15, "Index",
      CellTags->"SelectionExact"],
    Cell[1842688, 71418, 658, 21, 45, "IndexSubentry",
      CellTags->"SelectionExact"]},
  "Selection on diploids"->{
    Cell[399661, 13081, 290, 11, 15, "Index",
      CellTags->"Selection on diploids"],
    Cell[399954, 13094, 888, 33, 75, "IndexSubentry",
      CellTags->"Selection on diploids"],
    Cell[715985, 25858, 290, 11, 23, "Index",
      CellTags->"Selection on diploids"],
    Cell[716278, 25871, 888, 33, 83, "IndexSubentry",
      CellTags->"Selection on diploids"],
    Cell[1010764, 37777, 290, 11, 15, "Index",
      CellTags->"Selection on diploids"],
    Cell[1011057, 37790, 888, 33, 75, "IndexSubentry",
      CellTags->"Selection on diploids"],
    Cell[1299806, 49464, 290, 11, 23, "Index",
      CellTags->"Selection on diploids"],
    Cell[1300099, 49477, 888, 33, 83, "IndexSubentry",
      CellTags->"Selection on diploids"],
    Cell[1579289, 60743, 290, 11, 23, "Index",
      CellTags->"Selection on diploids"],
    Cell[1579582, 60756, 888, 33, 83, "IndexSubentry",
      CellTags->"Selection on diploids"],
    Cell[1843349, 71441, 290, 11, 15, "Index",
      CellTags->"Selection on diploids"],
    Cell[1843642, 71454, 888, 33, 75, "IndexSubentry",
      CellTags->"Selection on diploids"]},
  "SelectionRate"->{
    Cell[400845, 13129, 304, 11, 15, "Index",
      CellTags->"SelectionRate"],
    Cell[717169, 25906, 304, 11, 23, "Index",
      CellTags->"SelectionRate"],
    Cell[1011948, 37825, 304, 11, 15, "Index",
      CellTags->"SelectionRate"],
    Cell[1300990, 49512, 304, 11, 23, "Index",
      CellTags->"SelectionRate"],
    Cell[1580473, 60791, 304, 11, 23, "Index",
      CellTags->"SelectionRate"],
    Cell[1844533, 71489, 304, 11, 15, "Index",
      CellTags->"SelectionRate"]},
  "SelectLoci"->{
    Cell[401152, 13142, 251, 10, 15, "Index",
      CellTags->"SelectLoci"],
    Cell[717476, 25919, 251, 10, 23, "Index",
      CellTags->"SelectLoci"],
    Cell[1012255, 37838, 251, 10, 15, "Index",
      CellTags->"SelectLoci"],
    Cell[1301297, 49525, 251, 10, 23, "Index",
      CellTags->"SelectLoci"],
    Cell[1580780, 60804, 251, 10, 23, "Index",
      CellTags->"SelectLoci"],
    Cell[1844840, 71502, 251, 10, 15, "Index",
      CellTags->"SelectLoci"]},
  "Selfing"->{
    Cell[401406, 13154, 217, 10, 15, "Index",
      CellTags->"Selfing"],
    Cell[717730, 25931, 217, 10, 23, "Index",
      CellTags->"Selfing"],
    Cell[1012509, 37850, 217, 10, 15, "Index",
      CellTags->"Selfing"],
    Cell[1301551, 49537, 217, 10, 23, "Index",
      CellTags->"Selfing"],
    Cell[1581034, 60816, 217, 10, 23, "Index",
      CellTags->"Selfing"],
    Cell[1845094, 71514, 217, 10, 15, "Index",
      CellTags->"Selfing"]},
  "Separate"->{
    Cell[401626, 13166, 235, 10, 15, "Index",
      CellTags->"Separate"],
    Cell[717950, 25943, 235, 10, 23, "Index",
      CellTags->"Separate"],
    Cell[1012729, 37862, 235, 10, 15, "Index",
      CellTags->"Separate"],
    Cell[1301771, 49549, 235, 10, 23, "Index",
      CellTags->"Separate"],
    Cell[1581254, 60828, 235, 10, 23, "Index",
      CellTags->"Separate"],
    Cell[1845314, 71526, 235, 10, 15, "Index",
      CellTags->"Separate"]},
  "Servedio"->{
    Cell[401864, 13178, 258, 11, 15, "Index",
      CellTags->"Servedio"],
    Cell[718188, 25955, 258, 11, 23, "Index",
      CellTags->"Servedio"],
    Cell[1012967, 37874, 258, 11, 15, "Index",
      CellTags->"Servedio"],
    Cell[1302009, 49561, 258, 11, 23, "Index",
      CellTags->"Servedio"],
    Cell[1581492, 60840, 258, 11, 23, "Index",
      CellTags->"Servedio"]},
  "Set"->{
    Cell[402125, 13191, 339, 12, 15, "Index",
      CellTags->"Set"],
    Cell[402467, 13205, 323, 10, 15, "IndexSubentry",
      CellTags->"Set"],
    Cell[718449, 25968, 339, 12, 23, "Index",
      CellTags->"Set"],
    Cell[718791, 25982, 323, 10, 23, "IndexSubentry",
      CellTags->"Set"],
    Cell[1013228, 37887, 339, 12, 15, "Index",
      CellTags->"Set"],
    Cell[1013570, 37901, 323, 10, 15, "IndexSubentry",
      CellTags->"Set"],
    Cell[1302270, 49574, 339, 12, 23, "Index",
      CellTags->"Set"],
    Cell[1302612, 49588, 323, 10, 23, "IndexSubentry",
      CellTags->"Set"],
    Cell[1581753, 60853, 339, 12, 23, "Index",
      CellTags->"Set"],
    Cell[1582095, 60867, 323, 10, 23, "IndexSubentry",
      CellTags->"Set"],
    Cell[1845552, 71538, 339, 12, 15, "Index",
      CellTags->"Set"],
    Cell[1845894, 71552, 323, 10, 15, "IndexSubentry",
      CellTags->"Set"]},
  "Set manipulation"->{
    Cell[402793, 13217, 293, 11, 15, "Index",
      CellTags->"Set manipulation"],
    Cell[719117, 25994, 293, 11, 23, "Index",
      CellTags->"Set manipulation"],
    Cell[1013896, 37913, 293, 11, 15, "Index",
      CellTags->"Set manipulation"],
    Cell[1302938, 49600, 293, 11, 23, "Index",
      CellTags->"Set manipulation"],
    Cell[1582421, 60879, 293, 11, 23, "Index",
      CellTags->"Set manipulation"],
    Cell[1846220, 71564, 293, 11, 15, "Index",
      CellTags->"Set manipulation"]},
  "SetOfCombinations"->{
    Cell[403089, 13230, 270, 10, 15, "Index",
      CellTags->"SetOfCombinations"],
    Cell[719413, 26007, 270, 10, 23, "Index",
      CellTags->"SetOfCombinations"],
    Cell[1014192, 37926, 270, 10, 15, "Index",
      CellTags->"SetOfCombinations"]},
  "SetPartition"->{
    Cell[403362, 13242, 251, 10, 15, "Index",
      CellTags->"SetPartition"],
    Cell[719686, 26019, 251, 10, 23, "Index",
      CellTags->"SetPartition"],
    Cell[1014465, 37938, 251, 10, 15, "Index",
      CellTags->"SetPartition"],
    Cell[1303234, 49613, 251, 10, 23, "Index",
      CellTags->"SetPartition"],
    Cell[1582717, 60892, 251, 10, 23, "Index",
      CellTags->"SetPartition"],
    Cell[1846516, 71577, 251, 10, 15, "Index",
      CellTags->"SetPartition"]},
  "Sets of loci"->{
    Cell[403616, 13254, 304, 11, 15, "Index",
      CellTags->"Sets of loci"],
    Cell[719940, 26031, 304, 11, 23, "Index",
      CellTags->"Sets of loci"],
    Cell[1014719, 37950, 304, 11, 15, "Index",
      CellTags->"Sets of loci"],
    Cell[1303488, 49625, 304, 11, 23, "Index",
      CellTags->"Sets of loci"],
    Cell[1582971, 60904, 304, 11, 23, "Index",
      CellTags->"Sets of loci"],
    Cell[1846770, 71589, 282, 11, 15, "Index",
      CellTags->"Sets of loci"]},
  "Sex"->{
    Cell[403923, 13267, 216, 10, 15, "Index",
      CellTags->"Sex"],
    Cell[720247, 26044, 216, 10, 23, "Index",
      CellTags->"Sex"],
    Cell[1015026, 37963, 216, 10, 15, "Index",
      CellTags->"Sex"],
    Cell[1303795, 49638, 216, 10, 23, "Index",
      CellTags->"Sex"],
    Cell[1583278, 60917, 216, 10, 23, "Index",
      CellTags->"Sex"],
    Cell[1847055, 71602, 216, 10, 15, "Index",
      CellTags->"Sex"]},
  "Sex linkage"->{
    Cell[404142, 13279, 394, 14, 15, "Index",
      CellTags->"Sex linkage"],
    Cell[404539, 13295, 236, 9, 15, "IndexSubentry",
      CellTags->"Sex linkage"],
    Cell[720466, 26056, 394, 14, 23, "Index",
      CellTags->"Sex linkage"],
    Cell[720863, 26072, 236, 9, 23, "IndexSubentry",
      CellTags->"Sex linkage"],
    Cell[1015245, 37975, 394, 14, 15, "Index",
      CellTags->"Sex linkage"],
    Cell[1015642, 37991, 236, 9, 15, "IndexSubentry",
      CellTags->"Sex linkage"],
    Cell[1304014, 49650, 394, 14, 23, "Index",
      CellTags->"Sex linkage"],
    Cell[1304411, 49666, 236, 9, 23, "IndexSubentry",
      CellTags->"Sex linkage"],
    Cell[1583497, 60929, 394, 14, 23, "Index",
      CellTags->"Sex linkage"],
    Cell[1583894, 60945, 236, 9, 23, "IndexSubentry",
      CellTags->"Sex linkage"],
    Cell[1847274, 71614, 394, 14, 15, "Index",
      CellTags->"Sex linkage"],
    Cell[1847671, 71630, 236, 9, 15, "IndexSubentry",
      CellTags->"Sex linkage"]},
  "SexOfOrigin"->{
    Cell[404778, 13306, 240, 10, 15, "Index",
      CellTags->"SexOfOrigin"],
    Cell[721102, 26083, 240, 10, 23, "Index",
      CellTags->"SexOfOrigin"],
    Cell[1015881, 38002, 240, 10, 15, "Index",
      CellTags->"SexOfOrigin"],
    Cell[1304650, 49677, 240, 10, 23, "Index",
      CellTags->"SexOfOrigin"],
    Cell[1584133, 60956, 240, 10, 23, "Index",
      CellTags->"SexOfOrigin"],
    Cell[1847910, 71641, 240, 10, 15, "Index",
      CellTags->"SexOfOrigin"]},
  "Sexual selection"->{
    Cell[405021, 13318, 267, 10, 15, "Index",
      CellTags->"Sexual selection"],
    Cell[405291, 13330, 1209, 45, 105, "IndexSubentry",
      CellTags->"Sexual selection"],
    Cell[721345, 26095, 267, 10, 23, "Index",
      CellTags->"Sexual selection"],
    Cell[721615, 26107, 1209, 45, 113, "IndexSubentry",
      CellTags->"Sexual selection"],
    Cell[1016124, 38014, 267, 10, 15, "Index",
      CellTags->"Sexual selection"],
    Cell[1016394, 38026, 1209, 45, 105, "IndexSubentry",
      CellTags->"Sexual selection"],
    Cell[1304893, 49689, 267, 10, 23, "Index",
      CellTags->"Sexual selection"],
    Cell[1305163, 49701, 1209, 45, 113, "IndexSubentry",
      CellTags->"Sexual selection"],
    Cell[1584376, 60968, 267, 10, 23, "Index",
      CellTags->"Sexual selection"],
    Cell[1584646, 60980, 1209, 45, 113, "IndexSubentry",
      CellTags->"Sexual selection"],
    Cell[1848153, 71653, 267, 10, 15, "Index",
      CellTags->"Sexual selection"],
    Cell[1848423, 71665, 892, 33, 75, "IndexSubentry",
      CellTags->"Sexual selection"]},
  "ShortContext"->{
    Cell[406503, 13377, 265, 10, 15, "Index",
      CellTags->"ShortContext"],
    Cell[722827, 26154, 265, 10, 23, "Index",
      CellTags->"ShortContext"],
    Cell[1017606, 38073, 265, 10, 15, "Index",
      CellTags->"ShortContext"],
    Cell[1306375, 49748, 265, 10, 23, "Index",
      CellTags->"ShortContext"],
    Cell[1585858, 61027, 265, 10, 23, "Index",
      CellTags->"ShortContext"],
    Cell[1849318, 71700, 265, 10, 15, "Index",
      CellTags->"ShortContext"]},
  "SigmaMatrix"->{
    Cell[406771, 13389, 278, 10, 15, "Index",
      CellTags->"SigmaMatrix"],
    Cell[723095, 26166, 278, 10, 23, "Index",
      CellTags->"SigmaMatrix"],
    Cell[1017874, 38085, 278, 10, 15, "Index",
      CellTags->"SigmaMatrix"],
    Cell[1306643, 49760, 278, 10, 23, "Index",
      CellTags->"SigmaMatrix"],
    Cell[1586126, 61039, 278, 10, 23, "Index",
      CellTags->"SigmaMatrix"],
    Cell[1849586, 71712, 278, 10, 15, "Index",
      CellTags->"SigmaMatrix"]},
  "SignMask"->{
    Cell[407052, 13401, 247, 10, 15, "Index",
      CellTags->"SignMask"],
    Cell[723376, 26178, 247, 10, 23, "Index",
      CellTags->"SignMask"],
    Cell[1018155, 38097, 247, 10, 15, "Index",
      CellTags->"SignMask"],
    Cell[1306924, 49772, 247, 10, 23, "Index",
      CellTags->"SignMask"],
    Cell[1586407, 61051, 247, 10, 23, "Index",
      CellTags->"SignMask"],
    Cell[1849867, 71724, 247, 10, 15, "Index",
      CellTags->"SignMask"]},
  "SimplifyAddUp"->{
    Cell[407302, 13413, 236, 10, 15, "Index",
      CellTags->"SimplifyAddUp"],
    Cell[723626, 26190, 236, 10, 23, "Index",
      CellTags->"SimplifyAddUp"],
    Cell[1018405, 38109, 236, 10, 15, "Index",
      CellTags->"SimplifyAddUp"],
    Cell[1307174, 49784, 236, 10, 23, "Index",
      CellTags->"SimplifyAddUp"],
    Cell[1586657, 61063, 236, 10, 23, "Index",
      CellTags->"SimplifyAddUp"],
    Cell[1850117, 71736, 236, 10, 15, "Index",
      CellTags->"SimplifyAddUp"]},
  "SimplifyAddUpQ"->{
    Cell[407541, 13425, 239, 10, 15, "Index",
      CellTags->"SimplifyAddUpQ"],
    Cell[723865, 26202, 239, 10, 23, "Index",
      CellTags->"SimplifyAddUpQ"],
    Cell[1018644, 38121, 239, 10, 15, "Index",
      CellTags->"SimplifyAddUpQ"],
    Cell[1307413, 49796, 239, 10, 23, "Index",
      CellTags->"SimplifyAddUpQ"],
    Cell[1586896, 61075, 239, 10, 23, "Index",
      CellTags->"SimplifyAddUpQ"],
    Cell[1850356, 71748, 239, 10, 15, "Index",
      CellTags->"SimplifyAddUpQ"]},
  "SimplifyFamilies"->{
    Cell[407783, 13437, 261, 10, 15, "Index",
      CellTags->"SimplifyFamilies"],
    Cell[724107, 26214, 261, 10, 23, "Index",
      CellTags->"SimplifyFamilies"],
    Cell[1018886, 38133, 261, 10, 15, "Index",
      CellTags->"SimplifyFamilies"],
    Cell[1307655, 49808, 261, 10, 23, "Index",
      CellTags->"SimplifyFamilies"],
    Cell[1587138, 61087, 261, 10, 23, "Index",
      CellTags->"SimplifyFamilies"],
    Cell[1850598, 71760, 261, 10, 15, "Index",
      CellTags->"SimplifyFamilies"]},
  "Simulating individuals"->{
    Cell[408047, 13449, 335, 11, 15, "Index",
      CellTags->"Simulating individuals"],
    Cell[408385, 13462, 503, 15, 30, "IndexSubentry",
      CellTags->"Simulating individuals"],
    Cell[724371, 26226, 335, 11, 23, "Index",
      CellTags->"Simulating individuals"],
    Cell[724709, 26239, 503, 15, 38, "IndexSubentry",
      CellTags->"Simulating individuals"],
    Cell[1019150, 38145, 335, 11, 15, "Index",
      CellTags->"Simulating individuals"],
    Cell[1019488, 38158, 503, 15, 30, "IndexSubentry",
      CellTags->"Simulating individuals"],
    Cell[1307919, 49820, 335, 11, 23, "Index",
      CellTags->"Simulating individuals"],
    Cell[1308257, 49833, 503, 15, 38, "IndexSubentry",
      CellTags->"Simulating individuals"],
    Cell[1587402, 61099, 335, 11, 23, "Index",
      CellTags->"Simulating individuals"],
    Cell[1587740, 61112, 503, 15, 38, "IndexSubentry",
      CellTags->"Simulating individuals"],
    Cell[1850862, 71772, 335, 11, 15, "Index",
      CellTags->"Simulating individuals"],
    Cell[1851200, 71785, 503, 15, 30, "IndexSubentry",
      CellTags->"Simulating individuals"]},
  "SizeOfGenealogyPlot"->{
    Cell[408891, 13479, 284, 10, 15, "Index",
      CellTags->"SizeOfGenealogyPlot"],
    Cell[725215, 26256, 284, 10, 23, "Index",
      CellTags->"SizeOfGenealogyPlot"],
    Cell[1019994, 38175, 284, 10, 15, "Index",
      CellTags->"SizeOfGenealogyPlot"],
    Cell[1308763, 49850, 284, 10, 23, "Index",
      CellTags->"SizeOfGenealogyPlot"],
    Cell[1588246, 61129, 284, 10, 23, "Index",
      CellTags->"SizeOfGenealogyPlot"],
    Cell[1851706, 71802, 284, 10, 15, "Index",
      CellTags->"SizeOfGenealogyPlot"]},
  "Slatkin & Excoffier 1996"->{
    Cell[409178, 13491, 279, 10, 15, "Index",
      CellTags->"Slatkin & Excoffier 1996"],
    Cell[725502, 26268, 279, 10, 23, "Index",
      CellTags->"Slatkin & Excoffier 1996"],
    Cell[1020281, 38187, 279, 10, 15, "Index",
      CellTags->"Slatkin & Excoffier 1996"],
    Cell[1309050, 49862, 279, 10, 23, "Index",
      CellTags->"Slatkin & Excoffier 1996"],
    Cell[1588533, 61141, 279, 10, 23, "Index",
      CellTags->"Slatkin & Excoffier 1996"],
    Cell[1851993, 71814, 279, 10, 15, "Index",
      CellTags->"Slatkin & Excoffier 1996"]},
  "SlowChange"->{
    Cell[409460, 13503, 239, 10, 15, "Index",
      CellTags->"SlowChange"],
    Cell[725784, 26280, 239, 10, 23, "Index",
      CellTags->"SlowChange"],
    Cell[1020563, 38199, 239, 10, 15, "Index",
      CellTags->"SlowChange"],
    Cell[1309332, 49874, 239, 10, 23, "Index",
      CellTags->"SlowChange"],
    Cell[1588815, 61153, 239, 10, 23, "Index",
      CellTags->"SlowChange"],
    Cell[1852275, 71826, 239, 10, 15, "Index",
      CellTags->"SlowChange"]},
  "SortByClass"->{
    Cell[409702, 13515, 274, 10, 15, "Index",
      CellTags->"SortByClass"],
    Cell[409979, 13527, 284, 9, 15, "IndexSubentry",
      CellTags->"SortByClass"],
    Cell[726026, 26292, 274, 10, 23, "Index",
      CellTags->"SortByClass"],
    Cell[726303, 26304, 284, 9, 23, "IndexSubentry",
      CellTags->"SortByClass"],
    Cell[1020805, 38211, 274, 10, 15, "Index",
      CellTags->"SortByClass"],
    Cell[1021082, 38223, 284, 9, 15, "IndexSubentry",
      CellTags->"SortByClass"],
    Cell[1309574, 49886, 274, 10, 23, "Index",
      CellTags->"SortByClass"],
    Cell[1309851, 49898, 284, 9, 23, "IndexSubentry",
      CellTags->"SortByClass"],
    Cell[1589057, 61165, 274, 10, 23, "Index",
      CellTags->"SortByClass"],
    Cell[1589334, 61177, 284, 9, 23, "IndexSubentry",
      CellTags->"SortByClass"],
    Cell[1852517, 71838, 274, 10, 15, "Index",
      CellTags->"SortByClass"],
    Cell[1852794, 71850, 284, 9, 15, "IndexSubentry",
      CellTags->"SortByClass"]},
  "SortByHead"->{
    Cell[410266, 13538, 231, 10, 15, "Index",
      CellTags->"SortByHead"],
    Cell[726590, 26315, 231, 10, 23, "Index",
      CellTags->"SortByHead"],
    Cell[1021369, 38234, 231, 10, 15, "Index",
      CellTags->"SortByHead"],
    Cell[1310138, 49909, 231, 10, 23, "Index",
      CellTags->"SortByHead"],
    Cell[1589621, 61188, 231, 10, 23, "Index",
      CellTags->"SortByHead"],
    Cell[1853081, 71861, 231, 10, 15, "Index",
      CellTags->"SortByHead"]},
  "SpatialCovariance"->{
    Cell[410500, 13550, 254, 10, 15, "Index",
      CellTags->"SpatialCovariance"],
    Cell[726824, 26327, 254, 10, 23, "Index",
      CellTags->"SpatialCovariance"],
    Cell[1021603, 38246, 254, 10, 15, "Index",
      CellTags->"SpatialCovariance"],
    Cell[1310372, 49921, 254, 10, 23, "Index",
      CellTags->"SpatialCovariance"],
    Cell[1589855, 61200, 254, 10, 23, "Index",
      CellTags->"SpatialCovariance"],
    Cell[1853315, 71873, 254, 10, 15, "Index",
      CellTags->"SpatialCovariance"]},
  "Spatially varying selection"->{
    Cell[410757, 13562, 323, 11, 15, "Index",
      CellTags->"Spatially varying selection"],
    Cell[727081, 26339, 323, 11, 23, "Index",
      CellTags->"Spatially varying selection"],
    Cell[1021860, 38258, 323, 11, 15, "Index",
      CellTags->"Spatially varying selection"],
    Cell[1310629, 49933, 323, 11, 23, "Index",
      CellTags->"Spatially varying selection"],
    Cell[1590112, 61212, 323, 11, 23, "Index",
      CellTags->"Spatially varying selection"],
    Cell[1853572, 71885, 323, 11, 15, "Index",
      CellTags->"Spatially varying selection"]},
  "Special notation"->{
    Cell[411083, 13575, 268, 10, 15, "Index",
      CellTags->"Special notation"],
    Cell[727407, 26352, 268, 10, 23, "Index",
      CellTags->"Special notation"],
    Cell[1022186, 38271, 268, 10, 15, "Index",
      CellTags->"Special notation"],
    Cell[1310955, 49946, 268, 10, 23, "Index",
      CellTags->"Special notation"],
    Cell[1590438, 61225, 268, 10, 23, "Index",
      CellTags->"Special notation"],
    Cell[1853898, 71898, 268, 10, 15, "Index",
      CellTags->"Special notation"]},
  "SplitSet"->{
    Cell[411354, 13587, 239, 10, 15, "Index",
      CellTags->"SplitSet"],
    Cell[727678, 26364, 239, 10, 23, "Index",
      CellTags->"SplitSet"],
    Cell[1022457, 38283, 239, 10, 15, "Index",
      CellTags->"SplitSet"],
    Cell[1311226, 49958, 239, 10, 23, "Index",
      CellTags->"SplitSet"]},
  "Stabilising selection"->{
    Cell[411596, 13599, 301, 11, 15, "Index",
      CellTags->"Stabilising selection"],
    Cell[411900, 13612, 1135, 40, 90, "IndexSubentry",
      CellTags->"Stabilising selection"],
    Cell[727920, 26376, 301, 11, 23, "Index",
      CellTags->"Stabilising selection"],
    Cell[728224, 26389, 1135, 40, 98, "IndexSubentry",
      CellTags->"Stabilising selection"],
    Cell[1022699, 38295, 301, 11, 15, "Index",
      CellTags->"Stabilising selection"],
    Cell[1023003, 38308, 1135, 40, 90, "IndexSubentry",
      CellTags->"Stabilising selection"],
    Cell[1311468, 49970, 301, 11, 23, "Index",
      CellTags->"Stabilising selection"],
    Cell[1311772, 49983, 1135, 40, 98, "IndexSubentry",
      CellTags->"Stabilising selection"],
    Cell[1590709, 61237, 301, 11, 23, "Index",
      CellTags->"Stabilising selection"],
    Cell[1591013, 61250, 1135, 40, 98, "IndexSubentry",
      CellTags->"Stabilising selection"],
    Cell[1854169, 71910, 301, 11, 15, "Index",
      CellTags->"Stabilising selection"],
    Cell[1854473, 71923, 940, 33, 75, "IndexSubentry",
      CellTags->"Stabilising selection"]},
  "Stability"->{
    Cell[413038, 13654, 411, 15, 15, "Index",
      CellTags->"Stability"],
    Cell[413452, 13671, 275, 9, 15, "IndexSubentry",
      CellTags->"Stability"],
    Cell[729362, 26431, 411, 15, 23, "Index",
      CellTags->"Stability"],
    Cell[729776, 26448, 275, 9, 23, "IndexSubentry",
      CellTags->"Stability"],
    Cell[1024141, 38350, 411, 15, 15, "Index",
      CellTags->"Stability"],
    Cell[1024555, 38367, 275, 9, 15, "IndexSubentry",
      CellTags->"Stability"],
    Cell[1312910, 50025, 411, 15, 23, "Index",
      CellTags->"Stability"],
    Cell[1313324, 50042, 275, 9, 23, "IndexSubentry",
      CellTags->"Stability"],
    Cell[1592151, 61292, 411, 15, 23, "Index",
      CellTags->"Stability"],
    Cell[1592565, 61309, 275, 9, 23, "IndexSubentry",
      CellTags->"Stability"],
    Cell[1855416, 71958, 411, 15, 15, "Index",
      CellTags->"Stability"],
    Cell[1855830, 71975, 275, 9, 15, "IndexSubentry",
      CellTags->"Stability"]},
  "StabilityDirect"->{
    Cell[413730, 13682, 320, 11, 15, "Index",
      CellTags->"StabilityDirect"],
    Cell[414053, 13695, 280, 9, 15, "IndexSubentry",
      CellTags->"StabilityDirect"],
    Cell[730054, 26459, 320, 11, 23, "Index",
      CellTags->"StabilityDirect"],
    Cell[730377, 26472, 280, 9, 23, "IndexSubentry",
      CellTags->"StabilityDirect"],
    Cell[1024833, 38378, 320, 11, 15, "Index",
      CellTags->"StabilityDirect"],
    Cell[1025156, 38391, 280, 9, 15, "IndexSubentry",
      CellTags->"StabilityDirect"],
    Cell[1313602, 50053, 320, 11, 23, "Index",
      CellTags->"StabilityDirect"],
    Cell[1313925, 50066, 280, 9, 23, "IndexSubentry",
      CellTags->"StabilityDirect"],
    Cell[1592843, 61320, 320, 11, 23, "Index",
      CellTags->"StabilityDirect"],
    Cell[1593166, 61333, 280, 9, 23, "IndexSubentry",
      CellTags->"StabilityDirect"],
    Cell[1856108, 71986, 320, 11, 15, "Index",
      CellTags->"StabilityDirect"],
    Cell[1856431, 71999, 280, 9, 15, "IndexSubentry",
      CellTags->"StabilityDirect"]},
  "StabilityK"->{
    Cell[414336, 13706, 422, 14, 15, "Index",
      CellTags->"StabilityK"],
    Cell[730660, 26483, 422, 14, 23, "Index",
      CellTags->"StabilityK"],
    Cell[1025439, 38402, 422, 14, 15, "Index",
      CellTags->"StabilityK"],
    Cell[1314208, 50077, 422, 14, 23, "Index",
      CellTags->"StabilityK"],
    Cell[1593449, 61344, 422, 14, 23, "Index",
      CellTags->"StabilityK"],
    Cell[1856714, 72010, 422, 14, 15, "Index",
      CellTags->"StabilityK"]},
  "StabilityKTable"->{
    Cell[414761, 13722, 313, 11, 15, "Index",
      CellTags->"StabilityKTable"],
    Cell[731085, 26499, 313, 11, 23, "Index",
      CellTags->"StabilityKTable"],
    Cell[1025864, 38418, 313, 11, 15, "Index",
      CellTags->"StabilityKTable"],
    Cell[1314633, 50093, 313, 11, 23, "Index",
      CellTags->"StabilityKTable"],
    Cell[1593874, 61360, 313, 11, 23, "Index",
      CellTags->"StabilityKTable"],
    Cell[1857139, 72026, 313, 11, 15, "Index",
      CellTags->"StabilityKTable"]},
  "StabilityMatrix"->{
    Cell[415077, 13735, 282, 10, 15, "Index",
      CellTags->"StabilityMatrix"],
    Cell[731401, 26512, 282, 10, 23, "Index",
      CellTags->"StabilityMatrix"],
    Cell[1026180, 38431, 282, 10, 15, "Index",
      CellTags->"StabilityMatrix"],
    Cell[1314949, 50106, 282, 10, 23, "Index",
      CellTags->"StabilityMatrix"],
    Cell[1594190, 61373, 282, 10, 23, "Index",
      CellTags->"StabilityMatrix"],
    Cell[1857455, 72039, 282, 10, 15, "Index",
      CellTags->"StabilityMatrix"]},
  "Stage"->{
    Cell[415362, 13747, 293, 11, 15, "Index",
      CellTags->"Stage"],
    Cell[731686, 26524, 293, 11, 23, "Index",
      CellTags->"Stage"],
    Cell[1026465, 38443, 293, 11, 15, "Index",
      CellTags->"Stage"],
    Cell[1315234, 50118, 293, 11, 23, "Index",
      CellTags->"Stage"],
    Cell[1594475, 61385, 293, 11, 23, "Index",
      CellTags->"Stage"],
    Cell[1857740, 72051, 293, 11, 15, "Index",
      CellTags->"Stage"]},
  "Stages"->{
    Cell[415658, 13760, 225, 10, 15, "Index",
      CellTags->"Stages"],
    Cell[415886, 13772, 288, 9, 15, "IndexSubentry",
      CellTags->"Stages"],
    Cell[731982, 26537, 225, 10, 23, "Index",
      CellTags->"Stages"],
    Cell[732210, 26549, 288, 9, 23, "IndexSubentry",
      CellTags->"Stages"],
    Cell[1026761, 38456, 225, 10, 15, "Index",
      CellTags->"Stages"],
    Cell[1026989, 38468, 288, 9, 15, "IndexSubentry",
      CellTags->"Stages"],
    Cell[1315530, 50131, 225, 10, 23, "Index",
      CellTags->"Stages"],
    Cell[1315758, 50143, 288, 9, 23, "IndexSubentry",
      CellTags->"Stages"],
    Cell[1594771, 61398, 225, 10, 23, "Index",
      CellTags->"Stages"],
    Cell[1594999, 61410, 288, 9, 23, "IndexSubentry",
      CellTags->"Stages"],
    Cell[1858036, 72064, 225, 10, 15, "Index",
      CellTags->"Stages"],
    Cell[1858264, 72076, 266, 9, 15, "IndexSubentry",
      CellTags->"Stages"]},
  "StandardPartition"->{
    Cell[416177, 13783, 266, 10, 15, "Index",
      CellTags->"StandardPartition"],
    Cell[732501, 26560, 266, 10, 23, "Index",
      CellTags->"StandardPartition"],
    Cell[1027280, 38479, 266, 10, 15, "Index",
      CellTags->"StandardPartition"],
    Cell[1316049, 50154, 266, 10, 23, "Index",
      CellTags->"StandardPartition"]},
  "StandardPartitionQ"->{
    Cell[416446, 13795, 269, 10, 15, "Index",
      CellTags->"StandardPartitionQ"],
    Cell[732770, 26572, 269, 10, 23, "Index",
      CellTags->"StandardPartitionQ"],
    Cell[1027549, 38491, 269, 10, 15, "Index",
      CellTags->"StandardPartitionQ"],
    Cell[1316318, 50166, 269, 10, 23, "Index",
      CellTags->"StandardPartitionQ"]},
  "StartingStepSize"->{
    Cell[416718, 13807, 285, 10, 15, "Index",
      CellTags->"StartingStepSize"],
    Cell[733042, 26584, 285, 10, 23, "Index",
      CellTags->"StartingStepSize"],
    Cell[1027821, 38503, 285, 10, 15, "Index",
      CellTags->"StartingStepSize"],
    Cell[1316590, 50178, 285, 10, 23, "Index",
      CellTags->"StartingStepSize"],
    Cell[1595290, 61421, 285, 10, 23, "Index",
      CellTags->"StartingStepSize"],
    Cell[1858533, 72087, 285, 10, 15, "Index",
      CellTags->"StartingStepSize"]},
  "Stepping-stone migration"->{
    Cell[417006, 13819, 357, 12, 15, "Index",
      CellTags->"Stepping-stone migration"],
    Cell[733330, 26596, 357, 12, 23, "Index",
      CellTags->"Stepping-stone migration"],
    Cell[1028109, 38515, 357, 12, 15, "Index",
      CellTags->"Stepping-stone migration"],
    Cell[1316878, 50190, 357, 12, 23, "Index",
      CellTags->"Stepping-stone migration"],
    Cell[1595578, 61433, 357, 12, 23, "Index",
      CellTags->"Stepping-stone migration"],
    Cell[1858821, 72099, 357, 12, 15, "Index",
      CellTags->"Stepping-stone migration"]},
  "Stepping-stone model"->{
    Cell[417366, 13833, 347, 12, 15, "Index",
      CellTags->"Stepping-stone model"],
    Cell[417716, 13847, 501, 16, 30, "IndexSubentry",
      CellTags->"Stepping-stone model"],
    Cell[733690, 26610, 347, 12, 23, "Index",
      CellTags->"Stepping-stone model"],
    Cell[734040, 26624, 501, 16, 38, "IndexSubentry",
      CellTags->"Stepping-stone model"],
    Cell[1028469, 38529, 347, 12, 15, "Index",
      CellTags->"Stepping-stone model"],
    Cell[1028819, 38543, 501, 16, 30, "IndexSubentry",
      CellTags->"Stepping-stone model"],
    Cell[1317238, 50204, 347, 12, 23, "Index",
      CellTags->"Stepping-stone model"],
    Cell[1317588, 50218, 501, 16, 38, "IndexSubentry",
      CellTags->"Stepping-stone model"],
    Cell[1595938, 61447, 347, 12, 23, "Index",
      CellTags->"Stepping-stone model"],
    Cell[1596288, 61461, 501, 16, 38, "IndexSubentry",
      CellTags->"Stepping-stone model"],
    Cell[1859181, 72113, 347, 12, 15, "Index",
      CellTags->"Stepping-stone model"],
    Cell[1859531, 72127, 501, 16, 30, "IndexSubentry",
      CellTags->"Stepping-stone model"]},
  "StoreExact"->{
    Cell[418220, 13865, 323, 11, 15, "Index",
      CellTags->"StoreExact"],
    Cell[418546, 13878, 1518, 45, 105, "IndexSubentry",
      CellTags->"StoreExact"],
    Cell[734544, 26642, 323, 11, 23, "Index",
      CellTags->"StoreExact"],
    Cell[734870, 26655, 1518, 45, 113, "IndexSubentry",
      CellTags->"StoreExact"],
    Cell[1029323, 38561, 323, 11, 15, "Index",
      CellTags->"StoreExact"],
    Cell[1029649, 38574, 1518, 45, 105, "IndexSubentry",
      CellTags->"StoreExact"],
    Cell[1318092, 50236, 323, 11, 23, "Index",
      CellTags->"StoreExact"],
    Cell[1318418, 50249, 1518, 45, 113, "IndexSubentry",
      CellTags->"StoreExact"],
    Cell[1596792, 61479, 323, 11, 23, "Index",
      CellTags->"StoreExact"],
    Cell[1597118, 61492, 1518, 45, 113, "IndexSubentry",
      CellTags->"StoreExact"],
    Cell[1860035, 72145, 323, 11, 15, "Index",
      CellTags->"StoreExact"],
    Cell[1860361, 72158, 1518, 45, 105, "IndexSubentry",
      CellTags->"StoreExact"]},
  "StoreResults"->{
    Cell[420067, 13925, 450, 15, 15, "Index",
      CellTags->"StoreResults"],
    Cell[420520, 13942, 813, 24, 30, "IndexSubentry",
      CellTags->"StoreResults"],
    Cell[736391, 26702, 450, 15, 23, "Index",
      CellTags->"StoreResults"],
    Cell[736844, 26719, 813, 24, 38, "IndexSubentry",
      CellTags->"StoreResults"],
    Cell[1031170, 38621, 450, 15, 15, "Index",
      CellTags->"StoreResults"],
    Cell[1031623, 38638, 813, 24, 30, "IndexSubentry",
      CellTags->"StoreResults"],
    Cell[1319939, 50296, 450, 15, 23, "Index",
      CellTags->"StoreResults"],
    Cell[1320392, 50313, 813, 24, 38, "IndexSubentry",
      CellTags->"StoreResults"],
    Cell[1598639, 61539, 450, 15, 23, "Index",
      CellTags->"StoreResults"],
    Cell[1599092, 61556, 813, 24, 38, "IndexSubentry",
      CellTags->"StoreResults"],
    Cell[1861882, 72205, 450, 15, 15, "Index",
      CellTags->"StoreResults"],
    Cell[1862335, 72222, 813, 24, 30, "IndexSubentry",
      CellTags->"StoreResults"]},
  "StructuredArray"->{
    Cell[421336, 13968, 264, 10, 15, "Index",
      CellTags->"StructuredArray"],
    Cell[737660, 26745, 264, 10, 23, "Index",
      CellTags->"StructuredArray"],
    Cell[1032439, 38664, 264, 10, 15, "Index",
      CellTags->"StructuredArray"],
    Cell[1321208, 50339, 264, 10, 23, "Index",
      CellTags->"StructuredArray"],
    Cell[1599908, 61582, 264, 10, 23, "Index",
      CellTags->"StructuredArray"],
    Cell[1863151, 72248, 264, 10, 15, "Index",
      CellTags->"StructuredArray"]},
  "StructuredInitialParameters"->{
    Cell[421603, 13980, 304, 10, 15, "Index",
      CellTags->"StructuredInitialParameters"],
    Cell[737927, 26757, 304, 10, 23, "Index",
      CellTags->"StructuredInitialParameters"],
    Cell[1032706, 38676, 304, 10, 15, "Index",
      CellTags->"StructuredInitialParameters"],
    Cell[1321475, 50351, 304, 10, 23, "Index",
      CellTags->"StructuredInitialParameters"],
    Cell[1600175, 61594, 304, 10, 23, "Index",
      CellTags->"StructuredInitialParameters"],
    Cell[1863418, 72260, 304, 10, 15, "Index",
      CellTags->"StructuredInitialParameters"]},
  "StructuredLogLikelihood"->{
    Cell[421910, 13992, 327, 11, 15, "Index",
      CellTags->"StructuredLogLikelihood"],
    Cell[738234, 26769, 327, 11, 23, "Index",
      CellTags->"StructuredLogLikelihood"],
    Cell[1033013, 38688, 327, 11, 15, "Index",
      CellTags->"StructuredLogLikelihood"],
    Cell[1321782, 50363, 327, 11, 23, "Index",
      CellTags->"StructuredLogLikelihood"],
    Cell[1600482, 61606, 327, 11, 23, "Index",
      CellTags->"StructuredLogLikelihood"],
    Cell[1863725, 72272, 327, 11, 15, "Index",
      CellTags->"StructuredLogLikelihood"]},
  "StructuredMLE"->{
    Cell[422240, 14005, 434, 14, 15, "Index",
      CellTags->"StructuredMLE"],
    Cell[738564, 26782, 434, 14, 23, "Index",
      CellTags->"StructuredMLE"],
    Cell[1033343, 38701, 434, 14, 15, "Index",
      CellTags->"StructuredMLE"],
    Cell[1322112, 50376, 434, 14, 23, "Index",
      CellTags->"StructuredMLE"],
    Cell[1600812, 61619, 434, 14, 23, "Index",
      CellTags->"StructuredMLE"],
    Cell[1864055, 72285, 434, 14, 15, "Index",
      CellTags->"StructuredMLE"]},
  "StructuredModel"->{
    Cell[422677, 14021, 264, 10, 15, "Index",
      CellTags->"StructuredModel"],
    Cell[739001, 26798, 264, 10, 23, "Index",
      CellTags->"StructuredModel"],
    Cell[1033780, 38717, 264, 10, 15, "Index",
      CellTags->"StructuredModel"],
    Cell[1322549, 50392, 264, 10, 23, "Index",
      CellTags->"StructuredModel"],
    Cell[1601249, 61635, 264, 10, 23, "Index",
      CellTags->"StructuredModel"],
    Cell[1864492, 72301, 264, 10, 15, "Index",
      CellTags->"StructuredModel"]},
  "StructuredModelReduce"->{
    Cell[422944, 14033, 288, 10, 15, "Index",
      CellTags->"StructuredModelReduce"],
    Cell[739268, 26810, 288, 10, 23, "Index",
      CellTags->"StructuredModelReduce"],
    Cell[1034047, 38729, 288, 10, 15, "Index",
      CellTags->"StructuredModelReduce"],
    Cell[1322816, 50404, 288, 10, 23, "Index",
      CellTags->"StructuredModelReduce"],
    Cell[1601516, 61647, 288, 10, 23, "Index",
      CellTags->"StructuredModelReduce"],
    Cell[1864759, 72313, 288, 10, 15, "Index",
      CellTags->"StructuredModelReduce"]},
  "Structured models"->{
    Cell[423235, 14045, 262, 11, 15, "Index",
      CellTags->"Structured models"],
    Cell[423500, 14058, 272, 9, 15, "IndexSubentry",
      CellTags->"Structured models"],
    Cell[739559, 26822, 262, 11, 23, "Index",
      CellTags->"Structured models"],
    Cell[739824, 26835, 272, 9, 23, "IndexSubentry",
      CellTags->"Structured models"],
    Cell[1034338, 38741, 262, 11, 15, "Index",
      CellTags->"Structured models"],
    Cell[1034603, 38754, 272, 9, 15, "IndexSubentry",
      CellTags->"Structured models"],
    Cell[1323107, 50416, 262, 11, 23, "Index",
      CellTags->"Structured models"],
    Cell[1323372, 50429, 272, 9, 23, "IndexSubentry",
      CellTags->"Structured models"],
    Cell[1601807, 61659, 262, 11, 23, "Index",
      CellTags->"Structured models"],
    Cell[1602072, 61672, 272, 9, 23, "IndexSubentry",
      CellTags->"Structured models"],
    Cell[1865050, 72325, 262, 11, 15, "Index",
      CellTags->"Structured models"],
    Cell[1865315, 72338, 272, 9, 15, "IndexSubentry",
      CellTags->"Structured models"]},
  "StructuredParameter"->{
    Cell[423775, 14069, 286, 10, 15, "Index",
      CellTags->"StructuredParameter"],
    Cell[740099, 26846, 286, 10, 23, "Index",
      CellTags->"StructuredParameter"],
    Cell[1034878, 38765, 286, 10, 15, "Index",
      CellTags->"StructuredParameter"],
    Cell[1323647, 50440, 286, 10, 23, "Index",
      CellTags->"StructuredParameter"],
    Cell[1602347, 61683, 286, 10, 23, "Index",
      CellTags->"StructuredParameter"],
    Cell[1865590, 72349, 286, 10, 15, "Index",
      CellTags->"StructuredParameter"]},
  "StructuredVariance"->{
    Cell[424064, 14081, 332, 11, 15, "Index",
      CellTags->"StructuredVariance"],
    Cell[740388, 26858, 332, 11, 23, "Index",
      CellTags->"StructuredVariance"],
    Cell[1035167, 38777, 332, 11, 15, "Index",
      CellTags->"StructuredVariance"],
    Cell[1323936, 50452, 332, 11, 23, "Index",
      CellTags->"StructuredVariance"],
    Cell[1602636, 61695, 332, 11, 23, "Index",
      CellTags->"StructuredVariance"],
    Cell[1865879, 72361, 332, 11, 15, "Index",
      CellTags->"StructuredVariance"]},
  "Style sheets"->{
    Cell[424399, 14094, 248, 11, 15, "Index",
      CellTags->"Style sheets"],
    Cell[740723, 26871, 248, 11, 23, "Index",
      CellTags->"Style sheets"],
    Cell[1035502, 38790, 248, 11, 15, "Index",
      CellTags->"Style sheets"],
    Cell[1324271, 50465, 248, 11, 23, "Index",
      CellTags->"Style sheets"],
    Cell[1602971, 61708, 248, 11, 23, "Index",
      CellTags->"Style sheets"]},
  "Subdivide"->{
    Cell[424650, 14107, 272, 10, 15, "Index",
      CellTags->"Subdivide"],
    Cell[740974, 26884, 272, 10, 23, "Index",
      CellTags->"Subdivide"],
    Cell[1035753, 38803, 272, 10, 15, "Index",
      CellTags->"Subdivide"],
    Cell[1324522, 50478, 272, 10, 23, "Index",
      CellTags->"Subdivide"],
    Cell[1603222, 61721, 272, 10, 23, "Index",
      CellTags->"Subdivide"],
    Cell[1866214, 72374, 272, 10, 15, "Index",
      CellTags->"Subdivide"]},
  "Subscripts"->{
    Cell[424925, 14119, 309, 11, 15, "Index",
      CellTags->"Subscripts"],
    Cell[741249, 26896, 309, 11, 23, "Index",
      CellTags->"Subscripts"],
    Cell[1036028, 38815, 309, 11, 15, "Index",
      CellTags->"Subscripts"],
    Cell[1324797, 50490, 309, 11, 23, "Index",
      CellTags->"Subscripts"],
    Cell[1603497, 61733, 309, 11, 23, "Index",
      CellTags->"Subscripts"],
    Cell[1866489, 72386, 287, 11, 15, "Index",
      CellTags->"Subscripts"]},
  "Subsets"->{
    Cell[425237, 14132, 222, 10, 15, "Index",
      CellTags->"Subsets"],
    Cell[425462, 14144, 366, 15, 30, "IndexSubentry",
      CellTags->"Subsets"],
    Cell[741561, 26909, 222, 10, 23, "Index",
      CellTags->"Subsets"],
    Cell[741786, 26921, 366, 15, 38, "IndexSubentry",
      CellTags->"Subsets"],
    Cell[1036340, 38828, 222, 10, 15, "Index",
      CellTags->"Subsets"],
    Cell[1036565, 38840, 366, 15, 30, "IndexSubentry",
      CellTags->"Subsets"],
    Cell[1325109, 50503, 222, 10, 23, "Index",
      CellTags->"Subsets"],
    Cell[1325334, 50515, 366, 15, 38, "IndexSubentry",
      CellTags->"Subsets"],
    Cell[1603809, 61746, 222, 10, 23, "Index",
      CellTags->"Subsets"],
    Cell[1604034, 61758, 366, 15, 38, "IndexSubentry",
      CellTags->"Subsets"],
    Cell[1866779, 72399, 222, 10, 15, "Index",
      CellTags->"Subsets"],
    Cell[1867004, 72411, 366, 15, 30, "IndexSubentry",
      CellTags->"Subsets"]},
  "Sums"->{
    Cell[425831, 14161, 234, 11, 15, "Index",
      CellTags->"Sums"],
    Cell[742155, 26938, 234, 11, 23, "Index",
      CellTags->"Sums"],
    Cell[1036934, 38857, 234, 11, 15, "Index",
      CellTags->"Sums"],
    Cell[1325703, 50532, 234, 11, 23, "Index",
      CellTags->"Sums"],
    Cell[1604403, 61775, 234, 11, 23, "Index",
      CellTags->"Sums"],
    Cell[1867373, 72428, 234, 11, 15, "Index",
      CellTags->"Sums"]},
  "SwapStates"->{
    Cell[426068, 14174, 255, 10, 15, "Index",
      CellTags->"SwapStates"],
    Cell[742392, 26951, 255, 10, 23, "Index",
      CellTags->"SwapStates"],
    Cell[1037171, 38870, 255, 10, 15, "Index",
      CellTags->"SwapStates"]},
  "Symmetric cline"->{
    Cell[426326, 14186, 344, 11, 15, "Index",
      CellTags->"Symmetric cline"],
    Cell[426673, 14199, 317, 9, 15, "IndexSubentry",
      CellTags->"Symmetric cline"],
    Cell[742650, 26963, 344, 11, 23, "Index",
      CellTags->"Symmetric cline"],
    Cell[742997, 26976, 317, 9, 23, "IndexSubentry",
      CellTags->"Symmetric cline"],
    Cell[1037429, 38882, 344, 11, 15, "Index",
      CellTags->"Symmetric cline"],
    Cell[1037776, 38895, 317, 9, 15, "IndexSubentry",
      CellTags->"Symmetric cline"],
    Cell[1325940, 50545, 344, 11, 23, "Index",
      CellTags->"Symmetric cline"],
    Cell[1326287, 50558, 317, 9, 23, "IndexSubentry",
      CellTags->"Symmetric cline"],
    Cell[1604640, 61788, 344, 11, 23, "Index",
      CellTags->"Symmetric cline"],
    Cell[1604987, 61801, 317, 9, 23, "IndexSubentry",
      CellTags->"Symmetric cline"],
    Cell[1867610, 72441, 344, 11, 15, "Index",
      CellTags->"Symmetric cline"],
    Cell[1867957, 72454, 317, 9, 15, "IndexSubentry",
      CellTags->"Symmetric cline"]},
  "SymmetricDiploidFrequencies"->{
    Cell[426993, 14210, 331, 11, 15, "Index",
      CellTags->"SymmetricDiploidFrequencies"],
    Cell[743317, 26987, 331, 11, 23, "Index",
      CellTags->"SymmetricDiploidFrequencies"],
    Cell[1038096, 38906, 331, 11, 15, "Index",
      CellTags->"SymmetricDiploidFrequencies"],
    Cell[1326607, 50569, 331, 11, 23, "Index",
      CellTags->"SymmetricDiploidFrequencies"],
    Cell[1605307, 61812, 331, 11, 23, "Index",
      CellTags->"SymmetricDiploidFrequencies"],
    Cell[1868277, 72465, 331, 11, 15, "Index",
      CellTags->"SymmetricDiploidFrequencies"]},
  "SymmetricHaploidFrequencies"->{
    Cell[427327, 14223, 331, 11, 15, "Index",
      CellTags->"SymmetricHaploidFrequencies"],
    Cell[743651, 27000, 331, 11, 23, "Index",
      CellTags->"SymmetricHaploidFrequencies"],
    Cell[1038430, 38919, 331, 11, 15, "Index",
      CellTags->"SymmetricHaploidFrequencies"],
    Cell[1326941, 50582, 331, 11, 23, "Index",
      CellTags->"SymmetricHaploidFrequencies"],
    Cell[1605641, 61825, 331, 11, 23, "Index",
      CellTags->"SymmetricHaploidFrequencies"],
    Cell[1868611, 72478, 331, 11, 15, "Index",
      CellTags->"SymmetricHaploidFrequencies"]},
  "Symmetric model"->{
    Cell[427661, 14236, 431, 15, 15, "Index",
      CellTags->"Symmetric model"],
    Cell[428095, 14253, 1473, 49, 105, "IndexSubentry",
      CellTags->"Symmetric model"],
    Cell[743985, 27013, 431, 15, 23, "Index",
      CellTags->"Symmetric model"],
    Cell[744419, 27030, 1473, 49, 113, "IndexSubentry",
      CellTags->"Symmetric model"],
    Cell[1038764, 38932, 431, 15, 15, "Index",
      CellTags->"Symmetric model"],
    Cell[1039198, 38949, 1473, 49, 105, "IndexSubentry",
      CellTags->"Symmetric model"],
    Cell[1327275, 50595, 431, 15, 23, "Index",
      CellTags->"Symmetric model"],
    Cell[1327709, 50612, 1473, 49, 113, "IndexSubentry",
      CellTags->"Symmetric model"],
    Cell[1605975, 61838, 431, 15, 23, "Index",
      CellTags->"Symmetric model"],
    Cell[1606409, 61855, 1473, 49, 113, "IndexSubentry",
      CellTags->"Symmetric model"],
    Cell[1868945, 72491, 431, 15, 15, "Index",
      CellTags->"Symmetric model"],
    Cell[1869379, 72508, 1473, 49, 105, "IndexSubentry",
      CellTags->"Symmetric model"]},
  "SymmetricNeutralDiploidFrequencies"->{
    Cell[429571, 14304, 477, 15, 15, "Index",
      CellTags->"SymmetricNeutralDiploidFrequencies"],
    Cell[745895, 27081, 477, 15, 23, "Index",
      CellTags->"SymmetricNeutralDiploidFrequencies"],
    Cell[1040674, 39000, 477, 15, 15, "Index",
      CellTags->"SymmetricNeutralDiploidFrequencies"],
    Cell[1329185, 50663, 477, 15, 23, "Index",
      CellTags->"SymmetricNeutralDiploidFrequencies"],
    Cell[1607885, 61906, 477, 15, 23, "Index",
      CellTags->"SymmetricNeutralDiploidFrequencies"],
    Cell[1870855, 72559, 477, 15, 15, "Index",
      CellTags->"SymmetricNeutralDiploidFrequencies"]},
  "SymmetricNeutralHaploidFrequencies"->{
    Cell[430051, 14321, 477, 15, 15, "Index",
      CellTags->"SymmetricNeutralHaploidFrequencies"],
    Cell[746375, 27098, 477, 15, 23, "Index",
      CellTags->"SymmetricNeutralHaploidFrequencies"],
    Cell[1041154, 39017, 477, 15, 15, "Index",
      CellTags->"SymmetricNeutralHaploidFrequencies"],
    Cell[1329665, 50680, 477, 15, 23, "Index",
      CellTags->"SymmetricNeutralHaploidFrequencies"],
    Cell[1608365, 61923, 477, 15, 23, "Index",
      CellTags->"SymmetricNeutralHaploidFrequencies"],
    Cell[1871335, 72576, 477, 15, 15, "Index",
      CellTags->"SymmetricNeutralHaploidFrequencies"]},
  "SymmetricRecombination"->{
    Cell[430531, 14338, 279, 10, 15, "Index",
      CellTags->"SymmetricRecombination"],
    Cell[746855, 27115, 279, 10, 23, "Index",
      CellTags->"SymmetricRecombination"],
    Cell[1041634, 39034, 279, 10, 15, "Index",
      CellTags->"SymmetricRecombination"],
    Cell[1330145, 50697, 279, 10, 23, "Index",
      CellTags->"SymmetricRecombination"],
    Cell[1608845, 61940, 279, 10, 23, "Index",
      CellTags->"SymmetricRecombination"],
    Cell[1871815, 72593, 279, 10, 15, "Index",
      CellTags->"SymmetricRecombination"]},
  "SymmetricRepresentations"->{
    Cell[430813, 14350, 315, 10, 15, "Index",
      CellTags->"SymmetricRepresentations"],
    Cell[747137, 27127, 315, 10, 23, "Index",
      CellTags->"SymmetricRepresentations"],
    Cell[1041916, 39046, 315, 10, 15, "Index",
      CellTags->"SymmetricRepresentations"],
    Cell[1330427, 50709, 315, 10, 23, "Index",
      CellTags->"SymmetricRepresentations"],
    Cell[1609127, 61952, 315, 10, 23, "Index",
      CellTags->"SymmetricRepresentations"],
    Cell[1872097, 72605, 315, 10, 15, "Index",
      CellTags->"SymmetricRepresentations"]},
  "SymmetricSexes"->{
    Cell[431131, 14362, 259, 10, 15, "Index",
      CellTags->"SymmetricSexes"],
    Cell[747455, 27139, 259, 10, 23, "Index",
      CellTags->"SymmetricSexes"],
    Cell[1042234, 39058, 259, 10, 15, "Index",
      CellTags->"SymmetricSexes"],
    Cell[1330745, 50721, 259, 10, 23, "Index",
      CellTags->"SymmetricSexes"],
    Cell[1609445, 61964, 259, 10, 23, "Index",
      CellTags->"SymmetricSexes"],
    Cell[1872415, 72617, 259, 10, 15, "Index",
      CellTags->"SymmetricSexes"]},
  "Symmetrise"->{
    Cell[431393, 14374, 356, 14, 15, "Index",
      CellTags->"Symmetrise"],
    Cell[747717, 27151, 356, 14, 23, "Index",
      CellTags->"Symmetrise"],
    Cell[1042496, 39070, 356, 14, 15, "Index",
      CellTags->"Symmetrise"],
    Cell[1331007, 50733, 356, 14, 23, "Index",
      CellTags->"Symmetrise"],
    Cell[1609707, 61976, 356, 14, 23, "Index",
      CellTags->"Symmetrise"],
    Cell[1872677, 72629, 356, 14, 15, "Index",
      CellTags->"Symmetrise"]},
  "T"->{
    Cell[431752, 14390, 234, 11, 15, "Index",
      CellTags->"T"],
    Cell[748076, 27167, 234, 11, 23, "Index",
      CellTags->"T"],
    Cell[1042855, 39086, 234, 11, 15, "Index",
      CellTags->"T"],
    Cell[1331366, 50749, 234, 11, 23, "Index",
      CellTags->"T"],
    Cell[1610066, 61992, 234, 11, 23, "Index",
      CellTags->"T"],
    Cell[1873036, 72645, 234, 11, 15, "Index",
      CellTags->"T"]},
  "Table"->{
    Cell[431989, 14403, 277, 11, 15, "Index",
      CellTags->"Table"],
    Cell[748313, 27180, 277, 11, 23, "Index",
      CellTags->"Table"],
    Cell[1043092, 39099, 277, 11, 15, "Index",
      CellTags->"Table"],
    Cell[1331603, 50762, 277, 11, 23, "Index",
      CellTags->"Table"],
    Cell[1610303, 62005, 277, 11, 23, "Index",
      CellTags->"Table"],
    Cell[1873273, 72658, 277, 11, 15, "Index",
      CellTags->"Table"]},
  "Tag"->{
    Cell[432269, 14416, 220, 10, 15, "Index",
      CellTags->"Tag"],
    Cell[748593, 27193, 220, 10, 23, "Index",
      CellTags->"Tag"],
    Cell[1043372, 39112, 220, 10, 15, "Index",
      CellTags->"Tag"],
    Cell[1331883, 50775, 220, 10, 23, "Index",
      CellTags->"Tag"],
    Cell[1610583, 62018, 220, 10, 23, "Index",
      CellTags->"Tag"],
    Cell[1873553, 72671, 220, 10, 15, "Index",
      CellTags->"Tag"]},
  "Tags"->{
    Cell[432492, 14428, 260, 11, 15, "Index",
      CellTags->"Tags"],
    Cell[432755, 14441, 295, 10, 15, "IndexSubentry",
      CellTags->"Tags"],
    Cell[748816, 27205, 260, 11, 23, "Index",
      CellTags->"Tags"],
    Cell[749079, 27218, 295, 10, 23, "IndexSubentry",
      CellTags->"Tags"],
    Cell[1043595, 39124, 260, 11, 15, "Index",
      CellTags->"Tags"],
    Cell[1043858, 39137, 295, 10, 15, "IndexSubentry",
      CellTags->"Tags"],
    Cell[1332106, 50787, 260, 11, 23, "Index",
      CellTags->"Tags"],
    Cell[1332369, 50800, 295, 10, 23, "IndexSubentry",
      CellTags->"Tags"],
    Cell[1610806, 62030, 260, 11, 23, "Index",
      CellTags->"Tags"],
    Cell[1611069, 62043, 295, 10, 23, "IndexSubentry",
      CellTags->"Tags"],
    Cell[1873776, 72683, 260, 11, 15, "Index",
      CellTags->"Tags"],
    Cell[1874039, 72696, 295, 10, 15, "IndexSubentry",
      CellTags->"Tags"]},
  "TakeAway"->{
    Cell[433053, 14453, 390, 12, 15, "Index",
      CellTags->"TakeAway"],
    Cell[749377, 27230, 390, 12, 23, "Index",
      CellTags->"TakeAway"],
    Cell[1044156, 39149, 390, 12, 15, "Index",
      CellTags->"TakeAway"],
    Cell[1332667, 50812, 390, 12, 23, "Index",
      CellTags->"TakeAway"],
    Cell[1611367, 62055, 390, 12, 23, "Index",
      CellTags->"TakeAway"],
    Cell[1874337, 72708, 390, 12, 15, "Index",
      CellTags->"TakeAway"]},
  "TakeOptions"->{
    Cell[433446, 14467, 260, 10, 15, "Index",
      CellTags->"TakeOptions"],
    Cell[749770, 27244, 260, 10, 23, "Index",
      CellTags->"TakeOptions"],
    Cell[1044549, 39163, 260, 10, 15, "Index",
      CellTags->"TakeOptions"],
    Cell[1333060, 50826, 260, 10, 23, "Index",
      CellTags->"TakeOptions"],
    Cell[1611760, 62069, 260, 10, 23, "Index",
      CellTags->"TakeOptions"],
    Cell[1874730, 72722, 260, 10, 15, "Index",
      CellTags->"TakeOptions"]},
  "Time"->{
    Cell[433709, 14479, 237, 11, 15, "Index",
      CellTags->"Time"],
    Cell[750033, 27256, 237, 11, 23, "Index",
      CellTags->"Time"],
    Cell[1044812, 39175, 237, 11, 15, "Index",
      CellTags->"Time"],
    Cell[1333323, 50838, 237, 11, 23, "Index",
      CellTags->"Time"],
    Cell[1612023, 62081, 237, 11, 23, "Index",
      CellTags->"Time"],
    Cell[1874993, 72734, 237, 11, 15, "Index",
      CellTags->"Time"]},
  "TimesOfEvents"->{
    Cell[433949, 14492, 307, 11, 15, "Index",
      CellTags->"TimesOfEvents"],
    Cell[750273, 27269, 307, 11, 23, "Index",
      CellTags->"TimesOfEvents"]},
  "TimespanOfJunction"->{
    Cell[434259, 14505, 322, 11, 15, "Index",
      CellTags->"TimespanOfJunction"],
    Cell[750583, 27282, 322, 11, 23, "Index",
      CellTags->"TimespanOfJunction"]},
  "TimespanOfLineage"->{
    Cell[434584, 14518, 319, 11, 15, "Index",
      CellTags->"TimespanOfLineage"],
    Cell[750908, 27295, 319, 11, 23, "Index",
      CellTags->"TimespanOfLineage"]},
  "TimesUp"->{
    Cell[434906, 14531, 346, 14, 15, "Index",
      CellTags->"TimesUp"],
    Cell[435255, 14547, 375, 15, 30, "IndexSubentry",
      CellTags->"TimesUp"],
    Cell[751230, 27308, 346, 14, 23, "Index",
      CellTags->"TimesUp"],
    Cell[751579, 27324, 375, 15, 38, "IndexSubentry",
      CellTags->"TimesUp"],
    Cell[1045052, 39188, 346, 14, 15, "Index",
      CellTags->"TimesUp"],
    Cell[1045401, 39204, 375, 15, 30, "IndexSubentry",
      CellTags->"TimesUp"],
    Cell[1333563, 50851, 346, 14, 23, "Index",
      CellTags->"TimesUp"],
    Cell[1333912, 50867, 375, 15, 38, "IndexSubentry",
      CellTags->"TimesUp"],
    Cell[1612263, 62094, 346, 14, 23, "Index",
      CellTags->"TimesUp"],
    Cell[1612612, 62110, 375, 15, 38, "IndexSubentry",
      CellTags->"TimesUp"],
    Cell[1875233, 72747, 346, 14, 15, "Index",
      CellTags->"TimesUp"],
    Cell[1875582, 72763, 375, 15, 30, "IndexSubentry",
      CellTags->"TimesUp"]},
  "ToBaake"->{
    Cell[435633, 14564, 248, 10, 15, "Index",
      CellTags->"ToBaake"],
    Cell[751957, 27341, 248, 10, 23, "Index",
      CellTags->"ToBaake"],
    Cell[1045779, 39221, 248, 10, 15, "Index",
      CellTags->"ToBaake"],
    Cell[1334290, 50884, 248, 10, 23, "Index",
      CellTags->"ToBaake"]},
  "ToBennett"->{
    Cell[435884, 14576, 254, 10, 15, "Index",
      CellTags->"ToBennett"],
    Cell[752208, 27353, 254, 10, 23, "Index",
      CellTags->"ToBennett"],
    Cell[1046030, 39233, 254, 10, 15, "Index",
      CellTags->"ToBennett"],
    Cell[1334541, 50896, 254, 10, 23, "Index",
      CellTags->"ToBennett"]},
  "ToBennettExpression"->{
    Cell[436141, 14588, 284, 10, 15, "Index",
      CellTags->"ToBennettExpression"],
    Cell[752465, 27365, 284, 10, 23, "Index",
      CellTags->"ToBennettExpression"],
    Cell[1046287, 39245, 284, 10, 15, "Index",
      CellTags->"ToBennettExpression"],
    Cell[1334798, 50908, 284, 10, 23, "Index",
      CellTags->"ToBennettExpression"]},
  "ToCumulants"->{
    Cell[436428, 14600, 260, 10, 15, "Index",
      CellTags->"ToCumulants"],
    Cell[752752, 27377, 260, 10, 23, "Index",
      CellTags->"ToCumulants"],
    Cell[1046574, 39257, 260, 10, 15, "Index",
      CellTags->"ToCumulants"],
    Cell[1335085, 50920, 260, 10, 23, "Index",
      CellTags->"ToCumulants"],
    Cell[1612990, 62127, 260, 10, 23, "Index",
      CellTags->"ToCumulants"],
    Cell[1875960, 72780, 260, 10, 15, "Index",
      CellTags->"ToCumulants"]},
  "ToMoments"->{
    Cell[436691, 14612, 254, 10, 15, "Index",
      CellTags->"ToMoments"],
    Cell[753015, 27389, 254, 10, 23, "Index",
      CellTags->"ToMoments"],
    Cell[1046837, 39269, 254, 10, 15, "Index",
      CellTags->"ToMoments"],
    Cell[1335348, 50932, 254, 10, 23, "Index",
      CellTags->"ToMoments"],
    Cell[1613253, 62139, 254, 10, 23, "Index",
      CellTags->"ToMoments"],
    Cell[1876223, 72792, 254, 10, 15, "Index",
      CellTags->"ToMoments"]},
  "ToPopulationCumulants"->{
    Cell[436948, 14624, 296, 10, 15, "Index",
      CellTags->"ToPopulationCumulants"],
    Cell[753272, 27401, 296, 10, 23, "Index",
      CellTags->"ToPopulationCumulants"],
    Cell[1047094, 39281, 296, 10, 15, "Index",
      CellTags->"ToPopulationCumulants"],
    Cell[1335605, 50944, 296, 10, 23, "Index",
      CellTags->"ToPopulationCumulants"],
    Cell[1613510, 62151, 296, 10, 23, "Index",
      CellTags->"ToPopulationCumulants"],
    Cell[1876480, 72804, 296, 10, 15, "Index",
      CellTags->"ToPopulationCumulants"]},
  "ToPopulationMoments"->{
    Cell[437247, 14636, 290, 10, 15, "Index",
      CellTags->"ToPopulationMoments"],
    Cell[753571, 27413, 290, 10, 23, "Index",
      CellTags->"ToPopulationMoments"],
    Cell[1047393, 39293, 290, 10, 15, "Index",
      CellTags->"ToPopulationMoments"],
    Cell[1335904, 50956, 290, 10, 23, "Index",
      CellTags->"ToPopulationMoments"],
    Cell[1613809, 62163, 290, 10, 23, "Index",
      CellTags->"ToPopulationMoments"],
    Cell[1876779, 72816, 290, 10, 15, "Index",
      CellTags->"ToPopulationMoments"]},
  "TotalLength"->{
    Cell[437540, 14648, 286, 10, 15, "Index",
      CellTags->"TotalLength"],
    Cell[753864, 27425, 286, 10, 23, "Index",
      CellTags->"TotalLength"],
    Cell[1047686, 39305, 286, 10, 15, "Index",
      CellTags->"TotalLength"],
    Cell[1336197, 50968, 286, 10, 23, "Index",
      CellTags->"TotalLength"],
    Cell[1614102, 62175, 286, 10, 23, "Index",
      CellTags->"TotalLength"],
    Cell[1877072, 72828, 286, 10, 15, "Index",
      CellTags->"TotalLength"]},
  "TotalNumber"->{
    Cell[437829, 14660, 252, 10, 15, "Index",
      CellTags->"TotalNumber"],
    Cell[754153, 27437, 252, 10, 23, "Index",
      CellTags->"TotalNumber"],
    Cell[1047975, 39317, 252, 10, 15, "Index",
      CellTags->"TotalNumber"],
    Cell[1336486, 50980, 252, 10, 23, "Index",
      CellTags->"TotalNumber"],
    Cell[1614391, 62187, 252, 10, 23, "Index",
      CellTags->"TotalNumber"],
    Cell[1877361, 72840, 252, 10, 15, "Index",
      CellTags->"TotalNumber"]},
  "Trait"->{
    Cell[438084, 14672, 339, 12, 15, "Index",
      CellTags->"Trait"],
    Cell[754408, 27449, 339, 12, 23, "Index",
      CellTags->"Trait"],
    Cell[1048230, 39329, 339, 12, 15, "Index",
      CellTags->"Trait"],
    Cell[1336741, 50992, 339, 12, 23, "Index",
      CellTags->"Trait"],
    Cell[1614646, 62199, 339, 12, 23, "Index",
      CellTags->"Trait"],
    Cell[1877616, 72852, 339, 12, 15, "Index",
      CellTags->"Trait"]},
  "TransformedRange"->{
    Cell[438426, 14686, 271, 10, 15, "Index",
      CellTags->"TransformedRange"],
    Cell[754750, 27463, 271, 10, 23, "Index",
      CellTags->"TransformedRange"],
    Cell[1048572, 39343, 271, 10, 15, "Index",
      CellTags->"TransformedRange"],
    Cell[1337083, 51006, 271, 10, 23, "Index",
      CellTags->"TransformedRange"],
    Cell[1614988, 62213, 271, 10, 23, "Index",
      CellTags->"TransformedRange"],
    Cell[1877958, 72866, 271, 10, 15, "Index",
      CellTags->"TransformedRange"]},
  "TransformInformation"->{
    Cell[438700, 14698, 291, 10, 15, "Index",
      CellTags->"TransformInformation"],
    Cell[755024, 27475, 291, 10, 23, "Index",
      CellTags->"TransformInformation"],
    Cell[1048846, 39355, 291, 10, 15, "Index",
      CellTags->"TransformInformation"],
    Cell[1337357, 51018, 291, 10, 23, "Index",
      CellTags->"TransformInformation"],
    Cell[1615262, 62225, 291, 10, 23, "Index",
      CellTags->"TransformInformation"],
    Cell[1878232, 72878, 291, 10, 15, "Index",
      CellTags->"TransformInformation"]},
  "TransmissionRule"->{
    Cell[438994, 14710, 269, 10, 15, "Index",
      CellTags->"TransmissionRule"],
    Cell[755318, 27487, 269, 10, 23, "Index",
      CellTags->"TransmissionRule"],
    Cell[1049140, 39367, 269, 10, 15, "Index",
      CellTags->"TransmissionRule"],
    Cell[1337651, 51030, 269, 10, 23, "Index",
      CellTags->"TransmissionRule"],
    Cell[1615556, 62237, 269, 10, 23, "Index",
      CellTags->"TransmissionRule"],
    Cell[1878526, 72890, 269, 10, 15, "Index",
      CellTags->"TransmissionRule"]},
  "Transmission rules"->{
    Cell[439266, 14722, 300, 11, 15, "Index",
      CellTags->"Transmission rules"],
    Cell[439569, 14735, 647, 21, 45, "IndexSubentry",
      CellTags->"Transmission rules"],
    Cell[755590, 27499, 300, 11, 23, "Index",
      CellTags->"Transmission rules"],
    Cell[755893, 27512, 647, 21, 53, "IndexSubentry",
      CellTags->"Transmission rules"],
    Cell[1049412, 39379, 300, 11, 15, "Index",
      CellTags->"Transmission rules"],
    Cell[1049715, 39392, 647, 21, 45, "IndexSubentry",
      CellTags->"Transmission rules"],
    Cell[1337923, 51042, 300, 11, 23, "Index",
      CellTags->"Transmission rules"],
    Cell[1338226, 51055, 647, 21, 53, "IndexSubentry",
      CellTags->"Transmission rules"],
    Cell[1615828, 62249, 300, 11, 23, "Index",
      CellTags->"Transmission rules"],
    Cell[1616131, 62262, 647, 21, 53, "IndexSubentry",
      CellTags->"Transmission rules"],
    Cell[1878798, 72902, 300, 11, 15, "Index",
      CellTags->"Transmission rules"],
    Cell[1879101, 72915, 472, 15, 30, "IndexSubentry",
      CellTags->"Transmission rules"]},
  "TriDiagonalMatrix"->{
    Cell[440219, 14758, 272, 10, 15, "Index",
      CellTags->"TriDiagonalMatrix"],
    Cell[756543, 27535, 272, 10, 23, "Index",
      CellTags->"TriDiagonalMatrix"],
    Cell[1050365, 39415, 272, 10, 15, "Index",
      CellTags->"TriDiagonalMatrix"],
    Cell[1338876, 51078, 272, 10, 23, "Index",
      CellTags->"TriDiagonalMatrix"],
    Cell[1616781, 62285, 272, 10, 23, "Index",
      CellTags->"TriDiagonalMatrix"],
    Cell[1879576, 72932, 272, 10, 15, "Index",
      CellTags->"TriDiagonalMatrix"]},
  "TruncationSelection"->{
    Cell[440494, 14770, 352, 12, 15, "Index",
      CellTags->"TruncationSelection"],
    Cell[440849, 14784, 318, 9, 15, "IndexSubentry",
      CellTags->"TruncationSelection"],
    Cell[756818, 27547, 352, 12, 23, "Index",
      CellTags->"TruncationSelection"],
    Cell[757173, 27561, 318, 9, 23, "IndexSubentry",
      CellTags->"TruncationSelection"],
    Cell[1050640, 39427, 352, 12, 15, "Index",
      CellTags->"TruncationSelection"],
    Cell[1050995, 39441, 318, 9, 15, "IndexSubentry",
      CellTags->"TruncationSelection"],
    Cell[1339151, 51090, 352, 12, 23, "Index",
      CellTags->"TruncationSelection"],
    Cell[1339506, 51104, 318, 9, 23, "IndexSubentry",
      CellTags->"TruncationSelection"],
    Cell[1617056, 62297, 352, 12, 23, "Index",
      CellTags->"TruncationSelection"],
    Cell[1617411, 62311, 318, 9, 23, "IndexSubentry",
      CellTags->"TruncationSelection"]},
  "Turelli and Barton 1994"->{
    Cell[441170, 14795, 298, 10, 15, "Index",
      CellTags->"Turelli and Barton 1994"],
    Cell[757494, 27572, 298, 10, 23, "Index",
      CellTags->"Turelli and Barton 1994"],
    Cell[1051316, 39452, 298, 10, 15, "Index",
      CellTags->"Turelli and Barton 1994"],
    Cell[1339827, 51115, 298, 10, 23, "Index",
      CellTags->"Turelli and Barton 1994"],
    Cell[1617732, 62322, 298, 10, 23, "Index",
      CellTags->"Turelli and Barton 1994"],
    Cell[1879851, 72944, 298, 10, 15, "Index",
      CellTags->"Turelli and Barton 1994"]},
  "Turelli & Barton 1994"->{
    Cell[441471, 14807, 270, 10, 15, "Index",
      CellTags->"Turelli & Barton 1994"],
    Cell[757795, 27584, 270, 10, 23, "Index",
      CellTags->"Turelli & Barton 1994"],
    Cell[1051617, 39464, 270, 10, 15, "Index",
      CellTags->"Turelli & Barton 1994"],
    Cell[1340128, 51127, 270, 10, 23, "Index",
      CellTags->"Turelli & Barton 1994"],
    Cell[1618033, 62334, 270, 10, 23, "Index",
      CellTags->"Turelli & Barton 1994"],
    Cell[1880152, 72956, 270, 10, 15, "Index",
      CellTags->"Turelli & Barton 1994"]},
  "Two alleles"->{
    Cell[441744, 14819, 240, 10, 15, "Index",
      CellTags->"Two alleles"],
    Cell[441987, 14831, 360, 13, 15, "IndexSubentry",
      CellTags->"Two alleles"],
    Cell[758068, 27596, 240, 10, 23, "Index",
      CellTags->"Two alleles"],
    Cell[758311, 27608, 360, 13, 23, "IndexSubentry",
      CellTags->"Two alleles"],
    Cell[1051890, 39476, 240, 10, 15, "Index",
      CellTags->"Two alleles"],
    Cell[1052133, 39488, 360, 13, 15, "IndexSubentry",
      CellTags->"Two alleles"],
    Cell[1340401, 51139, 240, 10, 23, "Index",
      CellTags->"Two alleles"],
    Cell[1340644, 51151, 360, 13, 23, "IndexSubentry",
      CellTags->"Two alleles"],
    Cell[1618306, 62346, 240, 10, 23, "Index",
      CellTags->"Two alleles"],
    Cell[1618549, 62358, 360, 13, 23, "IndexSubentry",
      CellTags->"Two alleles"],
    Cell[1880425, 72968, 240, 10, 15, "Index",
      CellTags->"Two alleles"],
    Cell[1880668, 72980, 360, 13, 15, "IndexSubentry",
      CellTags->"Two alleles"]},
  "UMS"->{
    Cell[442350, 14846, 302, 11, 15, "Index",
      CellTags->"UMS"],
    Cell[442655, 14859, 667, 21, 45, "IndexSubentry",
      CellTags->"UMS"],
    Cell[758674, 27623, 302, 11, 23, "Index",
      CellTags->"UMS"],
    Cell[758979, 27636, 667, 21, 53, "IndexSubentry",
      CellTags->"UMS"],
    Cell[1052496, 39503, 302, 11, 15, "Index",
      CellTags->"UMS"],
    Cell[1052801, 39516, 667, 21, 45, "IndexSubentry",
      CellTags->"UMS"],
    Cell[1341007, 51166, 302, 11, 23, "Index",
      CellTags->"UMS"],
    Cell[1341312, 51179, 667, 21, 53, "IndexSubentry",
      CellTags->"UMS"],
    Cell[1618912, 62373, 302, 11, 23, "Index",
      CellTags->"UMS"],
    Cell[1619217, 62386, 667, 21, 53, "IndexSubentry",
      CellTags->"UMS"],
    Cell[1881031, 72995, 302, 11, 15, "Index",
      CellTags->"UMS"],
    Cell[1881336, 73008, 667, 21, 45, "IndexSubentry",
      CellTags->"UMS"]},
  "UnionOfGametes"->{
    Cell[443325, 14882, 261, 10, 15, "Index",
      CellTags->"UnionOfGametes"],
    Cell[759649, 27659, 261, 10, 23, "Index",
      CellTags->"UnionOfGametes"],
    Cell[1053471, 39539, 261, 10, 15, "Index",
      CellTags->"UnionOfGametes"],
    Cell[1341982, 51202, 261, 10, 23, "Index",
      CellTags->"UnionOfGametes"],
    Cell[1619887, 62409, 261, 10, 23, "Index",
      CellTags->"UnionOfGametes"],
    Cell[1882006, 73031, 261, 10, 15, "Index",
      CellTags->"UnionOfGametes"]},
  "UnlinkedRecombination"->{
    Cell[443589, 14894, 276, 10, 15, "Index",
      CellTags->"UnlinkedRecombination"],
    Cell[759913, 27671, 276, 10, 23, "Index",
      CellTags->"UnlinkedRecombination"],
    Cell[1053735, 39551, 276, 10, 15, "Index",
      CellTags->"UnlinkedRecombination"],
    Cell[1342246, 51214, 276, 10, 23, "Index",
      CellTags->"UnlinkedRecombination"],
    Cell[1620151, 62421, 276, 10, 23, "Index",
      CellTags->"UnlinkedRecombination"],
    Cell[1882270, 73043, 276, 10, 15, "Index",
      CellTags->"UnlinkedRecombination"]},
  "UnrootedGenealogy"->{
    Cell[443868, 14906, 286, 10, 15, "Index",
      CellTags->"UnrootedGenealogy"],
    Cell[760192, 27683, 286, 10, 23, "Index",
      CellTags->"UnrootedGenealogy"],
    Cell[1054014, 39563, 286, 10, 15, "Index",
      CellTags->"UnrootedGenealogy"],
    Cell[1342525, 51226, 286, 10, 23, "Index",
      CellTags->"UnrootedGenealogy"],
    Cell[1620430, 62433, 286, 10, 23, "Index",
      CellTags->"UnrootedGenealogy"],
    Cell[1882549, 73055, 286, 10, 15, "Index",
      CellTags->"UnrootedGenealogy"]},
  "UpperOffDiagonal"->{
    Cell[444157, 14918, 269, 10, 15, "Index",
      CellTags->"UpperOffDiagonal"],
    Cell[760481, 27695, 269, 10, 23, "Index",
      CellTags->"UpperOffDiagonal"],
    Cell[1054303, 39575, 269, 10, 15, "Index",
      CellTags->"UpperOffDiagonal"],
    Cell[1342814, 51238, 269, 10, 23, "Index",
      CellTags->"UpperOffDiagonal"],
    Cell[1620719, 62445, 269, 10, 23, "Index",
      CellTags->"UpperOffDiagonal"],
    Cell[1882838, 73067, 269, 10, 15, "Index",
      CellTags->"UpperOffDiagonal"]},
  "USM"->{
    Cell[444429, 14930, 302, 11, 15, "Index",
      CellTags->"USM"],
    Cell[444734, 14943, 667, 21, 45, "IndexSubentry",
      CellTags->"USM"],
    Cell[760753, 27707, 302, 11, 23, "Index",
      CellTags->"USM"],
    Cell[761058, 27720, 667, 21, 53, "IndexSubentry",
      CellTags->"USM"],
    Cell[1054575, 39587, 302, 11, 15, "Index",
      CellTags->"USM"],
    Cell[1054880, 39600, 667, 21, 45, "IndexSubentry",
      CellTags->"USM"],
    Cell[1343086, 51250, 302, 11, 23, "Index",
      CellTags->"USM"],
    Cell[1343391, 51263, 667, 21, 53, "IndexSubentry",
      CellTags->"USM"],
    Cell[1620991, 62457, 302, 11, 23, "Index",
      CellTags->"USM"],
    Cell[1621296, 62470, 667, 21, 53, "IndexSubentry",
      CellTags->"USM"],
    Cell[1883110, 73079, 302, 11, 15, "Index",
      CellTags->"USM"],
    Cell[1883415, 73092, 667, 21, 45, "IndexSubentry",
      CellTags->"USM"]},
  "ValidMatrixQ"->{
    Cell[445404, 14966, 281, 10, 15, "Index",
      CellTags->"ValidMatrixQ"],
    Cell[761728, 27743, 281, 10, 23, "Index",
      CellTags->"ValidMatrixQ"],
    Cell[1055550, 39623, 281, 10, 15, "Index",
      CellTags->"ValidMatrixQ"]},
  "VarianceComponents"->{
    Cell[445688, 14978, 332, 11, 15, "Index",
      CellTags->"VarianceComponents"],
    Cell[446023, 14991, 263, 9, 15, "IndexSubentry",
      CellTags->"VarianceComponents"],
    Cell[762012, 27755, 332, 11, 23, "Index",
      CellTags->"VarianceComponents"],
    Cell[762347, 27768, 263, 9, 23, "IndexSubentry",
      CellTags->"VarianceComponents"],
    Cell[1055834, 39635, 332, 11, 15, "Index",
      CellTags->"VarianceComponents"],
    Cell[1056169, 39648, 263, 9, 15, "IndexSubentry",
      CellTags->"VarianceComponents"],
    Cell[1344061, 51286, 332, 11, 23, "Index",
      CellTags->"VarianceComponents"],
    Cell[1344396, 51299, 263, 9, 23, "IndexSubentry",
      CellTags->"VarianceComponents"],
    Cell[1621966, 62493, 332, 11, 23, "Index",
      CellTags->"VarianceComponents"],
    Cell[1622301, 62506, 263, 9, 23, "IndexSubentry",
      CellTags->"VarianceComponents"],
    Cell[1884085, 73115, 332, 11, 15, "Index",
      CellTags->"VarianceComponents"],
    Cell[1884420, 73128, 263, 9, 15, "IndexSubentry",
      CellTags->"VarianceComponents"]},
  "Versions"->{
    Cell[446289, 15002, 253, 11, 15, "Index",
      CellTags->"Versions"],
    Cell[762613, 27779, 253, 11, 23, "Index",
      CellTags->"Versions"],
    Cell[1056435, 39659, 253, 11, 15, "Index",
      CellTags->"Versions"],
    Cell[1344662, 51310, 253, 11, 23, "Index",
      CellTags->"Versions"],
    Cell[1622567, 62517, 253, 11, 23, "Index",
      CellTags->"Versions"],
    Cell[1884686, 73139, 253, 11, 15, "Index",
      CellTags->"Versions"]},
  "Wiuf & Hein 1999"->{
    Cell[446545, 15015, 426, 14, 15, "Index",
      CellTags->"Wiuf & Hein 1999"],
    Cell[762869, 27792, 428, 14, 23, "Index",
      CellTags->"Wiuf & Hein 1999"]},
  "WLinkedLoci"->{
    Cell[446974, 15031, 260, 11, 15, "Index",
      CellTags->"WLinkedLoci"],
    Cell[447237, 15044, 441, 15, 30, "IndexSubentry",
      CellTags->"WLinkedLoci"],
    Cell[763300, 27808, 260, 11, 23, "Index",
      CellTags->"WLinkedLoci"],
    Cell[763563, 27821, 441, 15, 38, "IndexSubentry",
      CellTags->"WLinkedLoci"],
    Cell[1056691, 39672, 260, 11, 15, "Index",
      CellTags->"WLinkedLoci"],
    Cell[1056954, 39685, 441, 15, 30, "IndexSubentry",
      CellTags->"WLinkedLoci"],
    Cell[1344918, 51323, 260, 11, 23, "Index",
      CellTags->"WLinkedLoci"],
    Cell[1345181, 51336, 441, 15, 38, "IndexSubentry",
      CellTags->"WLinkedLoci"],
    Cell[1622823, 62530, 260, 11, 23, "Index",
      CellTags->"WLinkedLoci"],
    Cell[1623086, 62543, 441, 15, 38, "IndexSubentry",
      CellTags->"WLinkedLoci"],
    Cell[1884942, 73152, 260, 11, 15, "Index",
      CellTags->"WLinkedLoci"],
    Cell[1885205, 73165, 441, 15, 30, "IndexSubentry",
      CellTags->"WLinkedLoci"]},
  "Wright-Fisher sampling"->{
    Cell[447681, 15061, 277, 10, 15, "Index",
      CellTags->"Wright-Fisher sampling"],
    Cell[764007, 27838, 277, 10, 23, "Index",
      CellTags->"Wright-Fisher sampling"],
    Cell[1057398, 39702, 277, 10, 15, "Index",
      CellTags->"Wright-Fisher sampling"],
    Cell[1345625, 51353, 277, 10, 23, "Index",
      CellTags->"Wright-Fisher sampling"],
    Cell[1623530, 62560, 277, 10, 23, "Index",
      CellTags->"Wright-Fisher sampling"],
    Cell[1885649, 73182, 277, 10, 15, "Index",
      CellTags->"Wright-Fisher sampling"]},
  "X"->{
    Cell[447961, 15073, 247, 11, 15, "Index",
      CellTags->"X"],
    Cell[764287, 27850, 247, 11, 23, "Index",
      CellTags->"X"],
    Cell[1057678, 39714, 247, 11, 15, "Index",
      CellTags->"X"],
    Cell[1345905, 51365, 247, 11, 15, "Index",
      CellTags->"X"],
    Cell[1623810, 62572, 247, 11, 23, "Index",
      CellTags->"X"],
    Cell[1885929, 73194, 247, 11, 15, "Index",
      CellTags->"X"]},
  "XLinkedLoci"->{
    Cell[448211, 15086, 260, 11, 15, "Index",
      CellTags->"XLinkedLoci"],
    Cell[448474, 15099, 441, 15, 30, "IndexSubentry",
      CellTags->"XLinkedLoci"],
    Cell[764537, 27863, 260, 11, 23, "Index",
      CellTags->"XLinkedLoci"],
    Cell[764800, 27876, 441, 15, 38, "IndexSubentry",
      CellTags->"XLinkedLoci"],
    Cell[1057928, 39727, 260, 11, 15, "Index",
      CellTags->"XLinkedLoci"],
    Cell[1058191, 39740, 441, 15, 30, "IndexSubentry",
      CellTags->"XLinkedLoci"],
    Cell[1346155, 51378, 260, 11, 15, "Index",
      CellTags->"XLinkedLoci"],
    Cell[1346418, 51391, 441, 15, 30, "IndexSubentry",
      CellTags->"XLinkedLoci"],
    Cell[1624060, 62585, 260, 11, 23, "Index",
      CellTags->"XLinkedLoci"],
    Cell[1624323, 62598, 441, 15, 38, "IndexSubentry",
      CellTags->"XLinkedLoci"],
    Cell[1886179, 73207, 260, 11, 15, "Index",
      CellTags->"XLinkedLoci"],
    Cell[1886442, 73220, 441, 15, 30, "IndexSubentry",
      CellTags->"XLinkedLoci"]},
  "YLinkedLoci"->{
    Cell[448918, 15116, 260, 11, 15, "Index",
      CellTags->"YLinkedLoci"],
    Cell[449181, 15129, 441, 15, 30, "IndexSubentry",
      CellTags->"YLinkedLoci"],
    Cell[765244, 27893, 260, 11, 23, "Index",
      CellTags->"YLinkedLoci"],
    Cell[765507, 27906, 441, 15, 38, "IndexSubentry",
      CellTags->"YLinkedLoci"],
    Cell[1058635, 39757, 260, 11, 15, "Index",
      CellTags->"YLinkedLoci"],
    Cell[1058898, 39770, 441, 15, 30, "IndexSubentry",
      CellTags->"YLinkedLoci"],
    Cell[1346862, 51408, 260, 11, 15, "Index",
      CellTags->"YLinkedLoci"],
    Cell[1347125, 51421, 441, 15, 30, "IndexSubentry",
      CellTags->"YLinkedLoci"],
    Cell[1624767, 62615, 260, 11, 23, "Index",
      CellTags->"YLinkedLoci"],
    Cell[1625030, 62628, 441, 15, 38, "IndexSubentry",
      CellTags->"YLinkedLoci"],
    Cell[1886886, 73237, 260, 11, 15, "Index",
      CellTags->"YLinkedLoci"],
    Cell[1887149, 73250, 441, 15, 30, "IndexSubentry",
      CellTags->"YLinkedLoci"]},
  "ZLinkedLoci"->{
    Cell[449625, 15146, 260, 11, 15, "Index",
      CellTags->"ZLinkedLoci"],
    Cell[449888, 15159, 441, 15, 30, "IndexSubentry",
      CellTags->"ZLinkedLoci"],
    Cell[765951, 27923, 260, 11, 23, "Index",
      CellTags->"ZLinkedLoci"],
    Cell[766214, 27936, 441, 15, 38, "IndexSubentry",
      CellTags->"ZLinkedLoci"],
    Cell[1059342, 39787, 260, 11, 15, "Index",
      CellTags->"ZLinkedLoci"],
    Cell[1059605, 39800, 441, 15, 30, "IndexSubentry",
      CellTags->"ZLinkedLoci"],
    Cell[1347569, 51438, 260, 11, 15, "Index",
      CellTags->"ZLinkedLoci"],
    Cell[1347832, 51451, 441, 15, 30, "IndexSubentry",
      CellTags->"ZLinkedLoci"],
    Cell[1625474, 62645, 260, 11, 23, "Index",
      CellTags->"ZLinkedLoci"],
    Cell[1625737, 62658, 441, 15, 38, "IndexSubentry",
      CellTags->"ZLinkedLoci"],
    Cell[1887593, 73267, 260, 11, 15, "Index",
      CellTags->"ZLinkedLoci"],
    Cell[1887856, 73280, 441, 15, 30, "IndexSubentry",
      CellTags->"ZLinkedLoci"]},
  "Zygotes"->{
    Cell[450332, 15176, 411, 15, 15, "Index",
      CellTags->"Zygotes"],
    Cell[766658, 27953, 411, 15, 23, "Index",
      CellTags->"Zygotes"],
    Cell[1060049, 39817, 411, 15, 15, "Index",
      CellTags->"Zygotes"],
    Cell[1348276, 51468, 411, 15, 15, "Index",
      CellTags->"Zygotes"],
    Cell[1626181, 62675, 411, 15, 23, "Index",
      CellTags->"Zygotes"],
    Cell[1888300, 73297, 411, 15, 15, "Index",
      CellTags->"Zygotes"]},
  "\[GothicA]"->{
    Cell[450746, 15193, 427, 15, 15, "Index",
      CellTags->"\[GothicA]"],
    Cell[767072, 27970, 427, 15, 23, "Index",
      CellTags->"\[GothicA]"],
    Cell[1060463, 39834, 427, 15, 15, "Index",
      CellTags->"\[GothicA]"],
    Cell[1348690, 51485, 427, 15, 15, "Index",
      CellTags->"\[GothicA]"],
    Cell[1626595, 62692, 427, 15, 23, "Index",
      CellTags->"\[GothicA]"],
    Cell[1888714, 73314, 427, 15, 15, "Index",
      CellTags->"\[GothicA]"]},
  "\[GothicCapitalA]"->{
    Cell[451176, 15210, 419, 15, 15, "Index",
      CellTags->"\[GothicCapitalA]"],
    Cell[767502, 27987, 419, 15, 23, "Index",
      CellTags->"\[GothicCapitalA]"],
    Cell[1060893, 39851, 419, 15, 15, "Index",
      CellTags->"\[GothicCapitalA]"],
    Cell[1349120, 51502, 419, 15, 15, "Index",
      CellTags->"\[GothicCapitalA]"],
    Cell[1627025, 62709, 419, 15, 23, "Index",
      CellTags->"\[GothicCapitalA]"],
    Cell[1889144, 73331, 419, 15, 15, "Index",
      CellTags->"\[GothicCapitalA]"]},
  "\[GothicCapitalC]"->{
    Cell[451598, 15227, 340, 11, 15, "Index",
      CellTags->"\[GothicCapitalC]"],
    Cell[767924, 28004, 340, 11, 23, "Index",
      CellTags->"\[GothicCapitalC]"],
    Cell[1061315, 39868, 340, 11, 15, "Index",
      CellTags->"\[GothicCapitalC]"],
    Cell[1349542, 51519, 340, 11, 15, "Index",
      CellTags->"\[GothicCapitalC]"],
    Cell[1627447, 62726, 340, 11, 23, "Index",
      CellTags->"\[GothicCapitalC]"],
    Cell[1889566, 73348, 340, 11, 15, "Index",
      CellTags->"\[GothicCapitalC]"]},
  "\[GothicCapitalD]"->{
    Cell[451941, 15240, 612, 19, 15, "Index",
      CellTags->"\[GothicCapitalD]"],
    Cell[768267, 28017, 612, 19, 23, "Index",
      CellTags->"\[GothicCapitalD]"],
    Cell[1061658, 39881, 612, 19, 15, "Index",
      CellTags->"\[GothicCapitalD]"],
    Cell[1349885, 51532, 612, 19, 15, "Index",
      CellTags->"\[GothicCapitalD]"],
    Cell[1627790, 62739, 612, 19, 23, "Index",
      CellTags->"\[GothicCapitalD]"],
    Cell[1889909, 73361, 612, 19, 15, "Index",
      CellTags->"\[GothicCapitalD]"]},
  "\!\(\(\[GothicCapitalG]\^\[RawStar]\)\)"->{
    Cell[452556, 15261, 494, 16, 23, "Index",
      CellTags->"\!\(\(\[GothicCapitalG]\^\[RawStar]\)\)"],
    Cell[768882, 28038, 494, 16, 23, "Index",
      CellTags->"\!\(\(\[GothicCapitalG]\^\[RawStar]\)\)"],
    Cell[1062273, 39902, 494, 16, 15, "Index",
      CellTags->"\!\(\(\[GothicCapitalG]\^\[RawStar]\)\)"],
    Cell[1350500, 51553, 494, 16, 15, "Index",
      CellTags->"\!\(\(\[GothicCapitalG]\^\[RawStar]\)\)"],
    Cell[1628405, 62760, 494, 16, 23, "Index",
      CellTags->"\!\(\(\[GothicCapitalG]\^\[RawStar]\)\)"],
    Cell[1890524, 73382, 494, 16, 15, "Index",
      CellTags->"\!\(\(\[GothicCapitalG]\^\[RawStar]\)\)"]},
  "\[GothicCapitalG]"->{
    Cell[453053, 15279, 421, 15, 23, "Index",
      CellTags->"\[GothicCapitalG]"],
    Cell[769379, 28056, 421, 15, 23, "Index",
      CellTags->"\[GothicCapitalG]"],
    Cell[1062770, 39920, 421, 15, 15, "Index",
      CellTags->"\[GothicCapitalG]"],
    Cell[1350997, 51571, 421, 15, 15, "Index",
      CellTags->"\[GothicCapitalG]"],
    Cell[1628902, 62778, 421, 15, 23, "Index",
      CellTags->"\[GothicCapitalG]"],
    Cell[1891021, 73400, 421, 15, 23, "Index",
      CellTags->"\[GothicCapitalG]"]},
  "\[GothicCapitalH]"->{
    Cell[453477, 15296, 435, 15, 23, "Index",
      CellTags->"\[GothicCapitalH]"],
    Cell[769803, 28073, 435, 15, 23, "Index",
      CellTags->"\[GothicCapitalH]"],
    Cell[1063194, 39937, 435, 15, 15, "Index",
      CellTags->"\[GothicCapitalH]"],
    Cell[1351421, 51588, 435, 15, 15, "Index",
      CellTags->"\[GothicCapitalH]"],
    Cell[1629326, 62795, 435, 15, 23, "Index",
      CellTags->"\[GothicCapitalH]"],
    Cell[1891445, 73417, 435, 15, 23, "Index",
      CellTags->"\[GothicCapitalH]"]},
  "\[GothicCapitalJ]"->{
    Cell[453915, 15313, 425, 15, 23, "Index",
      CellTags->"\[GothicCapitalJ]"],
    Cell[770241, 28090, 425, 15, 23, "Index",
      CellTags->"\[GothicCapitalJ]"],
    Cell[1063632, 39954, 425, 15, 15, "Index",
      CellTags->"\[GothicCapitalJ]"],
    Cell[1351859, 51605, 425, 15, 15, "Index",
      CellTags->"\[GothicCapitalJ]"],
    Cell[1629764, 62812, 425, 15, 23, "Index",
      CellTags->"\[GothicCapitalJ]"],
    Cell[1891883, 73434, 425, 15, 23, "Index",
      CellTags->"\[GothicCapitalJ]"]},
  "\[GothicK]"->{
    Cell[454343, 15330, 320, 11, 23, "Index",
      CellTags->"\[GothicK]"],
    Cell[770669, 28107, 320, 11, 23, "Index",
      CellTags->"\[GothicK]"],
    Cell[1064060, 39971, 320, 11, 15, "Index",
      CellTags->"\[GothicK]"],
    Cell[1352287, 51622, 320, 11, 15, "Index",
      CellTags->"\[GothicK]"],
    Cell[1630192, 62829, 320, 11, 23, "Index",
      CellTags->"\[GothicK]"],
    Cell[1892311, 73451, 320, 11, 23, "Index",
      CellTags->"\[GothicK]"]},
  "\[GothicCapitalK]"->{
    Cell[454666, 15343, 377, 11, 23, "Index",
      CellTags->"\[GothicCapitalK]"],
    Cell[770992, 28120, 377, 11, 23, "Index",
      CellTags->"\[GothicCapitalK]"],
    Cell[1064383, 39984, 377, 11, 15, "Index",
      CellTags->"\[GothicCapitalK]"],
    Cell[1352610, 51635, 377, 11, 15, "Index",
      CellTags->"\[GothicCapitalK]"],
    Cell[1630515, 62842, 377, 11, 23, "Index",
      CellTags->"\[GothicCapitalK]"],
    Cell[1892634, 73464, 377, 11, 23, "Index",
      CellTags->"\[GothicCapitalK]"]},
  "\[GothicM]"->{
    Cell[455046, 15356, 308, 11, 23, "Index",
      CellTags->"\[GothicM]"],
    Cell[771372, 28133, 308, 11, 23, "Index",
      CellTags->"\[GothicM]"],
    Cell[1064763, 39997, 308, 11, 15, "Index",
      CellTags->"\[GothicM]"],
    Cell[1352990, 51648, 308, 11, 15, "Index",
      CellTags->"\[GothicM]"],
    Cell[1630895, 62855, 308, 11, 23, "Index",
      CellTags->"\[GothicM]"],
    Cell[1893014, 73477, 308, 11, 23, "Index",
      CellTags->"\[GothicM]"]},
  "\[GothicP]"->{
    Cell[455357, 15369, 308, 11, 23, "Index",
      CellTags->"\[GothicP]"],
    Cell[771683, 28146, 308, 11, 23, "Index",
      CellTags->"\[GothicP]"],
    Cell[1065074, 40010, 308, 11, 15, "Index",
      CellTags->"\[GothicP]"],
    Cell[1353301, 51661, 308, 11, 15, "Index",
      CellTags->"\[GothicP]"],
    Cell[1631206, 62868, 308, 11, 23, "Index",
      CellTags->"\[GothicP]"],
    Cell[1893325, 73490, 308, 11, 23, "Index",
      CellTags->"\[GothicP]"]},
  "\[GothicP]\[GothicQ]"->{
    Cell[455668, 15382, 369, 12, 23, "Index",
      CellTags->"\[GothicP]\[GothicQ]"],
    Cell[771994, 28159, 369, 12, 23, "Index",
      CellTags->"\[GothicP]\[GothicQ]"],
    Cell[1065385, 40023, 369, 12, 15, "Index",
      CellTags->"\[GothicP]\[GothicQ]"],
    Cell[1353612, 51674, 369, 12, 15, "Index",
      CellTags->"\[GothicP]\[GothicQ]"],
    Cell[1631517, 62881, 369, 12, 23, "Index",
      CellTags->"\[GothicP]\[GothicQ]"],
    Cell[1893636, 73503, 369, 12, 23, "Index",
      CellTags->"\[GothicP]\[GothicQ]"]},
  "\[GothicQ]"->{
    Cell[456040, 15396, 308, 11, 23, "Index",
      CellTags->"\[GothicQ]"],
    Cell[772366, 28173, 308, 11, 23, "Index",
      CellTags->"\[GothicQ]"],
    Cell[1065757, 40037, 308, 11, 15, "Index",
      CellTags->"\[GothicQ]"],
    Cell[1353984, 51688, 308, 11, 15, "Index",
      CellTags->"\[GothicQ]"],
    Cell[1631889, 62895, 308, 11, 23, "Index",
      CellTags->"\[GothicQ]"],
    Cell[1894008, 73517, 308, 11, 23, "Index",
      CellTags->"\[GothicQ]"]},
  "\[GothicR]"->{
    Cell[456351, 15409, 314, 11, 23, "Index",
      CellTags->"\[GothicR]"],
    Cell[772677, 28186, 314, 11, 23, "Index",
      CellTags->"\[GothicR]"],
    Cell[1066068, 40050, 314, 11, 15, "Index",
      CellTags->"\[GothicR]"],
    Cell[1354295, 51701, 314, 11, 15, "Index",
      CellTags->"\[GothicR]"],
    Cell[1632200, 62908, 314, 11, 23, "Index",
      CellTags->"\[GothicR]"],
    Cell[1894319, 73530, 314, 11, 23, "Index",
      CellTags->"\[GothicR]"]},
  "\[GothicS]"->{
    Cell[456668, 15422, 301, 11, 23, "Index",
      CellTags->"\[GothicS]"],
    Cell[772994, 28199, 301, 11, 23, "Index",
      CellTags->"\[GothicS]"],
    Cell[1066385, 40063, 301, 11, 15, "Index",
      CellTags->"\[GothicS]"],
    Cell[1354612, 51714, 301, 11, 15, "Index",
      CellTags->"\[GothicS]"],
    Cell[1632517, 62921, 301, 11, 23, "Index",
      CellTags->"\[GothicS]"],
    Cell[1894636, 73543, 301, 11, 23, "Index",
      CellTags->"\[GothicS]"]},
  "\[GothicCapitalZ]"->{
    Cell[456972, 15435, 421, 15, 23, "Index",
      CellTags->"\[GothicCapitalZ]"],
    Cell[773298, 28212, 421, 15, 23, "Index",
      CellTags->"\[GothicCapitalZ]"],
    Cell[1066689, 40076, 421, 15, 15, "Index",
      CellTags->"\[GothicCapitalZ]"],
    Cell[1354916, 51727, 421, 15, 15, "Index",
      CellTags->"\[GothicCapitalZ]"],
    Cell[1632821, 62934, 421, 15, 23, "Index",
      CellTags->"\[GothicCapitalZ]"],
    Cell[1894940, 73556, 421, 15, 23, "Index",
      CellTags->"\[GothicCapitalZ]"]},
  "\[DoubleStruckCapitalG]"->{
    Cell[457396, 15452, 348, 11, 23, "Index",
      CellTags->"\[DoubleStruckCapitalG]"],
    Cell[773722, 28229, 348, 11, 23, "Index",
      CellTags->"\[DoubleStruckCapitalG]"],
    Cell[1067113, 40093, 348, 11, 15, "Index",
      CellTags->"\[DoubleStruckCapitalG]"],
    Cell[1355340, 51744, 348, 11, 15, "Index",
      CellTags->"\[DoubleStruckCapitalG]"],
    Cell[1633245, 62951, 348, 11, 23, "Index",
      CellTags->"\[DoubleStruckCapitalG]"],
    Cell[1895364, 73573, 348, 11, 23, "Index",
      CellTags->"\[DoubleStruckCapitalG]"]},
  "\[DoubleStruckCapitalM]"->{
    Cell[457747, 15465, 322, 11, 23, "Index",
      CellTags->"\[DoubleStruckCapitalM]"],
    Cell[774073, 28242, 322, 11, 23, "Index",
      CellTags->"\[DoubleStruckCapitalM]"],
    Cell[1067464, 40106, 322, 11, 15, "Index",
      CellTags->"\[DoubleStruckCapitalM]"],
    Cell[1355691, 51757, 322, 11, 15, "Index",
      CellTags->"\[DoubleStruckCapitalM]"],
    Cell[1633596, 62964, 322, 11, 23, "Index",
      CellTags->"\[DoubleStruckCapitalM]"],
    Cell[1895715, 73586, 322, 11, 23, "Index",
      CellTags->"\[DoubleStruckCapitalM]"]},
  "\[DoubleStruckCapitalR]"->{
    Cell[458072, 15478, 457, 15, 23, "Index",
      CellTags->"\[DoubleStruckCapitalR]"],
    Cell[774398, 28255, 457, 15, 23, "Index",
      CellTags->"\[DoubleStruckCapitalR]"],
    Cell[1067789, 40119, 457, 15, 15, "Index",
      CellTags->"\[DoubleStruckCapitalR]"],
    Cell[1356016, 51770, 457, 15, 15, "Index",
      CellTags->"\[DoubleStruckCapitalR]"],
    Cell[1633921, 62977, 457, 15, 23, "Index",
      CellTags->"\[DoubleStruckCapitalR]"],
    Cell[1896040, 73599, 457, 15, 23, "Index",
      CellTags->"\[DoubleStruckCapitalR]"]},
  "\[DoubleStruckCapitalW]"->{
    Cell[458532, 15495, 318, 11, 23, "Index",
      CellTags->"\[DoubleStruckCapitalW]"],
    Cell[774858, 28272, 318, 11, 23, "Index",
      CellTags->"\[DoubleStruckCapitalW]"],
    Cell[1068249, 40136, 318, 11, 15, "Index",
      CellTags->"\[DoubleStruckCapitalW]"],
    Cell[1356476, 51787, 318, 11, 15, "Index",
      CellTags->"\[DoubleStruckCapitalW]"],
    Cell[1634381, 62994, 318, 11, 23, "Index",
      CellTags->"\[DoubleStruckCapitalW]"],
    Cell[1896500, 73616, 318, 11, 23, "Index",
      CellTags->"\[DoubleStruckCapitalW]"]},
  "\[DoubleStruckCapitalZ]"->{
    Cell[458853, 15508, 358, 12, 23, "Index",
      CellTags->"\[DoubleStruckCapitalZ]"],
    Cell[775179, 28285, 358, 12, 23, "Index",
      CellTags->"\[DoubleStruckCapitalZ]"],
    Cell[1068570, 40149, 358, 12, 15, "Index",
      CellTags->"\[DoubleStruckCapitalZ]"],
    Cell[1356797, 51800, 358, 12, 15, "Index",
      CellTags->"\[DoubleStruckCapitalZ]"],
    Cell[1634702, 63007, 358, 12, 23, "Index",
      CellTags->"\[DoubleStruckCapitalZ]"],
    Cell[1896821, 73629, 358, 12, 23, "Index",
      CellTags->"\[DoubleStruckCapitalZ]"]},
  "\[Gamma]"->{
    Cell[459214, 15522, 310, 11, 23, "Index",
      CellTags->"\[Gamma]"],
    Cell[775540, 28299, 310, 11, 23, "Index",
      CellTags->"\[Gamma]"],
    Cell[1068931, 40163, 310, 11, 15, "Index",
      CellTags->"\[Gamma]"],
    Cell[1357158, 51814, 310, 11, 15, "Index",
      CellTags->"\[Gamma]"],
    Cell[1635063, 63021, 310, 11, 23, "Index",
      CellTags->"\[Gamma]"],
    Cell[1897182, 73643, 270, 11, 23, "Index",
      CellTags->"\[Gamma]"],
    Cell[1897455, 73656, 297, 9, 23, "IndexSubentry",
      CellTags->"\[Gamma]"]},
  "\[Zeta]"->{
    Cell[459527, 15535, 304, 11, 23, "Index",
      CellTags->"\[Zeta]"],
    Cell[775853, 28312, 304, 11, 23, "Index",
      CellTags->"\[Zeta]"],
    Cell[1069244, 40176, 304, 11, 15, "Index",
      CellTags->"\[Zeta]"],
    Cell[1357471, 51827, 304, 11, 15, "Index",
      CellTags->"\[Zeta]"],
    Cell[1635376, 63034, 304, 11, 23, "Index",
      CellTags->"\[Zeta]"],
    Cell[1897755, 73667, 304, 11, 23, "Index",
      CellTags->"\[Zeta]"]},
  "\[CapitalMu]"->{
    Cell[459834, 15548, 307, 11, 23, "Index",
      CellTags->"\[CapitalMu]"],
    Cell[776160, 28325, 307, 11, 23, "Index",
      CellTags->"\[CapitalMu]"],
    Cell[1069551, 40189, 307, 11, 15, "Index",
      CellTags->"\[CapitalMu]"],
    Cell[1357778, 51840, 307, 11, 15, "Index",
      CellTags->"\[CapitalMu]"],
    Cell[1635683, 63047, 307, 11, 23, "Index",
      CellTags->"\[CapitalMu]"],
    Cell[1898062, 73680, 307, 11, 23, "Index",
      CellTags->"\[CapitalMu]"]},
  "\[Chi]"->{
    Cell[460144, 15561, 312, 11, 23, "Index",
      CellTags->"\[Chi]"],
    Cell[776470, 28338, 312, 11, 23, "Index",
      CellTags->"\[Chi]"],
    Cell[1069861, 40202, 312, 11, 15, "Index",
      CellTags->"\[Chi]"],
    Cell[1358088, 51853, 312, 11, 15, "Index",
      CellTags->"\[Chi]"],
    Cell[1635993, 63060, 312, 11, 23, "Index",
      CellTags->"\[Chi]"],
    Cell[1898372, 73693, 312, 11, 23, "Index",
      CellTags->"\[Chi]"]},
  "\[Sampi]"->{
    Cell[460459, 15574, 296, 11, 23, "Index",
      CellTags->"\[Sampi]"],
    Cell[776785, 28351, 296, 11, 23, "Index",
      CellTags->"\[Sampi]"],
    Cell[1070176, 40215, 296, 11, 15, "Index",
      CellTags->"\[Sampi]"],
    Cell[1358403, 51866, 296, 11, 15, "Index",
      CellTags->"\[Sampi]"],
    Cell[1636308, 63073, 296, 11, 23, "Index",
      CellTags->"\[Sampi]"],
    Cell[1898687, 73706, 296, 11, 23, "Index",
      CellTags->"\[Sampi]"]},
  "$MetropolisAdjustment"->{
    Cell[460758, 15587, 290, 10, 23, "Index",
      CellTags->"$MetropolisAdjustment"],
    Cell[777084, 28364, 290, 10, 23, "Index",
      CellTags->"$MetropolisAdjustment"],
    Cell[1070475, 40228, 290, 10, 15, "Index",
      CellTags->"$MetropolisAdjustment"],
    Cell[1358702, 51879, 290, 10, 15, "Index",
      CellTags->"$MetropolisAdjustment"],
    Cell[1636607, 63086, 290, 10, 23, "Index",
      CellTags->"$MetropolisAdjustment"],
    Cell[1898986, 73719, 290, 10, 23, "Index",
      CellTags->"$MetropolisAdjustment"]},
  "\[WeierstrassP]"->{
    Cell[461051, 15599, 317, 11, 23, "Index",
      CellTags->"\[WeierstrassP]"],
    Cell[777377, 28376, 317, 11, 23, "Index",
      CellTags->"\[WeierstrassP]"],
    Cell[1070768, 40240, 317, 11, 15, "Index",
      CellTags->"\[WeierstrassP]"],
    Cell[1358995, 51891, 317, 11, 15, "Index",
      CellTags->"\[WeierstrassP]"],
    Cell[1636900, 63098, 317, 11, 23, "Index",
      CellTags->"\[WeierstrassP]"],
    Cell[1899279, 73731, 317, 11, 23, "Index",
      CellTags->"\[WeierstrassP]"]},
  "\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"->{
    Cell[461371, 15612, 449, 12, 23, "Index",
      CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],
    Cell[777697, 28389, 449, 12, 23, "Index",
      CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],
    Cell[1071088, 40253, 449, 12, 15, "Index",
      CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],
    Cell[1359315, 51904, 449, 12, 15, "Index",
      CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],
    Cell[1637220, 63111, 449, 12, 23, "Index",
      CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],
    Cell[1899599, 73744, 449, 12, 23, "Index",
      CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"]},
  "\[CircleDot]"->{
    Cell[461823, 15626, 320, 11, 23, "Index",
      CellTags->"\[CircleDot]"],
    Cell[778149, 28403, 320, 11, 23, "Index",
      CellTags->"\[CircleDot]"],
    Cell[1071540, 40267, 320, 11, 15, "Index",
      CellTags->"\[CircleDot]"],
    Cell[1359767, 51918, 320, 11, 15, "Index",
      CellTags->"\[CircleDot]"],
    Cell[1637672, 63125, 320, 11, 23, "Index",
      CellTags->"\[CircleDot]"],
    Cell[1900051, 73758, 320, 11, 23, "Index",
      CellTags->"\[CircleDot]"]},
  "\[Backslash]"->{
    Cell[462146, 15639, 394, 12, 23, "Index",
      CellTags->"\[Backslash]"],
    Cell[778472, 28416, 394, 12, 23, "Index",
      CellTags->"\[Backslash]"],
    Cell[1071863, 40280, 394, 12, 15, "Index",
      CellTags->"\[Backslash]"],
    Cell[1360090, 51931, 394, 12, 15, "Index",
      CellTags->"\[Backslash]"],
    Cell[1637995, 63138, 394, 12, 23, "Index",
      CellTags->"\[Backslash]"],
    Cell[1900374, 73771, 394, 12, 23, "Index",
      CellTags->"\[Backslash]"]},
  "\[Wedge]"->{
    Cell[462543, 15653, 450, 15, 23, "Index",
      CellTags->"\[Wedge]"],
    Cell[778869, 28430, 450, 15, 23, "Index",
      CellTags->"\[Wedge]"],
    Cell[1072260, 40294, 450, 15, 15, "Index",
      CellTags->"\[Wedge]"],
    Cell[1360487, 51945, 450, 15, 15, "Index",
      CellTags->"\[Wedge]"],
    Cell[1638392, 63152, 450, 15, 23, "Index",
      CellTags->"\[Wedge]"],
    Cell[1900771, 73785, 450, 15, 23, "Index",
      CellTags->"\[Wedge]"]},
  "\[CirclePlus]"->{
    Cell[462996, 15670, 319, 11, 23, "Index",
      CellTags->"\[CirclePlus]"],
    Cell[779322, 28447, 319, 11, 23, "Index",
      CellTags->"\[CirclePlus]"],
    Cell[1072713, 40311, 319, 11, 15, "Index",
      CellTags->"\[CirclePlus]"],
    Cell[1360940, 51962, 319, 11, 15, "Index",
      CellTags->"\[CirclePlus]"],
    Cell[1638845, 63169, 319, 11, 23, "Index",
      CellTags->"\[CirclePlus]"],
    Cell[1901224, 73802, 319, 11, 23, "Index",
      CellTags->"\[CirclePlus]"]},
  "AlleleFrequency"->{
    Cell[471906, 16058, 286, 10, 23, "Index",
      CellTags->"AlleleFrequency"]},
  "Genotype frequency"->{
    Cell[561263, 19628, 321, 11, 23, "Index",
      CellTags->"Genotype frequency"]},
  "GenotypeFrequency"->{
    Cell[561587, 19641, 292, 10, 23, "Index",
      CellTags->"GenotypeFrequency"]},
  "InferParentalGenotypes"->{
    Cell[575107, 20202, 301, 10, 23, "Index",
      CellTags->"InferParentalGenotypes"]},
  "MissingData"->{
    Cell[624059, 22139, 312, 11, 23, "Index",
      CellTags->"MissingData"],
    Cell[624374, 22152, 300, 9, 23, "IndexSubentry",
      CellTags->"MissingData"]},
  "NullAllele"->{
    Cell[655126, 23384, 310, 11, 23, "Index",
      CellTags->"NullAllele"],
    Cell[655439, 23397, 299, 9, 23, "IndexSubentry",
      CellTags->"NullAllele"]},
  "Null alleles"->{
    Cell[655741, 23408, 312, 11, 23, "Index",
      CellTags->"Null alleles"],
    Cell[656056, 23421, 304, 9, 23, "IndexSubentry",
      CellTags->"Null alleles"]},
  "ParentalGenotypes"->{
    Cell[671340, 24027, 272, 10, 23, "Index",
      CellTags->"ParentalGenotypes"]},
  "Johnson et al."->{
    Cell[1737036, 67120, 380, 14, 15, "Index",
      CellTags->"Johnson et al."],
    Cell[1737419, 67136, 2235, 85, 195, "IndexSubentry",
      CellTags->"Johnson et al."]},
  "Notation package"->{
    Cell[1795495, 69493, 253, 10, 15, "Index",
      CellTags->"Notation package"]},
  "ProductSum over sets"->{
    Cell[1817688, 70392, 267, 10, 15, "Index",
      CellTags->"ProductSum over sets"]},
  "MasterIndexMatrix"->{
    Cell[1915179, 74178, 69, 1, 30, "Section",
      CellTags->"MasterIndexMatrix"],
    Cell[1915273, 74183, 208, 5, 42, "Subsubsection",
      CellTags->"MasterIndexMatrix"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Setting up IndexTags", 2145334, 78838},
  {"Checking files", 2145439, 78841},
  {"Converting hyperlinks", 2145547, 78844},
  {"Index initial set-up", 2145660, 78847},
  {"Generating the index", 2145773, 78850},
  {"|.", 2145870, 78853},
  {"\\\\", 2146299, 78866},
  {"<>", 2146738, 78879},
  {"||.", 2147166, 78892},
  {"AddAncestors", 2147609, 78905},
  {"AddCoalescentLineage", 2147795, 78910},
  {"AddDescendants", 2147991, 78915},
  {"AddGenealogy", 2148173, 78920},
  {"Additive models", 2148673, 78933},
  {"Additive selection", 2149194, 78946},
  {"AddMutation", 2150286, 78971},
  {"AddNode", 2150535, 78978},
  {"AddRecombinantLineages", 2151012, 78991},
  {"AddTag", 2151204, 78996},
  {"AddUp", 2151658, 79009},
  {"AdmixtureFrequency", 2152601, 79034},
  {"Admixture models", 2153138, 79047},
  {"Adults", 2154201, 79072},
  {"Allele frequencies", 2154668, 79085},
  {"AlleleFrequencies", 2155298, 79100},
  {"AlleleFrequencyMean", 2155832, 79113},
  {"AlleleFrequencyP", 2156941, 79138},
  {"AlleleFrequencyPermutations", 2157477, 79151},
  {"AlleleFrequencyPQ", 2158069, 79164},
  {"AlleleFrequencyQ", 2158600, 79177},
  {"AlleleFrequencyTable", 2159129, 79190},
  {"AllelicDeviation", 2160251, 79215},
  {"AllelicState", 2160772, 79228},
  {"AllEvents", 2161266, 79241},
  {"AllSets", 2161433, 79246},
  {"Ancestors", 2161897, 79259},
  {"AncestralGraphPattern", 2162550, 79276},
  {"Ancestral graphs", 2162750, 79281},
  {"AncestralLineage", 2163121, 79290},
  {"AncestralLineagePattern", 2163318, 79295},
  {"Ancestry", 2163514, 79300},
  {"Arbitrary sets of loci", 2163997, 79313},
  {"Arnold 1996", 2164553, 79326},
  {"Asmussen and Orive 2000", 2165055, 79339},
  {"Asmussen et al. 1987", 2165626, 79352},
  {"B", 2166160, 79365},
  {"Baake 2001", 2166589, 79378},
  {"BackgroundStyle", 2166921, 79387},
  {"Barrier", 2167100, 79392},
  {"BarrierStrength", 2167570, 79405},
  {"Barton 1986", 2168084, 79418},
  {"Barton 1995", 2168574, 79431},
  {"Barton 2000", 2169064, 79444},
  {"Barton and Turelli 1991", 2169566, 79457},
  {"Barton & Gale 1993", 2170135, 79470},
  {"Barton & Shpak 1999", 2170675, 79483},
  {"Barton & Turelli 1991", 2171223, 79496},
  {"Bennett 1954", 2171774, 79509},
  {"BennettB", 2172107, 79518},
  {"BennettC", 2172424, 79527},
  {"BennettExpansion", 2172749, 79536},
  {"Biallelic", 2173099, 79545},
  {"BiallelicMutation", 2174089, 79570},
  {"Binary integers", 2174813, 79587},
  {"Birth", 2175072, 79594},
  {"BirthTime", 2175524, 79607},
  {"Boundary conditions", 2176010, 79620},
  {"Box", 2176540, 79633},
  {"Boxes", 2176976, 79646},
  {"Browser categories", 2177437, 79659},
  {"Bugs", 2177962, 79672},
  {"ChangeContext", 2178900, 79697},
  {"ChangeSex", 2179400, 79710},
  {"ClassToGenotypes", 2179883, 79723},
  {"Cline", 2180397, 79736},
  {"ClineGradient", 2181347, 79761},
  {"ClineWidth", 2181848, 79774},
  {"CoalesceLineages", 2182849, 79799},
  {"CoalescenceDistribution", 2183046, 79804},
  {"CoalescenceEvents", 2183614, 79817},
  {"Coalescence times", 2183807, 79822},
  {"CoalescentLineages", 2184001, 79827},
  {"Coalescing lineages", 2184198, 79832},
  {"CollapseGenealogy", 2184395, 79837},
  {"Combinations", 2184922, 79850},
  {"Combine", 2185174, 79857},
  {"CompareLogL", 2185640, 79870},
  {"Compiled", 2186127, 79883},
  {"Compiling", 2186603, 79896},
  {"CondenseGenealogy", 2187093, 79909},
  {"CondenseMatrix", 2187622, 79922},
  {"ConfigurationSet", 2187889, 79929},
  {"ConstrainedIntervals", 2188083, 79934},
  {"ConstructMutateList", 2188635, 79947},
  {"ConstructMutateMatrix", 2189096, 79958},
  {"ContextComponentQ", 2189563, 79969},
  {"ContextPosition", 2190093, 79982},
  {"ContextStageQ", 2190609, 79995},
  {"ContextStructure", 2191116, 80008},
  {"Continuous populations", 2191647, 80021},
  {"ContinuumVariables", 2192794, 80046},
  {"ConvertData", 2193154, 80055},
  {"ConvertHyperlinkToAddOnsLink", 2193661, 80068},
  {"Converting", 2194252, 80081},
  {"CountHeterozygotes", 2194743, 80094},
  {"Covariance", 2195274, 80107},
  {"CovarianceMidPoints", 2195766, 80120},
  {"Crow and Kimura 1970", 2196313, 80133},
  {"Cumulant", 2196854, 80146},
  {"CumulantDisequilibrium", 2197337, 80159},
  {"CumulantEquilibrium", 2197901, 80172},
  {"CumulantPopulationDisequilibrium", 2198460, 80185},
  {"CumulantReduced", 2199080, 80198},
  {"Cumulants", 2199592, 80211},
  {"Cytoplasmic inheritance", 2200082, 80224},
  {"CytoplasmicLoci", 2201238, 80249},
  {"dAlleleFrequencyPermutations", 2202311, 80274},
  {"Data", 2202896, 80287},
  {"Datasets", 2203817, 80312},
  {"Dawson 2000", 2204289, 80325},
  {"Death", 2204615, 80334},
  {"DeathTime", 2205067, 80347},
  {"DefineContext", 2205547, 80360},
  {"DegreesOfFreedom", 2206054, 80373},
  {"DeletedMutations", 2206579, 80386},
  {"DeleteGenealogy", 2207103, 80399},
  {"DeleteNullLineages", 2207624, 80412},
  {"Deme", 2207989, 80421},
  {"DemeSize", 2208434, 80434},
  {"Dempster et al 1977", 2209426, 80459},
  {"Density", 2209960, 80472},
  {"Descendants", 2210426, 80485},
  {"Dicytonuclear associations", 2211445, 80510},
  {"Diploid", 2212021, 80523},
  {"DiploidConstraints", 2212494, 80536},
  {"DiploidFrequencies", 2213033, 80549},
  {"DiploidGenotypeFrequency", 2213578, 80562},
  {"DiploidGenotypeFrequencyList", 2214163, 80575},
  {"DiploidGenotypeFrequencyReduced", 2214775, 80588},
  {"DiploidGenotypeFrequencyTable", 2215403, 80601},
  {"DiploidIndividuals", 2216008, 80614},
  {"DiploidPhenotype", 2216545, 80627},
  {"DiploidPsi", 2217064, 80640},
  {"DiploidRepresentations", 2217559, 80653},
  {"DiploidSource", 2218117, 80666},
  {"DiploidSubsets", 2218622, 80679},
  {"DiploidTypes", 2219131, 80692},
  {"Disequilibrium", 2219630, 80705},
  {"DisequilibriumMean", 2220681, 80730},
  {"DisequilibriumTable", 2221781, 80755},
  {"Dispersal", 2222883, 80780},
  {"DistanceSquared", 2223211, 80789},
  {"Distribution", 2223726, 80802},
  {"DivideZero", 2224221, 80815},
  {"DoReplicates", 2224706, 80828},
  {"DoubleCline", 2225202, 80841},
  {"DrawSamples", 2226210, 80866},
  {"DropOptions", 2226700, 80879},
  {"Edwards 1972", 2227191, 80892},
  {"EmptySets", 2227685, 80905},
  {"Epistasis", 2228007, 80914},
  {"EquivalentSexes", 2228489, 80927},
  {"ErrorBound", 2229002, 80940},
  {"EstimateFamilyMoments", 2229496, 80953},
  {"EstimateMoments", 2230050, 80966},
  {"Estimating D", 2230565, 80979},
  {"ExactEigenvalues", 2231602, 81004},
  {"ExactIntersection", 2232128, 81017},
  {"ExactProbability", 2232659, 81030},
  {"Expectation", 2233095, 81041},
  {"ExponentialF", 2234104, 81066},
  {"ExtantIndividuals", 2235130, 81091},
  {"ExtractContexts", 2235660, 81104},
  {"ExtractExtant", 2236176, 81117},
  {"ExtractGenealogy", 2236683, 81130},
  {"ExtractGenes", 2237204, 81143},
  {"ExtractInformation", 2237794, 81158},
  {"ExtractLabel", 2238510, 81175},
  {"ExtractLineagesEndingAtT", 2238700, 81180},
  {"ExtractLineagesStartingAtT", 2238916, 81185},
  {"ExtractRepeat", 2239123, 81190},
  {"ExtractSubMatrix", 2239630, 81203},
  {"FamilyAlleleFrequencyEstimate", 2240168, 81216},
  {"FamilyEffects", 2240768, 81229},
  {"FamilyM", 2241266, 81242},
  {"FamilyProbability", 2241738, 81255},
  {"Family structure", 2242269, 81268},
  {"Fecundity", 2242787, 81281},
  {"FindHyperlinks", 2243268, 81294},
  {"FindIndexTag", 2243777, 81307},
  {"FindMLE", 2244269, 81320},
  {"FindNode", 2244732, 81333},
  {"FindPosition", 2245205, 81346},
  {"FindTags", 2245698, 81359},
  {"Fitness", 2246166, 81372},
  {"FitnessSet", 2247125, 81397},
  {"FitnessTable", 2247610, 81410},
  {"FixedEnds", 2248628, 81435},
  {"Flatten", 2249614, 81460},
  {"FlattenList", 2250080, 81473},
  {"FourierNormalised", 2251088, 81498},
  {"FourierNormalisedTable", 2251625, 81511},
  {"FrequencyRepresentations", 2252194, 81524},
  {"FromBaake", 2252760, 81537},
  {"FromBennett", 2253084, 81546},
  {"FromBennettExpression", 2253426, 81555},
  {"FullContext", 2253798, 81564},
  {"FullGenotypeFrequencyReduced", 2254305, 81577},
  {"FullGenotypeFrequencyTable", 2254912, 81590},
  {"FullOutput", 2255491, 81603},
  {"Function", 2255972, 81616},
  {"Gametes", 2256440, 81629},
  {"GameteTable", 2257406, 81654},
  {"GaussianLogLikelihood", 2258424, 81679},
  {"GaussianMLE", 2258974, 81692},
  {"Genealogies", 2259464, 81705},
  {"Genealogy", 2260470, 81730},
  {"GenealogyToMatrix", 2260723, 81737},
  {"GeneralizedTransform", 2261258, 81750},
  {"Generating functions", 2261811, 81763},
  {"Genes and contexts", 2262750, 81784},
  {"Genome", 2263277, 81797},
  {"Genotype", 2263734, 81810},
  {"Genotype frequencies", 2264547, 81831},
  {"GenotypeFrequencyArguments", 2265106, 81844},
  {"GenotypeFrequencyConvert", 2265699, 81857},
  {"GenotypeFrequencyTable", 2266278, 81870},
  {"GenotypePosition", 2266839, 81883},
  {"GenotypeProbability", 2267367, 81896},
  {"Genotypes", 2268463, 81921},
  {"GlobalContinuumVariables", 2268954, 81934},
  {"Gnew", 2269331, 81943},
  {"Goodman et al 1999", 2269786, 81956},
  {"Graphs", 2270313, 81969},
  {"Griffiths-Tavare", 2270483, 81974},
  {"Guiasu & Shenitzer 1985", 2271563, 81999},
  {"HaploidConstraints", 2272132, 82012},
  {"HaploidFrequencies", 2272671, 82025},
  {"HaploidGenotypeFrequency", 2273216, 82038},
  {"HaploidIndividuals", 2273791, 82051},
  {"HaploidRepresentations", 2274334, 82064},
  {"Haploids", 2274887, 82077},
  {"HaploidSource", 2275285, 82088},
  {"HaploidSubsets", 2275790, 82101},
  {"HaploidTypes", 2276299, 82114},
  {"Help browser", 2276796, 82127},
  {"Help Browser", 2277293, 82140},
  {"Hermaphrodites", 2278310, 82165},
  {"HeterozygoteB", 2278820, 82178},
  {"Hill 1974a", 2279321, 82191},
  {"Hill 1974b", 2279804, 82204},
  {"Hill 1974c", 2280287, 82217},
  {"Hudson 1990", 2280771, 82230},
  {"Hypergeometric model", 2280955, 82235},
  {"Hyperlinks", 2281498, 82248},
  {"IncidenceMatrix", 2282498, 82273},
  {"Index", 2283006, 82286},
  {"Individual", 2283459, 82299},
  {"IndividualContinuumVariables", 2283960, 82312},
  {"IndividualRepresentations", 2284374, 82321},
  {"Individuals", 2284948, 82334},
  {"Infinite sites mutation", 2285450, 82347},
  {"InformationFunction", 2285747, 82354},
  {"InitialiseContinuum", 2286133, 82363},
  {"InitialiseCovariance", 2286680, 82376},
  {"InitialiseDemes", 2287228, 82389},
  {"InitialStep", 2287742, 82402},
  {"InitialStepReduced", 2288239, 82415},
  {"InternalNodes", 2288773, 82428},
  {"IntervalCombine", 2289279, 82441},
  {"IntervalPosition", 2289798, 82454},
  {"InverseFourierNormalised", 2290331, 82467},
  {"InverseFourierNormalisedTable", 2290917, 82480},
  {"Island model", 2291516, 82493},
  {"IterateContinuum", 2292541, 82518},
  {"IterateExact", 2293062, 82531},
  {"Join", 2294087, 82556},
  {"Junctions", 2294533, 82569},
  {"JunctionStyle", 2294706, 82574},
  {"Juveniles", 2294883, 82579},
  {"Kirkpatrick and Barton 1997", 2295377, 82592},
  {"Kirkpatrick and Servedio 1998", 2295981, 82605},
  {"Kirkpatrick et al.", 2296586, 82618},
  {"Kirkpatrick et al. 1983", 2297525, 82639},
  {"Kruuk 1997", 2298086, 82652},
  {"LeafEvents", 2298569, 82665},
  {"LeafLabels", 2298741, 82670},
  {"LeafOffset", 2299224, 82683},
  {"Leaves", 2299703, 82696},
  {"Life cycle", 2300321, 82713},
  {"LineagesPresent", 2301339, 82738},
  {"Li & Nei 1974", 2301524, 82743},
  {"Linkage", 2302022, 82756},
  {"Linkage disequilibrium", 2302993, 82781},
  {"LinkedRecombination", 2303557, 82794},
  {"ListToGenealogy", 2303925, 82803},
  {"ListToMatrix", 2304440, 82816},
  {"Location", 2304933, 82829},
  {"Locations", 2305403, 82842},
  {"LocusNames", 2305880, 82855},
  {"LogLikelihoodDisequilibrium", 2306380, 82868},
  {"LogLikelihoodDisequilibriumReduced", 2306989, 82881},
  {"LogLikelihoodTest", 2307623, 82894},
  {"Log-linear models", 2308155, 82907},
  {"Long et al 1995", 2308685, 82920},
  {"LowerOffDiagonal", 2309204, 82933},
  {"MacCallum 1994", 2309727, 82946},
  {"MacCallum et al. 1998", 2310245, 82959},
  {"MakeCline", 2310793, 82972},
  {"MakeDiploid", 2311777, 82997},
  {"MakeDistanceList", 2312790, 83022},
  {"MakeDistances", 2313312, 83035},
  {"MakeFitnessSet", 2313817, 83048},
  {"MakeGenealogy", 2314857, 83073},
  {"MakeGenealogyPlot", 2315365, 83086},
  {"MakeHaploid", 2315891, 83099},
  {"MakeIndividuals", 2316903, 83124},
  {"MakeOneWayTable", 2317963, 83149},
  {"MakePairwiseTable", 2318483, 83162},
  {"MakePopulation", 2319012, 83175},
  {"MakeSelectionCoefficient", 2320069, 83200},
  {"Mangel & Hilborn 1996", 2321243, 83225},
  {"MapLength", 2321791, 83238},
  {"MapPosition", 2321962, 83243},
  {"Marginal fitness", 2322311, 83252},
  {"MarginalTable", 2323381, 83277},
  {"MarginalW", 2323881, 83290},
  {"MaternalLoci", 2324866, 83315},
  {"MatrixGamma", 2325718, 83336},
  {"MatrixToGenealogy", 2326214, 83349},
  {"MatrixToList", 2326741, 83362},
  {"MeanContribution", 2327242, 83375},
  {"Mean fitness", 2327763, 83388},
  {"MeanW", 2328777, 83413},
  {"Meiosis", 2329709, 83438},
  {"MethodC", 2330659, 83463},
  {"MethodP", 2331121, 83476},
  {"Metropolis algorithm", 2331596, 83489},
  {"MetropolisDisequilibrium", 2332153, 83502},
  {"MetropolisDisequilibriumReduced", 2332741, 83515},
  {"Metropolis et al. 1954", 2333362, 83528},
  {"MFromC", 2333913, 83541},
  {"Migrate", 2334369, 83554},
  {"MigrateExact", 2334836, 83567},
  {"Migration", 2335854, 83592},
  {"MigrationOrder", 2336853, 83617},
  {"MigrationRate", 2337899, 83642},
  {"MigrationSet", 2338402, 83655},
  {"MissingCombination", 2338905, 83668},
  {"Missing data", 2339180, 83675},
  {"Moment", 2339758, 83690},
  {"MomentAfterMigration", 2340227, 83703},
  {"MomentAfterRecombination", 2340784, 83716},
  {"MomentEquilibrium", 2341358, 83729},
  {"MomentGeneratingFunction", 2341897, 83742},
  {"MomentLimits", 2342870, 83763},
  {"MomentNew", 2343364, 83776},
  {"MomentReduced", 2343844, 83789},
  {"Moments", 2344342, 83802},
  {"MomentsFromG", 2345315, 83827},
  {"MomentSimple", 2345812, 83840},
  {"MonteCarloGriffithsTavare", 2346322, 83853},
  {"MonteCarloProbability", 2346906, 83866},
  {"Mortality", 2347454, 83879},
  {"MostRecentCommonAncestor", 2347945, 83892},
  {"MToC", 2348506, 83905},
  {"MToCEquations", 2348956, 83918},
  {"Muddle", 2349453, 83931},
  {"Multilocus algebra", 2349920, 83944},
  {"Multilocus MS", 2351020, 83969},
  {"Multilocus notation", 2351530, 83982},
  {"Multinomial sampling", 2352077, 83995},
  {"MultinomialSamplingProbability", 2352640, 84008},
  {"Multiple alleles", 2353249, 84021},
  {"Multiple arguments", 2354324, 84046},
  {"Multiplicative models", 2354866, 84059},
  {"MUS", 2355408, 84072},
  {"Mutate", 2356315, 84097},
  {"MutateCompiled", 2357110, 84118},
  {"Mutation", 2357534, 84129},
  {"MutationInterval", 2358357, 84150},
  {"MutationLabels", 2358881, 84163},
  {"MutationOrigin", 2359393, 84176},
  {"MutationRate", 2359903, 84189},
  {"Mutations", 2360398, 84202},
  {"MVariables", 2361128, 84221},
  {"Negative binomial", 2361619, 84234},
  {"NegativeBinomialLogLikelihood", 2362719, 84259},
  {"NegativeBinomialMLE", 2363326, 84272},
  {"NegativeHypergeometricDistribution", 2363888, 84285},
  {"NeighbourArray", 2364520, 84298},
  {"Neighbours", 2365028, 84311},
  {"NetCovariance", 2365515, 84324},
  {"NetFecundity", 2366019, 84337},
  {"NetMortality", 2366517, 84350},
  {"NetRecombination", 2367019, 84363},
  {"Neutral marker", 2368090, 84388},
  {"NeutralRepresentations", 2368610, 84401},
  {"NewGametes", 2369166, 84414},
  {"NewS", 2370163, 84439},
  {"Node", 2370605, 84452},
  {"NodeFunction", 2371055, 84465},
  {"NodeLabels", 2371983, 84488},
  {"NodeOffset", 2372467, 84501},
  {"Nodes", 2372946, 84514},
  {"NonMendelian", 2373402, 84527},
  {"NonNeutralRepresentations", 2374438, 84552},
  {"NonSymmetricRepresentations", 2375029, 84565},
  {"Normalisation", 2375618, 84578},
  {"Normalised", 2376120, 84591},
  {"Notation", 2376602, 84604},
  {"Notation Package", 2377581, 84629},
  {"Null lineages", 2378020, 84640},
  {"NullLineages", 2378201, 84645},
  {"NullRecombinationEvents", 2378391, 84650},
  {"NumberedLink", 2378592, 84655},
  {"Numbering", 2379087, 84668},
  {"NumberOfCoalescences", 2380082, 84693},
  {"NumberOfGenes", 2380629, 84706},
  {"NumberOfGenesTable", 2381670, 84731},
  {"NumberOfIndividuals", 2382211, 84744},
  {"NumberOfIndividualsTable", 2382763, 84757},
  {"NumberOfLineages", 2383337, 84770},
  {"NumberOfLoci", 2383859, 84783},
  {"NumberOfMutations", 2384362, 84796},
  {"NumberOfPossibleCoalescences", 2384906, 84809},
  {"NumberOfSamplePartitions", 2385512, 84822},
  {"NumberOfSetPartitions", 2386091, 84835},
  {"NumericalModel", 2386645, 84848},
  {"Numerical models", 2387690, 84873},
  {"Observable genotype", 2388774, 84898},
  {"Obsolete", 2389310, 84911},
  {"Offspring", 2390300, 84936},
  {"Ordered", 2390775, 84949},
  {"Orive & Barton 1999", 2391100, 84958},
  {"OtherSex", 2391636, 84971},
  {"Packages", 2392106, 84984},
  {"PackageSaver", 2393081, 85009},
  {"Partitions", 2393577, 85022},
  {"PartitionSet", 2394248, 85039},
  {"Paternal inheritance", 2394594, 85048},
  {"PaternalLoci", 2395052, 85059},
  {"PatternFree", 2395906, 85080},
  {"Permutations", 2396398, 85093},
  {"Permutations in defining coefficients", 2396761, 85102},
  {"Phenotypes", 2397302, 85113},
  {"Phipps & Brill 1995", 2397717, 85124},
  {"Ploidy", 2398251, 85137},
  {"PloidyWeightList", 2398717, 85150},
  {"PlotGenealogy", 2399240, 85163},
  {"PlotLogL", 2399740, 85176},
  {"PlotSegments", 2400214, 85189},
  {"Plotting", 2400389, 85194},
  {"PopulationDisequilibrium", 2400572, 85199},
  {"PopulationExpectation", 2401151, 85212},
  {"PopulationRepresentations", 2402289, 85237},
  {"Position", 2402861, 85250},
  {"PositionsList", 2403836, 85275},
  {"PositionsMatrix", 2404343, 85288},
  {"PossibleCoalescenceOrder", 2404871, 85301},
  {"PossibleDiploidGenotypes", 2405453, 85314},
  {"PossibleGenotypes", 2406028, 85327},
  {"PossibleRootings", 2406560, 85340},
  {"PowerF", 2406824, 85347},
  {"PresentOneWayTable", 2407781, 85372},
  {"PresentPairwiseTable", 2408323, 85385},
  {"PresentResults", 2408871, 85398},
  {"Principal components", 2409389, 85411},
  {"PrintDetails", 2409759, 85420},
  {"Problems", 2410427, 85437},
  {"Products", 2411398, 85462},
  {"ProductSum", 2411870, 85475},
  {"QLE", 2412769, 85498},
  {"Quasi-linkage equilibrium", 2413542, 85519},
  {"RandomBottleneckedGenealogy", 2414040, 85530},
  {"RandomCoalescenceOrder", 2414638, 85543},
  {"RandomCoalescenceTimes", 2415206, 85556},
  {"RandomCum", 2415953, 85573},
  {"Random drift", 2416433, 85586},
  {"RandomDrift", 2417467, 85611},
  {"RandomFamilies", 2418480, 85636},
  {"RandomFamily", 2418990, 85649},
  {"Random genealogies", 2420013, 85674},
  {"RandomGenealogy", 2420550, 85687},
  {"RandomList", 2421242, 85704},
  {"Random lists", 2422235, 85729},
  {"RandomMating", 2422733, 85742},
  {"RandomMultinomial", 2423236, 85755},
  {"RandomPreviousFamily", 2423772, 85768},
  {"Random sampling", 2424321, 85781},
  {"RandomSet", 2425377, 85806},
  {"Random union", 2425857, 85819},
  {"RandomUnion", 2426873, 85844},
  {"RandomUnionMethod", 2427370, 85857},
  {"RandomUnionObsolete", 2427905, 85870},
  {"Random walk", 2428444, 85883},
  {"RecombinantLineages", 2428943, 85896},
  {"Recombination", 2429137, 85901},
  {"RecombinationEvents", 2430183, 85926},
  {"RecombinationRate", 2430381, 85931},
  {"RecombinationSet", 2430913, 85944},
  {"Recombined", 2431433, 85957},
  {"RecombineLineage", 2431923, 85970},
  {"ReducedData", 2432109, 85975},
  {"ReferencePoint", 2432603, 85988},
  {"ReferencePointMean", 2433119, 86001},
  {"ReferencePointSame", 2434225, 86026},
  {"ReferencePointZero", 2434765, 86039},
  {"References", 2435297, 86052},
  {"Reference values", 2435476, 86057},
  {"RemoveTag", 2436543, 86082},
  {"Repeat", 2437018, 86095},
  {"Replace", 2437476, 86108},
  {"ReplaceAllSpecial", 2437950, 86121},
  {"ReplaceRepeatedSpecial", 2438489, 86134},
  {"Representations", 2439051, 86147},
  {"Reproduction", 2440112, 86172},
  {"Reverse", 2440606, 86185},
  {"Root", 2441067, 86198},
  {"RootedGenealogy", 2441305, 86205},
  {"RootEvents", 2441820, 86218},
  {"Rootings", 2441991, 86223},
  {"Rules", 2442231, 86230},
  {"SampleCovariance", 2443170, 86255},
  {"SampleIndividuals", 2443698, 86268},
  {"SamplePartition", 2444230, 86281},
  {"Sampling", 2444743, 86294},
  {"Scripts and faces", 2445223, 86307},
  {"Segments", 2445748, 86320},
  {"SegmentStyle", 2445919, 86325},
  {"SegregationRatio", 2446102, 86330},
  {"SelectContext", 2446626, 86343},
  {"SelectIndividuals", 2447136, 86356},
  {"Selection", 2447662, 86369},
  {"SelectionCoefficient", 2448671, 86394},
  {"Selection coefficients", 2449228, 86407},
  {"SelectionExact", 2450375, 86432},
  {"Selection on diploids", 2451433, 86457},
  {"SelectionRate", 2452567, 86482},
  {"SelectLoci", 2453070, 86495},
  {"Selfing", 2453552, 86508},
  {"Separate", 2454017, 86521},
  {"Servedio", 2454488, 86534},
  {"Set", 2454878, 86545},
  {"Set manipulation", 2455799, 86570},
  {"SetOfCombinations", 2456327, 86583},
  {"SetPartition", 2456601, 86590},
  {"Sets of loci", 2457100, 86603},
  {"Sex", 2457590, 86616},
  {"Sex linkage", 2458034, 86629},
  {"SexOfOrigin", 2459040, 86654},
  {"Sexual selection", 2459537, 86667},
  {"ShortContext", 2460620, 86692},
  {"SigmaMatrix", 2461118, 86705},
  {"SignMask", 2461607, 86718},
  {"SimplifyAddUp", 2462083, 86731},
  {"SimplifyAddUpQ", 2462590, 86744},
  {"SimplifyFamilies", 2463105, 86757},
  {"Simulating individuals", 2463638, 86770},
  {"SizeOfGenealogyPlot", 2464790, 86795},
  {"Slatkin & Excoffier 1996", 2465343, 86808},
  {"SlowChange", 2465912, 86821},
  {"SortByClass", 2466398, 86834},
  {"SortByHead", 2467403, 86859},
  {"SpatialCovariance", 2467895, 86872},
  {"Spatially varying selection", 2468439, 86885},
  {"Special notation", 2469032, 86898},
  {"SplitSet", 2469551, 86911},
  {"Stabilising selection", 2469883, 86920},
  {"Stability", 2471018, 86945},
  {"StabilityDirect", 2472004, 86970},
  {"StabilityK", 2473057, 86995},
  {"StabilityKTable", 2473547, 87008},
  {"StabilityMatrix", 2474067, 87021},
  {"Stage", 2474577, 87034},
  {"Stages", 2475028, 87047},
  {"StandardPartition", 2475980, 87072},
  {"StandardPartitionQ", 2476345, 87081},
  {"StartingStepSize", 2476712, 87090},
  {"Stepping-stone migration", 2477247, 87103},
  {"Stepping-stone model", 2477826, 87116},
  {"StoreExact", 2478945, 87141},
  {"StoreResults", 2479958, 87166},
  {"StructuredArray", 2480986, 87191},
  {"StructuredInitialParameters", 2481518, 87204},
  {"StructuredLogLikelihood", 2482118, 87217},
  {"StructuredMLE", 2482684, 87230},
  {"StructuredModel", 2483192, 87243},
  {"StructuredModelReduce", 2483718, 87256},
  {"Structured models", 2484276, 87269},
  {"StructuredParameter", 2485362, 87294},
  {"StructuredVariance", 2485909, 87307},
  {"Style sheets", 2486444, 87320},
  {"Subdivide", 2486860, 87331},
  {"Subscripts", 2487339, 87344},
  {"Subsets", 2487821, 87357},
  {"Sums", 2488778, 87382},
  {"SwapStates", 2489227, 87395},
  {"Symmetric cline", 2489483, 87402},
  {"SymmetricDiploidFrequencies", 2490553, 87427},
  {"SymmetricHaploidFrequencies", 2491157, 87440},
  {"Symmetric model", 2491749, 87453},
  {"SymmetricNeutralDiploidFrequencies", 2492844, 87478},
  {"SymmetricNeutralHaploidFrequencies", 2493497, 87491},
  {"SymmetricRecombination", 2494138, 87504},
  {"SymmetricRepresentations", 2494709, 87517},
  {"SymmetricSexes", 2495282, 87530},
  {"Symmetrise", 2495791, 87543},
  {"T", 2496267, 87556},
  {"Table", 2496693, 87569},
  {"Tag", 2497141, 87582},
  {"Tags", 2497578, 87595},
  {"TakeAway", 2498503, 87620},
  {"TakeOptions", 2498977, 87633},
  {"Time", 2499462, 87646},
  {"TimesOfEvents", 2499914, 87659},
  {"TimespanOfJunction", 2500101, 87664},
  {"TimespanOfLineage", 2500297, 87669},
  {"TimesUp", 2500481, 87674},
  {"ToBaake", 2501441, 87699},
  {"ToBennett", 2501757, 87708},
  {"ToBennettExpression", 2502091, 87717},
  {"ToCumulants", 2502457, 87726},
  {"ToMoments", 2502947, 87739},
  {"ToPopulationCumulants", 2503437, 87752},
  {"ToPopulationMoments", 2503997, 87765},
  {"TotalLength", 2504537, 87778},
  {"TotalNumber", 2505029, 87791},
  {"Trait", 2505515, 87804},
  {"TransformedRange", 2505976, 87817},
  {"TransformInformation", 2506507, 87830},
  {"TransmissionRule", 2507058, 87843},
  {"Transmission rules", 2507587, 87856},
  {"TriDiagonalMatrix", 2508689, 87881},
  {"TruncationSelection", 2509225, 87894},
  {"Turelli and Barton 1994", 2510158, 87915},
  {"Turelli & Barton 1994", 2510732, 87928},
  {"Two alleles", 2511284, 87941},
  {"UMS", 2512288, 87966},
  {"UnionOfGametes", 2513207, 87991},
  {"UnlinkedRecombination", 2513727, 88004},
  {"UnrootedGenealogy", 2514285, 88017},
  {"UpperOffDiagonal", 2514818, 88030},
  {"USM", 2515332, 88043},
  {"ValidMatrixQ", 2516249, 88068},
  {"VarianceComponents", 2516514, 88075},
  {"Versions", 2517601, 88100},
  {"Wiuf & Hein 1999", 2518080, 88113},
  {"WLinkedLoci", 2518266, 88118},
  {"Wright-Fisher sampling", 2519289, 88143},
  {"X", 2519837, 88156},
  {"XLinkedLoci", 2520269, 88169},
  {"YLinkedLoci", 2521281, 88194},
  {"ZLinkedLoci", 2522293, 88219},
  {"Zygotes", 2523301, 88244},
  {"\[GothicA]", 2523768, 88257},
  {"\[GothicCapitalA]", 2524260, 88270},
  {"\[GothicCapitalC]", 2524794, 88283},
  {"\[GothicCapitalD]", 2525328, 88296},
  {"\!\(\(\[GothicCapitalG]\^\[RawStar]\)\)", 2525884, 88309},
  {"\[GothicCapitalG]", 2526550, 88322},
  {"\[GothicCapitalH]", 2527084, 88335},
  {"\[GothicCapitalJ]", 2527618, 88348},
  {"\[GothicK]", 2528145, 88361},
  {"\[GothicCapitalK]", 2528637, 88374},
  {"\[GothicM]", 2529164, 88387},
  {"\[GothicP]", 2529649, 88400},
  {"\[GothicP]\[GothicQ]", 2530144, 88413},
  {"\[GothicQ]", 2530689, 88426},
  {"\[GothicR]", 2531174, 88439},
  {"\[GothicS]", 2531659, 88452},
  {"\[GothicCapitalZ]", 2532151, 88465},
  {"\[DoubleStruckCapitalG]", 2532691, 88478},
  {"\[DoubleStruckCapitalM]", 2533267, 88491},
  {"\[DoubleStruckCapitalR]", 2533843, 88504},
  {"\[DoubleStruckCapitalW]", 2534419, 88517},
  {"\[DoubleStruckCapitalZ]", 2534995, 88530},
  {"\[Gamma]", 2535556, 88543},
  {"\[Zeta]", 2536109, 88558},
  {"\[CapitalMu]", 2536578, 88571},
  {"\[Chi]", 2537071, 88584},
  {"\[Sampi]", 2537530, 88597},
  {"$MetropolisAdjustment", 2538014, 88610},
  {"\[WeierstrassP]", 2538570, 88623},
  {"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]", 2539129, 88636},
  {"\[CircleDot]", 2539880, 88649},
  {"\[Backslash]", 2540379, 88662},
  {"\[Wedge]", 2540874, 88675},
  {"\[CirclePlus]", 2541350, 88688},
  {"AlleleFrequency", 2541858, 88701},
  {"Genotype frequency", 2541967, 88704},
  {"GenotypeFrequency", 2542078, 88707},
  {"InferParentalGenotypes", 2542193, 88710},
  {"MissingData", 2542302, 88713},
  {"NullAllele", 2542484, 88718},
  {"Null alleles", 2542666, 88723},
  {"ParentalGenotypes", 2542857, 88728},
  {"Johnson et al.", 2542964, 88731},
  {"Notation package", 2543163, 88736},
  {"ProductSum over sets", 2543276, 88739},
  {"MasterIndexMatrix", 2543390, 88742}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 75, 1, 50, "Section",
  CellTags->"Setting up IndexTags"],
Cell[1817, 54, 128, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[1970, 61, 238, 4, 59, "Input"],
Cell[2211, 67, 36, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2284, 73, 67, 1, 27, "Input"],
Cell[2354, 76, 909, 22, 41, "Output"]
}, Open  ]],
Cell[3278, 101, 146, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[3449, 108, 39, 0, 46, "Subsection"],
Cell[3491, 110, 232, 5, 46, "Text"],
Cell[3726, 117, 114, 2, 27, "Input"],
Cell[3843, 121, 71, 0, 30, "Text"],
Cell[3917, 123, 135, 3, 30, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4101, 132, 138, 4, 30, "Section",
  CellTags->"Checking files"],
Cell[4242, 138, 122, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[4389, 145, 309, 6, 59, "Input"],
Cell[4701, 153, 91, 1, 26, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4841, 160, 92, 1, 50, "Section",
  CellTags->"Converting hyperlinks"],

Cell[CellGroupData[{
Cell[4958, 165, 35, 0, 42, "Subsubsection"],
Cell[4996, 167, 139, 3, 27, "Input"],
Cell[5138, 172, 101, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[5264, 179, 635, 14, 123, "Input"],
Cell[5902, 195, 2901, 62, 731, "Output"]
}, Closed]],
Cell[8818, 260, 268, 5, 43, "Text"],
Cell[9089, 267, 824, 16, 155, "Input"],
Cell[9916, 285, 39, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[9980, 290, 79, 1, 27, "Input"],
Cell[10062, 293, 117, 2, 26, "Output"]
}, Open  ]],
Cell[10194, 298, 190, 5, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10421, 308, 36, 0, 28, "Subsubsection"],
Cell[10460, 310, 140, 3, 27, "Input"],
Cell[10603, 315, 268, 5, 46, "Text"],
Cell[10874, 322, 1118, 22, 203, "Input"],
Cell[11995, 346, 39, 1, 27, "Input"],
Cell[12037, 349, 510, 12, 91, "Input"],
Cell[12550, 363, 510, 12, 91, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[13097, 380, 39, 0, 28, "Subsubsection"],
Cell[13139, 382, 143, 3, 27, "Input"],
Cell[13285, 387, 268, 5, 46, "Text"],
Cell[13556, 394, 1118, 22, 203, "Input"],

Cell[CellGroupData[{
Cell[14699, 420, 38, 1, 27, "Input"],
Cell[14740, 423, 203, 4, 22, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[14992, 433, 34, 0, 28, "Subsubsection"],
Cell[15029, 435, 138, 3, 27, "Input"],
Cell[15170, 440, 268, 5, 46, "Text"],
Cell[15441, 447, 1118, 22, 203, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[16608, 475, 87, 1, 30, "Section",
  CellTags->"Index initial set-up"],
Cell[16698, 478, 159, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[16882, 486, 42, 0, 42, "Subsubsection"],
Cell[16927, 488, 117, 3, 30, "Text"],
Cell[17047, 493, 349, 6, 75, "Input"],
Cell[17399, 501, 340, 6, 59, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[17776, 512, 31, 0, 28, "Subsubsection"],
Cell[17810, 514, 95, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[17930, 521, 50, 1, 27, "Input"],
Cell[17983, 524, 2599, 46, 329, "Output"]
}, Open  ]],
Cell[20597, 573, 607, 15, 73, "Input"],

Cell[CellGroupData[{
Cell[21229, 592, 51, 1, 27, "Input"],
Cell[21283, 595, 924, 17, 105, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[22244, 617, 51, 1, 24, "Input"],
Cell[22298, 620, 1098, 20, 169, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[23433, 645, 51, 1, 24, "Input"],
Cell[23487, 648, 2573, 42, 329, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[26097, 695, 51, 1, 24, "Input"],
Cell[26151, 698, 2382, 41, 329, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[28570, 744, 52, 1, 24, "Input"],
Cell[28625, 747, 2271, 39, 329, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30933, 791, 53, 1, 27, "Input"],
Cell[30989, 794, 2346, 42, 329, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33372, 841, 53, 1, 27, "Input"],
Cell[33428, 844, 2091, 35, 329, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[35556, 884, 53, 1, 24, "Input"],
Cell[35612, 887, 2279, 39, 329, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[37928, 931, 53, 1, 24, "Input"],
Cell[37984, 934, 2595, 46, 329, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40616, 985, 53, 1, 27, "Input"],
Cell[40672, 988, 2064, 36, 329, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[42773, 1029, 53, 1, 24, "Input"],
Cell[42829, 1032, 1542, 27, 233, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[44420, 1065, 38, 0, 28, "Subsubsection"],
Cell[44461, 1067, 26462, 567, 8144, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[70960, 1639, 41, 0, 28, "Subsubsection"],
Cell[71004, 1641, 237, 5, 59, "Input"],
Cell[71244, 1648, 50, 1, 27, "Input"],
Cell[71297, 1651, 79360, 1395, 11165, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[150694, 3051, 48, 0, 28, "Subsubsection"],
Cell[150745, 3053, 86, 1, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[150880, 3060, 75, 1, 30, "Section",
  CellTags->"Generating the index"],
Cell[150958, 3063, 134, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[151117, 3070, 34, 0, 42, "Subsubsection"],
Cell[151154, 3072, 294, 7, 94, "Text"],
Cell[151451, 3081, 106, 2, 27, "Input"],
Cell[151560, 3085, 247, 11, 23, "Index",
  CellTags->"|."],
Cell[151810, 3098, 233, 11, 23, "Index",
  CellTags->"\\\\"],
Cell[152046, 3111, 243, 11, 23, "Index",
  CellTags->"<>"],
Cell[152292, 3124, 254, 11, 23, "Index",
  CellTags->"||."],
Cell[152549, 3137, 296, 11, 23, "Index",
  CellTags->"AddAncestors"],
Cell[152848, 3150, 331, 11, 23, "Index",
  CellTags->"AddCoalescentLineage"],
Cell[153182, 3163, 302, 11, 23, "Index",
  CellTags->"AddDescendants"],
Cell[153487, 3176, 271, 10, 23, "Index",
  CellTags->"AddGenealogy"],
Cell[153761, 3188, 272, 10, 23, "Index",
  CellTags->"Additive models"],
Cell[154036, 3200, 303, 11, 23, "Index",
  CellTags->"Additive selection"],
Cell[154342, 3213, 713, 27, 68, "IndexSubentry",
  CellTags->"Additive selection"],
Cell[155058, 3242, 268, 10, 23, "Index",
  CellTags->"AddMutation"],
Cell[155329, 3254, 256, 10, 23, "Index",
  CellTags->"AddNode"],
Cell[155588, 3266, 337, 11, 23, "Index",
  CellTags->"AddRecombinantLineages"],
Cell[155928, 3279, 229, 10, 23, "Index",
  CellTags->"AddTag"],
Cell[156160, 3291, 334, 14, 23, "Index",
  CellTags->"AddUp"],
Cell[156497, 3307, 492, 21, 45, "IndexSubentry",
  CellTags->"AddUp"],
Cell[156992, 3330, 261, 10, 15, "Index",
  CellTags->"AdmixtureFrequency"],
Cell[157256, 3342, 352, 14, 15, "Index",
  CellTags->"Admixture models"],
Cell[157611, 3358, 843, 33, 75, "IndexSubentry",
  CellTags->"Admixture models"],
Cell[158457, 3393, 408, 15, 15, "Index",
  CellTags->"Adults"],
Cell[158868, 3410, 326, 11, 15, "Index",
  CellTags->"Allele frequencies"],
Cell[159197, 3423, 470, 15, 15, "Index",
  CellTags->"AlleleFrequencies"],
Cell[159670, 3440, 298, 10, 15, "Index",
  CellTags->"AlleleFrequencyMean"],
Cell[159971, 3452, 952, 29, 60, "IndexSubentry",
  CellTags->"AlleleFrequencyMean"],
Cell[160926, 3483, 314, 11, 15, "Index",
  CellTags->"AlleleFrequencyP"],
Cell[161243, 3496, 304, 10, 15, "Index",
  CellTags->"AlleleFrequencyPermutations"],
Cell[161550, 3508, 366, 12, 15, "Index",
  CellTags->"AlleleFrequencyPQ"],
Cell[161919, 3522, 314, 11, 15, "Index",
  CellTags->"AlleleFrequencyQ"],
Cell[162236, 3535, 301, 10, 15, "Index",
  CellTags->"AlleleFrequencyTable"],
Cell[162540, 3547, 962, 30, 60, "IndexSubentry",
  CellTags->"AlleleFrequencyTable"],
Cell[163505, 3579, 313, 11, 15, "Index",
  CellTags->"AllelicDeviation"],
Cell[163821, 3592, 258, 11, 15, "Index",
  CellTags->"AllelicState"],
Cell[164082, 3605, 295, 11, 15, "Index",
  CellTags->"AllEvents"],
Cell[164380, 3618, 258, 10, 15, "Index",
  CellTags->"AllSets"],
Cell[164641, 3630, 273, 11, 15, "Index",
  CellTags->"Ancestors"],
Cell[164917, 3643, 273, 9, 15, "IndexSubentry",
  CellTags->"Ancestors"],
Cell[165193, 3654, 308, 10, 15, "Index",
  CellTags->"AncestralGraphPattern"],
Cell[165504, 3666, 293, 11, 15, "Index",
  CellTags->"Ancestral graphs"],
Cell[165800, 3679, 924, 33, 75, "IndexSubentry",
  CellTags->"Ancestral graphs"],
Cell[166727, 3714, 293, 10, 15, "Index",
  CellTags->"AncestralLineage"],
Cell[167023, 3726, 314, 10, 15, "Index",
  CellTags->"AncestralLineagePattern"],
Cell[167340, 3738, 255, 10, 15, "Index",
  CellTags->"Ancestry"],
Cell[167598, 3750, 334, 11, 15, "Index",
  CellTags->"Arbitrary sets of loci"],
Cell[167935, 3763, 240, 10, 15, "Index",
  CellTags->"Arnold 1996"],
Cell[168178, 3775, 414, 14, 15, "Index",
  CellTags->"Asmussen and Orive 2000"],
Cell[168595, 3791, 266, 10, 15, "Index",
  CellTags->"Asmussen et al. 1987"],
Cell[168864, 3803, 256, 10, 15, "Index",
  CellTags->"B"],
Cell[169123, 3815, 363, 14, 15, "Index",
  CellTags->"Baake 2001"],
Cell[169489, 3831, 313, 11, 15, "Index",
  CellTags->"BackgroundStyle"],
Cell[169805, 3844, 276, 11, 15, "Index",
  CellTags->"Barrier"],
Cell[170084, 3857, 276, 10, 15, "Index",
  CellTags->"BarrierStrength"],
Cell[170363, 3869, 240, 10, 15, "Index",
  CellTags->"Barton 1986"],
Cell[170606, 3881, 262, 10, 15, "Index",
  CellTags->"Barton 1995"],
Cell[170871, 3893, 240, 10, 15, "Index",
  CellTags->"Barton 2000"],
Cell[171114, 3905, 298, 10, 15, "Index",
  CellTags->"Barton and Turelli 1991"],
Cell[171415, 3917, 261, 10, 15, "Index",
  CellTags->"Barton & Gale 1993"],
Cell[171679, 3929, 264, 10, 15, "Index",
  CellTags->"Barton & Shpak 1999"],
Cell[171946, 3941, 270, 10, 15, "Index",
  CellTags->"Barton & Turelli 1991"],
Cell[172219, 3953, 243, 10, 15, "Index",
  CellTags->"Bennett 1954"],
Cell[172465, 3965, 251, 10, 15, "Index",
  CellTags->"BennettB"],
Cell[172719, 3977, 251, 10, 15, "Index",
  CellTags->"BennettC"],
Cell[172973, 3989, 275, 10, 15, "Index",
  CellTags->"BennettExpansion"],
Cell[173251, 4001, 236, 10, 15, "Index",
  CellTags->"Biallelic"],
Cell[173490, 4013, 358, 13, 15, "IndexSubentry",
  CellTags->"Biallelic"],
Cell[173851, 4028, 276, 10, 15, "Index",
  CellTags->"BiallelicMutation"],
Cell[174130, 4040, 268, 9, 15, "IndexSubentry",
  CellTags->"BiallelicMutation"],
Cell[174401, 4051, 266, 10, 15, "Index",
  CellTags->"Binary integers"],
Cell[174670, 4063, 262, 10, 15, "Index",
  CellTags->"Birth"],
Cell[174935, 4075, 258, 10, 15, "Index",
  CellTags->"BirthTime"],
Cell[175196, 4087, 447, 15, 15, "Index",
  CellTags->"Boundary conditions"],
Cell[175646, 4104, 240, 10, 15, "Index",
  CellTags->"Box"],
Cell[175889, 4116, 246, 10, 15, "Index",
  CellTags->"Boxes"],
Cell[176138, 4128, 293, 10, 15, "Index",
  CellTags->"Browser categories"],
Cell[176434, 4140, 239, 11, 15, "Index",
  CellTags->"Bugs"],
Cell[176676, 4153, 1583, 63, 150, "IndexSubentry",
  CellTags->"Bugs"],
Cell[178262, 4218, 318, 11, 15, "Index",
  CellTags->"ChangeContext"],
Cell[178583, 4231, 238, 10, 15, "Index",
  CellTags->"ChangeSex"],
Cell[178824, 4243, 289, 10, 15, "Index",
  CellTags->"ClassToGenotypes"],
Cell[179116, 4255, 253, 11, 15, "Index",
  CellTags->"Cline"],
Cell[179372, 4268, 2662, 78, 119, "IndexSubentry",
  CellTags->"Cline"],
Cell[182037, 4348, 325, 11, 15, "Index",
  CellTags->"ClineGradient"],
Cell[182365, 4361, 323, 11, 15, "Index",
  CellTags->"ClineWidth"],
Cell[182691, 4374, 695, 21, 45, "IndexSubentry",
  CellTags->"ClineWidth"],
Cell[183389, 4397, 293, 10, 15, "Index",
  CellTags->"CoalesceLineages"],
Cell[183685, 4409, 329, 11, 15, "Index",
  CellTags->"CoalescenceDistribution"],
Cell[184017, 4422, 319, 11, 15, "Index",
  CellTags->"CoalescenceEvents"],
Cell[184339, 4435, 325, 11, 15, "Index",
  CellTags->"Coalescence times"],
Cell[184667, 4448, 322, 11, 15, "Index",
  CellTags->"CoalescentLineages"],
Cell[184992, 4461, 326, 11, 15, "Index",
  CellTags->"Coalescing lineages"],
Cell[185321, 4474, 282, 10, 15, "Index",
  CellTags->"CollapseGenealogy"],
Cell[185606, 4486, 274, 11, 15, "Index",
  CellTags->"Combinations"],
Cell[185883, 4499, 232, 10, 15, "Index",
  CellTags->"Combine"],
Cell[186118, 4511, 256, 10, 15, "Index",
  CellTags->"CompareLogL"],
Cell[186377, 4523, 1075, 31, 30, "Index",
  CellTags->"Compiled"],
Cell[187455, 4556, 1073, 31, 30, "Index",
  CellTags->"Compiling"],
Cell[188531, 4589, 286, 10, 15, "Index",
  CellTags->"CondenseGenealogy"],
Cell[188820, 4601, 271, 10, 15, "Index",
  CellTags->"CondenseMatrix"],
Cell[189094, 4613, 267, 10, 15, "Index",
  CellTags->"ConfigurationSet"],
Cell[189364, 4625, 289, 10, 15, "Index",
  CellTags->"ConstrainedIntervals"],
Cell[189656, 4637, 754, 22, 15, "Index",
  CellTags->"ConstructMutateList"],
Cell[190413, 4661, 442, 14, 15, "Index",
  CellTags->"ConstructMutateMatrix"],
Cell[190858, 4677, 286, 10, 15, "Index",
  CellTags->"ContextComponentQ"],
Cell[191147, 4689, 280, 10, 15, "Index",
  CellTags->"ContextPosition"],
Cell[191430, 4701, 274, 10, 15, "Index",
  CellTags->"ContextStageQ"],
Cell[191707, 4713, 283, 10, 15, "Index",
  CellTags->"ContextStructure"],
Cell[191993, 4725, 312, 11, 15, "Index",
  CellTags->"Continuous populations"],
Cell[192308, 4738, 665, 27, 60, "IndexSubentry",
  CellTags->"Continuous populations"],
Cell[192976, 4767, 273, 10, 15, "Index",
  CellTags->"ContinuumVariables"],
Cell[193252, 4779, 260, 10, 15, "Index",
  CellTags->"ConvertData"],
Cell[193515, 4791, 291, 10, 15, "Index",
  CellTags->"ConvertHyperlinkToAddOnsLink"],
Cell[193809, 4803, 427, 15, 15, "Index",
  CellTags->"Converting"],
Cell[194239, 4820, 287, 10, 15, "Index",
  CellTags->"CountHeterozygotes"],
Cell[194529, 4832, 292, 11, 15, "Index",
  CellTags->"Covariance"],
Cell[194824, 4845, 260, 10, 15, "Index",
  CellTags->"CovarianceMidPoints"],
Cell[195087, 4857, 289, 10, 15, "Index",
  CellTags->"Crow and Kimura 1970"],
Cell[195379, 4869, 253, 10, 15, "Index",
  CellTags->"Cumulant"],
Cell[195635, 4881, 332, 11, 15, "Index",
  CellTags->"CumulantDisequilibrium"],
Cell[195970, 4894, 264, 10, 15, "Index",
  CellTags->"CumulantEquilibrium"],
Cell[196237, 4906, 392, 11, 15, "Index",
  CellTags->"CumulantPopulationDisequilibrium"],
Cell[196632, 4919, 268, 10, 15, "Index",
  CellTags->"CumulantReduced"],
Cell[196903, 4931, 333, 14, 15, "Index",
  CellTags->"Cumulants"],
Cell[197239, 4947, 426, 14, 15, "Index",
  CellTags->"Cytoplasmic inheritance"],
Cell[197668, 4963, 440, 15, 30, "IndexSubentry",
  CellTags->"Cytoplasmic inheritance"],
Cell[198111, 4980, 283, 11, 15, "Index",
  CellTags->"CytoplasmicLoci"],
Cell[198397, 4993, 453, 15, 30, "IndexSubentry",
  CellTags->"CytoplasmicLoci"],
Cell[198853, 5010, 307, 10, 15, "Index",
  CellTags->"dAlleleFrequencyPermutations"],
Cell[199163, 5022, 235, 10, 15, "Index",
  CellTags->"Data"],
Cell[199401, 5034, 423, 15, 30, "IndexSubentry",
  CellTags->"Data"],
Cell[199827, 5051, 259, 11, 15, "Index",
  CellTags->"Datasets"],
Cell[200089, 5064, 368, 14, 15, "Index",
  CellTags->"Dawson 2000"],
Cell[200460, 5080, 262, 10, 15, "Index",
  CellTags->"Death"],
Cell[200725, 5092, 258, 10, 15, "Index",
  CellTags->"DeathTime"],
Cell[200986, 5104, 274, 10, 15, "Index",
  CellTags->"DefineContext"],
Cell[201263, 5116, 271, 10, 15, "Index",
  CellTags->"DegreesOfFreedom"],
Cell[201537, 5128, 279, 10, 15, "Index",
  CellTags->"DeletedMutations"],
Cell[201819, 5140, 280, 10, 15, "Index",
  CellTags->"DeleteGenealogy"],
Cell[202102, 5152, 321, 11, 15, "Index",
  CellTags->"DeleteNullLineages"],
Cell[202426, 5165, 311, 9, 15, "IndexSubentry",
  CellTags->"DeleteNullLineages"],
Cell[202740, 5176, 322, 14, 15, "Index",
  CellTags->"Deme"],
Cell[203065, 5192, 614, 20, 15, "Index",
  CellTags->"DemeSize"],
Cell[203682, 5214, 3024, 86, 149, "IndexSubentry",
  CellTags->"DemeSize"],
Cell[206709, 5302, 264, 10, 15, "Index",
  CellTags->"Dempster et al 1977"],
Cell[206976, 5314, 252, 10, 15, "Index",
  CellTags->"Density"],
Cell[207231, 5326, 270, 10, 15, "Index",
  CellTags->"Descendants"],
Cell[207504, 5338, 436, 15, 30, "IndexSubentry",
  CellTags->"Descendants"],
Cell[207943, 5355, 296, 10, 15, "Index",
  CellTags->"Dicytonuclear associations"],
Cell[208242, 5367, 304, 11, 15, "Index",
  CellTags->"Diploid"],
Cell[208549, 5380, 277, 10, 15, "Index",
  CellTags->"DiploidConstraints"],
Cell[208829, 5392, 297, 10, 15, "Index",
  CellTags->"DiploidFrequencies"],
Cell[209129, 5404, 332, 11, 15, "Index",
  CellTags->"DiploidGenotypeFrequency"],
Cell[209464, 5417, 305, 10, 15, "Index",
  CellTags->"DiploidGenotypeFrequencyList"],
Cell[209772, 5429, 316, 10, 15, "Index",
  CellTags->"DiploidGenotypeFrequencyReduced"],
Cell[210091, 5441, 310, 10, 15, "Index",
  CellTags->"DiploidGenotypeFrequencyTable"],
Cell[210404, 5453, 297, 10, 15, "Index",
  CellTags->"DiploidIndividuals"],
Cell[210704, 5465, 275, 10, 15, "Index",
  CellTags->"DiploidPhenotype"],
Cell[210982, 5477, 402, 14, 15, "Index",
  CellTags->"DiploidPsi"],
Cell[211387, 5493, 309, 10, 15, "Index",
  CellTags->"DiploidRepresentations"],
Cell[211699, 5505, 414, 14, 15, "Index",
  CellTags->"DiploidSource"],
Cell[212116, 5521, 259, 10, 15, "Index",
  CellTags->"DiploidSubsets"],
Cell[212378, 5533, 257, 10, 15, "Index",
  CellTags->"DiploidTypes"],
Cell[212638, 5545, 283, 11, 15, "Index",
  CellTags->"Disequilibrium"],
Cell[212924, 5558, 919, 29, 45, "IndexSubentry",
  CellTags->"Disequilibrium"],
Cell[213846, 5589, 337, 11, 15, "Index",
  CellTags->"DisequilibriumMean"],
Cell[214186, 5602, 744, 23, 45, "IndexSubentry",
  CellTags->"DisequilibriumMean"],
Cell[214933, 5627, 340, 11, 15, "Index",
  CellTags->"DisequilibriumTable"],
Cell[215276, 5640, 748, 23, 45, "IndexSubentry",
  CellTags->"DisequilibriumTable"],
Cell[216027, 5665, 299, 11, 15, "Index",
  CellTags->"Dispersal"],
Cell[216329, 5678, 276, 10, 15, "Index",
  CellTags->"DistanceSquared"],
Cell[216608, 5690, 241, 10, 15, "Index",
  CellTags->"Distribution"],
Cell[216852, 5702, 237, 10, 15, "Index",
  CellTags->"DivideZero"],
Cell[217092, 5714, 277, 10, 15, "Index",
  CellTags->"DoReplicates"],
Cell[217372, 5726, 353, 12, 15, "Index",
  CellTags->"DoubleCline"],
Cell[217728, 5740, 772, 23, 45, "IndexSubentry",
  CellTags->"DoubleCline"],
Cell[218503, 5765, 262, 10, 15, "Index",
  CellTags->"DrawSamples"],
Cell[218768, 5777, 260, 10, 15, "Index",
  CellTags->"DropOptions"],
Cell[219031, 5789, 243, 10, 15, "Index",
  CellTags->"Edwards 1972"],
Cell[219277, 5801, 272, 11, 15, "Index",
  CellTags->"EmptySets"],
Cell[219552, 5814, 270, 11, 15, "Index",
  CellTags->"Epistasis"],
Cell[219825, 5827, 300, 11, 15, "Index",
  CellTags->"EquivalentSexes"],
Cell[220128, 5840, 267, 10, 15, "Index",
  CellTags->"ErrorBound"],
Cell[220398, 5852, 298, 10, 15, "Index",
  CellTags->"EstimateFamilyMoments"],
Cell[220699, 5864, 274, 10, 15, "Index",
  CellTags->"EstimateMoments"],
Cell[220976, 5876, 269, 11, 15, "Index",
  CellTags->"Estimating D"],
Cell[221248, 5889, 2407, 92, 210, "IndexSubentry",
  CellTags->"Estimating D"],
Cell[223658, 5983, 293, 10, 15, "Index",
  CellTags->"ExactEigenvalues"],
Cell[223954, 5995, 459, 15, 15, "Index",
  CellTags->"ExactIntersection"],
Cell[224416, 6012, 269, 10, 15, "Index",
  CellTags->"ExactProbability"],
Cell[224688, 6024, 252, 11, 15, "Index",
  CellTags->"Expectation"],
Cell[224943, 6037, 572, 16, 30, "IndexSubentry",
  CellTags->"Expectation"],
Cell[225518, 6055, 329, 11, 15, "Index",
  CellTags->"ExponentialF"],
Cell[225850, 6068, 877, 26, 45, "IndexSubentry",
  CellTags->"ExponentialF"],
Cell[226730, 6096, 270, 10, 15, "Index",
  CellTags->"ExtantIndividuals"],
Cell[227003, 6108, 321, 11, 15, "Index",
  CellTags->"ExtractContexts"],
Cell[227327, 6121, 242, 10, 15, "Index",
  CellTags->"ExtractExtant"],
Cell[227572, 6133, 424, 14, 15, "Index",
  CellTags->"ExtractGenealogy"],
Cell[227999, 6149, 314, 11, 15, "Index",
  CellTags->"ExtractGenes"],
Cell[228316, 6162, 285, 10, 15, "Index",
  CellTags->"ExtractInformation"],
Cell[228604, 6174, 301, 9, 15, "IndexSubentry",
  CellTags->"ExtractInformation"],
Cell[228908, 6185, 306, 11, 15, "Index",
  CellTags->"ExtractLabel"],
Cell[229217, 6198, 342, 11, 15, "Index",
  CellTags->"ExtractLineagesEndingAtT"],
Cell[229562, 6211, 353, 12, 15, "Index",
  CellTags->"ExtractLineagesStartingAtT"],
Cell[229918, 6225, 260, 10, 15, "Index",
  CellTags->"ExtractRepeat"],
Cell[230181, 6237, 279, 10, 15, "Index",
  CellTags->"ExtractSubMatrix"],
Cell[230463, 6249, 327, 11, 15, "Index",
  CellTags->"FamilyAlleleFrequencyEstimate"],
Cell[230793, 6262, 274, 10, 15, "Index",
  CellTags->"FamilyEffects"],
Cell[231070, 6274, 256, 10, 15, "Index",
  CellTags->"FamilyM"],
Cell[231329, 6286, 264, 10, 15, "Index",
  CellTags->"FamilyProbability"],
Cell[231596, 6298, 291, 11, 15, "Index",
  CellTags->"Family structure"],
Cell[231890, 6311, 258, 10, 15, "Index",
  CellTags->"Fecundity"],
Cell[232151, 6323, 249, 10, 15, "Index",
  CellTags->"FindHyperlinks"],
Cell[232403, 6335, 243, 10, 15, "Index",
  CellTags->"FindIndexTag"],
Cell[232649, 6347, 238, 10, 15, "Index",
  CellTags->"FindMLE"],
Cell[232890, 6359, 253, 10, 15, "Index",
  CellTags->"FindNode"],
Cell[233146, 6371, 239, 10, 15, "Index",
  CellTags->"FindPosition"],
Cell[233388, 6383, 249, 10, 15, "Index",
  CellTags->"FindTags"],
Cell[233640, 6395, 316, 11, 15, "Index",
  CellTags->"Fitness"],
Cell[233959, 6408, 618, 21, 45, "IndexSubentry",
  CellTags->"Fitness"],
Cell[234580, 6431, 305, 11, 15, "Index",
  CellTags->"FitnessSet"],
Cell[234888, 6444, 295, 11, 15, "Index",
  CellTags->"FitnessTable"],
Cell[235186, 6457, 475, 15, 30, "IndexSubentry",
  CellTags->"FitnessTable"],
Cell[235664, 6474, 300, 11, 15, "Index",
  CellTags->"FixedEnds"],
Cell[235967, 6487, 1296, 37, 60, "IndexSubentry",
  CellTags->"FixedEnds"],
Cell[237266, 6526, 278, 10, 15, "Index",
  CellTags->"Flatten"],
Cell[237547, 6538, 274, 10, 15, "Index",
  CellTags->"FlattenList"],
Cell[237824, 6550, 277, 9, 15, "IndexSubentry",
  CellTags->"FlattenList"],
Cell[238104, 6561, 274, 10, 15, "Index",
  CellTags->"FourierNormalised"],
Cell[238381, 6573, 289, 10, 15, "Index",
  CellTags->"FourierNormalisedTable"],
Cell[238673, 6585, 315, 10, 15, "Index",
  CellTags->"FrequencyRepresentations"],
Cell[238991, 6597, 254, 10, 15, "Index",
  CellTags->"FromBaake"],
Cell[239248, 6609, 260, 10, 15, "Index",
  CellTags->"FromBennett"],
Cell[239511, 6621, 290, 10, 15, "Index",
  CellTags->"FromBennettExpression"],
Cell[239804, 6633, 262, 10, 15, "Index",
  CellTags->"FullContext"],
Cell[240069, 6645, 307, 10, 15, "Index",
  CellTags->"FullGenotypeFrequencyReduced"],
Cell[240379, 6657, 301, 10, 15, "Index",
  CellTags->"FullGenotypeFrequencyTable"],
Cell[240683, 6669, 257, 10, 15, "Index",
  CellTags->"FullOutput"],
Cell[240943, 6681, 241, 10, 15, "Index",
  CellTags->"Function"],
Cell[241187, 6693, 286, 11, 15, "Index",
  CellTags->"Gametes"],
Cell[241476, 6706, 1087, 36, 60, "IndexSubentry",
  CellTags->"Gametes"],
Cell[242566, 6744, 298, 11, 15, "Index",
  CellTags->"GameteTable"],
Cell[242867, 6757, 440, 15, 30, "IndexSubentry",
  CellTags->"GameteTable"],
Cell[243310, 6774, 290, 10, 15, "Index",
  CellTags->"GaussianLogLikelihood"],
Cell[243603, 6786, 260, 10, 15, "Index",
  CellTags->"GaussianMLE"],
Cell[243866, 6798, 270, 11, 15, "Index",
  CellTags->"Genealogies"],
Cell[244139, 6811, 929, 33, 75, "IndexSubentry",
  CellTags->"Genealogies"],
Cell[245071, 6846, 412, 15, 15, "Index",
  CellTags->"Genealogy"],
Cell[245486, 6863, 276, 10, 15, "Index",
  CellTags->"GenealogyToMatrix"],
Cell[245765, 6875, 265, 10, 15, "Index",
  CellTags->"GeneralizedTransform"],
Cell[246033, 6887, 283, 11, 15, "Index",
  CellTags->"Generating functions"],
Cell[246319, 6900, 437, 15, 30, "IndexSubentry",
  CellTags->"Generating functions"],
Cell[246759, 6917, 277, 10, 15, "Index",
  CellTags->"Genes and contexts"],
Cell[247039, 6929, 334, 12, 15, "Index",
  CellTags->"Genome"],
Cell[247376, 6943, 287, 11, 15, "Index",
  CellTags->"Genotype"],
Cell[247666, 6956, 566, 19, 30, "IndexSubentry",
  CellTags->"Genotype"],
Cell[248235, 6977, 299, 11, 15, "Index",
  CellTags->"Genotype frequencies"],
Cell[248537, 6990, 301, 10, 15, "Index",
  CellTags->"GenotypeFrequencyArguments"],
Cell[248841, 7002, 303, 10, 15, "Index",
  CellTags->"GenotypeFrequencyConvert"],
Cell[249147, 7014, 307, 10, 15, "Index",
  CellTags->"GenotypeFrequencyTable"],
Cell[249457, 7026, 281, 10, 15, "Index",
  CellTags->"GenotypePosition"],
Cell[249741, 7038, 288, 10, 15, "Index",
  CellTags->"GenotypeProbability"],
Cell[250032, 7050, 286, 9, 15, "IndexSubentry",
  CellTags->"GenotypeProbability"],
Cell[250321, 7061, 256, 11, 15, "Index",
  CellTags->"Genotypes"],
Cell[250580, 7074, 291, 10, 15, "Index",
  CellTags->"GlobalContinuumVariables"],
Cell[250874, 7086, 452, 16, 15, "Index",
  CellTags->"Gnew"],
Cell[251329, 7104, 261, 10, 15, "Index",
  CellTags->"Goodman et al 1999"],
Cell[251593, 7116, 274, 11, 15, "Index",
  CellTags->"Graphs"],
Cell[251870, 7129, 399, 14, 15, "Index",
  CellTags->"Griffiths-Tavare"],
Cell[252272, 7145, 833, 26, 45, "IndexSubentry",
  CellTags->"Griffiths-Tavare"],
Cell[253108, 7173, 276, 10, 15, "Index",
  CellTags->"Guiasu & Shenitzer 1985"],
Cell[253387, 7185, 277, 10, 15, "Index",
  CellTags->"HaploidConstraints"],
Cell[253667, 7197, 297, 10, 15, "Index",
  CellTags->"HaploidFrequencies"],
Cell[253967, 7209, 332, 11, 15, "Index",
  CellTags->"HaploidGenotypeFrequency"],
Cell[254302, 7222, 297, 10, 15, "Index",
  CellTags->"HaploidIndividuals"],
Cell[254602, 7234, 309, 10, 15, "Index",
  CellTags->"HaploidRepresentations"],
Cell[254914, 7246, 259, 11, 15, "Index",
  CellTags->"Haploids"],
Cell[255176, 7259, 414, 14, 15, "Index",
  CellTags->"HaploidSource"],
Cell[255593, 7275, 259, 10, 15, "Index",
  CellTags->"HaploidSubsets"],
Cell[255855, 7287, 257, 10, 15, "Index",
  CellTags->"HaploidTypes"],
Cell[256115, 7299, 314, 11, 15, "Index",
  CellTags->"Help browser"],
Cell[256432, 7312, 281, 10, 15, "Index",
  CellTags->"Help Browser"],
Cell[256716, 7324, 291, 9, 15, "IndexSubentry",
  CellTags->"Help Browser"],
Cell[257010, 7335, 432, 15, 15, "Index",
  CellTags->"Hermaphrodites"],
Cell[257445, 7352, 284, 10, 15, "Index",
  CellTags->"HeterozygoteB"],
Cell[257732, 7364, 237, 10, 15, "Index",
  CellTags->"Hill 1974a"],
Cell[257972, 7376, 237, 10, 15, "Index",
  CellTags->"Hill 1974b"],
Cell[258212, 7388, 237, 10, 15, "Index",
  CellTags->"Hill 1974c"],
Cell[258452, 7400, 411, 14, 15, "Index",
  CellTags->"Hudson 1990"],
Cell[258866, 7416, 303, 10, 15, "Index",
  CellTags->"Hypergeometric model"],
Cell[259172, 7428, 256, 11, 15, "Index",
  CellTags->"Hyperlinks"],
Cell[259431, 7441, 621, 22, 45, "IndexSubentry",
  CellTags->"Hyperlinks"],
Cell[260055, 7465, 270, 10, 15, "Index",
  CellTags->"IncidenceMatrix"],
Cell[260328, 7477, 290, 11, 15, "Index",
  CellTags->"Index"],
Cell[260621, 7490, 237, 10, 15, "Index",
  CellTags->"Individual"],
Cell[260861, 7502, 303, 10, 15, "Index",
  CellTags->"IndividualContinuumVariables"],
Cell[261167, 7514, 323, 11, 15, "Index",
  CellTags->"IndividualRepresentations"],
Cell[261493, 7527, 264, 10, 15, "Index",
  CellTags->"Individuals"],
Cell[261760, 7539, 275, 10, 15, "Index",
  CellTags->"Infinite sites mutation"],
Cell[262038, 7551, 338, 11, 15, "Index",
  CellTags->"InformationFunction"],
Cell[262379, 7564, 501, 15, 30, "IndexSubentry",
  CellTags->"InformationFunction"],
Cell[262883, 7581, 272, 10, 15, "Index",
  CellTags->"InitialiseContinuum"],
Cell[263158, 7593, 263, 10, 15, "Index",
  CellTags->"InitialiseCovariance"],
Cell[263424, 7605, 414, 14, 15, "Index",
  CellTags->"InitialiseDemes"],
Cell[263841, 7621, 254, 10, 15, "Index",
  CellTags->"InitialStep"],
Cell[264098, 7633, 277, 10, 15, "Index",
  CellTags->"InitialStepReduced"],
Cell[264378, 7645, 270, 10, 15, "Index",
  CellTags->"InternalNodes"],
Cell[264651, 7657, 268, 10, 15, "Index",
  CellTags->"IntervalCombine"],
Cell[264922, 7669, 271, 10, 15, "Index",
  CellTags->"IntervalPosition"],
Cell[265196, 7681, 295, 10, 15, "Index",
  CellTags->"InverseFourierNormalised"],
Cell[265494, 7693, 310, 10, 15, "Index",
  CellTags->"InverseFourierNormalisedTable"],
Cell[265807, 7705, 476, 15, 15, "Index",
  CellTags->"Island model"],
Cell[266286, 7722, 795, 25, 45, "IndexSubentry",
  CellTags->"Island model"],
Cell[267084, 7749, 295, 10, 15, "Index",
  CellTags->"IterateContinuum"],
Cell[267382, 7761, 264, 11, 15, "Index",
  CellTags->"IterateExact"],
Cell[267649, 7774, 1753, 53, 120, "IndexSubentry",
  CellTags->"IterateExact"],
Cell[269405, 7829, 328, 14, 15, "Index",
  CellTags->"Join"],
Cell[269736, 7845, 295, 11, 15, "Index",
  CellTags->"Junctions"],
Cell[270034, 7858, 307, 11, 15, "Index",
  CellTags->"JunctionStyle"],
Cell[270344, 7871, 417, 15, 15, "Index",
  CellTags->"Juveniles"],
Cell[270764, 7888, 310, 10, 15, "Index",
  CellTags->"Kirkpatrick and Barton 1997"],
Cell[271077, 7900, 316, 10, 15, "Index",
  CellTags->"Kirkpatrick and Servedio 1998"],
Cell[271396, 7912, 392, 14, 15, "Index",
  CellTags->"Kirkpatrick et al."],
Cell[271791, 7928, 3891, 138, 285, "IndexSubentry",
  CellTags->"Kirkpatrick et al."],
Cell[275685, 8068, 275, 10, 15, "Index",
  CellTags->"Kirkpatrick et al. 1983"],
Cell[275963, 8080, 237, 10, 15, "Index",
  CellTags->"Kruuk 1997"],
Cell[276203, 8092, 298, 11, 15, "Index",
  CellTags->"LeafEvents"],
Cell[276504, 8105, 257, 10, 15, "Index",
  CellTags->"LeafLabels"],
Cell[276764, 8117, 257, 10, 15, "Index",
  CellTags->"LeafOffset"],
Cell[277024, 8129, 249, 10, 15, "Index",
  CellTags->"Leaves"],
Cell[277276, 8141, 275, 9, 15, "IndexSubentry",
  CellTags->"Leaves"],
Cell[277554, 8152, 229, 10, 15, "Index",
  CellTags->"Life cycle"],
Cell[277786, 8164, 3070, 111, 180, "IndexSubentry",
  CellTags->"Life cycle"],
Cell[280859, 8277, 313, 11, 15, "Index",
  CellTags->"LineagesPresent"],
Cell[281175, 8290, 246, 10, 15, "Index",
  CellTags->"Li & Nei 1974"],
Cell[281424, 8302, 480, 18, 15, "Index",
  CellTags->"Linkage"],
Cell[281907, 8322, 451, 15, 30, "IndexSubentry",
  CellTags->"Linkage"],
Cell[282361, 8339, 307, 10, 15, "Index",
  CellTags->"Linkage disequilibrium"],
Cell[282671, 8351, 270, 10, 15, "Index",
  CellTags->"LinkedRecombination"],
Cell[282944, 8363, 280, 10, 15, "Index",
  CellTags->"ListToGenealogy"],
Cell[283227, 8375, 291, 10, 15, "Index",
  CellTags->"ListToMatrix"],
Cell[283521, 8387, 255, 10, 15, "Index",
  CellTags->"Location"],
Cell[283779, 8399, 232, 10, 15, "Index",
  CellTags->"Locations"],
Cell[284014, 8411, 253, 10, 15, "Index",
  CellTags->"LocusNames"],
Cell[284270, 8423, 288, 10, 15, "Index",
  CellTags->"LogLikelihoodDisequilibrium"],
Cell[284561, 8435, 325, 10, 15, "Index",
  CellTags->"LogLikelihoodDisequilibriumReduced"],
Cell[284889, 8447, 270, 10, 15, "Index",
  CellTags->"LogLikelihoodTest"],
Cell[285162, 8459, 397, 14, 15, "Index",
  CellTags->"Log-linear models"],
Cell[285562, 8475, 252, 10, 15, "Index",
  CellTags->"Long et al 1995"],
Cell[285817, 8487, 269, 10, 15, "Index",
  CellTags->"LowerOffDiagonal"],
Cell[286089, 8499, 249, 10, 15, "Index",
  CellTags->"MacCallum 1994"],
Cell[286341, 8511, 269, 10, 15, "Index",
  CellTags->"MacCallum et al. 1998"],
Cell[286613, 8523, 320, 11, 15, "Index",
  CellTags->"MakeCline"],
Cell[286936, 8536, 691, 21, 45, "IndexSubentry",
  CellTags->"MakeCline"],
Cell[287630, 8559, 296, 11, 15, "Index",
  CellTags->"MakeDiploid"],
Cell[287929, 8572, 474, 15, 30, "IndexSubentry",
  CellTags->"MakeDiploid"],
Cell[288406, 8589, 279, 10, 15, "Index",
  CellTags->"MakeDistanceList"],
Cell[288688, 8601, 270, 10, 15, "Index",
  CellTags->"MakeDistances"],
Cell[288961, 8613, 243, 10, 15, "Index",
  CellTags->"MakeFitnessSet"],
Cell[289207, 8625, 255, 9, 15, "IndexSubentry",
  CellTags->"MakeFitnessSet"],
Cell[289465, 8636, 262, 10, 15, "Index",
  CellTags->"MakeGenealogy"],
Cell[289730, 8648, 278, 10, 15, "Index",
  CellTags->"MakeGenealogyPlot"],
Cell[290011, 8660, 296, 11, 15, "Index",
  CellTags->"MakeHaploid"],
Cell[290310, 8673, 474, 15, 30, "IndexSubentry",
  CellTags->"MakeHaploid"],
Cell[290787, 8690, 322, 11, 15, "Index",
  CellTags->"MakeIndividuals"],
Cell[291112, 8703, 666, 21, 45, "IndexSubentry",
  CellTags->"MakeIndividuals"],
Cell[291781, 8726, 270, 10, 15, "Index",
  CellTags->"MakeOneWayTable"],
Cell[292054, 8738, 268, 10, 15, "Index",
  CellTags->"MakePairwiseTable"],
Cell[292325, 8750, 325, 11, 15, "Index",
  CellTags->"MakePopulation"],
Cell[292653, 8763, 711, 22, 45, "IndexSubentry",
  CellTags->"MakePopulation"],
Cell[293367, 8787, 398, 14, 15, "Index",
  CellTags->"MakeSelectionCoefficient"],
Cell[293768, 8803, 423, 15, 30, "IndexSubentry",
  CellTags->"MakeSelectionCoefficient"],
Cell[294194, 8820, 270, 10, 15, "Index",
  CellTags->"Mangel & Hilborn 1996"],
Cell[294467, 8832, 295, 11, 15, "Index",
  CellTags->"MapLength"],
Cell[294765, 8845, 298, 11, 15, "Index",
  CellTags->"MapPosition"],
Cell[295066, 8858, 284, 9, 15, "IndexSubentry",
  CellTags->"MapPosition"],
Cell[295353, 8869, 316, 11, 15, "Index",
  CellTags->"Marginal fitness"],
Cell[295672, 8882, 642, 21, 45, "IndexSubentry",
  CellTags->"Marginal fitness"],
Cell[296317, 8905, 256, 10, 15, "Index",
  CellTags->"MarginalTable"],
Cell[296576, 8917, 302, 11, 15, "Index",
  CellTags->"MarginalW"],
Cell[296881, 8930, 636, 21, 45, "IndexSubentry",
  CellTags->"MarginalW"],
Cell[297520, 8953, 277, 11, 15, "Index",
  CellTags->"MaternalLoci"],
Cell[297800, 8966, 450, 15, 30, "IndexSubentry",
  CellTags->"MaternalLoci"],
Cell[298253, 8983, 254, 10, 15, "Index",
  CellTags->"MatrixGamma"],
Cell[298510, 8995, 280, 10, 15, "Index",
  CellTags->"MatrixToGenealogy"],
Cell[298793, 9007, 291, 10, 15, "Index",
  CellTags->"MatrixToList"],
Cell[299087, 9019, 314, 11, 15, "Index",
  CellTags->"MeanContribution"],
Cell[299404, 9032, 400, 14, 15, "Index",
  CellTags->"Mean fitness"],
Cell[299807, 9048, 461, 15, 30, "IndexSubentry",
  CellTags->"Mean fitness"],
Cell[300271, 9065, 290, 11, 15, "Index",
  CellTags->"MeanW"],
Cell[300564, 9078, 620, 21, 45, "IndexSubentry",
  CellTags->"MeanW"],
Cell[301187, 9101, 234, 10, 15, "Index",
  CellTags->"Meiosis"],
Cell[301424, 9113, 264, 9, 15, "IndexSubentry",
  CellTags->"Meiosis"],
Cell[301691, 9124, 256, 10, 15, "Index",
  CellTags->"MethodC"],
Cell[301950, 9136, 256, 10, 15, "Index",
  CellTags->"MethodP"],
Cell[302209, 9148, 271, 11, 15, "Index",
  CellTags->"Metropolis algorithm"],
Cell[302483, 9161, 295, 10, 15, "Index",
  CellTags->"MetropolisDisequilibrium"],
Cell[302781, 9173, 316, 10, 15, "Index",
  CellTags->"MetropolisDisequilibriumReduced"],
Cell[303100, 9185, 272, 10, 15, "Index",
  CellTags->"Metropolis et al. 1954"],
Cell[303375, 9197, 382, 14, 15, "Index",
  CellTags->"MFromC"],
Cell[303760, 9213, 226, 10, 15, "Index",
  CellTags->"Migrate"],
Cell[303989, 9225, 311, 11, 15, "Index",
  CellTags->"MigrateExact"],
Cell[304303, 9238, 646, 21, 45, "IndexSubentry",
  CellTags->"MigrateExact"],
Cell[304952, 9261, 298, 11, 15, "Index",
  CellTags->"Migration"],
Cell[305253, 9274, 2405, 85, 195, "IndexSubentry",
  CellTags->"Migration"],
Cell[307661, 9361, 491, 15, 15, "Index",
  CellTags->"MigrationOrder"],
Cell[308155, 9378, 524, 16, 30, "IndexSubentry",
  CellTags->"MigrationOrder"],
Cell[308682, 9396, 308, 11, 15, "Index",
  CellTags->"MigrationRate"],
Cell[308993, 9409, 311, 11, 15, "Index",
  CellTags->"MigrationSet"],
Cell[309307, 9422, 299, 10, 15, "Index",
  CellTags->"MissingCombination"],
Cell[309609, 9434, 259, 10, 15, "Index",
  CellTags->"Missing data"],
Cell[309871, 9446, 352, 14, 15, "Index",
  CellTags->"Moment"],
Cell[310226, 9462, 305, 10, 15, "Index",
  CellTags->"MomentAfterMigration"],
Cell[310534, 9474, 332, 11, 15, "Index",
  CellTags->"MomentAfterRecombination"],
Cell[310869, 9487, 258, 10, 15, "Index",
  CellTags->"MomentEquilibrium"],
Cell[311130, 9499, 315, 11, 15, "Index",
  CellTags->"MomentGeneratingFunction"],
Cell[311448, 9512, 582, 21, 45, "IndexSubentry",
  CellTags->"MomentGeneratingFunction"],
Cell[312033, 9535, 267, 10, 15, "Index",
  CellTags->"MomentLimits"],
Cell[312303, 9547, 232, 10, 15, "Index",
  CellTags->"MomentNew"],
Cell[312538, 9559, 262, 10, 15, "Index",
  CellTags->"MomentReduced"],
Cell[312803, 9571, 222, 10, 15, "Index",
  CellTags->"Moments"],
Cell[313028, 9583, 1552, 53, 120, "IndexSubentry",
  CellTags->"Moments"],
Cell[314583, 9638, 289, 10, 15, "Index",
  CellTags->"MomentsFromG"],
Cell[314875, 9650, 269, 10, 15, "Index",
  CellTags->"MomentSimple"],
Cell[315147, 9662, 302, 10, 15, "Index",
  CellTags->"MonteCarloGriffithsTavare"],
Cell[315452, 9674, 302, 10, 15, "Index",
  CellTags->"MonteCarloProbability"],
Cell[315757, 9686, 258, 10, 15, "Index",
  CellTags->"Mortality"],
Cell[316018, 9698, 299, 10, 15, "Index",
  CellTags->"MostRecentCommonAncestor"],
Cell[316320, 9710, 374, 14, 15, "Index",
  CellTags->"MToC"],
Cell[316697, 9726, 410, 14, 15, "Index",
  CellTags->"MToCEquations"],
Cell[317110, 9742, 263, 10, 15, "Index",
  CellTags->"Muddle"],
Cell[317376, 9754, 295, 11, 15, "Index",
  CellTags->"Multilocus algebra"],
Cell[317674, 9767, 1010, 36, 60, "IndexSubentry",
  CellTags->"Multilocus algebra"],
Cell[318687, 9805, 408, 15, 15, "Index",
  CellTags->"Multilocus MS"],
Cell[319098, 9822, 264, 11, 15, "Index",
  CellTags->"Multilocus notation"],
Cell[319365, 9835, 344, 12, 15, "Index",
  CellTags->"Multinomial sampling"],
Cell[319712, 9849, 332, 11, 15, "Index",
  CellTags->"MultinomialSamplingProbability"],
Cell[320047, 9862, 289, 11, 15, "Index",
  CellTags->"Multiple alleles"],
Cell[320339, 9875, 694, 27, 60, "IndexSubentry",
  CellTags->"Multiple alleles"],
Cell[321036, 9904, 297, 11, 15, "Index",
  CellTags->"Multiple arguments"],
Cell[321336, 9917, 336, 11, 15, "Index",
  CellTags->"Multiplicative models"],
Cell[321675, 9930, 302, 11, 15, "Index",
  CellTags->"MUS"],
Cell[321980, 9943, 667, 21, 45, "IndexSubentry",
  CellTags->"MUS"],
Cell[322650, 9966, 287, 11, 15, "Index",
  CellTags->"Mutate"],
Cell[322940, 9979, 607, 21, 45, "IndexSubentry",
  CellTags->"Mutate"],
Cell[323550, 10002, 724, 22, 15, "Index",
  CellTags->"MutateCompiled"],
Cell[324277, 10026, 263, 11, 15, "Index",
  CellTags->"Mutation"],
Cell[324543, 10039, 1083, 33, 59, "IndexSubentry",
  CellTags->"Mutation"],
Cell[325629, 10074, 275, 10, 15, "Index",
  CellTags->"MutationInterval"],
Cell[325907, 10086, 297, 10, 15, "Index",
  CellTags->"MutationLabels"],
Cell[326207, 10098, 269, 10, 15, "Index",
  CellTags->"MutationOrigin"],
Cell[326479, 10110, 261, 10, 15, "Index",
  CellTags->"MutationRate"],
Cell[326743, 10122, 293, 11, 15, "Index",
  CellTags->"Mutations"],
Cell[327039, 10135, 772, 27, 60, "IndexSubentry",
  CellTags->"Mutations"],
Cell[327814, 10164, 398, 14, 15, "Index",
  CellTags->"MVariables"],
Cell[328215, 10180, 293, 11, 15, "Index",
  CellTags->"Negative binomial"],
Cell[328511, 10193, 828, 27, 60, "IndexSubentry",
  CellTags->"Negative binomial"],
Cell[329342, 10222, 339, 11, 15, "Index",
  CellTags->"NegativeBinomialLogLikelihood"],
Cell[329684, 10235, 302, 10, 15, "Index",
  CellTags->"NegativeBinomialMLE"],
Cell[329989, 10247, 368, 11, 15, "Index",
  CellTags->"NegativeHypergeometricDistribution"],
Cell[330360, 10260, 273, 10, 15, "Index",
  CellTags->"NeighbourArray"],
Cell[330636, 10272, 261, 10, 15, "Index",
  CellTags->"Neighbours"],
Cell[330900, 10284, 280, 10, 15, "Index",
  CellTags->"NetCovariance"],
Cell[331183, 10296, 255, 10, 15, "Index",
  CellTags->"NetFecundity"],
Cell[331441, 10308, 255, 10, 15, "Index",
  CellTags->"NetMortality"],
Cell[331699, 10320, 384, 14, 15, "Index",
  CellTags->"NetRecombination"],
Cell[332086, 10336, 438, 15, 30, "IndexSubentry",
  CellTags->"NetRecombination"],
Cell[332527, 10353, 285, 11, 15, "Index",
  CellTags->"Neutral marker"],
Cell[332815, 10366, 309, 10, 15, "Index",
  CellTags->"NeutralRepresentations"],
Cell[333127, 10378, 309, 11, 15, "Index",
  CellTags->"NewGametes"],
Cell[333439, 10391, 1653, 52, 104, "IndexSubentry",
  CellTags->"NewGametes"],
Cell[335095, 10445, 249, 10, 15, "Index",
  CellTags->"NewS"],
Cell[335347, 10457, 380, 14, 15, "Index",
  CellTags->"Node"],
Cell[335730, 10473, 404, 14, 15, "Index",
  CellTags->"NodeFunction"],
Cell[336137, 10489, 275, 9, 15, "IndexSubentry",
  CellTags->"NodeFunction"],
Cell[336415, 10500, 257, 10, 15, "Index",
  CellTags->"NodeLabels"],
Cell[336675, 10512, 257, 10, 15, "Index",
  CellTags->"NodeOffset"],
Cell[336935, 10524, 246, 10, 15, "Index",
  CellTags->"Nodes"],
Cell[337184, 10536, 263, 10, 15, "Index",
  CellTags->"NonMendelian"],
Cell[337450, 10548, 366, 13, 15, "IndexSubentry",
  CellTags->"NonMendelian"],
Cell[337819, 10563, 323, 11, 15, "Index",
  CellTags->"NonNeutralRepresentations"],
Cell[338145, 10576, 331, 11, 15, "Index",
  CellTags->"NonSymmetricRepresentations"],
Cell[338479, 10589, 284, 10, 15, "Index",
  CellTags->"Normalisation"],
Cell[338766, 10601, 275, 10, 15, "Index",
  CellTags->"Normalised"],
Cell[339044, 10613, 287, 11, 15, "Index",
  CellTags->"Notation"],
Cell[339334, 10626, 727, 27, 60, "IndexSubentry",
  CellTags->"Notation"],
Cell[340064, 10655, 253, 10, 15, "Index",
  CellTags->"Notation Package"],
Cell[340320, 10667, 304, 11, 15, "Index",
  CellTags->"Null lineages"],
Cell[340627, 10680, 304, 11, 15, "Index",
  CellTags->"NullLineages"],
Cell[340934, 10693, 337, 11, 15, "Index",
  CellTags->"NullRecombinationEvents"],
Cell[341274, 10706, 261, 10, 15, "Index",
  CellTags->"NumberedLink"],
Cell[341538, 10718, 271, 11, 15, "Index",
  CellTags->"Numbering"],
Cell[341812, 10731, 560, 21, 45, "IndexSubentry",
  CellTags->"Numbering"],
Cell[342375, 10754, 318, 11, 15, "Index",
  CellTags->"NumberOfCoalescences"],
Cell[342696, 10767, 266, 10, 15, "Index",
  CellTags->"NumberOfGenes"],
Cell[342965, 10779, 915, 28, 60, "IndexSubentry",
  CellTags->"NumberOfGenes"],
Cell[343883, 10809, 281, 10, 15, "Index",
  CellTags->"NumberOfGenesTable"],
Cell[344167, 10821, 416, 14, 15, "Index",
  CellTags->"NumberOfIndividuals"],
Cell[344586, 10837, 299, 10, 15, "Index",
  CellTags->"NumberOfIndividualsTable"],
Cell[344888, 10849, 279, 10, 15, "Index",
  CellTags->"NumberOfLineages"],
Cell[345170, 10861, 263, 10, 15, "Index",
  CellTags->"NumberOfLoci"],
Cell[345436, 10873, 278, 10, 15, "Index",
  CellTags->"NumberOfMutations"],
Cell[345717, 10885, 317, 10, 15, "Index",
  CellTags->"NumberOfPossibleCoalescences"],
Cell[346037, 10897, 287, 10, 15, "Index",
  CellTags->"NumberOfSamplePartitions"],
Cell[346327, 10909, 278, 10, 15, "Index",
  CellTags->"NumberOfSetPartitions"],
Cell[346608, 10921, 325, 11, 15, "Index",
  CellTags->"NumericalModel"],
Cell[346936, 10934, 294, 9, 15, "IndexSubentry",
  CellTags->"NumericalModel"],
Cell[347233, 10945, 301, 11, 15, "Index",
  CellTags->"Numerical models"],
Cell[347537, 10958, 1265, 43, 90, "IndexSubentry",
  CellTags->"Numerical models"],
Cell[348805, 11003, 420, 14, 15, "Index",
  CellTags->"Observable genotype"],
Cell[349228, 11019, 250, 11, 15, "Index",
  CellTags->"Obsolete"],
Cell[349481, 11032, 3402, 121, 285, "IndexSubentry",
  CellTags->"Obsolete"],
Cell[352886, 11155, 258, 10, 15, "Index",
  CellTags->"Offspring"],
Cell[353147, 11167, 266, 11, 15, "Index",
  CellTags->"Ordered"],
Cell[353416, 11180, 264, 10, 15, "Index",
  CellTags->"Orive & Barton 1999"],
Cell[353683, 11192, 247, 10, 15, "Index",
  CellTags->"OtherSex"],
Cell[353933, 11204, 275, 11, 15, "Index",
  CellTags->"Packages"],
Cell[354211, 11217, 839, 31, 60, "IndexSubentry",
  CellTags->"Packages"],
Cell[355053, 11250, 235, 10, 15, "Index",
  CellTags->"PackageSaver"],
Cell[355291, 11262, 262, 11, 15, "Index",
  CellTags->"Partitions"],
Cell[355556, 11275, 426, 15, 30, "IndexSubentry",
  CellTags->"Partitions"],
Cell[355985, 11292, 251, 10, 15, "Index",
  CellTags->"PartitionSet"],
Cell[356239, 11304, 414, 14, 15, "Index",
  CellTags->"Paternal inheritance"],
Cell[356656, 11320, 277, 11, 15, "Index",
  CellTags->"PaternalLoci"],
Cell[356936, 11333, 444, 15, 30, "IndexSubentry",
  CellTags->"PaternalLoci"],
Cell[357383, 11350, 274, 10, 15, "Index",
  CellTags->"PatternFree"],
Cell[357660, 11362, 281, 11, 15, "Index",
  CellTags->"Permutations"],
Cell[357944, 11375, 325, 11, 15, "Index",
  CellTags->"Permutations in defining coefficients"],
Cell[358272, 11388, 269, 11, 15, "Index",
  CellTags->"Phenotypes"],
Cell[358544, 11401, 264, 10, 15, "Index",
  CellTags->"Phipps & Brill 1995"],
Cell[358811, 11413, 245, 10, 15, "Index",
  CellTags->"Ploidy"],
Cell[359059, 11425, 271, 10, 15, "Index",
  CellTags->"PloidyWeightList"],
Cell[359333, 11437, 266, 10, 15, "Index",
  CellTags->"PlotGenealogy"],
Cell[359602, 11449, 247, 10, 15, "Index",
  CellTags->"PlotLogL"],
Cell[359852, 11461, 300, 11, 15, "Index",
  CellTags->"PlotSegments"],
Cell[360155, 11474, 279, 11, 15, "Index",
  CellTags->"Plotting"],
Cell[360437, 11487, 346, 11, 15, "Index",
  CellTags->"PopulationDisequilibrium"],
Cell[360786, 11500, 274, 10, 15, "Index",
  CellTags->"PopulationExpectation"],
Cell[361063, 11512, 271, 9, 15, "IndexSubentry",
  CellTags->"PopulationExpectation"],
Cell[361337, 11523, 323, 11, 15, "Index",
  CellTags->"PopulationRepresentations"],
Cell[361663, 11536, 380, 14, 15, "Index",
  CellTags->"Position"],
Cell[362046, 11552, 442, 15, 30, "IndexSubentry",
  CellTags->"Position"],
Cell[362491, 11569, 270, 10, 15, "Index",
  CellTags->"PositionsList"],
Cell[362764, 11581, 276, 10, 15, "Index",
  CellTags->"PositionsMatrix"],
Cell[363043, 11593, 305, 10, 15, "Index",
  CellTags->"PossibleCoalescenceOrder"],
Cell[363351, 11605, 303, 10, 15, "Index",
  CellTags->"PossibleDiploidGenotypes"],
Cell[363657, 11617, 272, 10, 15, "Index",
  CellTags->"PossibleGenotypes"],
Cell[363932, 11629, 273, 10, 15, "Index",
  CellTags->"PossibleRootings"],
Cell[364208, 11641, 311, 11, 15, "Index",
  CellTags->"PowerF"],
Cell[364522, 11654, 871, 27, 60, "IndexSubentry",
  CellTags->"PowerF"],
Cell[365396, 11683, 279, 10, 15, "Index",
  CellTags->"PresentOneWayTable"],
Cell[365678, 11695, 277, 10, 15, "Index",
  CellTags->"PresentPairwiseTable"],
Cell[365958, 11707, 265, 10, 15, "Index",
  CellTags->"PresentResults"],
Cell[366226, 11719, 317, 11, 15, "Index",
  CellTags->"Principal components"],
Cell[366546, 11732, 273, 10, 15, "Index",
  CellTags->"PrintDetails"],
Cell[366822, 11744, 321, 10, 15, "IndexSubentry",
  CellTags->"PrintDetails"],
Cell[367146, 11756, 275, 11, 15, "Index",
  CellTags->"Problems"],
Cell[367424, 11769, 587, 18, 15, "IndexSubentry",
  CellTags->"Problems"],
Cell[368014, 11789, 250, 11, 15, "Index",
  CellTags->"Products"],
Cell[368267, 11802, 237, 10, 15, "Index",
  CellTags->"ProductSum"],
Cell[368507, 11814, 249, 9, 15, "IndexSubentry",
  CellTags->"ProductSum"],
Cell[368759, 11825, 263, 11, 15, "Index",
  CellTags->"QLE"],
Cell[369025, 11838, 258, 9, 15, "IndexSubentry",
  CellTags->"QLE"],
Cell[369286, 11849, 310, 11, 15, "Index",
  CellTags->"Quasi-linkage equilibrium"],
Cell[369599, 11862, 312, 10, 15, "Index",
  CellTags->"RandomBottleneckedGenealogy"],
Cell[369914, 11874, 299, 10, 15, "Index",
  CellTags->"RandomCoalescenceOrder"],
Cell[370216, 11886, 326, 11, 15, "Index",
  CellTags->"RandomCoalescenceTimes"],
Cell[370545, 11899, 300, 9, 15, "IndexSubentry",
  CellTags->"RandomCoalescenceTimes"],
Cell[370848, 11910, 288, 10, 15, "Index",
  CellTags->"RandomCum"],
Cell[371139, 11922, 330, 12, 15, "Index",
  CellTags->"Random drift"],
Cell[371472, 11936, 2349, 77, 150, "IndexSubentry",
  CellTags->"Random drift"],
Cell[373824, 12015, 286, 11, 15, "Index",
  CellTags->"RandomDrift"],
Cell[374113, 12028, 956, 27, 30, "IndexSubentry",
  CellTags->"RandomDrift"],
Cell[375072, 12057, 259, 10, 15, "Index",
  CellTags->"RandomFamilies"],
Cell[375334, 12069, 261, 10, 15, "Index",
  CellTags->"RandomFamily"],
Cell[375598, 12081, 273, 9, 15, "IndexSubentry",
  CellTags->"RandomFamily"],
Cell[375874, 12092, 299, 11, 15, "Index",
  CellTags->"Random genealogies"],
Cell[376176, 12105, 270, 10, 15, "Index",
  CellTags->"RandomGenealogy"],
Cell[376449, 12117, 286, 9, 15, "IndexSubentry",
  CellTags->"RandomGenealogy"],
Cell[376738, 12128, 241, 10, 15, "Index",
  CellTags->"RandomList"],
Cell[376982, 12140, 259, 9, 15, "IndexSubentry",
  CellTags->"RandomList"],
Cell[377244, 12151, 259, 11, 15, "Index",
  CellTags->"Random lists"],
Cell[377506, 12164, 289, 10, 15, "Index",
  CellTags->"RandomMating"],
Cell[377798, 12176, 286, 10, 15, "Index",
  CellTags->"RandomMultinomial"],
Cell[378087, 12188, 277, 10, 15, "Index",
  CellTags->"RandomPreviousFamily"],
Cell[378367, 12200, 288, 10, 15, "Index",
  CellTags->"Random sampling"],
Cell[378658, 12212, 415, 15, 30, "IndexSubentry",
  CellTags->"Random sampling"],
Cell[379076, 12229, 236, 10, 15, "Index",
  CellTags->"RandomSet"],
Cell[379315, 12241, 371, 14, 15, "Index",
  CellTags->"Random union"],
Cell[379689, 12257, 306, 9, 15, "IndexSubentry",
  CellTags->"Random union"],
Cell[379998, 12268, 244, 10, 15, "Index",
  CellTags->"RandomUnion"],
Cell[380245, 12280, 276, 10, 15, "Index",
  CellTags->"RandomUnionMethod"],
Cell[380524, 12292, 260, 10, 15, "Index",
  CellTags->"RandomUnionObsolete"],
Cell[380787, 12304, 256, 11, 15, "Index",
  CellTags->"Random walk"],
Cell[381046, 12317, 325, 11, 15, "Index",
  CellTags->"RecombinantLineages"],
Cell[381374, 12330, 378, 14, 15, "Index",
  CellTags->"Recombination"],
Cell[381755, 12346, 1122, 39, 90, "IndexSubentry",
  CellTags->"Recombination"],
Cell[382880, 12387, 325, 11, 15, "Index",
  CellTags->"RecombinationEvents"],
Cell[383208, 12400, 321, 11, 15, "Index",
  CellTags->"RecombinationRate"],
Cell[383532, 12413, 450, 15, 15, "Index",
  CellTags->"RecombinationSet"],
Cell[383985, 12430, 283, 10, 15, "Index",
  CellTags->"Recombined"],
Cell[384271, 12442, 293, 10, 15, "Index",
  CellTags->"RecombineLineage"],
Cell[384567, 12454, 262, 10, 15, "Index",
  CellTags->"ReducedData"],
Cell[384832, 12466, 316, 11, 15, "Index",
  CellTags->"ReferencePoint"],
Cell[385151, 12479, 273, 10, 15, "Index",
  CellTags->"ReferencePointMean"],
Cell[385427, 12491, 1125, 37, 45, "IndexSubentry",
  CellTags->"ReferencePointMean"],
Cell[386555, 12530, 273, 10, 15, "Index",
  CellTags->"ReferencePointSame"],
Cell[386831, 12542, 273, 10, 15, "Index",
  CellTags->"ReferencePointZero"],
Cell[387107, 12554, 289, 11, 15, "Index",
  CellTags->"References"],
Cell[387399, 12567, 400, 14, 15, "Index",
  CellTags->"Reference values"],
Cell[387802, 12583, 472, 15, 30, "IndexSubentry",
  CellTags->"Reference values"],
Cell[388277, 12600, 238, 10, 15, "Index",
  CellTags->"RemoveTag"],
Cell[388518, 12612, 239, 10, 15, "Index",
  CellTags->"Repeat"],
Cell[388760, 12624, 232, 10, 15, "Index",
  CellTags->"Replace"],
Cell[388995, 12636, 262, 11, 15, "Index",
  CellTags->"ReplaceAllSpecial"],
Cell[389260, 12649, 278, 11, 15, "Index",
  CellTags->"ReplaceRepeatedSpecial"],
Cell[389541, 12662, 311, 11, 15, "Index",
  CellTags->"Representations"],
Cell[389855, 12675, 308, 10, 15, "IndexSubentry",
  CellTags->"Representations"],
Cell[390166, 12687, 286, 11, 15, "Index",
  CellTags->"Reproduction"],
Cell[390455, 12700, 222, 10, 15, "Index",
  CellTags->"Reverse"],
Cell[390680, 12712, 401, 15, 15, "Index",
  CellTags->"Root"],
Cell[391084, 12729, 280, 10, 15, "Index",
  CellTags->"RootedGenealogy"],
Cell[391367, 12741, 298, 11, 15, "Index",
  CellTags->"RootEvents"],
Cell[391668, 12754, 289, 11, 15, "Index",
  CellTags->"Rootings"],
Cell[391960, 12767, 244, 10, 15, "Index",
  CellTags->"Rules"],
Cell[392207, 12779, 234, 9, 15, "IndexSubentry",
  CellTags->"Rules"],
Cell[392444, 12790, 251, 10, 15, "Index",
  CellTags->"SampleCovariance"],
Cell[392698, 12802, 278, 10, 15, "Index",
  CellTags->"SampleIndividuals"],
Cell[392979, 12814, 260, 10, 15, "Index",
  CellTags->"SamplePartition"],
Cell[393242, 12826, 261, 11, 15, "Index",
  CellTags->"Sampling"],
Cell[393506, 12839, 319, 11, 15, "Index",
  CellTags->"Scripts and faces"],
Cell[393828, 12852, 292, 11, 15, "Index",
  CellTags->"Segments"],
Cell[394123, 12865, 304, 11, 15, "Index",
  CellTags->"SegmentStyle"],
Cell[394430, 12878, 414, 14, 15, "Index",
  CellTags->"SegregationRatio"],
Cell[394847, 12894, 321, 11, 15, "Index",
  CellTags->"SelectContext"],
Cell[395171, 12907, 272, 10, 15, "Index",
  CellTags->"SelectIndividuals"],
Cell[395446, 12919, 232, 10, 15, "Index",
  CellTags->"Selection"],
Cell[395681, 12931, 1704, 61, 135, "IndexSubentry",
  CellTags->"Selection"],
Cell[397388, 12994, 437, 15, 15, "Index",
  CellTags->"SelectionCoefficient"],
Cell[397828, 13011, 327, 11, 15, "Index",
  CellTags->"Selection coefficients"],
Cell[398158, 13024, 519, 19, 30, "IndexSubentry",
  CellTags->"Selection coefficients"],
Cell[398680, 13045, 317, 11, 15, "Index",
  CellTags->"SelectionExact"],
Cell[399000, 13058, 658, 21, 45, "IndexSubentry",
  CellTags->"SelectionExact"],
Cell[399661, 13081, 290, 11, 15, "Index",
  CellTags->"Selection on diploids"],
Cell[399954, 13094, 888, 33, 75, "IndexSubentry",
  CellTags->"Selection on diploids"],
Cell[400845, 13129, 304, 11, 15, "Index",
  CellTags->"SelectionRate"],
Cell[401152, 13142, 251, 10, 15, "Index",
  CellTags->"SelectLoci"],
Cell[401406, 13154, 217, 10, 15, "Index",
  CellTags->"Selfing"],
Cell[401626, 13166, 235, 10, 15, "Index",
  CellTags->"Separate"],
Cell[401864, 13178, 258, 11, 15, "Index",
  CellTags->"Servedio"],
Cell[402125, 13191, 339, 12, 15, "Index",
  CellTags->"Set"],
Cell[402467, 13205, 323, 10, 15, "IndexSubentry",
  CellTags->"Set"],
Cell[402793, 13217, 293, 11, 15, "Index",
  CellTags->"Set manipulation"],
Cell[403089, 13230, 270, 10, 15, "Index",
  CellTags->"SetOfCombinations"],
Cell[403362, 13242, 251, 10, 15, "Index",
  CellTags->"SetPartition"],
Cell[403616, 13254, 304, 11, 15, "Index",
  CellTags->"Sets of loci"],
Cell[403923, 13267, 216, 10, 15, "Index",
  CellTags->"Sex"],
Cell[404142, 13279, 394, 14, 15, "Index",
  CellTags->"Sex linkage"],
Cell[404539, 13295, 236, 9, 15, "IndexSubentry",
  CellTags->"Sex linkage"],
Cell[404778, 13306, 240, 10, 15, "Index",
  CellTags->"SexOfOrigin"],
Cell[405021, 13318, 267, 10, 15, "Index",
  CellTags->"Sexual selection"],
Cell[405291, 13330, 1209, 45, 105, "IndexSubentry",
  CellTags->"Sexual selection"],
Cell[406503, 13377, 265, 10, 15, "Index",
  CellTags->"ShortContext"],
Cell[406771, 13389, 278, 10, 15, "Index",
  CellTags->"SigmaMatrix"],
Cell[407052, 13401, 247, 10, 15, "Index",
  CellTags->"SignMask"],
Cell[407302, 13413, 236, 10, 15, "Index",
  CellTags->"SimplifyAddUp"],
Cell[407541, 13425, 239, 10, 15, "Index",
  CellTags->"SimplifyAddUpQ"],
Cell[407783, 13437, 261, 10, 15, "Index",
  CellTags->"SimplifyFamilies"],
Cell[408047, 13449, 335, 11, 15, "Index",
  CellTags->"Simulating individuals"],
Cell[408385, 13462, 503, 15, 30, "IndexSubentry",
  CellTags->"Simulating individuals"],
Cell[408891, 13479, 284, 10, 15, "Index",
  CellTags->"SizeOfGenealogyPlot"],
Cell[409178, 13491, 279, 10, 15, "Index",
  CellTags->"Slatkin & Excoffier 1996"],
Cell[409460, 13503, 239, 10, 15, "Index",
  CellTags->"SlowChange"],
Cell[409702, 13515, 274, 10, 15, "Index",
  CellTags->"SortByClass"],
Cell[409979, 13527, 284, 9, 15, "IndexSubentry",
  CellTags->"SortByClass"],
Cell[410266, 13538, 231, 10, 15, "Index",
  CellTags->"SortByHead"],
Cell[410500, 13550, 254, 10, 15, "Index",
  CellTags->"SpatialCovariance"],
Cell[410757, 13562, 323, 11, 15, "Index",
  CellTags->"Spatially varying selection"],
Cell[411083, 13575, 268, 10, 15, "Index",
  CellTags->"Special notation"],
Cell[411354, 13587, 239, 10, 15, "Index",
  CellTags->"SplitSet"],
Cell[411596, 13599, 301, 11, 15, "Index",
  CellTags->"Stabilising selection"],
Cell[411900, 13612, 1135, 40, 90, "IndexSubentry",
  CellTags->"Stabilising selection"],
Cell[413038, 13654, 411, 15, 15, "Index",
  CellTags->"Stability"],
Cell[413452, 13671, 275, 9, 15, "IndexSubentry",
  CellTags->"Stability"],
Cell[413730, 13682, 320, 11, 15, "Index",
  CellTags->"StabilityDirect"],
Cell[414053, 13695, 280, 9, 15, "IndexSubentry",
  CellTags->"StabilityDirect"],
Cell[414336, 13706, 422, 14, 15, "Index",
  CellTags->"StabilityK"],
Cell[414761, 13722, 313, 11, 15, "Index",
  CellTags->"StabilityKTable"],
Cell[415077, 13735, 282, 10, 15, "Index",
  CellTags->"StabilityMatrix"],
Cell[415362, 13747, 293, 11, 15, "Index",
  CellTags->"Stage"],
Cell[415658, 13760, 225, 10, 15, "Index",
  CellTags->"Stages"],
Cell[415886, 13772, 288, 9, 15, "IndexSubentry",
  CellTags->"Stages"],
Cell[416177, 13783, 266, 10, 15, "Index",
  CellTags->"StandardPartition"],
Cell[416446, 13795, 269, 10, 15, "Index",
  CellTags->"StandardPartitionQ"],
Cell[416718, 13807, 285, 10, 15, "Index",
  CellTags->"StartingStepSize"],
Cell[417006, 13819, 357, 12, 15, "Index",
  CellTags->"Stepping-stone migration"],
Cell[417366, 13833, 347, 12, 15, "Index",
  CellTags->"Stepping-stone model"],
Cell[417716, 13847, 501, 16, 30, "IndexSubentry",
  CellTags->"Stepping-stone model"],
Cell[418220, 13865, 323, 11, 15, "Index",
  CellTags->"StoreExact"],
Cell[418546, 13878, 1518, 45, 105, "IndexSubentry",
  CellTags->"StoreExact"],
Cell[420067, 13925, 450, 15, 15, "Index",
  CellTags->"StoreResults"],
Cell[420520, 13942, 813, 24, 30, "IndexSubentry",
  CellTags->"StoreResults"],
Cell[421336, 13968, 264, 10, 15, "Index",
  CellTags->"StructuredArray"],
Cell[421603, 13980, 304, 10, 15, "Index",
  CellTags->"StructuredInitialParameters"],
Cell[421910, 13992, 327, 11, 15, "Index",
  CellTags->"StructuredLogLikelihood"],
Cell[422240, 14005, 434, 14, 15, "Index",
  CellTags->"StructuredMLE"],
Cell[422677, 14021, 264, 10, 15, "Index",
  CellTags->"StructuredModel"],
Cell[422944, 14033, 288, 10, 15, "Index",
  CellTags->"StructuredModelReduce"],
Cell[423235, 14045, 262, 11, 15, "Index",
  CellTags->"Structured models"],
Cell[423500, 14058, 272, 9, 15, "IndexSubentry",
  CellTags->"Structured models"],
Cell[423775, 14069, 286, 10, 15, "Index",
  CellTags->"StructuredParameter"],
Cell[424064, 14081, 332, 11, 15, "Index",
  CellTags->"StructuredVariance"],
Cell[424399, 14094, 248, 11, 15, "Index",
  CellTags->"Style sheets"],
Cell[424650, 14107, 272, 10, 15, "Index",
  CellTags->"Subdivide"],
Cell[424925, 14119, 309, 11, 15, "Index",
  CellTags->"Subscripts"],
Cell[425237, 14132, 222, 10, 15, "Index",
  CellTags->"Subsets"],
Cell[425462, 14144, 366, 15, 30, "IndexSubentry",
  CellTags->"Subsets"],
Cell[425831, 14161, 234, 11, 15, "Index",
  CellTags->"Sums"],
Cell[426068, 14174, 255, 10, 15, "Index",
  CellTags->"SwapStates"],
Cell[426326, 14186, 344, 11, 15, "Index",
  CellTags->"Symmetric cline"],
Cell[426673, 14199, 317, 9, 15, "IndexSubentry",
  CellTags->"Symmetric cline"],
Cell[426993, 14210, 331, 11, 15, "Index",
  CellTags->"SymmetricDiploidFrequencies"],
Cell[427327, 14223, 331, 11, 15, "Index",
  CellTags->"SymmetricHaploidFrequencies"],
Cell[427661, 14236, 431, 15, 15, "Index",
  CellTags->"Symmetric model"],
Cell[428095, 14253, 1473, 49, 105, "IndexSubentry",
  CellTags->"Symmetric model"],
Cell[429571, 14304, 477, 15, 15, "Index",
  CellTags->"SymmetricNeutralDiploidFrequencies"],
Cell[430051, 14321, 477, 15, 15, "Index",
  CellTags->"SymmetricNeutralHaploidFrequencies"],
Cell[430531, 14338, 279, 10, 15, "Index",
  CellTags->"SymmetricRecombination"],
Cell[430813, 14350, 315, 10, 15, "Index",
  CellTags->"SymmetricRepresentations"],
Cell[431131, 14362, 259, 10, 15, "Index",
  CellTags->"SymmetricSexes"],
Cell[431393, 14374, 356, 14, 15, "Index",
  CellTags->"Symmetrise"],
Cell[431752, 14390, 234, 11, 15, "Index",
  CellTags->"T"],
Cell[431989, 14403, 277, 11, 15, "Index",
  CellTags->"Table"],
Cell[432269, 14416, 220, 10, 15, "Index",
  CellTags->"Tag"],
Cell[432492, 14428, 260, 11, 15, "Index",
  CellTags->"Tags"],
Cell[432755, 14441, 295, 10, 15, "IndexSubentry",
  CellTags->"Tags"],
Cell[433053, 14453, 390, 12, 15, "Index",
  CellTags->"TakeAway"],
Cell[433446, 14467, 260, 10, 15, "Index",
  CellTags->"TakeOptions"],
Cell[433709, 14479, 237, 11, 15, "Index",
  CellTags->"Time"],
Cell[433949, 14492, 307, 11, 15, "Index",
  CellTags->"TimesOfEvents"],
Cell[434259, 14505, 322, 11, 15, "Index",
  CellTags->"TimespanOfJunction"],
Cell[434584, 14518, 319, 11, 15, "Index",
  CellTags->"TimespanOfLineage"],
Cell[434906, 14531, 346, 14, 15, "Index",
  CellTags->"TimesUp"],
Cell[435255, 14547, 375, 15, 30, "IndexSubentry",
  CellTags->"TimesUp"],
Cell[435633, 14564, 248, 10, 15, "Index",
  CellTags->"ToBaake"],
Cell[435884, 14576, 254, 10, 15, "Index",
  CellTags->"ToBennett"],
Cell[436141, 14588, 284, 10, 15, "Index",
  CellTags->"ToBennettExpression"],
Cell[436428, 14600, 260, 10, 15, "Index",
  CellTags->"ToCumulants"],
Cell[436691, 14612, 254, 10, 15, "Index",
  CellTags->"ToMoments"],
Cell[436948, 14624, 296, 10, 15, "Index",
  CellTags->"ToPopulationCumulants"],
Cell[437247, 14636, 290, 10, 15, "Index",
  CellTags->"ToPopulationMoments"],
Cell[437540, 14648, 286, 10, 15, "Index",
  CellTags->"TotalLength"],
Cell[437829, 14660, 252, 10, 15, "Index",
  CellTags->"TotalNumber"],
Cell[438084, 14672, 339, 12, 15, "Index",
  CellTags->"Trait"],
Cell[438426, 14686, 271, 10, 15, "Index",
  CellTags->"TransformedRange"],
Cell[438700, 14698, 291, 10, 15, "Index",
  CellTags->"TransformInformation"],
Cell[438994, 14710, 269, 10, 15, "Index",
  CellTags->"TransmissionRule"],
Cell[439266, 14722, 300, 11, 15, "Index",
  CellTags->"Transmission rules"],
Cell[439569, 14735, 647, 21, 45, "IndexSubentry",
  CellTags->"Transmission rules"],
Cell[440219, 14758, 272, 10, 15, "Index",
  CellTags->"TriDiagonalMatrix"],
Cell[440494, 14770, 352, 12, 15, "Index",
  CellTags->"TruncationSelection"],
Cell[440849, 14784, 318, 9, 15, "IndexSubentry",
  CellTags->"TruncationSelection"],
Cell[441170, 14795, 298, 10, 15, "Index",
  CellTags->"Turelli and Barton 1994"],
Cell[441471, 14807, 270, 10, 15, "Index",
  CellTags->"Turelli & Barton 1994"],
Cell[441744, 14819, 240, 10, 15, "Index",
  CellTags->"Two alleles"],
Cell[441987, 14831, 360, 13, 15, "IndexSubentry",
  CellTags->"Two alleles"],
Cell[442350, 14846, 302, 11, 15, "Index",
  CellTags->"UMS"],
Cell[442655, 14859, 667, 21, 45, "IndexSubentry",
  CellTags->"UMS"],
Cell[443325, 14882, 261, 10, 15, "Index",
  CellTags->"UnionOfGametes"],
Cell[443589, 14894, 276, 10, 15, "Index",
  CellTags->"UnlinkedRecombination"],
Cell[443868, 14906, 286, 10, 15, "Index",
  CellTags->"UnrootedGenealogy"],
Cell[444157, 14918, 269, 10, 15, "Index",
  CellTags->"UpperOffDiagonal"],
Cell[444429, 14930, 302, 11, 15, "Index",
  CellTags->"USM"],
Cell[444734, 14943, 667, 21, 45, "IndexSubentry",
  CellTags->"USM"],
Cell[445404, 14966, 281, 10, 15, "Index",
  CellTags->"ValidMatrixQ"],
Cell[445688, 14978, 332, 11, 15, "Index",
  CellTags->"VarianceComponents"],
Cell[446023, 14991, 263, 9, 15, "IndexSubentry",
  CellTags->"VarianceComponents"],
Cell[446289, 15002, 253, 11, 15, "Index",
  CellTags->"Versions"],
Cell[446545, 15015, 426, 14, 15, "Index",
  CellTags->"Wiuf & Hein 1999"],
Cell[446974, 15031, 260, 11, 15, "Index",
  CellTags->"WLinkedLoci"],
Cell[447237, 15044, 441, 15, 30, "IndexSubentry",
  CellTags->"WLinkedLoci"],
Cell[447681, 15061, 277, 10, 15, "Index",
  CellTags->"Wright-Fisher sampling"],
Cell[447961, 15073, 247, 11, 15, "Index",
  CellTags->"X"],
Cell[448211, 15086, 260, 11, 15, "Index",
  CellTags->"XLinkedLoci"],
Cell[448474, 15099, 441, 15, 30, "IndexSubentry",
  CellTags->"XLinkedLoci"],
Cell[448918, 15116, 260, 11, 15, "Index",
  CellTags->"YLinkedLoci"],
Cell[449181, 15129, 441, 15, 30, "IndexSubentry",
  CellTags->"YLinkedLoci"],
Cell[449625, 15146, 260, 11, 15, "Index",
  CellTags->"ZLinkedLoci"],
Cell[449888, 15159, 441, 15, 30, "IndexSubentry",
  CellTags->"ZLinkedLoci"],
Cell[450332, 15176, 411, 15, 15, "Index",
  CellTags->"Zygotes"],
Cell[450746, 15193, 427, 15, 15, "Index",
  CellTags->"\[GothicA]"],
Cell[451176, 15210, 419, 15, 15, "Index",
  CellTags->"\[GothicCapitalA]"],
Cell[451598, 15227, 340, 11, 15, "Index",
  CellTags->"\[GothicCapitalC]"],
Cell[451941, 15240, 612, 19, 15, "Index",
  CellTags->"\[GothicCapitalD]"],
Cell[452556, 15261, 494, 16, 23, "Index",
  CellTags->"\!\(\(\[GothicCapitalG]\^\[RawStar]\)\)"],
Cell[453053, 15279, 421, 15, 23, "Index",
  CellTags->"\[GothicCapitalG]"],
Cell[453477, 15296, 435, 15, 23, "Index",
  CellTags->"\[GothicCapitalH]"],
Cell[453915, 15313, 425, 15, 23, "Index",
  CellTags->"\[GothicCapitalJ]"],
Cell[454343, 15330, 320, 11, 23, "Index",
  CellTags->"\[GothicK]"],
Cell[454666, 15343, 377, 11, 23, "Index",
  CellTags->"\[GothicCapitalK]"],
Cell[455046, 15356, 308, 11, 23, "Index",
  CellTags->"\[GothicM]"],
Cell[455357, 15369, 308, 11, 23, "Index",
  CellTags->"\[GothicP]"],
Cell[455668, 15382, 369, 12, 23, "Index",
  CellTags->"\[GothicP]\[GothicQ]"],
Cell[456040, 15396, 308, 11, 23, "Index",
  CellTags->"\[GothicQ]"],
Cell[456351, 15409, 314, 11, 23, "Index",
  CellTags->"\[GothicR]"],
Cell[456668, 15422, 301, 11, 23, "Index",
  CellTags->"\[GothicS]"],
Cell[456972, 15435, 421, 15, 23, "Index",
  CellTags->"\[GothicCapitalZ]"],
Cell[457396, 15452, 348, 11, 23, "Index",
  CellTags->"\[DoubleStruckCapitalG]"],
Cell[457747, 15465, 322, 11, 23, "Index",
  CellTags->"\[DoubleStruckCapitalM]"],
Cell[458072, 15478, 457, 15, 23, "Index",
  CellTags->"\[DoubleStruckCapitalR]"],
Cell[458532, 15495, 318, 11, 23, "Index",
  CellTags->"\[DoubleStruckCapitalW]"],
Cell[458853, 15508, 358, 12, 23, "Index",
  CellTags->"\[DoubleStruckCapitalZ]"],
Cell[459214, 15522, 310, 11, 23, "Index",
  CellTags->"\[Gamma]"],
Cell[459527, 15535, 304, 11, 23, "Index",
  CellTags->"\[Zeta]"],
Cell[459834, 15548, 307, 11, 23, "Index",
  CellTags->"\[CapitalMu]"],
Cell[460144, 15561, 312, 11, 23, "Index",
  CellTags->"\[Chi]"],
Cell[460459, 15574, 296, 11, 23, "Index",
  CellTags->"\[Sampi]"],
Cell[460758, 15587, 290, 10, 23, "Index",
  CellTags->"$MetropolisAdjustment"],
Cell[461051, 15599, 317, 11, 23, "Index",
  CellTags->"\[WeierstrassP]"],
Cell[461371, 15612, 449, 12, 23, "Index",
  CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],
Cell[461823, 15626, 320, 11, 23, "Index",
  CellTags->"\[CircleDot]"],
Cell[462146, 15639, 394, 12, 23, "Index",
  CellTags->"\[Backslash]"],
Cell[462543, 15653, 450, 15, 23, "Index",
  CellTags->"\[Wedge]"],
Cell[462996, 15670, 319, 11, 23, "Index",
  CellTags->"\[CirclePlus]"]
}, Closed]],

Cell[CellGroupData[{
Cell[463352, 15686, 40, 0, 28, "Subsubsection"],
Cell[463395, 15688, 106, 2, 27, "Input"],
Cell[463504, 15692, 247, 11, 23, "Index",
  CellTags->"|."],
Cell[463754, 15705, 233, 11, 23, "Index",
  CellTags->"\\\\"],
Cell[463990, 15718, 243, 11, 23, "Index",
  CellTags->"<>"],
Cell[464236, 15731, 254, 11, 23, "Index",
  CellTags->"||."],
Cell[464493, 15744, 296, 11, 23, "Index",
  CellTags->"AddAncestors"],
Cell[464792, 15757, 331, 11, 23, "Index",
  CellTags->"AddCoalescentLineage"],
Cell[465126, 15770, 302, 11, 23, "Index",
  CellTags->"AddDescendants"],
Cell[465431, 15783, 271, 10, 23, "Index",
  CellTags->"AddGenealogy"],
Cell[465705, 15795, 272, 10, 23, "Index",
  CellTags->"Additive models"],
Cell[465980, 15807, 303, 11, 23, "Index",
  CellTags->"Additive selection"],
Cell[466286, 15820, 713, 27, 68, "IndexSubentry",
  CellTags->"Additive selection"],
Cell[467002, 15849, 268, 10, 23, "Index",
  CellTags->"AddMutation"],
Cell[467273, 15861, 256, 10, 23, "Index",
  CellTags->"AddNode"],
Cell[467532, 15873, 337, 11, 23, "Index",
  CellTags->"AddRecombinantLineages"],
Cell[467872, 15886, 229, 10, 23, "Index",
  CellTags->"AddTag"],
Cell[468104, 15898, 334, 14, 23, "Index",
  CellTags->"AddUp"],
Cell[468441, 15914, 492, 21, 53, "IndexSubentry",
  CellTags->"AddUp"],
Cell[468936, 15937, 261, 10, 23, "Index",
  CellTags->"AdmixtureFrequency"],
Cell[469200, 15949, 352, 14, 23, "Index",
  CellTags->"Admixture models"],
Cell[469555, 15965, 843, 33, 83, "IndexSubentry",
  CellTags->"Admixture models"],
Cell[470401, 16000, 408, 15, 23, "Index",
  CellTags->"Adults"],
Cell[470812, 16017, 326, 11, 23, "Index",
  CellTags->"Allele frequencies"],
Cell[471141, 16030, 287, 9, 23, "IndexSubentry",
  CellTags->"Allele frequencies"],
Cell[471431, 16041, 472, 15, 23, "Index",
  CellTags->"AlleleFrequencies"],
Cell[471906, 16058, 286, 10, 23, "Index",
  CellTags->"AlleleFrequency"],
Cell[472195, 16070, 298, 10, 23, "Index",
  CellTags->"AlleleFrequencyMean"],
Cell[472496, 16082, 959, 30, 68, "IndexSubentry",
  CellTags->"AlleleFrequencyMean"],
Cell[473458, 16114, 314, 11, 23, "Index",
  CellTags->"AlleleFrequencyP"],
Cell[473775, 16127, 304, 10, 23, "Index",
  CellTags->"AlleleFrequencyPermutations"],
Cell[474082, 16139, 366, 12, 23, "Index",
  CellTags->"AlleleFrequencyPQ"],
Cell[474451, 16153, 314, 11, 23, "Index",
  CellTags->"AlleleFrequencyQ"],
Cell[474768, 16166, 301, 10, 23, "Index",
  CellTags->"AlleleFrequencyTable"],
Cell[475072, 16178, 1143, 36, 83, "IndexSubentry",
  CellTags->"AlleleFrequencyTable"],
Cell[476218, 16216, 313, 11, 23, "Index",
  CellTags->"AllelicDeviation"],
Cell[476534, 16229, 258, 11, 23, "Index",
  CellTags->"AllelicState"],
Cell[476795, 16242, 295, 11, 23, "Index",
  CellTags->"AllEvents"],
Cell[477093, 16255, 258, 10, 23, "Index",
  CellTags->"AllSets"],
Cell[477354, 16267, 273, 11, 23, "Index",
  CellTags->"Ancestors"],
Cell[477630, 16280, 273, 9, 23, "IndexSubentry",
  CellTags->"Ancestors"],
Cell[477906, 16291, 308, 10, 23, "Index",
  CellTags->"AncestralGraphPattern"],
Cell[478217, 16303, 293, 11, 23, "Index",
  CellTags->"Ancestral graphs"],
Cell[478513, 16316, 926, 33, 83, "IndexSubentry",
  CellTags->"Ancestral graphs"],
Cell[479442, 16351, 293, 10, 23, "Index",
  CellTags->"AncestralLineage"],
Cell[479738, 16363, 314, 10, 23, "Index",
  CellTags->"AncestralLineagePattern"],
Cell[480055, 16375, 255, 10, 23, "Index",
  CellTags->"Ancestry"],
Cell[480313, 16387, 334, 11, 23, "Index",
  CellTags->"Arbitrary sets of loci"],
Cell[480650, 16400, 240, 10, 23, "Index",
  CellTags->"Arnold 1996"],
Cell[480893, 16412, 414, 14, 23, "Index",
  CellTags->"Asmussen and Orive 2000"],
Cell[481310, 16428, 266, 10, 23, "Index",
  CellTags->"Asmussen et al. 1987"],
Cell[481579, 16440, 256, 10, 23, "Index",
  CellTags->"B"],
Cell[481838, 16452, 363, 14, 23, "Index",
  CellTags->"Baake 2001"],
Cell[482204, 16468, 313, 11, 23, "Index",
  CellTags->"BackgroundStyle"],
Cell[482520, 16481, 276, 11, 23, "Index",
  CellTags->"Barrier"],
Cell[482799, 16494, 276, 10, 23, "Index",
  CellTags->"BarrierStrength"],
Cell[483078, 16506, 240, 10, 23, "Index",
  CellTags->"Barton 1986"],
Cell[483321, 16518, 262, 10, 23, "Index",
  CellTags->"Barton 1995"],
Cell[483586, 16530, 240, 10, 23, "Index",
  CellTags->"Barton 2000"],
Cell[483829, 16542, 298, 10, 23, "Index",
  CellTags->"Barton and Turelli 1991"],
Cell[484130, 16554, 261, 10, 23, "Index",
  CellTags->"Barton & Gale 1993"],
Cell[484394, 16566, 264, 10, 23, "Index",
  CellTags->"Barton & Shpak 1999"],
Cell[484661, 16578, 270, 10, 23, "Index",
  CellTags->"Barton & Turelli 1991"],
Cell[484934, 16590, 243, 10, 23, "Index",
  CellTags->"Bennett 1954"],
Cell[485180, 16602, 251, 10, 23, "Index",
  CellTags->"BennettB"],
Cell[485434, 16614, 251, 10, 23, "Index",
  CellTags->"BennettC"],
Cell[485688, 16626, 275, 10, 23, "Index",
  CellTags->"BennettExpansion"],
Cell[485966, 16638, 236, 10, 23, "Index",
  CellTags->"Biallelic"],
Cell[486205, 16650, 358, 13, 23, "IndexSubentry",
  CellTags->"Biallelic"],
Cell[486566, 16665, 276, 10, 23, "Index",
  CellTags->"BiallelicMutation"],
Cell[486845, 16677, 268, 9, 23, "IndexSubentry",
  CellTags->"BiallelicMutation"],
Cell[487116, 16688, 266, 10, 23, "Index",
  CellTags->"Binary integers"],
Cell[487385, 16700, 262, 10, 23, "Index",
  CellTags->"Birth"],
Cell[487650, 16712, 258, 10, 23, "Index",
  CellTags->"BirthTime"],
Cell[487911, 16724, 447, 15, 23, "Index",
  CellTags->"Boundary conditions"],
Cell[488361, 16741, 240, 10, 23, "Index",
  CellTags->"Box"],
Cell[488604, 16753, 246, 10, 23, "Index",
  CellTags->"Boxes"],
Cell[488853, 16765, 293, 10, 23, "Index",
  CellTags->"Browser categories"],
Cell[489149, 16777, 239, 11, 23, "Index",
  CellTags->"Bugs"],
Cell[489391, 16790, 1583, 63, 158, "IndexSubentry",
  CellTags->"Bugs"],
Cell[490977, 16855, 318, 11, 23, "Index",
  CellTags->"ChangeContext"],
Cell[491298, 16868, 238, 10, 23, "Index",
  CellTags->"ChangeSex"],
Cell[491539, 16880, 289, 10, 23, "Index",
  CellTags->"ClassToGenotypes"],
Cell[491831, 16892, 253, 11, 23, "Index",
  CellTags->"Cline"],
Cell[492087, 16905, 2662, 78, 113, "IndexSubentry",
  CellTags->"Cline"],
Cell[494752, 16985, 325, 11, 23, "Index",
  CellTags->"ClineGradient"],
Cell[495080, 16998, 323, 11, 23, "Index",
  CellTags->"ClineWidth"],
Cell[495406, 17011, 695, 21, 53, "IndexSubentry",
  CellTags->"ClineWidth"],
Cell[496104, 17034, 293, 10, 23, "Index",
  CellTags->"CoalesceLineages"],
Cell[496400, 17046, 329, 11, 23, "Index",
  CellTags->"CoalescenceDistribution"],
Cell[496732, 17059, 319, 11, 23, "Index",
  CellTags->"CoalescenceEvents"],
Cell[497054, 17072, 325, 11, 23, "Index",
  CellTags->"Coalescence times"],
Cell[497382, 17085, 322, 11, 23, "Index",
  CellTags->"CoalescentLineages"],
Cell[497707, 17098, 326, 11, 23, "Index",
  CellTags->"Coalescing lineages"],
Cell[498036, 17111, 282, 10, 23, "Index",
  CellTags->"CollapseGenealogy"],
Cell[498321, 17123, 274, 11, 23, "Index",
  CellTags->"Combinations"],
Cell[498598, 17136, 232, 10, 23, "Index",
  CellTags->"Combine"],
Cell[498833, 17148, 256, 10, 23, "Index",
  CellTags->"CompareLogL"],
Cell[499092, 17160, 1075, 31, 38, "Index",
  CellTags->"Compiled"],
Cell[500170, 17193, 1073, 31, 38, "Index",
  CellTags->"Compiling"],
Cell[501246, 17226, 286, 10, 23, "Index",
  CellTags->"CondenseGenealogy"],
Cell[501535, 17238, 271, 10, 23, "Index",
  CellTags->"CondenseMatrix"],
Cell[501809, 17250, 267, 10, 23, "Index",
  CellTags->"ConfigurationSet"],
Cell[502079, 17262, 289, 10, 23, "Index",
  CellTags->"ConstrainedIntervals"],
Cell[502371, 17274, 754, 22, 23, "Index",
  CellTags->"ConstructMutateList"],
Cell[503128, 17298, 442, 14, 23, "Index",
  CellTags->"ConstructMutateMatrix"],
Cell[503573, 17314, 286, 10, 23, "Index",
  CellTags->"ContextComponentQ"],
Cell[503862, 17326, 280, 10, 23, "Index",
  CellTags->"ContextPosition"],
Cell[504145, 17338, 274, 10, 23, "Index",
  CellTags->"ContextStageQ"],
Cell[504422, 17350, 283, 10, 23, "Index",
  CellTags->"ContextStructure"],
Cell[504708, 17362, 312, 11, 23, "Index",
  CellTags->"Continuous populations"],
Cell[505023, 17375, 665, 27, 68, "IndexSubentry",
  CellTags->"Continuous populations"],
Cell[505691, 17404, 273, 10, 23, "Index",
  CellTags->"ContinuumVariables"],
Cell[505967, 17416, 260, 10, 23, "Index",
  CellTags->"ConvertData"],
Cell[506230, 17428, 291, 10, 23, "Index",
  CellTags->"ConvertHyperlinkToAddOnsLink"],
Cell[506524, 17440, 427, 15, 23, "Index",
  CellTags->"Converting"],
Cell[506954, 17457, 287, 10, 23, "Index",
  CellTags->"CountHeterozygotes"],
Cell[507244, 17469, 292, 11, 23, "Index",
  CellTags->"Covariance"],
Cell[507539, 17482, 260, 10, 23, "Index",
  CellTags->"CovarianceMidPoints"],
Cell[507802, 17494, 289, 10, 23, "Index",
  CellTags->"Crow and Kimura 1970"],
Cell[508094, 17506, 253, 10, 23, "Index",
  CellTags->"Cumulant"],
Cell[508350, 17518, 332, 11, 23, "Index",
  CellTags->"CumulantDisequilibrium"],
Cell[508685, 17531, 264, 10, 23, "Index",
  CellTags->"CumulantEquilibrium"],
Cell[508952, 17543, 392, 11, 23, "Index",
  CellTags->"CumulantPopulationDisequilibrium"],
Cell[509347, 17556, 268, 10, 23, "Index",
  CellTags->"CumulantReduced"],
Cell[509618, 17568, 333, 14, 23, "Index",
  CellTags->"Cumulants"],
Cell[509954, 17584, 426, 14, 23, "Index",
  CellTags->"Cytoplasmic inheritance"],
Cell[510383, 17600, 440, 15, 38, "IndexSubentry",
  CellTags->"Cytoplasmic inheritance"],
Cell[510826, 17617, 283, 11, 23, "Index",
  CellTags->"CytoplasmicLoci"],
Cell[511112, 17630, 453, 15, 38, "IndexSubentry",
  CellTags->"CytoplasmicLoci"],
Cell[511568, 17647, 307, 10, 23, "Index",
  CellTags->"dAlleleFrequencyPermutations"],
Cell[511878, 17659, 235, 10, 23, "Index",
  CellTags->"Data"],
Cell[512116, 17671, 423, 15, 38, "IndexSubentry",
  CellTags->"Data"],
Cell[512542, 17688, 259, 11, 23, "Index",
  CellTags->"Datasets"],
Cell[512804, 17701, 368, 14, 23, "Index",
  CellTags->"Dawson 2000"],
Cell[513175, 17717, 262, 10, 23, "Index",
  CellTags->"Death"],
Cell[513440, 17729, 258, 10, 23, "Index",
  CellTags->"DeathTime"],
Cell[513701, 17741, 274, 10, 23, "Index",
  CellTags->"DefineContext"],
Cell[513978, 17753, 271, 10, 23, "Index",
  CellTags->"DegreesOfFreedom"],
Cell[514252, 17765, 279, 10, 23, "Index",
  CellTags->"DeletedMutations"],
Cell[514534, 17777, 280, 10, 23, "Index",
  CellTags->"DeleteGenealogy"],
Cell[514817, 17789, 321, 11, 23, "Index",
  CellTags->"DeleteNullLineages"],
Cell[515141, 17802, 311, 9, 23, "IndexSubentry",
  CellTags->"DeleteNullLineages"],
Cell[515455, 17813, 322, 14, 23, "Index",
  CellTags->"Deme"],
Cell[515780, 17829, 614, 20, 23, "Index",
  CellTags->"DemeSize"],
Cell[516397, 17851, 3026, 86, 142, "IndexSubentry",
  CellTags->"DemeSize"],
Cell[519426, 17939, 264, 10, 23, "Index",
  CellTags->"Dempster et al 1977"],
Cell[519693, 17951, 252, 10, 23, "Index",
  CellTags->"Density"],
Cell[519948, 17963, 270, 10, 23, "Index",
  CellTags->"Descendants"],
Cell[520221, 17975, 436, 15, 38, "IndexSubentry",
  CellTags->"Descendants"],
Cell[520660, 17992, 296, 10, 23, "Index",
  CellTags->"Dicytonuclear associations"],
Cell[520959, 18004, 304, 11, 23, "Index",
  CellTags->"Diploid"],
Cell[521266, 18017, 277, 10, 23, "Index",
  CellTags->"DiploidConstraints"],
Cell[521546, 18029, 297, 10, 23, "Index",
  CellTags->"DiploidFrequencies"],
Cell[521846, 18041, 332, 11, 23, "Index",
  CellTags->"DiploidGenotypeFrequency"],
Cell[522181, 18054, 305, 10, 23, "Index",
  CellTags->"DiploidGenotypeFrequencyList"],
Cell[522489, 18066, 316, 10, 23, "Index",
  CellTags->"DiploidGenotypeFrequencyReduced"],
Cell[522808, 18078, 310, 10, 23, "Index",
  CellTags->"DiploidGenotypeFrequencyTable"],
Cell[523121, 18090, 297, 10, 23, "Index",
  CellTags->"DiploidIndividuals"],
Cell[523421, 18102, 275, 10, 23, "Index",
  CellTags->"DiploidPhenotype"],
Cell[523699, 18114, 402, 14, 23, "Index",
  CellTags->"DiploidPsi"],
Cell[524104, 18130, 309, 10, 23, "Index",
  CellTags->"DiploidRepresentations"],
Cell[524416, 18142, 414, 14, 23, "Index",
  CellTags->"DiploidSource"],
Cell[524833, 18158, 259, 10, 23, "Index",
  CellTags->"DiploidSubsets"],
Cell[525095, 18170, 257, 10, 23, "Index",
  CellTags->"DiploidTypes"],
Cell[525355, 18182, 283, 11, 23, "Index",
  CellTags->"Disequilibrium"],
Cell[525641, 18195, 919, 29, 53, "IndexSubentry",
  CellTags->"Disequilibrium"],
Cell[526563, 18226, 339, 11, 23, "Index",
  CellTags->"DisequilibriumMean"],
Cell[526905, 18239, 744, 23, 53, "IndexSubentry",
  CellTags->"DisequilibriumMean"],
Cell[527652, 18264, 347, 12, 23, "Index",
  CellTags->"DisequilibriumTable"],
Cell[528002, 18278, 748, 23, 53, "IndexSubentry",
  CellTags->"DisequilibriumTable"],
Cell[528753, 18303, 299, 11, 23, "Index",
  CellTags->"Dispersal"],
Cell[529055, 18316, 276, 10, 23, "Index",
  CellTags->"DistanceSquared"],
Cell[529334, 18328, 241, 10, 23, "Index",
  CellTags->"Distribution"],
Cell[529578, 18340, 237, 10, 23, "Index",
  CellTags->"DivideZero"],
Cell[529818, 18352, 277, 10, 23, "Index",
  CellTags->"DoReplicates"],
Cell[530098, 18364, 353, 12, 23, "Index",
  CellTags->"DoubleCline"],
Cell[530454, 18378, 772, 23, 53, "IndexSubentry",
  CellTags->"DoubleCline"],
Cell[531229, 18403, 262, 10, 23, "Index",
  CellTags->"DrawSamples"],
Cell[531494, 18415, 260, 10, 23, "Index",
  CellTags->"DropOptions"],
Cell[531757, 18427, 243, 10, 23, "Index",
  CellTags->"Edwards 1972"],
Cell[532003, 18439, 272, 11, 23, "Index",
  CellTags->"EmptySets"],
Cell[532278, 18452, 270, 11, 23, "Index",
  CellTags->"Epistasis"],
Cell[532551, 18465, 300, 11, 23, "Index",
  CellTags->"EquivalentSexes"],
Cell[532854, 18478, 267, 10, 23, "Index",
  CellTags->"ErrorBound"],
Cell[533124, 18490, 298, 10, 23, "Index",
  CellTags->"EstimateFamilyMoments"],
Cell[533425, 18502, 274, 10, 23, "Index",
  CellTags->"EstimateMoments"],
Cell[533702, 18514, 269, 11, 23, "Index",
  CellTags->"Estimating D"],
Cell[533974, 18527, 2407, 92, 218, "IndexSubentry",
  CellTags->"Estimating D"],
Cell[536384, 18621, 293, 10, 23, "Index",
  CellTags->"ExactEigenvalues"],
Cell[536680, 18633, 459, 15, 23, "Index",
  CellTags->"ExactIntersection"],
Cell[537142, 18650, 269, 10, 23, "Index",
  CellTags->"ExactProbability"],
Cell[537414, 18662, 252, 11, 23, "Index",
  CellTags->"Expectation"],
Cell[537669, 18675, 572, 16, 38, "IndexSubentry",
  CellTags->"Expectation"],
Cell[538244, 18693, 329, 11, 23, "Index",
  CellTags->"ExponentialF"],
Cell[538576, 18706, 877, 26, 53, "IndexSubentry",
  CellTags->"ExponentialF"],
Cell[539456, 18734, 270, 10, 23, "Index",
  CellTags->"ExtantIndividuals"],
Cell[539729, 18746, 321, 11, 23, "Index",
  CellTags->"ExtractContexts"],
Cell[540053, 18759, 242, 10, 23, "Index",
  CellTags->"ExtractExtant"],
Cell[540298, 18771, 424, 14, 23, "Index",
  CellTags->"ExtractGenealogy"],
Cell[540725, 18787, 314, 11, 23, "Index",
  CellTags->"ExtractGenes"],
Cell[541042, 18800, 285, 10, 23, "Index",
  CellTags->"ExtractInformation"],
Cell[541330, 18812, 301, 9, 23, "IndexSubentry",
  CellTags->"ExtractInformation"],
Cell[541634, 18823, 306, 11, 23, "Index",
  CellTags->"ExtractLabel"],
Cell[541943, 18836, 342, 11, 23, "Index",
  CellTags->"ExtractLineagesEndingAtT"],
Cell[542288, 18849, 353, 12, 23, "Index",
  CellTags->"ExtractLineagesStartingAtT"],
Cell[542644, 18863, 260, 10, 23, "Index",
  CellTags->"ExtractRepeat"],
Cell[542907, 18875, 279, 10, 23, "Index",
  CellTags->"ExtractSubMatrix"],
Cell[543189, 18887, 327, 11, 23, "Index",
  CellTags->"FamilyAlleleFrequencyEstimate"],
Cell[543519, 18900, 274, 10, 23, "Index",
  CellTags->"FamilyEffects"],
Cell[543796, 18912, 256, 10, 23, "Index",
  CellTags->"FamilyM"],
Cell[544055, 18924, 264, 10, 23, "Index",
  CellTags->"FamilyProbability"],
Cell[544322, 18936, 291, 11, 23, "Index",
  CellTags->"Family structure"],
Cell[544616, 18949, 258, 10, 23, "Index",
  CellTags->"Fecundity"],
Cell[544877, 18961, 249, 10, 23, "Index",
  CellTags->"FindHyperlinks"],
Cell[545129, 18973, 243, 10, 23, "Index",
  CellTags->"FindIndexTag"],
Cell[545375, 18985, 238, 10, 23, "Index",
  CellTags->"FindMLE"],
Cell[545616, 18997, 253, 10, 23, "Index",
  CellTags->"FindNode"],
Cell[545872, 19009, 239, 10, 23, "Index",
  CellTags->"FindPosition"],
Cell[546114, 19021, 249, 10, 23, "Index",
  CellTags->"FindTags"],
Cell[546366, 19033, 316, 11, 23, "Index",
  CellTags->"Fitness"],
Cell[546685, 19046, 618, 21, 53, "IndexSubentry",
  CellTags->"Fitness"],
Cell[547306, 19069, 305, 11, 23, "Index",
  CellTags->"FitnessSet"],
Cell[547614, 19082, 295, 11, 23, "Index",
  CellTags->"FitnessTable"],
Cell[547912, 19095, 475, 15, 38, "IndexSubentry",
  CellTags->"FitnessTable"],
Cell[548390, 19112, 300, 11, 23, "Index",
  CellTags->"FixedEnds"],
Cell[548693, 19125, 1296, 37, 67, "IndexSubentry",
  CellTags->"FixedEnds"],
Cell[549992, 19164, 278, 10, 23, "Index",
  CellTags->"Flatten"],
Cell[550273, 19176, 274, 10, 23, "Index",
  CellTags->"FlattenList"],
Cell[550550, 19188, 277, 9, 23, "IndexSubentry",
  CellTags->"FlattenList"],
Cell[550830, 19199, 274, 10, 23, "Index",
  CellTags->"FourierNormalised"],
Cell[551107, 19211, 289, 10, 23, "Index",
  CellTags->"FourierNormalisedTable"],
Cell[551399, 19223, 315, 10, 23, "Index",
  CellTags->"FrequencyRepresentations"],
Cell[551717, 19235, 254, 10, 23, "Index",
  CellTags->"FromBaake"],
Cell[551974, 19247, 260, 10, 23, "Index",
  CellTags->"FromBennett"],
Cell[552237, 19259, 290, 10, 23, "Index",
  CellTags->"FromBennettExpression"],
Cell[552530, 19271, 262, 10, 23, "Index",
  CellTags->"FullContext"],
Cell[552795, 19283, 307, 10, 23, "Index",
  CellTags->"FullGenotypeFrequencyReduced"],
Cell[553105, 19295, 301, 10, 23, "Index",
  CellTags->"FullGenotypeFrequencyTable"],
Cell[553409, 19307, 257, 10, 23, "Index",
  CellTags->"FullOutput"],
Cell[553669, 19319, 241, 10, 23, "Index",
  CellTags->"Function"],
Cell[553913, 19331, 286, 11, 23, "Index",
  CellTags->"Gametes"],
Cell[554202, 19344, 1087, 36, 68, "IndexSubentry",
  CellTags->"Gametes"],
Cell[555292, 19382, 298, 11, 23, "Index",
  CellTags->"GameteTable"],
Cell[555593, 19395, 440, 15, 38, "IndexSubentry",
  CellTags->"GameteTable"],
Cell[556036, 19412, 290, 10, 23, "Index",
  CellTags->"GaussianLogLikelihood"],
Cell[556329, 19424, 260, 10, 23, "Index",
  CellTags->"GaussianMLE"],
Cell[556592, 19436, 270, 11, 23, "Index",
  CellTags->"Genealogies"],
Cell[556865, 19449, 929, 33, 83, "IndexSubentry",
  CellTags->"Genealogies"],
Cell[557797, 19484, 412, 15, 23, "Index",
  CellTags->"Genealogy"],
Cell[558212, 19501, 276, 10, 23, "Index",
  CellTags->"GenealogyToMatrix"],
Cell[558491, 19513, 265, 10, 23, "Index",
  CellTags->"GeneralizedTransform"],
Cell[558759, 19525, 283, 11, 23, "Index",
  CellTags->"Generating functions"],
Cell[559045, 19538, 437, 15, 38, "IndexSubentry",
  CellTags->"Generating functions"],
Cell[559485, 19555, 277, 10, 23, "Index",
  CellTags->"Genes and contexts"],
Cell[559765, 19567, 334, 12, 23, "Index",
  CellTags->"Genome"],
Cell[560102, 19581, 287, 11, 23, "Index",
  CellTags->"Genotype"],
Cell[560392, 19594, 566, 19, 38, "IndexSubentry",
  CellTags->"Genotype"],
Cell[560961, 19615, 299, 11, 23, "Index",
  CellTags->"Genotype frequencies"],
Cell[561263, 19628, 321, 11, 23, "Index",
  CellTags->"Genotype frequency"],
Cell[561587, 19641, 292, 10, 23, "Index",
  CellTags->"GenotypeFrequency"],
Cell[561882, 19653, 301, 10, 23, "Index",
  CellTags->"GenotypeFrequencyArguments"],
Cell[562186, 19665, 303, 10, 23, "Index",
  CellTags->"GenotypeFrequencyConvert"],
Cell[562492, 19677, 307, 10, 23, "Index",
  CellTags->"GenotypeFrequencyTable"],
Cell[562802, 19689, 281, 10, 23, "Index",
  CellTags->"GenotypePosition"],
Cell[563086, 19701, 288, 10, 23, "Index",
  CellTags->"GenotypeProbability"],
Cell[563377, 19713, 286, 9, 23, "IndexSubentry",
  CellTags->"GenotypeProbability"],
Cell[563666, 19724, 256, 11, 23, "Index",
  CellTags->"Genotypes"],
Cell[563925, 19737, 291, 10, 23, "Index",
  CellTags->"GlobalContinuumVariables"],
Cell[564219, 19749, 452, 16, 23, "Index",
  CellTags->"Gnew"],
Cell[564674, 19767, 261, 10, 23, "Index",
  CellTags->"Goodman et al 1999"],
Cell[564938, 19779, 274, 11, 23, "Index",
  CellTags->"Graphs"],
Cell[565215, 19792, 399, 14, 23, "Index",
  CellTags->"Griffiths-Tavare"],
Cell[565617, 19808, 833, 26, 53, "IndexSubentry",
  CellTags->"Griffiths-Tavare"],
Cell[566453, 19836, 276, 10, 23, "Index",
  CellTags->"Guiasu & Shenitzer 1985"],
Cell[566732, 19848, 277, 10, 23, "Index",
  CellTags->"HaploidConstraints"],
Cell[567012, 19860, 297, 10, 23, "Index",
  CellTags->"HaploidFrequencies"],
Cell[567312, 19872, 332, 11, 23, "Index",
  CellTags->"HaploidGenotypeFrequency"],
Cell[567647, 19885, 297, 10, 23, "Index",
  CellTags->"HaploidIndividuals"],
Cell[567947, 19897, 309, 10, 23, "Index",
  CellTags->"HaploidRepresentations"],
Cell[568259, 19909, 259, 11, 23, "Index",
  CellTags->"Haploids"],
Cell[568521, 19922, 414, 14, 23, "Index",
  CellTags->"HaploidSource"],
Cell[568938, 19938, 259, 10, 23, "Index",
  CellTags->"HaploidSubsets"],
Cell[569200, 19950, 257, 10, 23, "Index",
  CellTags->"HaploidTypes"],
Cell[569460, 19962, 314, 11, 23, "Index",
  CellTags->"Help browser"],
Cell[569777, 19975, 281, 10, 23, "Index",
  CellTags->"Help Browser"],
Cell[570061, 19987, 291, 9, 23, "IndexSubentry",
  CellTags->"Help Browser"],
Cell[570355, 19998, 432, 15, 23, "Index",
  CellTags->"Hermaphrodites"],
Cell[570790, 20015, 284, 10, 23, "Index",
  CellTags->"HeterozygoteB"],
Cell[571077, 20027, 237, 10, 23, "Index",
  CellTags->"Hill 1974a"],
Cell[571317, 20039, 237, 10, 23, "Index",
  CellTags->"Hill 1974b"],
Cell[571557, 20051, 237, 10, 23, "Index",
  CellTags->"Hill 1974c"],
Cell[571797, 20063, 413, 14, 23, "Index",
  CellTags->"Hudson 1990"],
Cell[572213, 20079, 303, 10, 23, "Index",
  CellTags->"Hypergeometric model"],
Cell[572519, 20091, 256, 11, 23, "Index",
  CellTags->"Hyperlinks"],
Cell[572778, 20104, 621, 22, 53, "IndexSubentry",
  CellTags->"Hyperlinks"],
Cell[573402, 20128, 270, 10, 23, "Index",
  CellTags->"IncidenceMatrix"],
Cell[573675, 20140, 290, 11, 23, "Index",
  CellTags->"Index"],
Cell[573968, 20153, 237, 10, 23, "Index",
  CellTags->"Individual"],
Cell[574208, 20165, 303, 10, 23, "Index",
  CellTags->"IndividualContinuumVariables"],
Cell[574514, 20177, 323, 11, 23, "Index",
  CellTags->"IndividualRepresentations"],
Cell[574840, 20190, 264, 10, 23, "Index",
  CellTags->"Individuals"],
Cell[575107, 20202, 301, 10, 23, "Index",
  CellTags->"InferParentalGenotypes"],
Cell[575411, 20214, 275, 10, 23, "Index",
  CellTags->"Infinite sites mutation"],
Cell[575689, 20226, 338, 11, 23, "Index",
  CellTags->"InformationFunction"],
Cell[576030, 20239, 501, 15, 38, "IndexSubentry",
  CellTags->"InformationFunction"],
Cell[576534, 20256, 272, 10, 23, "Index",
  CellTags->"InitialiseContinuum"],
Cell[576809, 20268, 263, 10, 23, "Index",
  CellTags->"InitialiseCovariance"],
Cell[577075, 20280, 414, 14, 23, "Index",
  CellTags->"InitialiseDemes"],
Cell[577492, 20296, 254, 10, 23, "Index",
  CellTags->"InitialStep"],
Cell[577749, 20308, 277, 10, 23, "Index",
  CellTags->"InitialStepReduced"],
Cell[578029, 20320, 270, 10, 23, "Index",
  CellTags->"InternalNodes"],
Cell[578302, 20332, 268, 10, 23, "Index",
  CellTags->"IntervalCombine"],
Cell[578573, 20344, 271, 10, 23, "Index",
  CellTags->"IntervalPosition"],
Cell[578847, 20356, 295, 10, 23, "Index",
  CellTags->"InverseFourierNormalised"],
Cell[579145, 20368, 310, 10, 23, "Index",
  CellTags->"InverseFourierNormalisedTable"],
Cell[579458, 20380, 476, 15, 23, "Index",
  CellTags->"Island model"],
Cell[579937, 20397, 795, 25, 53, "IndexSubentry",
  CellTags->"Island model"],
Cell[580735, 20424, 295, 10, 23, "Index",
  CellTags->"IterateContinuum"],
Cell[581033, 20436, 264, 11, 23, "Index",
  CellTags->"IterateExact"],
Cell[581300, 20449, 1753, 53, 128, "IndexSubentry",
  CellTags->"IterateExact"],
Cell[583056, 20504, 328, 14, 23, "Index",
  CellTags->"Join"],
Cell[583387, 20520, 295, 11, 23, "Index",
  CellTags->"Junctions"],
Cell[583685, 20533, 307, 11, 23, "Index",
  CellTags->"JunctionStyle"],
Cell[583995, 20546, 417, 15, 23, "Index",
  CellTags->"Juveniles"],
Cell[584415, 20563, 310, 10, 23, "Index",
  CellTags->"Kirkpatrick and Barton 1997"],
Cell[584728, 20575, 316, 10, 23, "Index",
  CellTags->"Kirkpatrick and Servedio 1998"],
Cell[585047, 20587, 392, 14, 23, "Index",
  CellTags->"Kirkpatrick et al."],
Cell[585442, 20603, 3891, 138, 293, "IndexSubentry",
  CellTags->"Kirkpatrick et al."],
Cell[589336, 20743, 275, 10, 23, "Index",
  CellTags->"Kirkpatrick et al. 1983"],
Cell[589614, 20755, 237, 10, 23, "Index",
  CellTags->"Kruuk 1997"],
Cell[589854, 20767, 298, 11, 23, "Index",
  CellTags->"LeafEvents"],
Cell[590155, 20780, 257, 10, 23, "Index",
  CellTags->"LeafLabels"],
Cell[590415, 20792, 257, 10, 23, "Index",
  CellTags->"LeafOffset"],
Cell[590675, 20804, 249, 10, 23, "Index",
  CellTags->"Leaves"],
Cell[590927, 20816, 275, 9, 23, "IndexSubentry",
  CellTags->"Leaves"],
Cell[591205, 20827, 229, 10, 23, "Index",
  CellTags->"Life cycle"],
Cell[591437, 20839, 3070, 111, 188, "IndexSubentry",
  CellTags->"Life cycle"],
Cell[594510, 20952, 313, 11, 23, "Index",
  CellTags->"LineagesPresent"],
Cell[594826, 20965, 246, 10, 23, "Index",
  CellTags->"Li & Nei 1974"],
Cell[595075, 20977, 480, 18, 23, "Index",
  CellTags->"Linkage"],
Cell[595558, 20997, 451, 15, 38, "IndexSubentry",
  CellTags->"Linkage"],
Cell[596012, 21014, 307, 10, 23, "Index",
  CellTags->"Linkage disequilibrium"],
Cell[596322, 21026, 270, 10, 23, "Index",
  CellTags->"LinkedRecombination"],
Cell[596595, 21038, 280, 10, 23, "Index",
  CellTags->"ListToGenealogy"],
Cell[596878, 21050, 291, 10, 23, "Index",
  CellTags->"ListToMatrix"],
Cell[597172, 21062, 255, 10, 23, "Index",
  CellTags->"Location"],
Cell[597430, 21074, 232, 10, 23, "Index",
  CellTags->"Locations"],
Cell[597665, 21086, 253, 10, 23, "Index",
  CellTags->"LocusNames"],
Cell[597921, 21098, 288, 10, 23, "Index",
  CellTags->"LogLikelihoodDisequilibrium"],
Cell[598212, 21110, 325, 10, 23, "Index",
  CellTags->"LogLikelihoodDisequilibriumReduced"],
Cell[598540, 21122, 270, 10, 23, "Index",
  CellTags->"LogLikelihoodTest"],
Cell[598813, 21134, 397, 14, 23, "Index",
  CellTags->"Log-linear models"],
Cell[599213, 21150, 252, 10, 23, "Index",
  CellTags->"Long et al 1995"],
Cell[599468, 21162, 269, 10, 23, "Index",
  CellTags->"LowerOffDiagonal"],
Cell[599740, 21174, 249, 10, 23, "Index",
  CellTags->"MacCallum 1994"],
Cell[599992, 21186, 269, 10, 23, "Index",
  CellTags->"MacCallum et al. 1998"],
Cell[600264, 21198, 320, 11, 23, "Index",
  CellTags->"MakeCline"],
Cell[600587, 21211, 691, 21, 53, "IndexSubentry",
  CellTags->"MakeCline"],
Cell[601281, 21234, 296, 11, 23, "Index",
  CellTags->"MakeDiploid"],
Cell[601580, 21247, 474, 15, 38, "IndexSubentry",
  CellTags->"MakeDiploid"],
Cell[602057, 21264, 279, 10, 23, "Index",
  CellTags->"MakeDistanceList"],
Cell[602339, 21276, 270, 10, 23, "Index",
  CellTags->"MakeDistances"],
Cell[602612, 21288, 243, 10, 23, "Index",
  CellTags->"MakeFitnessSet"],
Cell[602858, 21300, 255, 9, 23, "IndexSubentry",
  CellTags->"MakeFitnessSet"],
Cell[603116, 21311, 262, 10, 23, "Index",
  CellTags->"MakeGenealogy"],
Cell[603381, 21323, 278, 10, 23, "Index",
  CellTags->"MakeGenealogyPlot"],
Cell[603662, 21335, 296, 11, 23, "Index",
  CellTags->"MakeHaploid"],
Cell[603961, 21348, 474, 15, 38, "IndexSubentry",
  CellTags->"MakeHaploid"],
Cell[604438, 21365, 322, 11, 23, "Index",
  CellTags->"MakeIndividuals"],
Cell[604763, 21378, 666, 21, 53, "IndexSubentry",
  CellTags->"MakeIndividuals"],
Cell[605432, 21401, 270, 10, 23, "Index",
  CellTags->"MakeOneWayTable"],
Cell[605705, 21413, 268, 10, 23, "Index",
  CellTags->"MakePairwiseTable"],
Cell[605976, 21425, 327, 11, 23, "Index",
  CellTags->"MakePopulation"],
Cell[606306, 21438, 711, 22, 53, "IndexSubentry",
  CellTags->"MakePopulation"],
Cell[607020, 21462, 398, 14, 23, "Index",
  CellTags->"MakeSelectionCoefficient"],
Cell[607421, 21478, 423, 15, 38, "IndexSubentry",
  CellTags->"MakeSelectionCoefficient"],
Cell[607847, 21495, 270, 10, 23, "Index",
  CellTags->"Mangel & Hilborn 1996"],
Cell[608120, 21507, 295, 11, 23, "Index",
  CellTags->"MapLength"],
Cell[608418, 21520, 298, 11, 23, "Index",
  CellTags->"MapPosition"],
Cell[608719, 21533, 284, 9, 23, "IndexSubentry",
  CellTags->"MapPosition"],
Cell[609006, 21544, 316, 11, 23, "Index",
  CellTags->"Marginal fitness"],
Cell[609325, 21557, 642, 21, 53, "IndexSubentry",
  CellTags->"Marginal fitness"],
Cell[609970, 21580, 256, 10, 23, "Index",
  CellTags->"MarginalTable"],
Cell[610229, 21592, 302, 11, 23, "Index",
  CellTags->"MarginalW"],
Cell[610534, 21605, 636, 21, 53, "IndexSubentry",
  CellTags->"MarginalW"],
Cell[611173, 21628, 277, 11, 23, "Index",
  CellTags->"MaternalLoci"],
Cell[611453, 21641, 450, 15, 38, "IndexSubentry",
  CellTags->"MaternalLoci"],
Cell[611906, 21658, 254, 10, 23, "Index",
  CellTags->"MatrixGamma"],
Cell[612163, 21670, 280, 10, 23, "Index",
  CellTags->"MatrixToGenealogy"],
Cell[612446, 21682, 291, 10, 23, "Index",
  CellTags->"MatrixToList"],
Cell[612740, 21694, 314, 11, 23, "Index",
  CellTags->"MeanContribution"],
Cell[613057, 21707, 400, 14, 23, "Index",
  CellTags->"Mean fitness"],
Cell[613460, 21723, 461, 15, 38, "IndexSubentry",
  CellTags->"Mean fitness"],
Cell[613924, 21740, 290, 11, 23, "Index",
  CellTags->"MeanW"],
Cell[614217, 21753, 620, 21, 53, "IndexSubentry",
  CellTags->"MeanW"],
Cell[614840, 21776, 234, 10, 23, "Index",
  CellTags->"Meiosis"],
Cell[615077, 21788, 264, 9, 23, "IndexSubentry",
  CellTags->"Meiosis"],
Cell[615344, 21799, 256, 10, 23, "Index",
  CellTags->"MethodC"],
Cell[615603, 21811, 256, 10, 23, "Index",
  CellTags->"MethodP"],
Cell[615862, 21823, 271, 11, 23, "Index",
  CellTags->"Metropolis algorithm"],
Cell[616136, 21836, 295, 10, 23, "Index",
  CellTags->"MetropolisDisequilibrium"],
Cell[616434, 21848, 316, 10, 23, "Index",
  CellTags->"MetropolisDisequilibriumReduced"],
Cell[616753, 21860, 272, 10, 23, "Index",
  CellTags->"Metropolis et al. 1954"],
Cell[617028, 21872, 382, 14, 23, "Index",
  CellTags->"MFromC"],
Cell[617413, 21888, 226, 10, 23, "Index",
  CellTags->"Migrate"],
Cell[617642, 21900, 311, 11, 23, "Index",
  CellTags->"MigrateExact"],
Cell[617956, 21913, 646, 21, 53, "IndexSubentry",
  CellTags->"MigrateExact"],
Cell[618605, 21936, 298, 11, 23, "Index",
  CellTags->"Migration"],
Cell[618906, 21949, 2405, 85, 203, "IndexSubentry",
  CellTags->"Migration"],
Cell[621314, 22036, 491, 15, 23, "Index",
  CellTags->"MigrationOrder"],
Cell[621808, 22053, 524, 16, 38, "IndexSubentry",
  CellTags->"MigrationOrder"],
Cell[622335, 22071, 308, 11, 23, "Index",
  CellTags->"MigrationRate"],
Cell[622646, 22084, 311, 11, 23, "Index",
  CellTags->"MigrationSet"],
Cell[622960, 22097, 299, 10, 23, "Index",
  CellTags->"MissingCombination"],
Cell[623262, 22109, 323, 11, 23, "Index",
  CellTags->"Missing data"],
Cell[623588, 22122, 468, 15, 38, "IndexSubentry",
  CellTags->"Missing data"],
Cell[624059, 22139, 312, 11, 23, "Index",
  CellTags->"MissingData"],
Cell[624374, 22152, 300, 9, 23, "IndexSubentry",
  CellTags->"MissingData"],
Cell[624677, 22163, 352, 14, 23, "Index",
  CellTags->"Moment"],
Cell[625032, 22179, 305, 10, 23, "Index",
  CellTags->"MomentAfterMigration"],
Cell[625340, 22191, 332, 11, 23, "Index",
  CellTags->"MomentAfterRecombination"],
Cell[625675, 22204, 258, 10, 23, "Index",
  CellTags->"MomentEquilibrium"],
Cell[625936, 22216, 315, 11, 23, "Index",
  CellTags->"MomentGeneratingFunction"],
Cell[626254, 22229, 582, 21, 53, "IndexSubentry",
  CellTags->"MomentGeneratingFunction"],
Cell[626839, 22252, 267, 10, 23, "Index",
  CellTags->"MomentLimits"],
Cell[627109, 22264, 232, 10, 23, "Index",
  CellTags->"MomentNew"],
Cell[627344, 22276, 262, 10, 23, "Index",
  CellTags->"MomentReduced"],
Cell[627609, 22288, 222, 10, 23, "Index",
  CellTags->"Moments"],
Cell[627834, 22300, 1552, 53, 128, "IndexSubentry",
  CellTags->"Moments"],
Cell[629389, 22355, 289, 10, 23, "Index",
  CellTags->"MomentsFromG"],
Cell[629681, 22367, 269, 10, 23, "Index",
  CellTags->"MomentSimple"],
Cell[629953, 22379, 302, 10, 23, "Index",
  CellTags->"MonteCarloGriffithsTavare"],
Cell[630258, 22391, 302, 10, 23, "Index",
  CellTags->"MonteCarloProbability"],
Cell[630563, 22403, 258, 10, 23, "Index",
  CellTags->"Mortality"],
Cell[630824, 22415, 299, 10, 23, "Index",
  CellTags->"MostRecentCommonAncestor"],
Cell[631126, 22427, 374, 14, 23, "Index",
  CellTags->"MToC"],
Cell[631503, 22443, 410, 14, 23, "Index",
  CellTags->"MToCEquations"],
Cell[631916, 22459, 263, 10, 23, "Index",
  CellTags->"Muddle"],
Cell[632182, 22471, 295, 11, 23, "Index",
  CellTags->"Multilocus algebra"],
Cell[632480, 22484, 1010, 36, 68, "IndexSubentry",
  CellTags->"Multilocus algebra"],
Cell[633493, 22522, 408, 15, 23, "Index",
  CellTags->"Multilocus MS"],
Cell[633904, 22539, 264, 11, 23, "Index",
  CellTags->"Multilocus notation"],
Cell[634171, 22552, 344, 12, 23, "Index",
  CellTags->"Multinomial sampling"],
Cell[634518, 22566, 332, 11, 23, "Index",
  CellTags->"MultinomialSamplingProbability"],
Cell[634853, 22579, 289, 11, 23, "Index",
  CellTags->"Multiple alleles"],
Cell[635145, 22592, 694, 27, 68, "IndexSubentry",
  CellTags->"Multiple alleles"],
Cell[635842, 22621, 297, 11, 23, "Index",
  CellTags->"Multiple arguments"],
Cell[636142, 22634, 336, 11, 23, "Index",
  CellTags->"Multiplicative models"],
Cell[636481, 22647, 302, 11, 23, "Index",
  CellTags->"MUS"],
Cell[636786, 22660, 667, 21, 53, "IndexSubentry",
  CellTags->"MUS"],
Cell[637456, 22683, 287, 11, 23, "Index",
  CellTags->"Mutate"],
Cell[637746, 22696, 607, 21, 53, "IndexSubentry",
  CellTags->"Mutate"],
Cell[638356, 22719, 724, 22, 23, "Index",
  CellTags->"MutateCompiled"],
Cell[639083, 22743, 263, 11, 23, "Index",
  CellTags->"Mutation"],
Cell[639349, 22756, 1083, 33, 53, "IndexSubentry",
  CellTags->"Mutation"],
Cell[640435, 22791, 275, 10, 23, "Index",
  CellTags->"MutationInterval"],
Cell[640713, 22803, 297, 10, 23, "Index",
  CellTags->"MutationLabels"],
Cell[641013, 22815, 269, 10, 23, "Index",
  CellTags->"MutationOrigin"],
Cell[641285, 22827, 261, 10, 23, "Index",
  CellTags->"MutationRate"],
Cell[641549, 22839, 293, 11, 23, "Index",
  CellTags->"Mutations"],
Cell[641845, 22852, 772, 27, 68, "IndexSubentry",
  CellTags->"Mutations"],
Cell[642620, 22881, 398, 14, 23, "Index",
  CellTags->"MVariables"],
Cell[643021, 22897, 293, 11, 23, "Index",
  CellTags->"Negative binomial"],
Cell[643317, 22910, 828, 27, 68, "IndexSubentry",
  CellTags->"Negative binomial"],
Cell[644148, 22939, 339, 11, 23, "Index",
  CellTags->"NegativeBinomialLogLikelihood"],
Cell[644490, 22952, 302, 10, 23, "Index",
  CellTags->"NegativeBinomialMLE"],
Cell[644795, 22964, 368, 11, 23, "Index",
  CellTags->"NegativeHypergeometricDistribution"],
Cell[645166, 22977, 273, 10, 23, "Index",
  CellTags->"NeighbourArray"],
Cell[645442, 22989, 261, 10, 23, "Index",
  CellTags->"Neighbours"],
Cell[645706, 23001, 280, 10, 23, "Index",
  CellTags->"NetCovariance"],
Cell[645989, 23013, 255, 10, 23, "Index",
  CellTags->"NetFecundity"],
Cell[646247, 23025, 255, 10, 23, "Index",
  CellTags->"NetMortality"],
Cell[646505, 23037, 384, 14, 23, "Index",
  CellTags->"NetRecombination"],
Cell[646892, 23053, 438, 15, 38, "IndexSubentry",
  CellTags->"NetRecombination"],
Cell[647333, 23070, 285, 11, 23, "Index",
  CellTags->"Neutral marker"],
Cell[647621, 23083, 309, 10, 23, "Index",
  CellTags->"NeutralRepresentations"],
Cell[647933, 23095, 309, 11, 23, "Index",
  CellTags->"NewGametes"],
Cell[648245, 23108, 1653, 52, 98, "IndexSubentry",
  CellTags->"NewGametes"],
Cell[649901, 23162, 249, 10, 23, "Index",
  CellTags->"NewS"],
Cell[650153, 23174, 380, 14, 23, "Index",
  CellTags->"Node"],
Cell[650536, 23190, 404, 14, 23, "Index",
  CellTags->"NodeFunction"],
Cell[650943, 23206, 275, 9, 23, "IndexSubentry",
  CellTags->"NodeFunction"],
Cell[651221, 23217, 257, 10, 23, "Index",
  CellTags->"NodeLabels"],
Cell[651481, 23229, 257, 10, 23, "Index",
  CellTags->"NodeOffset"],
Cell[651741, 23241, 246, 10, 23, "Index",
  CellTags->"Nodes"],
Cell[651990, 23253, 263, 10, 23, "Index",
  CellTags->"NonMendelian"],
Cell[652256, 23265, 366, 13, 23, "IndexSubentry",
  CellTags->"NonMendelian"],
Cell[652625, 23280, 323, 11, 23, "Index",
  CellTags->"NonNeutralRepresentations"],
Cell[652951, 23293, 331, 11, 23, "Index",
  CellTags->"NonSymmetricRepresentations"],
Cell[653285, 23306, 284, 10, 23, "Index",
  CellTags->"Normalisation"],
Cell[653572, 23318, 275, 10, 23, "Index",
  CellTags->"Normalised"],
Cell[653850, 23330, 287, 11, 23, "Index",
  CellTags->"Notation"],
Cell[654140, 23343, 727, 27, 68, "IndexSubentry",
  CellTags->"Notation"],
Cell[654870, 23372, 253, 10, 23, "Index",
  CellTags->"Notation Package"],
Cell[655126, 23384, 310, 11, 23, "Index",
  CellTags->"NullAllele"],
Cell[655439, 23397, 299, 9, 23, "IndexSubentry",
  CellTags->"NullAllele"],
Cell[655741, 23408, 312, 11, 23, "Index",
  CellTags->"Null alleles"],
Cell[656056, 23421, 304, 9, 23, "IndexSubentry",
  CellTags->"Null alleles"],
Cell[656363, 23432, 304, 11, 23, "Index",
  CellTags->"Null lineages"],
Cell[656670, 23445, 304, 11, 23, "Index",
  CellTags->"NullLineages"],
Cell[656977, 23458, 337, 11, 23, "Index",
  CellTags->"NullRecombinationEvents"],
Cell[657317, 23471, 261, 10, 23, "Index",
  CellTags->"NumberedLink"],
Cell[657581, 23483, 271, 11, 23, "Index",
  CellTags->"Numbering"],
Cell[657855, 23496, 560, 21, 53, "IndexSubentry",
  CellTags->"Numbering"],
Cell[658418, 23519, 318, 11, 23, "Index",
  CellTags->"NumberOfCoalescences"],
Cell[658739, 23532, 266, 10, 23, "Index",
  CellTags->"NumberOfGenes"],
Cell[659008, 23544, 917, 28, 68, "IndexSubentry",
  CellTags->"NumberOfGenes"],
Cell[659928, 23574, 281, 10, 23, "Index",
  CellTags->"NumberOfGenesTable"],
Cell[660212, 23586, 416, 14, 23, "Index",
  CellTags->"NumberOfIndividuals"],
Cell[660631, 23602, 299, 10, 23, "Index",
  CellTags->"NumberOfIndividualsTable"],
Cell[660933, 23614, 279, 10, 23, "Index",
  CellTags->"NumberOfLineages"],
Cell[661215, 23626, 263, 10, 23, "Index",
  CellTags->"NumberOfLoci"],
Cell[661481, 23638, 278, 10, 23, "Index",
  CellTags->"NumberOfMutations"],
Cell[661762, 23650, 317, 10, 23, "Index",
  CellTags->"NumberOfPossibleCoalescences"],
Cell[662082, 23662, 287, 10, 23, "Index",
  CellTags->"NumberOfSamplePartitions"],
Cell[662372, 23674, 278, 10, 23, "Index",
  CellTags->"NumberOfSetPartitions"],
Cell[662653, 23686, 327, 11, 23, "Index",
  CellTags->"NumericalModel"],
Cell[662983, 23699, 294, 9, 23, "IndexSubentry",
  CellTags->"NumericalModel"],
Cell[663280, 23710, 301, 11, 23, "Index",
  CellTags->"Numerical models"],
Cell[663584, 23723, 1267, 43, 98, "IndexSubentry",
  CellTags->"Numerical models"],
Cell[664854, 23768, 420, 14, 23, "Index",
  CellTags->"Observable genotype"],
Cell[665277, 23784, 250, 11, 23, "Index",
  CellTags->"Obsolete"],
Cell[665530, 23797, 3402, 121, 293, "IndexSubentry",
  CellTags->"Obsolete"],
Cell[668935, 23920, 258, 10, 23, "Index",
  CellTags->"Offspring"],
Cell[669196, 23932, 266, 11, 23, "Index",
  CellTags->"Ordered"],
Cell[669465, 23945, 264, 10, 23, "Index",
  CellTags->"Orive & Barton 1999"],
Cell[669732, 23957, 247, 10, 23, "Index",
  CellTags->"OtherSex"],
Cell[669982, 23969, 275, 11, 23, "Index",
  CellTags->"Packages"],
Cell[670260, 23982, 839, 31, 68, "IndexSubentry",
  CellTags->"Packages"],
Cell[671102, 24015, 235, 10, 23, "Index",
  CellTags->"PackageSaver"],
Cell[671340, 24027, 272, 10, 23, "Index",
  CellTags->"ParentalGenotypes"],
Cell[671615, 24039, 262, 11, 23, "Index",
  CellTags->"Partitions"],
Cell[671880, 24052, 426, 15, 38, "IndexSubentry",
  CellTags->"Partitions"],
Cell[672309, 24069, 251, 10, 23, "Index",
  CellTags->"PartitionSet"],
Cell[672563, 24081, 414, 14, 23, "Index",
  CellTags->"Paternal inheritance"],
Cell[672980, 24097, 277, 11, 23, "Index",
  CellTags->"PaternalLoci"],
Cell[673260, 24110, 444, 15, 38, "IndexSubentry",
  CellTags->"PaternalLoci"],
Cell[673707, 24127, 274, 10, 23, "Index",
  CellTags->"PatternFree"],
Cell[673984, 24139, 281, 11, 23, "Index",
  CellTags->"Permutations"],
Cell[674268, 24152, 325, 11, 23, "Index",
  CellTags->"Permutations in defining coefficients"],
Cell[674596, 24165, 269, 11, 23, "Index",
  CellTags->"Phenotypes"],
Cell[674868, 24178, 264, 10, 23, "Index",
  CellTags->"Phipps & Brill 1995"],
Cell[675135, 24190, 245, 10, 23, "Index",
  CellTags->"Ploidy"],
Cell[675383, 24202, 271, 10, 23, "Index",
  CellTags->"PloidyWeightList"],
Cell[675657, 24214, 266, 10, 23, "Index",
  CellTags->"PlotGenealogy"],
Cell[675926, 24226, 247, 10, 23, "Index",
  CellTags->"PlotLogL"],
Cell[676176, 24238, 300, 11, 23, "Index",
  CellTags->"PlotSegments"],
Cell[676479, 24251, 279, 11, 23, "Index",
  CellTags->"Plotting"],
Cell[676761, 24264, 346, 11, 23, "Index",
  CellTags->"PopulationDisequilibrium"],
Cell[677110, 24277, 274, 10, 23, "Index",
  CellTags->"PopulationExpectation"],
Cell[677387, 24289, 271, 9, 23, "IndexSubentry",
  CellTags->"PopulationExpectation"],
Cell[677661, 24300, 323, 11, 23, "Index",
  CellTags->"PopulationRepresentations"],
Cell[677987, 24313, 380, 14, 23, "Index",
  CellTags->"Position"],
Cell[678370, 24329, 442, 15, 38, "IndexSubentry",
  CellTags->"Position"],
Cell[678815, 24346, 270, 10, 23, "Index",
  CellTags->"PositionsList"],
Cell[679088, 24358, 276, 10, 23, "Index",
  CellTags->"PositionsMatrix"],
Cell[679367, 24370, 305, 10, 23, "Index",
  CellTags->"PossibleCoalescenceOrder"],
Cell[679675, 24382, 303, 10, 23, "Index",
  CellTags->"PossibleDiploidGenotypes"],
Cell[679981, 24394, 272, 10, 23, "Index",
  CellTags->"PossibleGenotypes"],
Cell[680256, 24406, 273, 10, 23, "Index",
  CellTags->"PossibleRootings"],
Cell[680532, 24418, 311, 11, 23, "Index",
  CellTags->"PowerF"],
Cell[680846, 24431, 871, 27, 68, "IndexSubentry",
  CellTags->"PowerF"],
Cell[681720, 24460, 279, 10, 23, "Index",
  CellTags->"PresentOneWayTable"],
Cell[682002, 24472, 277, 10, 23, "Index",
  CellTags->"PresentPairwiseTable"],
Cell[682282, 24484, 265, 10, 23, "Index",
  CellTags->"PresentResults"],
Cell[682550, 24496, 317, 11, 23, "Index",
  CellTags->"Principal components"],
Cell[682870, 24509, 273, 10, 23, "Index",
  CellTags->"PrintDetails"],
Cell[683146, 24521, 321, 10, 23, "IndexSubentry",
  CellTags->"PrintDetails"],
Cell[683470, 24533, 275, 11, 23, "Index",
  CellTags->"Problems"],
Cell[683748, 24546, 587, 18, 23, "IndexSubentry",
  CellTags->"Problems"],
Cell[684338, 24566, 250, 11, 23, "Index",
  CellTags->"Products"],
Cell[684591, 24579, 237, 10, 23, "Index",
  CellTags->"ProductSum"],
Cell[684831, 24591, 249, 9, 23, "IndexSubentry",
  CellTags->"ProductSum"],
Cell[685083, 24602, 263, 11, 23, "Index",
  CellTags->"QLE"],
Cell[685349, 24615, 258, 9, 23, "IndexSubentry",
  CellTags->"QLE"],
Cell[685610, 24626, 310, 11, 23, "Index",
  CellTags->"Quasi-linkage equilibrium"],
Cell[685923, 24639, 312, 10, 23, "Index",
  CellTags->"RandomBottleneckedGenealogy"],
Cell[686238, 24651, 299, 10, 23, "Index",
  CellTags->"RandomCoalescenceOrder"],
Cell[686540, 24663, 326, 11, 23, "Index",
  CellTags->"RandomCoalescenceTimes"],
Cell[686869, 24676, 300, 9, 23, "IndexSubentry",
  CellTags->"RandomCoalescenceTimes"],
Cell[687172, 24687, 288, 10, 23, "Index",
  CellTags->"RandomCum"],
Cell[687463, 24699, 330, 12, 23, "Index",
  CellTags->"Random drift"],
Cell[687796, 24713, 2349, 77, 158, "IndexSubentry",
  CellTags->"Random drift"],
Cell[690148, 24792, 286, 11, 23, "Index",
  CellTags->"RandomDrift"],
Cell[690437, 24805, 956, 27, 38, "IndexSubentry",
  CellTags->"RandomDrift"],
Cell[691396, 24834, 259, 10, 23, "Index",
  CellTags->"RandomFamilies"],
Cell[691658, 24846, 261, 10, 23, "Index",
  CellTags->"RandomFamily"],
Cell[691922, 24858, 273, 9, 23, "IndexSubentry",
  CellTags->"RandomFamily"],
Cell[692198, 24869, 299, 11, 23, "Index",
  CellTags->"Random genealogies"],
Cell[692500, 24882, 270, 10, 23, "Index",
  CellTags->"RandomGenealogy"],
Cell[692773, 24894, 286, 9, 23, "IndexSubentry",
  CellTags->"RandomGenealogy"],
Cell[693062, 24905, 241, 10, 23, "Index",
  CellTags->"RandomList"],
Cell[693306, 24917, 259, 9, 23, "IndexSubentry",
  CellTags->"RandomList"],
Cell[693568, 24928, 259, 11, 23, "Index",
  CellTags->"Random lists"],
Cell[693830, 24941, 289, 10, 23, "Index",
  CellTags->"RandomMating"],
Cell[694122, 24953, 286, 10, 23, "Index",
  CellTags->"RandomMultinomial"],
Cell[694411, 24965, 277, 10, 23, "Index",
  CellTags->"RandomPreviousFamily"],
Cell[694691, 24977, 288, 10, 23, "Index",
  CellTags->"Random sampling"],
Cell[694982, 24989, 415, 15, 38, "IndexSubentry",
  CellTags->"Random sampling"],
Cell[695400, 25006, 236, 10, 23, "Index",
  CellTags->"RandomSet"],
Cell[695639, 25018, 371, 14, 23, "Index",
  CellTags->"Random union"],
Cell[696013, 25034, 306, 9, 23, "IndexSubentry",
  CellTags->"Random union"],
Cell[696322, 25045, 244, 10, 23, "Index",
  CellTags->"RandomUnion"],
Cell[696569, 25057, 276, 10, 23, "Index",
  CellTags->"RandomUnionMethod"],
Cell[696848, 25069, 260, 10, 23, "Index",
  CellTags->"RandomUnionObsolete"],
Cell[697111, 25081, 256, 11, 23, "Index",
  CellTags->"Random walk"],
Cell[697370, 25094, 325, 11, 23, "Index",
  CellTags->"RecombinantLineages"],
Cell[697698, 25107, 378, 14, 23, "Index",
  CellTags->"Recombination"],
Cell[698079, 25123, 1122, 39, 98, "IndexSubentry",
  CellTags->"Recombination"],
Cell[699204, 25164, 325, 11, 23, "Index",
  CellTags->"RecombinationEvents"],
Cell[699532, 25177, 321, 11, 23, "Index",
  CellTags->"RecombinationRate"],
Cell[699856, 25190, 450, 15, 23, "Index",
  CellTags->"RecombinationSet"],
Cell[700309, 25207, 283, 10, 23, "Index",
  CellTags->"Recombined"],
Cell[700595, 25219, 293, 10, 23, "Index",
  CellTags->"RecombineLineage"],
Cell[700891, 25231, 262, 10, 23, "Index",
  CellTags->"ReducedData"],
Cell[701156, 25243, 316, 11, 23, "Index",
  CellTags->"ReferencePoint"],
Cell[701475, 25256, 273, 10, 23, "Index",
  CellTags->"ReferencePointMean"],
Cell[701751, 25268, 1125, 37, 53, "IndexSubentry",
  CellTags->"ReferencePointMean"],
Cell[702879, 25307, 273, 10, 23, "Index",
  CellTags->"ReferencePointSame"],
Cell[703155, 25319, 273, 10, 23, "Index",
  CellTags->"ReferencePointZero"],
Cell[703431, 25331, 289, 11, 23, "Index",
  CellTags->"References"],
Cell[703723, 25344, 400, 14, 23, "Index",
  CellTags->"Reference values"],
Cell[704126, 25360, 472, 15, 38, "IndexSubentry",
  CellTags->"Reference values"],
Cell[704601, 25377, 238, 10, 23, "Index",
  CellTags->"RemoveTag"],
Cell[704842, 25389, 239, 10, 23, "Index",
  CellTags->"Repeat"],
Cell[705084, 25401, 232, 10, 23, "Index",
  CellTags->"Replace"],
Cell[705319, 25413, 262, 11, 23, "Index",
  CellTags->"ReplaceAllSpecial"],
Cell[705584, 25426, 278, 11, 23, "Index",
  CellTags->"ReplaceRepeatedSpecial"],
Cell[705865, 25439, 311, 11, 23, "Index",
  CellTags->"Representations"],
Cell[706179, 25452, 308, 10, 23, "IndexSubentry",
  CellTags->"Representations"],
Cell[706490, 25464, 286, 11, 23, "Index",
  CellTags->"Reproduction"],
Cell[706779, 25477, 222, 10, 23, "Index",
  CellTags->"Reverse"],
Cell[707004, 25489, 401, 15, 23, "Index",
  CellTags->"Root"],
Cell[707408, 25506, 280, 10, 23, "Index",
  CellTags->"RootedGenealogy"],
Cell[707691, 25518, 298, 11, 23, "Index",
  CellTags->"RootEvents"],
Cell[707992, 25531, 289, 11, 23, "Index",
  CellTags->"Rootings"],
Cell[708284, 25544, 244, 10, 23, "Index",
  CellTags->"Rules"],
Cell[708531, 25556, 234, 9, 23, "IndexSubentry",
  CellTags->"Rules"],
Cell[708768, 25567, 251, 10, 23, "Index",
  CellTags->"SampleCovariance"],
Cell[709022, 25579, 278, 10, 23, "Index",
  CellTags->"SampleIndividuals"],
Cell[709303, 25591, 260, 10, 23, "Index",
  CellTags->"SamplePartition"],
Cell[709566, 25603, 261, 11, 23, "Index",
  CellTags->"Sampling"],
Cell[709830, 25616, 319, 11, 23, "Index",
  CellTags->"Scripts and faces"],
Cell[710152, 25629, 292, 11, 23, "Index",
  CellTags->"Segments"],
Cell[710447, 25642, 304, 11, 23, "Index",
  CellTags->"SegmentStyle"],
Cell[710754, 25655, 414, 14, 23, "Index",
  CellTags->"SegregationRatio"],
Cell[711171, 25671, 321, 11, 23, "Index",
  CellTags->"SelectContext"],
Cell[711495, 25684, 272, 10, 23, "Index",
  CellTags->"SelectIndividuals"],
Cell[711770, 25696, 232, 10, 23, "Index",
  CellTags->"Selection"],
Cell[712005, 25708, 1704, 61, 143, "IndexSubentry",
  CellTags->"Selection"],
Cell[713712, 25771, 437, 15, 23, "Index",
  CellTags->"SelectionCoefficient"],
Cell[714152, 25788, 327, 11, 23, "Index",
  CellTags->"Selection coefficients"],
Cell[714482, 25801, 519, 19, 38, "IndexSubentry",
  CellTags->"Selection coefficients"],
Cell[715004, 25822, 317, 11, 23, "Index",
  CellTags->"SelectionExact"],
Cell[715324, 25835, 658, 21, 53, "IndexSubentry",
  CellTags->"SelectionExact"],
Cell[715985, 25858, 290, 11, 23, "Index",
  CellTags->"Selection on diploids"],
Cell[716278, 25871, 888, 33, 83, "IndexSubentry",
  CellTags->"Selection on diploids"],
Cell[717169, 25906, 304, 11, 23, "Index",
  CellTags->"SelectionRate"],
Cell[717476, 25919, 251, 10, 23, "Index",
  CellTags->"SelectLoci"],
Cell[717730, 25931, 217, 10, 23, "Index",
  CellTags->"Selfing"],
Cell[717950, 25943, 235, 10, 23, "Index",
  CellTags->"Separate"],
Cell[718188, 25955, 258, 11, 23, "Index",
  CellTags->"Servedio"],
Cell[718449, 25968, 339, 12, 23, "Index",
  CellTags->"Set"],
Cell[718791, 25982, 323, 10, 23, "IndexSubentry",
  CellTags->"Set"],
Cell[719117, 25994, 293, 11, 23, "Index",
  CellTags->"Set manipulation"],
Cell[719413, 26007, 270, 10, 23, "Index",
  CellTags->"SetOfCombinations"],
Cell[719686, 26019, 251, 10, 23, "Index",
  CellTags->"SetPartition"],
Cell[719940, 26031, 304, 11, 23, "Index",
  CellTags->"Sets of loci"],
Cell[720247, 26044, 216, 10, 23, "Index",
  CellTags->"Sex"],
Cell[720466, 26056, 394, 14, 23, "Index",
  CellTags->"Sex linkage"],
Cell[720863, 26072, 236, 9, 23, "IndexSubentry",
  CellTags->"Sex linkage"],
Cell[721102, 26083, 240, 10, 23, "Index",
  CellTags->"SexOfOrigin"],
Cell[721345, 26095, 267, 10, 23, "Index",
  CellTags->"Sexual selection"],
Cell[721615, 26107, 1209, 45, 113, "IndexSubentry",
  CellTags->"Sexual selection"],
Cell[722827, 26154, 265, 10, 23, "Index",
  CellTags->"ShortContext"],
Cell[723095, 26166, 278, 10, 23, "Index",
  CellTags->"SigmaMatrix"],
Cell[723376, 26178, 247, 10, 23, "Index",
  CellTags->"SignMask"],
Cell[723626, 26190, 236, 10, 23, "Index",
  CellTags->"SimplifyAddUp"],
Cell[723865, 26202, 239, 10, 23, "Index",
  CellTags->"SimplifyAddUpQ"],
Cell[724107, 26214, 261, 10, 23, "Index",
  CellTags->"SimplifyFamilies"],
Cell[724371, 26226, 335, 11, 23, "Index",
  CellTags->"Simulating individuals"],
Cell[724709, 26239, 503, 15, 38, "IndexSubentry",
  CellTags->"Simulating individuals"],
Cell[725215, 26256, 284, 10, 23, "Index",
  CellTags->"SizeOfGenealogyPlot"],
Cell[725502, 26268, 279, 10, 23, "Index",
  CellTags->"Slatkin & Excoffier 1996"],
Cell[725784, 26280, 239, 10, 23, "Index",
  CellTags->"SlowChange"],
Cell[726026, 26292, 274, 10, 23, "Index",
  CellTags->"SortByClass"],
Cell[726303, 26304, 284, 9, 23, "IndexSubentry",
  CellTags->"SortByClass"],
Cell[726590, 26315, 231, 10, 23, "Index",
  CellTags->"SortByHead"],
Cell[726824, 26327, 254, 10, 23, "Index",
  CellTags->"SpatialCovariance"],
Cell[727081, 26339, 323, 11, 23, "Index",
  CellTags->"Spatially varying selection"],
Cell[727407, 26352, 268, 10, 23, "Index",
  CellTags->"Special notation"],
Cell[727678, 26364, 239, 10, 23, "Index",
  CellTags->"SplitSet"],
Cell[727920, 26376, 301, 11, 23, "Index",
  CellTags->"Stabilising selection"],
Cell[728224, 26389, 1135, 40, 98, "IndexSubentry",
  CellTags->"Stabilising selection"],
Cell[729362, 26431, 411, 15, 23, "Index",
  CellTags->"Stability"],
Cell[729776, 26448, 275, 9, 23, "IndexSubentry",
  CellTags->"Stability"],
Cell[730054, 26459, 320, 11, 23, "Index",
  CellTags->"StabilityDirect"],
Cell[730377, 26472, 280, 9, 23, "IndexSubentry",
  CellTags->"StabilityDirect"],
Cell[730660, 26483, 422, 14, 23, "Index",
  CellTags->"StabilityK"],
Cell[731085, 26499, 313, 11, 23, "Index",
  CellTags->"StabilityKTable"],
Cell[731401, 26512, 282, 10, 23, "Index",
  CellTags->"StabilityMatrix"],
Cell[731686, 26524, 293, 11, 23, "Index",
  CellTags->"Stage"],
Cell[731982, 26537, 225, 10, 23, "Index",
  CellTags->"Stages"],
Cell[732210, 26549, 288, 9, 23, "IndexSubentry",
  CellTags->"Stages"],
Cell[732501, 26560, 266, 10, 23, "Index",
  CellTags->"StandardPartition"],
Cell[732770, 26572, 269, 10, 23, "Index",
  CellTags->"StandardPartitionQ"],
Cell[733042, 26584, 285, 10, 23, "Index",
  CellTags->"StartingStepSize"],
Cell[733330, 26596, 357, 12, 23, "Index",
  CellTags->"Stepping-stone migration"],
Cell[733690, 26610, 347, 12, 23, "Index",
  CellTags->"Stepping-stone model"],
Cell[734040, 26624, 501, 16, 38, "IndexSubentry",
  CellTags->"Stepping-stone model"],
Cell[734544, 26642, 323, 11, 23, "Index",
  CellTags->"StoreExact"],
Cell[734870, 26655, 1518, 45, 113, "IndexSubentry",
  CellTags->"StoreExact"],
Cell[736391, 26702, 450, 15, 23, "Index",
  CellTags->"StoreResults"],
Cell[736844, 26719, 813, 24, 38, "IndexSubentry",
  CellTags->"StoreResults"],
Cell[737660, 26745, 264, 10, 23, "Index",
  CellTags->"StructuredArray"],
Cell[737927, 26757, 304, 10, 23, "Index",
  CellTags->"StructuredInitialParameters"],
Cell[738234, 26769, 327, 11, 23, "Index",
  CellTags->"StructuredLogLikelihood"],
Cell[738564, 26782, 434, 14, 23, "Index",
  CellTags->"StructuredMLE"],
Cell[739001, 26798, 264, 10, 23, "Index",
  CellTags->"StructuredModel"],
Cell[739268, 26810, 288, 10, 23, "Index",
  CellTags->"StructuredModelReduce"],
Cell[739559, 26822, 262, 11, 23, "Index",
  CellTags->"Structured models"],
Cell[739824, 26835, 272, 9, 23, "IndexSubentry",
  CellTags->"Structured models"],
Cell[740099, 26846, 286, 10, 23, "Index",
  CellTags->"StructuredParameter"],
Cell[740388, 26858, 332, 11, 23, "Index",
  CellTags->"StructuredVariance"],
Cell[740723, 26871, 248, 11, 23, "Index",
  CellTags->"Style sheets"],
Cell[740974, 26884, 272, 10, 23, "Index",
  CellTags->"Subdivide"],
Cell[741249, 26896, 309, 11, 23, "Index",
  CellTags->"Subscripts"],
Cell[741561, 26909, 222, 10, 23, "Index",
  CellTags->"Subsets"],
Cell[741786, 26921, 366, 15, 38, "IndexSubentry",
  CellTags->"Subsets"],
Cell[742155, 26938, 234, 11, 23, "Index",
  CellTags->"Sums"],
Cell[742392, 26951, 255, 10, 23, "Index",
  CellTags->"SwapStates"],
Cell[742650, 26963, 344, 11, 23, "Index",
  CellTags->"Symmetric cline"],
Cell[742997, 26976, 317, 9, 23, "IndexSubentry",
  CellTags->"Symmetric cline"],
Cell[743317, 26987, 331, 11, 23, "Index",
  CellTags->"SymmetricDiploidFrequencies"],
Cell[743651, 27000, 331, 11, 23, "Index",
  CellTags->"SymmetricHaploidFrequencies"],
Cell[743985, 27013, 431, 15, 23, "Index",
  CellTags->"Symmetric model"],
Cell[744419, 27030, 1473, 49, 113, "IndexSubentry",
  CellTags->"Symmetric model"],
Cell[745895, 27081, 477, 15, 23, "Index",
  CellTags->"SymmetricNeutralDiploidFrequencies"],
Cell[746375, 27098, 477, 15, 23, "Index",
  CellTags->"SymmetricNeutralHaploidFrequencies"],
Cell[746855, 27115, 279, 10, 23, "Index",
  CellTags->"SymmetricRecombination"],
Cell[747137, 27127, 315, 10, 23, "Index",
  CellTags->"SymmetricRepresentations"],
Cell[747455, 27139, 259, 10, 23, "Index",
  CellTags->"SymmetricSexes"],
Cell[747717, 27151, 356, 14, 23, "Index",
  CellTags->"Symmetrise"],
Cell[748076, 27167, 234, 11, 23, "Index",
  CellTags->"T"],
Cell[748313, 27180, 277, 11, 23, "Index",
  CellTags->"Table"],
Cell[748593, 27193, 220, 10, 23, "Index",
  CellTags->"Tag"],
Cell[748816, 27205, 260, 11, 23, "Index",
  CellTags->"Tags"],
Cell[749079, 27218, 295, 10, 23, "IndexSubentry",
  CellTags->"Tags"],
Cell[749377, 27230, 390, 12, 23, "Index",
  CellTags->"TakeAway"],
Cell[749770, 27244, 260, 10, 23, "Index",
  CellTags->"TakeOptions"],
Cell[750033, 27256, 237, 11, 23, "Index",
  CellTags->"Time"],
Cell[750273, 27269, 307, 11, 23, "Index",
  CellTags->"TimesOfEvents"],
Cell[750583, 27282, 322, 11, 23, "Index",
  CellTags->"TimespanOfJunction"],
Cell[750908, 27295, 319, 11, 23, "Index",
  CellTags->"TimespanOfLineage"],
Cell[751230, 27308, 346, 14, 23, "Index",
  CellTags->"TimesUp"],
Cell[751579, 27324, 375, 15, 38, "IndexSubentry",
  CellTags->"TimesUp"],
Cell[751957, 27341, 248, 10, 23, "Index",
  CellTags->"ToBaake"],
Cell[752208, 27353, 254, 10, 23, "Index",
  CellTags->"ToBennett"],
Cell[752465, 27365, 284, 10, 23, "Index",
  CellTags->"ToBennettExpression"],
Cell[752752, 27377, 260, 10, 23, "Index",
  CellTags->"ToCumulants"],
Cell[753015, 27389, 254, 10, 23, "Index",
  CellTags->"ToMoments"],
Cell[753272, 27401, 296, 10, 23, "Index",
  CellTags->"ToPopulationCumulants"],
Cell[753571, 27413, 290, 10, 23, "Index",
  CellTags->"ToPopulationMoments"],
Cell[753864, 27425, 286, 10, 23, "Index",
  CellTags->"TotalLength"],
Cell[754153, 27437, 252, 10, 23, "Index",
  CellTags->"TotalNumber"],
Cell[754408, 27449, 339, 12, 23, "Index",
  CellTags->"Trait"],
Cell[754750, 27463, 271, 10, 23, "Index",
  CellTags->"TransformedRange"],
Cell[755024, 27475, 291, 10, 23, "Index",
  CellTags->"TransformInformation"],
Cell[755318, 27487, 269, 10, 23, "Index",
  CellTags->"TransmissionRule"],
Cell[755590, 27499, 300, 11, 23, "Index",
  CellTags->"Transmission rules"],
Cell[755893, 27512, 647, 21, 53, "IndexSubentry",
  CellTags->"Transmission rules"],
Cell[756543, 27535, 272, 10, 23, "Index",
  CellTags->"TriDiagonalMatrix"],
Cell[756818, 27547, 352, 12, 23, "Index",
  CellTags->"TruncationSelection"],
Cell[757173, 27561, 318, 9, 23, "IndexSubentry",
  CellTags->"TruncationSelection"],
Cell[757494, 27572, 298, 10, 23, "Index",
  CellTags->"Turelli and Barton 1994"],
Cell[757795, 27584, 270, 10, 23, "Index",
  CellTags->"Turelli & Barton 1994"],
Cell[758068, 27596, 240, 10, 23, "Index",
  CellTags->"Two alleles"],
Cell[758311, 27608, 360, 13, 23, "IndexSubentry",
  CellTags->"Two alleles"],
Cell[758674, 27623, 302, 11, 23, "Index",
  CellTags->"UMS"],
Cell[758979, 27636, 667, 21, 53, "IndexSubentry",
  CellTags->"UMS"],
Cell[759649, 27659, 261, 10, 23, "Index",
  CellTags->"UnionOfGametes"],
Cell[759913, 27671, 276, 10, 23, "Index",
  CellTags->"UnlinkedRecombination"],
Cell[760192, 27683, 286, 10, 23, "Index",
  CellTags->"UnrootedGenealogy"],
Cell[760481, 27695, 269, 10, 23, "Index",
  CellTags->"UpperOffDiagonal"],
Cell[760753, 27707, 302, 11, 23, "Index",
  CellTags->"USM"],
Cell[761058, 27720, 667, 21, 53, "IndexSubentry",
  CellTags->"USM"],
Cell[761728, 27743, 281, 10, 23, "Index",
  CellTags->"ValidMatrixQ"],
Cell[762012, 27755, 332, 11, 23, "Index",
  CellTags->"VarianceComponents"],
Cell[762347, 27768, 263, 9, 23, "IndexSubentry",
  CellTags->"VarianceComponents"],
Cell[762613, 27779, 253, 11, 23, "Index",
  CellTags->"Versions"],
Cell[762869, 27792, 428, 14, 23, "Index",
  CellTags->"Wiuf & Hein 1999"],
Cell[763300, 27808, 260, 11, 23, "Index",
  CellTags->"WLinkedLoci"],
Cell[763563, 27821, 441, 15, 38, "IndexSubentry",
  CellTags->"WLinkedLoci"],
Cell[764007, 27838, 277, 10, 23, "Index",
  CellTags->"Wright-Fisher sampling"],
Cell[764287, 27850, 247, 11, 23, "Index",
  CellTags->"X"],
Cell[764537, 27863, 260, 11, 23, "Index",
  CellTags->"XLinkedLoci"],
Cell[764800, 27876, 441, 15, 38, "IndexSubentry",
  CellTags->"XLinkedLoci"],
Cell[765244, 27893, 260, 11, 23, "Index",
  CellTags->"YLinkedLoci"],
Cell[765507, 27906, 441, 15, 38, "IndexSubentry",
  CellTags->"YLinkedLoci"],
Cell[765951, 27923, 260, 11, 23, "Index",
  CellTags->"ZLinkedLoci"],
Cell[766214, 27936, 441, 15, 38, "IndexSubentry",
  CellTags->"ZLinkedLoci"],
Cell[766658, 27953, 411, 15, 23, "Index",
  CellTags->"Zygotes"],
Cell[767072, 27970, 427, 15, 23, "Index",
  CellTags->"\[GothicA]"],
Cell[767502, 27987, 419, 15, 23, "Index",
  CellTags->"\[GothicCapitalA]"],
Cell[767924, 28004, 340, 11, 23, "Index",
  CellTags->"\[GothicCapitalC]"],
Cell[768267, 28017, 612, 19, 23, "Index",
  CellTags->"\[GothicCapitalD]"],
Cell[768882, 28038, 494, 16, 23, "Index",
  CellTags->"\!\(\(\[GothicCapitalG]\^\[RawStar]\)\)"],
Cell[769379, 28056, 421, 15, 23, "Index",
  CellTags->"\[GothicCapitalG]"],
Cell[769803, 28073, 435, 15, 23, "Index",
  CellTags->"\[GothicCapitalH]"],
Cell[770241, 28090, 425, 15, 23, "Index",
  CellTags->"\[GothicCapitalJ]"],
Cell[770669, 28107, 320, 11, 23, "Index",
  CellTags->"\[GothicK]"],
Cell[770992, 28120, 377, 11, 23, "Index",
  CellTags->"\[GothicCapitalK]"],
Cell[771372, 28133, 308, 11, 23, "Index",
  CellTags->"\[GothicM]"],
Cell[771683, 28146, 308, 11, 23, "Index",
  CellTags->"\[GothicP]"],
Cell[771994, 28159, 369, 12, 23, "Index",
  CellTags->"\[GothicP]\[GothicQ]"],
Cell[772366, 28173, 308, 11, 23, "Index",
  CellTags->"\[GothicQ]"],
Cell[772677, 28186, 314, 11, 23, "Index",
  CellTags->"\[GothicR]"],
Cell[772994, 28199, 301, 11, 23, "Index",
  CellTags->"\[GothicS]"],
Cell[773298, 28212, 421, 15, 23, "Index",
  CellTags->"\[GothicCapitalZ]"],
Cell[773722, 28229, 348, 11, 23, "Index",
  CellTags->"\[DoubleStruckCapitalG]"],
Cell[774073, 28242, 322, 11, 23, "Index",
  CellTags->"\[DoubleStruckCapitalM]"],
Cell[774398, 28255, 457, 15, 23, "Index",
  CellTags->"\[DoubleStruckCapitalR]"],
Cell[774858, 28272, 318, 11, 23, "Index",
  CellTags->"\[DoubleStruckCapitalW]"],
Cell[775179, 28285, 358, 12, 23, "Index",
  CellTags->"\[DoubleStruckCapitalZ]"],
Cell[775540, 28299, 310, 11, 23, "Index",
  CellTags->"\[Gamma]"],
Cell[775853, 28312, 304, 11, 23, "Index",
  CellTags->"\[Zeta]"],
Cell[776160, 28325, 307, 11, 23, "Index",
  CellTags->"\[CapitalMu]"],
Cell[776470, 28338, 312, 11, 23, "Index",
  CellTags->"\[Chi]"],
Cell[776785, 28351, 296, 11, 23, "Index",
  CellTags->"\[Sampi]"],
Cell[777084, 28364, 290, 10, 23, "Index",
  CellTags->"$MetropolisAdjustment"],
Cell[777377, 28376, 317, 11, 23, "Index",
  CellTags->"\[WeierstrassP]"],
Cell[777697, 28389, 449, 12, 23, "Index",
  CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],
Cell[778149, 28403, 320, 11, 23, "Index",
  CellTags->"\[CircleDot]"],
Cell[778472, 28416, 394, 12, 23, "Index",
  CellTags->"\[Backslash]"],
Cell[778869, 28430, 450, 15, 23, "Index",
  CellTags->"\[Wedge]"],
Cell[779322, 28447, 319, 11, 23, "Index",
  CellTags->"\[CirclePlus]"]
}, Closed]],

Cell[CellGroupData[{
Cell[779678, 28463, 40, 0, 28, "Subsubsection"],
Cell[779721, 28465, 106, 2, 27, "Input"],
Cell[779830, 28469, 247, 11, 15, "Index",
  CellTags->"|."],
Cell[780080, 28482, 233, 11, 15, "Index",
  CellTags->"\\\\"],
Cell[780316, 28495, 243, 11, 15, "Index",
  CellTags->"<>"],
Cell[780562, 28508, 254, 11, 15, "Index",
  CellTags->"||."],
Cell[780819, 28521, 271, 10, 15, "Index",
  CellTags->"AddGenealogy"],
Cell[781093, 28533, 272, 10, 15, "Index",
  CellTags->"Additive models"],
Cell[781368, 28545, 303, 11, 15, "Index",
  CellTags->"Additive selection"],
Cell[781674, 28558, 713, 27, 60, "IndexSubentry",
  CellTags->"Additive selection"],
Cell[782390, 28587, 268, 10, 15, "Index",
  CellTags->"AddMutation"],
Cell[782661, 28599, 256, 10, 15, "Index",
  CellTags->"AddNode"],
Cell[782920, 28611, 229, 10, 15, "Index",
  CellTags->"AddTag"],
Cell[783152, 28623, 334, 14, 15, "Index",
  CellTags->"AddUp"],
Cell[783489, 28639, 492, 21, 45, "IndexSubentry",
  CellTags->"AddUp"],
Cell[783984, 28662, 261, 10, 15, "Index",
  CellTags->"AdmixtureFrequency"],
Cell[784248, 28674, 352, 14, 15, "Index",
  CellTags->"Admixture models"],
Cell[784603, 28690, 843, 33, 75, "IndexSubentry",
  CellTags->"Admixture models"],
Cell[785449, 28725, 408, 15, 15, "Index",
  CellTags->"Adults"],
Cell[785860, 28742, 326, 11, 15, "Index",
  CellTags->"Allele frequencies"],
Cell[786189, 28755, 470, 15, 15, "Index",
  CellTags->"AlleleFrequencies"],
Cell[786662, 28772, 298, 10, 15, "Index",
  CellTags->"AlleleFrequencyMean"],
Cell[786963, 28784, 952, 29, 60, "IndexSubentry",
  CellTags->"AlleleFrequencyMean"],
Cell[787918, 28815, 314, 11, 15, "Index",
  CellTags->"AlleleFrequencyP"],
Cell[788235, 28828, 304, 10, 15, "Index",
  CellTags->"AlleleFrequencyPermutations"],
Cell[788542, 28840, 366, 12, 15, "Index",
  CellTags->"AlleleFrequencyPQ"],
Cell[788911, 28854, 314, 11, 15, "Index",
  CellTags->"AlleleFrequencyQ"],
Cell[789228, 28867, 301, 10, 15, "Index",
  CellTags->"AlleleFrequencyTable"],
Cell[789532, 28879, 962, 30, 60, "IndexSubentry",
  CellTags->"AlleleFrequencyTable"],
Cell[790497, 28911, 313, 11, 15, "Index",
  CellTags->"AllelicDeviation"],
Cell[790813, 28924, 258, 11, 15, "Index",
  CellTags->"AllelicState"],
Cell[791074, 28937, 258, 10, 15, "Index",
  CellTags->"AllSets"],
Cell[791335, 28949, 273, 11, 15, "Index",
  CellTags->"Ancestors"],
Cell[791611, 28962, 255, 10, 15, "Index",
  CellTags->"Ancestry"],
Cell[791869, 28974, 334, 11, 15, "Index",
  CellTags->"Arbitrary sets of loci"],
Cell[792206, 28987, 240, 10, 15, "Index",
  CellTags->"Arnold 1996"],
Cell[792449, 28999, 414, 14, 15, "Index",
  CellTags->"Asmussen and Orive 2000"],
Cell[792866, 29015, 266, 10, 15, "Index",
  CellTags->"Asmussen et al. 1987"],
Cell[793135, 29027, 256, 10, 15, "Index",
  CellTags->"B"],
Cell[793394, 29039, 363, 14, 15, "Index",
  CellTags->"Baake 2001"],
Cell[793760, 29055, 276, 11, 15, "Index",
  CellTags->"Barrier"],
Cell[794039, 29068, 276, 10, 15, "Index",
  CellTags->"BarrierStrength"],
Cell[794318, 29080, 240, 10, 15, "Index",
  CellTags->"Barton 1986"],
Cell[794561, 29092, 262, 10, 15, "Index",
  CellTags->"Barton 1995"],
Cell[794826, 29104, 240, 10, 15, "Index",
  CellTags->"Barton 2000"],
Cell[795069, 29116, 298, 10, 15, "Index",
  CellTags->"Barton and Turelli 1991"],
Cell[795370, 29128, 261, 10, 15, "Index",
  CellTags->"Barton & Gale 1993"],
Cell[795634, 29140, 264, 10, 15, "Index",
  CellTags->"Barton & Shpak 1999"],
Cell[795901, 29152, 270, 10, 15, "Index",
  CellTags->"Barton & Turelli 1991"],
Cell[796174, 29164, 243, 10, 15, "Index",
  CellTags->"Bennett 1954"],
Cell[796420, 29176, 251, 10, 15, "Index",
  CellTags->"BennettB"],
Cell[796674, 29188, 251, 10, 15, "Index",
  CellTags->"BennettC"],
Cell[796928, 29200, 275, 10, 15, "Index",
  CellTags->"BennettExpansion"],
Cell[797206, 29212, 236, 10, 15, "Index",
  CellTags->"Biallelic"],
Cell[797445, 29224, 358, 13, 15, "IndexSubentry",
  CellTags->"Biallelic"],
Cell[797806, 29239, 276, 10, 15, "Index",
  CellTags->"BiallelicMutation"],
Cell[798085, 29251, 268, 9, 15, "IndexSubentry",
  CellTags->"BiallelicMutation"],
Cell[798356, 29262, 266, 10, 15, "Index",
  CellTags->"Binary integers"],
Cell[798625, 29274, 262, 10, 15, "Index",
  CellTags->"Birth"],
Cell[798890, 29286, 258, 10, 15, "Index",
  CellTags->"BirthTime"],
Cell[799151, 29298, 447, 15, 15, "Index",
  CellTags->"Boundary conditions"],
Cell[799601, 29315, 240, 10, 15, "Index",
  CellTags->"Box"],
Cell[799844, 29327, 246, 10, 15, "Index",
  CellTags->"Boxes"],
Cell[800093, 29339, 293, 10, 15, "Index",
  CellTags->"Browser categories"],
Cell[800389, 29351, 239, 11, 15, "Index",
  CellTags->"Bugs"],
Cell[800631, 29364, 1583, 63, 150, "IndexSubentry",
  CellTags->"Bugs"],
Cell[802217, 29429, 318, 11, 15, "Index",
  CellTags->"ChangeContext"],
Cell[802538, 29442, 238, 10, 15, "Index",
  CellTags->"ChangeSex"],
Cell[802779, 29454, 289, 10, 15, "Index",
  CellTags->"ClassToGenotypes"],
Cell[803071, 29466, 253, 11, 15, "Index",
  CellTags->"Cline"],
Cell[803327, 29479, 2662, 78, 105, "IndexSubentry",
  CellTags->"Cline"],
Cell[805992, 29559, 325, 11, 15, "Index",
  CellTags->"ClineGradient"],
Cell[806320, 29572, 323, 11, 15, "Index",
  CellTags->"ClineWidth"],
Cell[806646, 29585, 695, 21, 45, "IndexSubentry",
  CellTags->"ClineWidth"],
Cell[807344, 29608, 329, 11, 15, "Index",
  CellTags->"CoalescenceDistribution"],
Cell[807676, 29621, 282, 10, 15, "Index",
  CellTags->"CollapseGenealogy"],
Cell[807961, 29633, 274, 11, 15, "Index",
  CellTags->"Combinations"],
Cell[808238, 29646, 232, 10, 15, "Index",
  CellTags->"Combine"],
Cell[808473, 29658, 256, 10, 15, "Index",
  CellTags->"CompareLogL"],
Cell[808732, 29670, 1075, 31, 30, "Index",
  CellTags->"Compiled"],
Cell[809810, 29703, 1073, 31, 30, "Index",
  CellTags->"Compiling"],
Cell[810886, 29736, 286, 10, 15, "Index",
  CellTags->"CondenseGenealogy"],
Cell[811175, 29748, 271, 10, 15, "Index",
  CellTags->"CondenseMatrix"],
Cell[811449, 29760, 289, 10, 15, "Index",
  CellTags->"ConstrainedIntervals"],
Cell[811741, 29772, 754, 22, 15, "Index",
  CellTags->"ConstructMutateList"],
Cell[812498, 29796, 442, 14, 15, "Index",
  CellTags->"ConstructMutateMatrix"],
Cell[812943, 29812, 286, 10, 15, "Index",
  CellTags->"ContextComponentQ"],
Cell[813232, 29824, 280, 10, 15, "Index",
  CellTags->"ContextPosition"],
Cell[813515, 29836, 274, 10, 15, "Index",
  CellTags->"ContextStageQ"],
Cell[813792, 29848, 283, 10, 15, "Index",
  CellTags->"ContextStructure"],
Cell[814078, 29860, 312, 11, 15, "Index",
  CellTags->"Continuous populations"],
Cell[814393, 29873, 665, 27, 60, "IndexSubentry",
  CellTags->"Continuous populations"],
Cell[815061, 29902, 273, 10, 15, "Index",
  CellTags->"ContinuumVariables"],
Cell[815337, 29914, 260, 10, 15, "Index",
  CellTags->"ConvertData"],
Cell[815600, 29926, 291, 10, 15, "Index",
  CellTags->"ConvertHyperlinkToAddOnsLink"],
Cell[815894, 29938, 427, 15, 15, "Index",
  CellTags->"Converting"],
Cell[816324, 29955, 287, 10, 15, "Index",
  CellTags->"CountHeterozygotes"],
Cell[816614, 29967, 292, 11, 15, "Index",
  CellTags->"Covariance"],
Cell[816909, 29980, 260, 10, 15, "Index",
  CellTags->"CovarianceMidPoints"],
Cell[817172, 29992, 289, 10, 15, "Index",
  CellTags->"Crow and Kimura 1970"],
Cell[817464, 30004, 253, 10, 15, "Index",
  CellTags->"Cumulant"],
Cell[817720, 30016, 332, 11, 15, "Index",
  CellTags->"CumulantDisequilibrium"],
Cell[818055, 30029, 264, 10, 15, "Index",
  CellTags->"CumulantEquilibrium"],
Cell[818322, 30041, 392, 11, 15, "Index",
  CellTags->"CumulantPopulationDisequilibrium"],
Cell[818717, 30054, 268, 10, 15, "Index",
  CellTags->"CumulantReduced"],
Cell[818988, 30066, 333, 14, 15, "Index",
  CellTags->"Cumulants"],
Cell[819324, 30082, 426, 14, 15, "Index",
  CellTags->"Cytoplasmic inheritance"],
Cell[819753, 30098, 440, 15, 30, "IndexSubentry",
  CellTags->"Cytoplasmic inheritance"],
Cell[820196, 30115, 283, 11, 15, "Index",
  CellTags->"CytoplasmicLoci"],
Cell[820482, 30128, 453, 15, 30, "IndexSubentry",
  CellTags->"CytoplasmicLoci"],
Cell[820938, 30145, 307, 10, 15, "Index",
  CellTags->"dAlleleFrequencyPermutations"],
Cell[821248, 30157, 235, 10, 15, "Index",
  CellTags->"Data"],
Cell[821486, 30169, 423, 15, 30, "IndexSubentry",
  CellTags->"Data"],
Cell[821912, 30186, 259, 11, 15, "Index",
  CellTags->"Datasets"],
Cell[822174, 30199, 368, 14, 15, "Index",
  CellTags->"Dawson 2000"],
Cell[822545, 30215, 262, 10, 15, "Index",
  CellTags->"Death"],
Cell[822810, 30227, 258, 10, 15, "Index",
  CellTags->"DeathTime"],
Cell[823071, 30239, 274, 10, 15, "Index",
  CellTags->"DefineContext"],
Cell[823348, 30251, 271, 10, 15, "Index",
  CellTags->"DegreesOfFreedom"],
Cell[823622, 30263, 279, 10, 15, "Index",
  CellTags->"DeletedMutations"],
Cell[823904, 30275, 280, 10, 15, "Index",
  CellTags->"DeleteGenealogy"],
Cell[824187, 30287, 322, 14, 15, "Index",
  CellTags->"Deme"],
Cell[824512, 30303, 614, 20, 15, "Index",
  CellTags->"DemeSize"],
Cell[825129, 30325, 3024, 86, 134, "IndexSubentry",
  CellTags->"DemeSize"],
Cell[828156, 30413, 264, 10, 15, "Index",
  CellTags->"Dempster et al 1977"],
Cell[828423, 30425, 252, 10, 15, "Index",
  CellTags->"Density"],
Cell[828678, 30437, 270, 10, 15, "Index",
  CellTags->"Descendants"],
Cell[828951, 30449, 263, 9, 15, "IndexSubentry",
  CellTags->"Descendants"],
Cell[829217, 30460, 296, 10, 15, "Index",
  CellTags->"Dicytonuclear associations"],
Cell[829516, 30472, 304, 11, 15, "Index",
  CellTags->"Diploid"],
Cell[829823, 30485, 277, 10, 15, "Index",
  CellTags->"DiploidConstraints"],
Cell[830103, 30497, 297, 10, 15, "Index",
  CellTags->"DiploidFrequencies"],
Cell[830403, 30509, 332, 11, 15, "Index",
  CellTags->"DiploidGenotypeFrequency"],
Cell[830738, 30522, 305, 10, 15, "Index",
  CellTags->"DiploidGenotypeFrequencyList"],
Cell[831046, 30534, 316, 10, 15, "Index",
  CellTags->"DiploidGenotypeFrequencyReduced"],
Cell[831365, 30546, 310, 10, 15, "Index",
  CellTags->"DiploidGenotypeFrequencyTable"],
Cell[831678, 30558, 297, 10, 15, "Index",
  CellTags->"DiploidIndividuals"],
Cell[831978, 30570, 275, 10, 15, "Index",
  CellTags->"DiploidPhenotype"],
Cell[832256, 30582, 402, 14, 15, "Index",
  CellTags->"DiploidPsi"],
Cell[832661, 30598, 309, 10, 15, "Index",
  CellTags->"DiploidRepresentations"],
Cell[832973, 30610, 414, 14, 15, "Index",
  CellTags->"DiploidSource"],
Cell[833390, 30626, 259, 10, 15, "Index",
  CellTags->"DiploidSubsets"],
Cell[833652, 30638, 257, 10, 15, "Index",
  CellTags->"DiploidTypes"],
Cell[833912, 30650, 283, 11, 15, "Index",
  CellTags->"Disequilibrium"],
Cell[834198, 30663, 919, 29, 45, "IndexSubentry",
  CellTags->"Disequilibrium"],
Cell[835120, 30694, 337, 11, 15, "Index",
  CellTags->"DisequilibriumMean"],
Cell[835460, 30707, 744, 23, 45, "IndexSubentry",
  CellTags->"DisequilibriumMean"],
Cell[836207, 30732, 340, 11, 15, "Index",
  CellTags->"DisequilibriumTable"],
Cell[836550, 30745, 748, 23, 45, "IndexSubentry",
  CellTags->"DisequilibriumTable"],
Cell[837301, 30770, 299, 11, 15, "Index",
  CellTags->"Dispersal"],
Cell[837603, 30783, 276, 10, 15, "Index",
  CellTags->"DistanceSquared"],
Cell[837882, 30795, 241, 10, 15, "Index",
  CellTags->"Distribution"],
Cell[838126, 30807, 237, 10, 15, "Index",
  CellTags->"DivideZero"],
Cell[838366, 30819, 277, 10, 15, "Index",
  CellTags->"DoReplicates"],
Cell[838646, 30831, 353, 12, 15, "Index",
  CellTags->"DoubleCline"],
Cell[839002, 30845, 772, 23, 45, "IndexSubentry",
  CellTags->"DoubleCline"],
Cell[839777, 30870, 262, 10, 15, "Index",
  CellTags->"DrawSamples"],
Cell[840042, 30882, 260, 10, 15, "Index",
  CellTags->"DropOptions"],
Cell[840305, 30894, 243, 10, 15, "Index",
  CellTags->"Edwards 1972"],
Cell[840551, 30906, 272, 11, 15, "Index",
  CellTags->"EmptySets"],
Cell[840826, 30919, 270, 11, 15, "Index",
  CellTags->"Epistasis"],
Cell[841099, 30932, 300, 11, 15, "Index",
  CellTags->"EquivalentSexes"],
Cell[841402, 30945, 267, 10, 15, "Index",
  CellTags->"ErrorBound"],
Cell[841672, 30957, 298, 10, 15, "Index",
  CellTags->"EstimateFamilyMoments"],
Cell[841973, 30969, 274, 10, 15, "Index",
  CellTags->"EstimateMoments"],
Cell[842250, 30981, 269, 11, 15, "Index",
  CellTags->"Estimating D"],
Cell[842522, 30994, 2407, 92, 210, "IndexSubentry",
  CellTags->"Estimating D"],
Cell[844932, 31088, 293, 10, 15, "Index",
  CellTags->"ExactEigenvalues"],
Cell[845228, 31100, 459, 15, 15, "Index",
  CellTags->"ExactIntersection"],
Cell[845690, 31117, 269, 10, 15, "Index",
  CellTags->"ExactProbability"],
Cell[845962, 31129, 252, 11, 15, "Index",
  CellTags->"Expectation"],
Cell[846217, 31142, 572, 16, 30, "IndexSubentry",
  CellTags->"Expectation"],
Cell[846792, 31160, 329, 11, 15, "Index",
  CellTags->"ExponentialF"],
Cell[847124, 31173, 877, 26, 45, "IndexSubentry",
  CellTags->"ExponentialF"],
Cell[848004, 31201, 270, 10, 15, "Index",
  CellTags->"ExtantIndividuals"],
Cell[848277, 31213, 321, 11, 15, "Index",
  CellTags->"ExtractContexts"],
Cell[848601, 31226, 242, 10, 15, "Index",
  CellTags->"ExtractExtant"],
Cell[848846, 31238, 283, 10, 15, "Index",
  CellTags->"ExtractGenealogy"],
Cell[849132, 31250, 314, 11, 15, "Index",
  CellTags->"ExtractGenes"],
Cell[849449, 31263, 285, 10, 15, "Index",
  CellTags->"ExtractInformation"],
Cell[849737, 31275, 260, 10, 15, "Index",
  CellTags->"ExtractRepeat"],
Cell[850000, 31287, 279, 10, 15, "Index",
  CellTags->"ExtractSubMatrix"],
Cell[850282, 31299, 327, 11, 15, "Index",
  CellTags->"FamilyAlleleFrequencyEstimate"],
Cell[850612, 31312, 274, 10, 15, "Index",
  CellTags->"FamilyEffects"],
Cell[850889, 31324, 256, 10, 15, "Index",
  CellTags->"FamilyM"],
Cell[851148, 31336, 264, 10, 15, "Index",
  CellTags->"FamilyProbability"],
Cell[851415, 31348, 291, 11, 15, "Index",
  CellTags->"Family structure"],
Cell[851709, 31361, 258, 10, 15, "Index",
  CellTags->"Fecundity"],
Cell[851970, 31373, 249, 10, 15, "Index",
  CellTags->"FindHyperlinks"],
Cell[852222, 31385, 243, 10, 15, "Index",
  CellTags->"FindIndexTag"],
Cell[852468, 31397, 238, 10, 15, "Index",
  CellTags->"FindMLE"],
Cell[852709, 31409, 253, 10, 15, "Index",
  CellTags->"FindNode"],
Cell[852965, 31421, 239, 10, 15, "Index",
  CellTags->"FindPosition"],
Cell[853207, 31433, 249, 10, 15, "Index",
  CellTags->"FindTags"],
Cell[853459, 31445, 316, 11, 15, "Index",
  CellTags->"Fitness"],
Cell[853778, 31458, 618, 21, 45, "IndexSubentry",
  CellTags->"Fitness"],
Cell[854399, 31481, 305, 11, 15, "Index",
  CellTags->"FitnessSet"],
Cell[854707, 31494, 295, 11, 15, "Index",
  CellTags->"FitnessTable"],
Cell[855005, 31507, 475, 15, 30, "IndexSubentry",
  CellTags->"FitnessTable"],
Cell[855483, 31524, 300, 11, 15, "Index",
  CellTags->"FixedEnds"],
Cell[855786, 31537, 1296, 37, 59, "IndexSubentry",
  CellTags->"FixedEnds"],
Cell[857085, 31576, 278, 10, 15, "Index",
  CellTags->"Flatten"],
Cell[857366, 31588, 274, 10, 15, "Index",
  CellTags->"FlattenList"],
Cell[857643, 31600, 277, 9, 15, "IndexSubentry",
  CellTags->"FlattenList"],
Cell[857923, 31611, 274, 10, 15, "Index",
  CellTags->"FourierNormalised"],
Cell[858200, 31623, 289, 10, 15, "Index",
  CellTags->"FourierNormalisedTable"],
Cell[858492, 31635, 315, 10, 15, "Index",
  CellTags->"FrequencyRepresentations"],
Cell[858810, 31647, 254, 10, 15, "Index",
  CellTags->"FromBaake"],
Cell[859067, 31659, 260, 10, 15, "Index",
  CellTags->"FromBennett"],
Cell[859330, 31671, 290, 10, 15, "Index",
  CellTags->"FromBennettExpression"],
Cell[859623, 31683, 262, 10, 15, "Index",
  CellTags->"FullContext"],
Cell[859888, 31695, 307, 10, 15, "Index",
  CellTags->"FullGenotypeFrequencyReduced"],
Cell[860198, 31707, 301, 10, 15, "Index",
  CellTags->"FullGenotypeFrequencyTable"],
Cell[860502, 31719, 257, 10, 15, "Index",
  CellTags->"FullOutput"],
Cell[860762, 31731, 241, 10, 15, "Index",
  CellTags->"Function"],
Cell[861006, 31743, 286, 11, 15, "Index",
  CellTags->"Gametes"],
Cell[861295, 31756, 1087, 36, 60, "IndexSubentry",
  CellTags->"Gametes"],
Cell[862385, 31794, 298, 11, 15, "Index",
  CellTags->"GameteTable"],
Cell[862686, 31807, 440, 15, 30, "IndexSubentry",
  CellTags->"GameteTable"],
Cell[863129, 31824, 290, 10, 15, "Index",
  CellTags->"GaussianLogLikelihood"],
Cell[863422, 31836, 260, 10, 15, "Index",
  CellTags->"GaussianMLE"],
Cell[863685, 31848, 270, 11, 15, "Index",
  CellTags->"Genealogies"],
Cell[863958, 31861, 740, 27, 60, "IndexSubentry",
  CellTags->"Genealogies"],
Cell[864701, 31890, 412, 15, 15, "Index",
  CellTags->"Genealogy"],
Cell[865116, 31907, 276, 10, 15, "Index",
  CellTags->"GenealogyToMatrix"],
Cell[865395, 31919, 265, 10, 15, "Index",
  CellTags->"GeneralizedTransform"],
Cell[865663, 31931, 283, 11, 15, "Index",
  CellTags->"Generating functions"],
Cell[865949, 31944, 437, 15, 30, "IndexSubentry",
  CellTags->"Generating functions"],
Cell[866389, 31961, 277, 10, 15, "Index",
  CellTags->"Genes and contexts"],
Cell[866669, 31973, 334, 12, 15, "Index",
  CellTags->"Genome"],
Cell[867006, 31987, 287, 11, 15, "Index",
  CellTags->"Genotype"],
Cell[867296, 32000, 566, 19, 30, "IndexSubentry",
  CellTags->"Genotype"],
Cell[867865, 32021, 299, 11, 15, "Index",
  CellTags->"Genotype frequencies"],
Cell[868167, 32034, 301, 10, 15, "Index",
  CellTags->"GenotypeFrequencyArguments"],
Cell[868471, 32046, 303, 10, 15, "Index",
  CellTags->"GenotypeFrequencyConvert"],
Cell[868777, 32058, 307, 10, 15, "Index",
  CellTags->"GenotypeFrequencyTable"],
Cell[869087, 32070, 281, 10, 15, "Index",
  CellTags->"GenotypePosition"],
Cell[869371, 32082, 288, 10, 15, "Index",
  CellTags->"GenotypeProbability"],
Cell[869662, 32094, 286, 9, 15, "IndexSubentry",
  CellTags->"GenotypeProbability"],
Cell[869951, 32105, 256, 11, 15, "Index",
  CellTags->"Genotypes"],
Cell[870210, 32118, 291, 10, 15, "Index",
  CellTags->"GlobalContinuumVariables"],
Cell[870504, 32130, 452, 16, 15, "Index",
  CellTags->"Gnew"],
Cell[870959, 32148, 261, 10, 15, "Index",
  CellTags->"Goodman et al 1999"],
Cell[871223, 32160, 399, 14, 15, "Index",
  CellTags->"Griffiths-Tavare"],
Cell[871625, 32176, 833, 26, 45, "IndexSubentry",
  CellTags->"Griffiths-Tavare"],
Cell[872461, 32204, 276, 10, 15, "Index",
  CellTags->"Guiasu & Shenitzer 1985"],
Cell[872740, 32216, 277, 10, 15, "Index",
  CellTags->"HaploidConstraints"],
Cell[873020, 32228, 297, 10, 15, "Index",
  CellTags->"HaploidFrequencies"],
Cell[873320, 32240, 332, 11, 15, "Index",
  CellTags->"HaploidGenotypeFrequency"],
Cell[873655, 32253, 297, 10, 15, "Index",
  CellTags->"HaploidIndividuals"],
Cell[873955, 32265, 309, 10, 15, "Index",
  CellTags->"HaploidRepresentations"],
Cell[874267, 32277, 259, 11, 15, "Index",
  CellTags->"Haploids"],
Cell[874529, 32290, 414, 14, 15, "Index",
  CellTags->"HaploidSource"],
Cell[874946, 32306, 259, 10, 15, "Index",
  CellTags->"HaploidSubsets"],
Cell[875208, 32318, 257, 10, 15, "Index",
  CellTags->"HaploidTypes"],
Cell[875468, 32330, 314, 11, 15, "Index",
  CellTags->"Help browser"],
Cell[875785, 32343, 281, 10, 15, "Index",
  CellTags->"Help Browser"],
Cell[876069, 32355, 291, 9, 15, "IndexSubentry",
  CellTags->"Help Browser"],
Cell[876363, 32366, 432, 15, 15, "Index",
  CellTags->"Hermaphrodites"],
Cell[876798, 32383, 284, 10, 15, "Index",
  CellTags->"HeterozygoteB"],
Cell[877085, 32395, 237, 10, 15, "Index",
  CellTags->"Hill 1974a"],
Cell[877325, 32407, 237, 10, 15, "Index",
  CellTags->"Hill 1974b"],
Cell[877565, 32419, 237, 10, 15, "Index",
  CellTags->"Hill 1974c"],
Cell[877805, 32431, 303, 10, 15, "Index",
  CellTags->"Hypergeometric model"],
Cell[878111, 32443, 256, 11, 15, "Index",
  CellTags->"Hyperlinks"],
Cell[878370, 32456, 621, 22, 45, "IndexSubentry",
  CellTags->"Hyperlinks"],
Cell[878994, 32480, 270, 10, 15, "Index",
  CellTags->"IncidenceMatrix"],
Cell[879267, 32492, 290, 11, 15, "Index",
  CellTags->"Index"],
Cell[879560, 32505, 237, 10, 15, "Index",
  CellTags->"Individual"],
Cell[879800, 32517, 303, 10, 15, "Index",
  CellTags->"IndividualContinuumVariables"],
Cell[880106, 32529, 323, 11, 15, "Index",
  CellTags->"IndividualRepresentations"],
Cell[880432, 32542, 264, 10, 15, "Index",
  CellTags->"Individuals"],
Cell[880699, 32554, 275, 10, 15, "Index",
  CellTags->"Infinite sites mutation"],
Cell[880977, 32566, 272, 10, 15, "Index",
  CellTags->"InitialiseContinuum"],
Cell[881252, 32578, 263, 10, 15, "Index",
  CellTags->"InitialiseCovariance"],
Cell[881518, 32590, 414, 14, 15, "Index",
  CellTags->"InitialiseDemes"],
Cell[881935, 32606, 254, 10, 15, "Index",
  CellTags->"InitialStep"],
Cell[882192, 32618, 277, 10, 15, "Index",
  CellTags->"InitialStepReduced"],
Cell[882472, 32630, 270, 10, 15, "Index",
  CellTags->"InternalNodes"],
Cell[882745, 32642, 268, 10, 15, "Index",
  CellTags->"IntervalCombine"],
Cell[883016, 32654, 271, 10, 15, "Index",
  CellTags->"IntervalPosition"],
Cell[883290, 32666, 295, 10, 15, "Index",
  CellTags->"InverseFourierNormalised"],
Cell[883588, 32678, 310, 10, 15, "Index",
  CellTags->"InverseFourierNormalisedTable"],
Cell[883901, 32690, 476, 15, 15, "Index",
  CellTags->"Island model"],
Cell[884380, 32707, 795, 25, 45, "IndexSubentry",
  CellTags->"Island model"],
Cell[885178, 32734, 295, 10, 15, "Index",
  CellTags->"IterateContinuum"],
Cell[885476, 32746, 264, 11, 15, "Index",
  CellTags->"IterateExact"],
Cell[885743, 32759, 1753, 53, 120, "IndexSubentry",
  CellTags->"IterateExact"],
Cell[887499, 32814, 328, 14, 15, "Index",
  CellTags->"Join"],
Cell[887830, 32830, 417, 15, 15, "Index",
  CellTags->"Juveniles"],
Cell[888250, 32847, 310, 10, 15, "Index",
  CellTags->"Kirkpatrick and Barton 1997"],
Cell[888563, 32859, 316, 10, 15, "Index",
  CellTags->"Kirkpatrick and Servedio 1998"],
Cell[888882, 32871, 392, 14, 15, "Index",
  CellTags->"Kirkpatrick et al."],
Cell[889277, 32887, 3891, 138, 285, "IndexSubentry",
  CellTags->"Kirkpatrick et al."],
Cell[893171, 33027, 275, 10, 15, "Index",
  CellTags->"Kirkpatrick et al. 1983"],
Cell[893449, 33039, 237, 10, 15, "Index",
  CellTags->"Kruuk 1997"],
Cell[893689, 33051, 257, 10, 15, "Index",
  CellTags->"LeafLabels"],
Cell[893949, 33063, 257, 10, 15, "Index",
  CellTags->"LeafOffset"],
Cell[894209, 33075, 249, 10, 15, "Index",
  CellTags->"Leaves"],
Cell[894461, 33087, 229, 10, 15, "Index",
  CellTags->"Life cycle"],
Cell[894693, 33099, 3070, 111, 180, "IndexSubentry",
  CellTags->"Life cycle"],
Cell[897766, 33212, 246, 10, 15, "Index",
  CellTags->"Li & Nei 1974"],
Cell[898015, 33224, 480, 18, 15, "Index",
  CellTags->"Linkage"],
Cell[898498, 33244, 451, 15, 30, "IndexSubentry",
  CellTags->"Linkage"],
Cell[898952, 33261, 307, 10, 15, "Index",
  CellTags->"Linkage disequilibrium"],
Cell[899262, 33273, 270, 10, 15, "Index",
  CellTags->"LinkedRecombination"],
Cell[899535, 33285, 280, 10, 15, "Index",
  CellTags->"ListToGenealogy"],
Cell[899818, 33297, 291, 10, 15, "Index",
  CellTags->"ListToMatrix"],
Cell[900112, 33309, 255, 10, 15, "Index",
  CellTags->"Location"],
Cell[900370, 33321, 232, 10, 15, "Index",
  CellTags->"Locations"],
Cell[900605, 33333, 253, 10, 15, "Index",
  CellTags->"LocusNames"],
Cell[900861, 33345, 288, 10, 15, "Index",
  CellTags->"LogLikelihoodDisequilibrium"],
Cell[901152, 33357, 325, 10, 15, "Index",
  CellTags->"LogLikelihoodDisequilibriumReduced"],
Cell[901480, 33369, 270, 10, 15, "Index",
  CellTags->"LogLikelihoodTest"],
Cell[901753, 33381, 397, 14, 15, "Index",
  CellTags->"Log-linear models"],
Cell[902153, 33397, 252, 10, 15, "Index",
  CellTags->"Long et al 1995"],
Cell[902408, 33409, 269, 10, 15, "Index",
  CellTags->"LowerOffDiagonal"],
Cell[902680, 33421, 249, 10, 15, "Index",
  CellTags->"MacCallum 1994"],
Cell[902932, 33433, 269, 10, 15, "Index",
  CellTags->"MacCallum et al. 1998"],
Cell[903204, 33445, 320, 11, 15, "Index",
  CellTags->"MakeCline"],
Cell[903527, 33458, 691, 21, 45, "IndexSubentry",
  CellTags->"MakeCline"],
Cell[904221, 33481, 296, 11, 15, "Index",
  CellTags->"MakeDiploid"],
Cell[904520, 33494, 474, 15, 30, "IndexSubentry",
  CellTags->"MakeDiploid"],
Cell[904997, 33511, 279, 10, 15, "Index",
  CellTags->"MakeDistanceList"],
Cell[905279, 33523, 270, 10, 15, "Index",
  CellTags->"MakeDistances"],
Cell[905552, 33535, 243, 10, 15, "Index",
  CellTags->"MakeFitnessSet"],
Cell[905798, 33547, 255, 9, 15, "IndexSubentry",
  CellTags->"MakeFitnessSet"],
Cell[906056, 33558, 262, 10, 15, "Index",
  CellTags->"MakeGenealogy"],
Cell[906321, 33570, 278, 10, 15, "Index",
  CellTags->"MakeGenealogyPlot"],
Cell[906602, 33582, 296, 11, 15, "Index",
  CellTags->"MakeHaploid"],
Cell[906901, 33595, 474, 15, 30, "IndexSubentry",
  CellTags->"MakeHaploid"],
Cell[907378, 33612, 322, 11, 15, "Index",
  CellTags->"MakeIndividuals"],
Cell[907703, 33625, 666, 21, 45, "IndexSubentry",
  CellTags->"MakeIndividuals"],
Cell[908372, 33648, 270, 10, 15, "Index",
  CellTags->"MakeOneWayTable"],
Cell[908645, 33660, 268, 10, 15, "Index",
  CellTags->"MakePairwiseTable"],
Cell[908916, 33672, 325, 11, 15, "Index",
  CellTags->"MakePopulation"],
Cell[909244, 33685, 711, 22, 45, "IndexSubentry",
  CellTags->"MakePopulation"],
Cell[909958, 33709, 398, 14, 15, "Index",
  CellTags->"MakeSelectionCoefficient"],
Cell[910359, 33725, 423, 15, 30, "IndexSubentry",
  CellTags->"MakeSelectionCoefficient"],
Cell[910785, 33742, 270, 10, 15, "Index",
  CellTags->"Mangel & Hilborn 1996"],
Cell[911058, 33754, 316, 11, 15, "Index",
  CellTags->"Marginal fitness"],
Cell[911377, 33767, 642, 21, 45, "IndexSubentry",
  CellTags->"Marginal fitness"],
Cell[912022, 33790, 256, 10, 15, "Index",
  CellTags->"MarginalTable"],
Cell[912281, 33802, 302, 11, 15, "Index",
  CellTags->"MarginalW"],
Cell[912586, 33815, 636, 21, 45, "IndexSubentry",
  CellTags->"MarginalW"],
Cell[913225, 33838, 277, 11, 15, "Index",
  CellTags->"MaternalLoci"],
Cell[913505, 33851, 450, 15, 30, "IndexSubentry",
  CellTags->"MaternalLoci"],
Cell[913958, 33868, 254, 10, 15, "Index",
  CellTags->"MatrixGamma"],
Cell[914215, 33880, 280, 10, 15, "Index",
  CellTags->"MatrixToGenealogy"],
Cell[914498, 33892, 291, 10, 15, "Index",
  CellTags->"MatrixToList"],
Cell[914792, 33904, 314, 11, 15, "Index",
  CellTags->"MeanContribution"],
Cell[915109, 33917, 400, 14, 15, "Index",
  CellTags->"Mean fitness"],
Cell[915512, 33933, 461, 15, 30, "IndexSubentry",
  CellTags->"Mean fitness"],
Cell[915976, 33950, 290, 11, 15, "Index",
  CellTags->"MeanW"],
Cell[916269, 33963, 620, 21, 45, "IndexSubentry",
  CellTags->"MeanW"],
Cell[916892, 33986, 234, 10, 15, "Index",
  CellTags->"Meiosis"],
Cell[917129, 33998, 264, 9, 15, "IndexSubentry",
  CellTags->"Meiosis"],
Cell[917396, 34009, 256, 10, 15, "Index",
  CellTags->"MethodC"],
Cell[917655, 34021, 256, 10, 15, "Index",
  CellTags->"MethodP"],
Cell[917914, 34033, 271, 11, 15, "Index",
  CellTags->"Metropolis algorithm"],
Cell[918188, 34046, 295, 10, 15, "Index",
  CellTags->"MetropolisDisequilibrium"],
Cell[918486, 34058, 316, 10, 15, "Index",
  CellTags->"MetropolisDisequilibriumReduced"],
Cell[918805, 34070, 272, 10, 15, "Index",
  CellTags->"Metropolis et al. 1954"],
Cell[919080, 34082, 382, 14, 15, "Index",
  CellTags->"MFromC"],
Cell[919465, 34098, 226, 10, 15, "Index",
  CellTags->"Migrate"],
Cell[919694, 34110, 311, 11, 15, "Index",
  CellTags->"MigrateExact"],
Cell[920008, 34123, 646, 21, 45, "IndexSubentry",
  CellTags->"MigrateExact"],
Cell[920657, 34146, 298, 11, 15, "Index",
  CellTags->"Migration"],
Cell[920958, 34159, 2405, 85, 195, "IndexSubentry",
  CellTags->"Migration"],
Cell[923366, 34246, 491, 15, 15, "Index",
  CellTags->"MigrationOrder"],
Cell[923860, 34263, 524, 16, 30, "IndexSubentry",
  CellTags->"MigrationOrder"],
Cell[924387, 34281, 308, 11, 15, "Index",
  CellTags->"MigrationRate"],
Cell[924698, 34294, 311, 11, 15, "Index",
  CellTags->"MigrationSet"],
Cell[925012, 34307, 299, 10, 15, "Index",
  CellTags->"MissingCombination"],
Cell[925314, 34319, 259, 10, 15, "Index",
  CellTags->"Missing data"],
Cell[925576, 34331, 352, 14, 15, "Index",
  CellTags->"Moment"],
Cell[925931, 34347, 305, 10, 15, "Index",
  CellTags->"MomentAfterMigration"],
Cell[926239, 34359, 332, 11, 15, "Index",
  CellTags->"MomentAfterRecombination"],
Cell[926574, 34372, 258, 10, 15, "Index",
  CellTags->"MomentEquilibrium"],
Cell[926835, 34384, 315, 11, 15, "Index",
  CellTags->"MomentGeneratingFunction"],
Cell[927153, 34397, 582, 21, 45, "IndexSubentry",
  CellTags->"MomentGeneratingFunction"],
Cell[927738, 34420, 267, 10, 15, "Index",
  CellTags->"MomentLimits"],
Cell[928008, 34432, 232, 10, 15, "Index",
  CellTags->"MomentNew"],
Cell[928243, 34444, 262, 10, 15, "Index",
  CellTags->"MomentReduced"],
Cell[928508, 34456, 222, 10, 15, "Index",
  CellTags->"Moments"],
Cell[928733, 34468, 1552, 53, 120, "IndexSubentry",
  CellTags->"Moments"],
Cell[930288, 34523, 289, 10, 15, "Index",
  CellTags->"MomentsFromG"],
Cell[930580, 34535, 269, 10, 15, "Index",
  CellTags->"MomentSimple"],
Cell[930852, 34547, 302, 10, 15, "Index",
  CellTags->"MonteCarloGriffithsTavare"],
Cell[931157, 34559, 302, 10, 15, "Index",
  CellTags->"MonteCarloProbability"],
Cell[931462, 34571, 258, 10, 15, "Index",
  CellTags->"Mortality"],
Cell[931723, 34583, 299, 10, 15, "Index",
  CellTags->"MostRecentCommonAncestor"],
Cell[932025, 34595, 374, 14, 15, "Index",
  CellTags->"MToC"],
Cell[932402, 34611, 410, 14, 15, "Index",
  CellTags->"MToCEquations"],
Cell[932815, 34627, 263, 10, 15, "Index",
  CellTags->"Muddle"],
Cell[933081, 34639, 295, 11, 15, "Index",
  CellTags->"Multilocus algebra"],
Cell[933379, 34652, 1010, 36, 60, "IndexSubentry",
  CellTags->"Multilocus algebra"],
Cell[934392, 34690, 408, 15, 15, "Index",
  CellTags->"Multilocus MS"],
Cell[934803, 34707, 264, 11, 15, "Index",
  CellTags->"Multilocus notation"],
Cell[935070, 34720, 344, 12, 15, "Index",
  CellTags->"Multinomial sampling"],
Cell[935417, 34734, 332, 11, 15, "Index",
  CellTags->"MultinomialSamplingProbability"],
Cell[935752, 34747, 289, 11, 15, "Index",
  CellTags->"Multiple alleles"],
Cell[936044, 34760, 694, 27, 60, "IndexSubentry",
  CellTags->"Multiple alleles"],
Cell[936741, 34789, 297, 11, 15, "Index",
  CellTags->"Multiple arguments"],
Cell[937041, 34802, 336, 11, 15, "Index",
  CellTags->"Multiplicative models"],
Cell[937380, 34815, 302, 11, 15, "Index",
  CellTags->"MUS"],
Cell[937685, 34828, 667, 21, 45, "IndexSubentry",
  CellTags->"MUS"],
Cell[938355, 34851, 287, 11, 15, "Index",
  CellTags->"Mutate"],
Cell[938645, 34864, 607, 21, 45, "IndexSubentry",
  CellTags->"Mutate"],
Cell[939255, 34887, 724, 22, 15, "Index",
  CellTags->"MutateCompiled"],
Cell[939982, 34911, 263, 11, 15, "Index",
  CellTags->"Mutation"],
Cell[940248, 34924, 1083, 33, 45, "IndexSubentry",
  CellTags->"Mutation"],
Cell[941334, 34959, 275, 10, 15, "Index",
  CellTags->"MutationInterval"],
Cell[941612, 34971, 297, 10, 15, "Index",
  CellTags->"MutationLabels"],
Cell[941912, 34983, 269, 10, 15, "Index",
  CellTags->"MutationOrigin"],
Cell[942184, 34995, 261, 10, 15, "Index",
  CellTags->"MutationRate"],
Cell[942448, 35007, 293, 11, 15, "Index",
  CellTags->"Mutations"],
Cell[942744, 35020, 772, 27, 60, "IndexSubentry",
  CellTags->"Mutations"],
Cell[943519, 35049, 398, 14, 15, "Index",
  CellTags->"MVariables"],
Cell[943920, 35065, 293, 11, 15, "Index",
  CellTags->"Negative binomial"],
Cell[944216, 35078, 828, 27, 60, "IndexSubentry",
  CellTags->"Negative binomial"],
Cell[945047, 35107, 339, 11, 15, "Index",
  CellTags->"NegativeBinomialLogLikelihood"],
Cell[945389, 35120, 302, 10, 15, "Index",
  CellTags->"NegativeBinomialMLE"],
Cell[945694, 35132, 368, 11, 15, "Index",
  CellTags->"NegativeHypergeometricDistribution"],
Cell[946065, 35145, 273, 10, 15, "Index",
  CellTags->"NeighbourArray"],
Cell[946341, 35157, 261, 10, 15, "Index",
  CellTags->"Neighbours"],
Cell[946605, 35169, 280, 10, 15, "Index",
  CellTags->"NetCovariance"],
Cell[946888, 35181, 255, 10, 15, "Index",
  CellTags->"NetFecundity"],
Cell[947146, 35193, 255, 10, 15, "Index",
  CellTags->"NetMortality"],
Cell[947404, 35205, 384, 14, 15, "Index",
  CellTags->"NetRecombination"],
Cell[947791, 35221, 438, 15, 30, "IndexSubentry",
  CellTags->"NetRecombination"],
Cell[948232, 35238, 285, 11, 15, "Index",
  CellTags->"Neutral marker"],
Cell[948520, 35251, 309, 10, 15, "Index",
  CellTags->"NeutralRepresentations"],
Cell[948832, 35263, 309, 11, 15, "Index",
  CellTags->"NewGametes"],
Cell[949144, 35276, 1653, 52, 90, "IndexSubentry",
  CellTags->"NewGametes"],
Cell[950800, 35330, 249, 10, 15, "Index",
  CellTags->"NewS"],
Cell[951052, 35342, 380, 14, 15, "Index",
  CellTags->"Node"],
Cell[951435, 35358, 404, 14, 15, "Index",
  CellTags->"NodeFunction"],
Cell[951842, 35374, 275, 9, 15, "IndexSubentry",
  CellTags->"NodeFunction"],
Cell[952120, 35385, 257, 10, 15, "Index",
  CellTags->"NodeLabels"],
Cell[952380, 35397, 257, 10, 15, "Index",
  CellTags->"NodeOffset"],
Cell[952640, 35409, 246, 10, 15, "Index",
  CellTags->"Nodes"],
Cell[952889, 35421, 263, 10, 15, "Index",
  CellTags->"NonMendelian"],
Cell[953155, 35433, 366, 13, 15, "IndexSubentry",
  CellTags->"NonMendelian"],
Cell[953524, 35448, 323, 11, 15, "Index",
  CellTags->"NonNeutralRepresentations"],
Cell[953850, 35461, 331, 11, 15, "Index",
  CellTags->"NonSymmetricRepresentations"],
Cell[954184, 35474, 284, 10, 15, "Index",
  CellTags->"Normalisation"],
Cell[954471, 35486, 275, 10, 15, "Index",
  CellTags->"Normalised"],
Cell[954749, 35498, 287, 11, 15, "Index",
  CellTags->"Notation"],
Cell[955039, 35511, 727, 27, 60, "IndexSubentry",
  CellTags->"Notation"],
Cell[955769, 35540, 253, 10, 15, "Index",
  CellTags->"Notation Package"],
Cell[956025, 35552, 261, 10, 15, "Index",
  CellTags->"NumberedLink"],
Cell[956289, 35564, 271, 11, 15, "Index",
  CellTags->"Numbering"],
Cell[956563, 35577, 560, 21, 45, "IndexSubentry",
  CellTags->"Numbering"],
Cell[957126, 35600, 318, 11, 15, "Index",
  CellTags->"NumberOfCoalescences"],
Cell[957447, 35613, 266, 10, 15, "Index",
  CellTags->"NumberOfGenes"],
Cell[957716, 35625, 915, 28, 60, "IndexSubentry",
  CellTags->"NumberOfGenes"],
Cell[958634, 35655, 281, 10, 15, "Index",
  CellTags->"NumberOfGenesTable"],
Cell[958918, 35667, 416, 14, 15, "Index",
  CellTags->"NumberOfIndividuals"],
Cell[959337, 35683, 299, 10, 15, "Index",
  CellTags->"NumberOfIndividualsTable"],
Cell[959639, 35695, 279, 10, 15, "Index",
  CellTags->"NumberOfLineages"],
Cell[959921, 35707, 263, 10, 15, "Index",
  CellTags->"NumberOfLoci"],
Cell[960187, 35719, 278, 10, 15, "Index",
  CellTags->"NumberOfMutations"],
Cell[960468, 35731, 317, 10, 15, "Index",
  CellTags->"NumberOfPossibleCoalescences"],
Cell[960788, 35743, 287, 10, 15, "Index",
  CellTags->"NumberOfSamplePartitions"],
Cell[961078, 35755, 278, 10, 15, "Index",
  CellTags->"NumberOfSetPartitions"],
Cell[961359, 35767, 325, 11, 15, "Index",
  CellTags->"NumericalModel"],
Cell[961687, 35780, 294, 9, 15, "IndexSubentry",
  CellTags->"NumericalModel"],
Cell[961984, 35791, 301, 11, 15, "Index",
  CellTags->"Numerical models"],
Cell[962288, 35804, 1265, 43, 90, "IndexSubentry",
  CellTags->"Numerical models"],
Cell[963556, 35849, 420, 14, 15, "Index",
  CellTags->"Observable genotype"],
Cell[963979, 35865, 250, 11, 15, "Index",
  CellTags->"Obsolete"],
Cell[964232, 35878, 3402, 121, 285, "IndexSubentry",
  CellTags->"Obsolete"],
Cell[967637, 36001, 258, 10, 15, "Index",
  CellTags->"Offspring"],
Cell[967898, 36013, 266, 11, 15, "Index",
  CellTags->"Ordered"],
Cell[968167, 36026, 264, 10, 15, "Index",
  CellTags->"Orive & Barton 1999"],
Cell[968434, 36038, 247, 10, 15, "Index",
  CellTags->"OtherSex"],
Cell[968684, 36050, 275, 11, 15, "Index",
  CellTags->"Packages"],
Cell[968962, 36063, 839, 31, 60, "IndexSubentry",
  CellTags->"Packages"],
Cell[969804, 36096, 235, 10, 15, "Index",
  CellTags->"PackageSaver"],
Cell[970042, 36108, 262, 11, 15, "Index",
  CellTags->"Partitions"],
Cell[970307, 36121, 426, 15, 30, "IndexSubentry",
  CellTags->"Partitions"],
Cell[970736, 36138, 251, 10, 15, "Index",
  CellTags->"PartitionSet"],
Cell[970990, 36150, 414, 14, 15, "Index",
  CellTags->"Paternal inheritance"],
Cell[971407, 36166, 277, 11, 15, "Index",
  CellTags->"PaternalLoci"],
Cell[971687, 36179, 444, 15, 30, "IndexSubentry",
  CellTags->"PaternalLoci"],
Cell[972134, 36196, 274, 10, 15, "Index",
  CellTags->"PatternFree"],
Cell[972411, 36208, 281, 11, 15, "Index",
  CellTags->"Permutations"],
Cell[972695, 36221, 325, 11, 15, "Index",
  CellTags->"Permutations in defining coefficients"],
Cell[973023, 36234, 269, 11, 15, "Index",
  CellTags->"Phenotypes"],
Cell[973295, 36247, 264, 10, 15, "Index",
  CellTags->"Phipps & Brill 1995"],
Cell[973562, 36259, 245, 10, 15, "Index",
  CellTags->"Ploidy"],
Cell[973810, 36271, 271, 10, 15, "Index",
  CellTags->"PloidyWeightList"],
Cell[974084, 36283, 266, 10, 15, "Index",
  CellTags->"PlotGenealogy"],
Cell[974353, 36295, 247, 10, 15, "Index",
  CellTags->"PlotLogL"],
Cell[974603, 36307, 346, 11, 15, "Index",
  CellTags->"PopulationDisequilibrium"],
Cell[974952, 36320, 274, 10, 15, "Index",
  CellTags->"PopulationExpectation"],
Cell[975229, 36332, 271, 9, 15, "IndexSubentry",
  CellTags->"PopulationExpectation"],
Cell[975503, 36343, 323, 11, 15, "Index",
  CellTags->"PopulationRepresentations"],
Cell[975829, 36356, 380, 14, 15, "Index",
  CellTags->"Position"],
Cell[976212, 36372, 442, 15, 30, "IndexSubentry",
  CellTags->"Position"],
Cell[976657, 36389, 270, 10, 15, "Index",
  CellTags->"PositionsList"],
Cell[976930, 36401, 276, 10, 15, "Index",
  CellTags->"PositionsMatrix"],
Cell[977209, 36413, 305, 10, 15, "Index",
  CellTags->"PossibleCoalescenceOrder"],
Cell[977517, 36425, 303, 10, 15, "Index",
  CellTags->"PossibleDiploidGenotypes"],
Cell[977823, 36437, 272, 10, 15, "Index",
  CellTags->"PossibleGenotypes"],
Cell[978098, 36449, 273, 10, 15, "Index",
  CellTags->"PossibleRootings"],
Cell[978374, 36461, 311, 11, 15, "Index",
  CellTags->"PowerF"],
Cell[978688, 36474, 871, 27, 60, "IndexSubentry",
  CellTags->"PowerF"],
Cell[979562, 36503, 279, 10, 15, "Index",
  CellTags->"PresentOneWayTable"],
Cell[979844, 36515, 277, 10, 15, "Index",
  CellTags->"PresentPairwiseTable"],
Cell[980124, 36527, 265, 10, 15, "Index",
  CellTags->"PresentResults"],
Cell[980392, 36539, 317, 11, 15, "Index",
  CellTags->"Principal components"],
Cell[980712, 36552, 273, 10, 15, "Index",
  CellTags->"PrintDetails"],
Cell[980988, 36564, 275, 11, 15, "Index",
  CellTags->"Problems"],
Cell[981266, 36577, 587, 18, 15, "IndexSubentry",
  CellTags->"Problems"],
Cell[981856, 36597, 250, 11, 15, "Index",
  CellTags->"Products"],
Cell[982109, 36610, 237, 10, 15, "Index",
  CellTags->"ProductSum"],
Cell[982349, 36622, 249, 9, 15, "IndexSubentry",
  CellTags->"ProductSum"],
Cell[982601, 36633, 263, 11, 15, "Index",
  CellTags->"QLE"],
Cell[982867, 36646, 258, 9, 15, "IndexSubentry",
  CellTags->"QLE"],
Cell[983128, 36657, 310, 11, 15, "Index",
  CellTags->"Quasi-linkage equilibrium"],
Cell[983441, 36670, 312, 10, 15, "Index",
  CellTags->"RandomBottleneckedGenealogy"],
Cell[983756, 36682, 299, 10, 15, "Index",
  CellTags->"RandomCoalescenceOrder"],
Cell[984058, 36694, 326, 11, 15, "Index",
  CellTags->"RandomCoalescenceTimes"],
Cell[984387, 36707, 288, 10, 15, "Index",
  CellTags->"RandomCum"],
Cell[984678, 36719, 330, 12, 15, "Index",
  CellTags->"Random drift"],
Cell[985011, 36733, 2349, 77, 150, "IndexSubentry",
  CellTags->"Random drift"],
Cell[987363, 36812, 286, 11, 15, "Index",
  CellTags->"RandomDrift"],
Cell[987652, 36825, 956, 27, 30, "IndexSubentry",
  CellTags->"RandomDrift"],
Cell[988611, 36854, 259, 10, 15, "Index",
  CellTags->"RandomFamilies"],
Cell[988873, 36866, 261, 10, 15, "Index",
  CellTags->"RandomFamily"],
Cell[989137, 36878, 273, 9, 15, "IndexSubentry",
  CellTags->"RandomFamily"],
Cell[989413, 36889, 299, 11, 15, "Index",
  CellTags->"Random genealogies"],
Cell[989715, 36902, 270, 10, 15, "Index",
  CellTags->"RandomGenealogy"],
Cell[989988, 36914, 241, 10, 15, "Index",
  CellTags->"RandomList"],
Cell[990232, 36926, 259, 9, 15, "IndexSubentry",
  CellTags->"RandomList"],
Cell[990494, 36937, 259, 11, 15, "Index",
  CellTags->"Random lists"],
Cell[990756, 36950, 289, 10, 15, "Index",
  CellTags->"RandomMating"],
Cell[991048, 36962, 286, 10, 15, "Index",
  CellTags->"RandomMultinomial"],
Cell[991337, 36974, 277, 10, 15, "Index",
  CellTags->"RandomPreviousFamily"],
Cell[991617, 36986, 288, 10, 15, "Index",
  CellTags->"Random sampling"],
Cell[991908, 36998, 415, 15, 30, "IndexSubentry",
  CellTags->"Random sampling"],
Cell[992326, 37015, 236, 10, 15, "Index",
  CellTags->"RandomSet"],
Cell[992565, 37027, 371, 14, 15, "Index",
  CellTags->"Random union"],
Cell[992939, 37043, 306, 9, 15, "IndexSubentry",
  CellTags->"Random union"],
Cell[993248, 37054, 244, 10, 15, "Index",
  CellTags->"RandomUnion"],
Cell[993495, 37066, 276, 10, 15, "Index",
  CellTags->"RandomUnionMethod"],
Cell[993774, 37078, 260, 10, 15, "Index",
  CellTags->"RandomUnionObsolete"],
Cell[994037, 37090, 256, 11, 15, "Index",
  CellTags->"Random walk"],
Cell[994296, 37103, 378, 14, 15, "Index",
  CellTags->"Recombination"],
Cell[994677, 37119, 1122, 39, 90, "IndexSubentry",
  CellTags->"Recombination"],
Cell[995802, 37160, 321, 11, 15, "Index",
  CellTags->"RecombinationRate"],
Cell[996126, 37173, 450, 15, 15, "Index",
  CellTags->"RecombinationSet"],
Cell[996579, 37190, 283, 10, 15, "Index",
  CellTags->"Recombined"],
Cell[996865, 37202, 262, 10, 15, "Index",
  CellTags->"ReducedData"],
Cell[997130, 37214, 316, 11, 15, "Index",
  CellTags->"ReferencePoint"],
Cell[997449, 37227, 273, 10, 15, "Index",
  CellTags->"ReferencePointMean"],
Cell[997725, 37239, 1125, 37, 45, "IndexSubentry",
  CellTags->"ReferencePointMean"],
Cell[998853, 37278, 273, 10, 15, "Index",
  CellTags->"ReferencePointSame"],
Cell[999129, 37290, 273, 10, 15, "Index",
  CellTags->"ReferencePointZero"],
Cell[999405, 37302, 400, 14, 15, "Index",
  CellTags->"Reference values"],
Cell[999808, 37318, 472, 15, 30, "IndexSubentry",
  CellTags->"Reference values"],
Cell[1000283, 37335, 238, 10, 15, "Index",
  CellTags->"RemoveTag"],
Cell[1000524, 37347, 239, 10, 15, "Index",
  CellTags->"Repeat"],
Cell[1000766, 37359, 232, 10, 15, "Index",
  CellTags->"Replace"],
Cell[1001001, 37371, 262, 11, 15, "Index",
  CellTags->"ReplaceAllSpecial"],
Cell[1001266, 37384, 278, 11, 15, "Index",
  CellTags->"ReplaceRepeatedSpecial"],
Cell[1001547, 37397, 311, 11, 15, "Index",
  CellTags->"Representations"],
Cell[1001861, 37410, 308, 10, 15, "IndexSubentry",
  CellTags->"Representations"],
Cell[1002172, 37422, 286, 11, 15, "Index",
  CellTags->"Reproduction"],
Cell[1002461, 37435, 222, 10, 15, "Index",
  CellTags->"Reverse"],
Cell[1002686, 37447, 401, 15, 15, "Index",
  CellTags->"Root"],
Cell[1003090, 37464, 280, 10, 15, "Index",
  CellTags->"RootedGenealogy"],
Cell[1003373, 37476, 289, 11, 15, "Index",
  CellTags->"Rootings"],
Cell[1003665, 37489, 244, 10, 15, "Index",
  CellTags->"Rules"],
Cell[1003912, 37501, 234, 9, 15, "IndexSubentry",
  CellTags->"Rules"],
Cell[1004149, 37512, 251, 10, 15, "Index",
  CellTags->"SampleCovariance"],
Cell[1004403, 37524, 278, 10, 15, "Index",
  CellTags->"SampleIndividuals"],
Cell[1004684, 37536, 260, 10, 15, "Index",
  CellTags->"SamplePartition"],
Cell[1004947, 37548, 261, 11, 15, "Index",
  CellTags->"Sampling"],
Cell[1005211, 37561, 319, 11, 15, "Index",
  CellTags->"Scripts and faces"],
Cell[1005533, 37574, 414, 14, 15, "Index",
  CellTags->"SegregationRatio"],
Cell[1005950, 37590, 321, 11, 15, "Index",
  CellTags->"SelectContext"],
Cell[1006274, 37603, 272, 10, 15, "Index",
  CellTags->"SelectIndividuals"],
Cell[1006549, 37615, 232, 10, 15, "Index",
  CellTags->"Selection"],
Cell[1006784, 37627, 1704, 61, 135, "IndexSubentry",
  CellTags->"Selection"],
Cell[1008491, 37690, 437, 15, 15, "Index",
  CellTags->"SelectionCoefficient"],
Cell[1008931, 37707, 327, 11, 15, "Index",
  CellTags->"Selection coefficients"],
Cell[1009261, 37720, 519, 19, 30, "IndexSubentry",
  CellTags->"Selection coefficients"],
Cell[1009783, 37741, 317, 11, 15, "Index",
  CellTags->"SelectionExact"],
Cell[1010103, 37754, 658, 21, 45, "IndexSubentry",
  CellTags->"SelectionExact"],
Cell[1010764, 37777, 290, 11, 15, "Index",
  CellTags->"Selection on diploids"],
Cell[1011057, 37790, 888, 33, 75, "IndexSubentry",
  CellTags->"Selection on diploids"],
Cell[1011948, 37825, 304, 11, 15, "Index",
  CellTags->"SelectionRate"],
Cell[1012255, 37838, 251, 10, 15, "Index",
  CellTags->"SelectLoci"],
Cell[1012509, 37850, 217, 10, 15, "Index",
  CellTags->"Selfing"],
Cell[1012729, 37862, 235, 10, 15, "Index",
  CellTags->"Separate"],
Cell[1012967, 37874, 258, 11, 15, "Index",
  CellTags->"Servedio"],
Cell[1013228, 37887, 339, 12, 15, "Index",
  CellTags->"Set"],
Cell[1013570, 37901, 323, 10, 15, "IndexSubentry",
  CellTags->"Set"],
Cell[1013896, 37913, 293, 11, 15, "Index",
  CellTags->"Set manipulation"],
Cell[1014192, 37926, 270, 10, 15, "Index",
  CellTags->"SetOfCombinations"],
Cell[1014465, 37938, 251, 10, 15, "Index",
  CellTags->"SetPartition"],
Cell[1014719, 37950, 304, 11, 15, "Index",
  CellTags->"Sets of loci"],
Cell[1015026, 37963, 216, 10, 15, "Index",
  CellTags->"Sex"],
Cell[1015245, 37975, 394, 14, 15, "Index",
  CellTags->"Sex linkage"],
Cell[1015642, 37991, 236, 9, 15, "IndexSubentry",
  CellTags->"Sex linkage"],
Cell[1015881, 38002, 240, 10, 15, "Index",
  CellTags->"SexOfOrigin"],
Cell[1016124, 38014, 267, 10, 15, "Index",
  CellTags->"Sexual selection"],
Cell[1016394, 38026, 1209, 45, 105, "IndexSubentry",
  CellTags->"Sexual selection"],
Cell[1017606, 38073, 265, 10, 15, "Index",
  CellTags->"ShortContext"],
Cell[1017874, 38085, 278, 10, 15, "Index",
  CellTags->"SigmaMatrix"],
Cell[1018155, 38097, 247, 10, 15, "Index",
  CellTags->"SignMask"],
Cell[1018405, 38109, 236, 10, 15, "Index",
  CellTags->"SimplifyAddUp"],
Cell[1018644, 38121, 239, 10, 15, "Index",
  CellTags->"SimplifyAddUpQ"],
Cell[1018886, 38133, 261, 10, 15, "Index",
  CellTags->"SimplifyFamilies"],
Cell[1019150, 38145, 335, 11, 15, "Index",
  CellTags->"Simulating individuals"],
Cell[1019488, 38158, 503, 15, 30, "IndexSubentry",
  CellTags->"Simulating individuals"],
Cell[1019994, 38175, 284, 10, 15, "Index",
  CellTags->"SizeOfGenealogyPlot"],
Cell[1020281, 38187, 279, 10, 15, "Index",
  CellTags->"Slatkin & Excoffier 1996"],
Cell[1020563, 38199, 239, 10, 15, "Index",
  CellTags->"SlowChange"],
Cell[1020805, 38211, 274, 10, 15, "Index",
  CellTags->"SortByClass"],
Cell[1021082, 38223, 284, 9, 15, "IndexSubentry",
  CellTags->"SortByClass"],
Cell[1021369, 38234, 231, 10, 15, "Index",
  CellTags->"SortByHead"],
Cell[1021603, 38246, 254, 10, 15, "Index",
  CellTags->"SpatialCovariance"],
Cell[1021860, 38258, 323, 11, 15, "Index",
  CellTags->"Spatially varying selection"],
Cell[1022186, 38271, 268, 10, 15, "Index",
  CellTags->"Special notation"],
Cell[1022457, 38283, 239, 10, 15, "Index",
  CellTags->"SplitSet"],
Cell[1022699, 38295, 301, 11, 15, "Index",
  CellTags->"Stabilising selection"],
Cell[1023003, 38308, 1135, 40, 90, "IndexSubentry",
  CellTags->"Stabilising selection"],
Cell[1024141, 38350, 411, 15, 15, "Index",
  CellTags->"Stability"],
Cell[1024555, 38367, 275, 9, 15, "IndexSubentry",
  CellTags->"Stability"],
Cell[1024833, 38378, 320, 11, 15, "Index",
  CellTags->"StabilityDirect"],
Cell[1025156, 38391, 280, 9, 15, "IndexSubentry",
  CellTags->"StabilityDirect"],
Cell[1025439, 38402, 422, 14, 15, "Index",
  CellTags->"StabilityK"],
Cell[1025864, 38418, 313, 11, 15, "Index",
  CellTags->"StabilityKTable"],
Cell[1026180, 38431, 282, 10, 15, "Index",
  CellTags->"StabilityMatrix"],
Cell[1026465, 38443, 293, 11, 15, "Index",
  CellTags->"Stage"],
Cell[1026761, 38456, 225, 10, 15, "Index",
  CellTags->"Stages"],
Cell[1026989, 38468, 288, 9, 15, "IndexSubentry",
  CellTags->"Stages"],
Cell[1027280, 38479, 266, 10, 15, "Index",
  CellTags->"StandardPartition"],
Cell[1027549, 38491, 269, 10, 15, "Index",
  CellTags->"StandardPartitionQ"],
Cell[1027821, 38503, 285, 10, 15, "Index",
  CellTags->"StartingStepSize"],
Cell[1028109, 38515, 357, 12, 15, "Index",
  CellTags->"Stepping-stone migration"],
Cell[1028469, 38529, 347, 12, 15, "Index",
  CellTags->"Stepping-stone model"],
Cell[1028819, 38543, 501, 16, 30, "IndexSubentry",
  CellTags->"Stepping-stone model"],
Cell[1029323, 38561, 323, 11, 15, "Index",
  CellTags->"StoreExact"],
Cell[1029649, 38574, 1518, 45, 105, "IndexSubentry",
  CellTags->"StoreExact"],
Cell[1031170, 38621, 450, 15, 15, "Index",
  CellTags->"StoreResults"],
Cell[1031623, 38638, 813, 24, 30, "IndexSubentry",
  CellTags->"StoreResults"],
Cell[1032439, 38664, 264, 10, 15, "Index",
  CellTags->"StructuredArray"],
Cell[1032706, 38676, 304, 10, 15, "Index",
  CellTags->"StructuredInitialParameters"],
Cell[1033013, 38688, 327, 11, 15, "Index",
  CellTags->"StructuredLogLikelihood"],
Cell[1033343, 38701, 434, 14, 15, "Index",
  CellTags->"StructuredMLE"],
Cell[1033780, 38717, 264, 10, 15, "Index",
  CellTags->"StructuredModel"],
Cell[1034047, 38729, 288, 10, 15, "Index",
  CellTags->"StructuredModelReduce"],
Cell[1034338, 38741, 262, 11, 15, "Index",
  CellTags->"Structured models"],
Cell[1034603, 38754, 272, 9, 15, "IndexSubentry",
  CellTags->"Structured models"],
Cell[1034878, 38765, 286, 10, 15, "Index",
  CellTags->"StructuredParameter"],
Cell[1035167, 38777, 332, 11, 15, "Index",
  CellTags->"StructuredVariance"],
Cell[1035502, 38790, 248, 11, 15, "Index",
  CellTags->"Style sheets"],
Cell[1035753, 38803, 272, 10, 15, "Index",
  CellTags->"Subdivide"],
Cell[1036028, 38815, 309, 11, 15, "Index",
  CellTags->"Subscripts"],
Cell[1036340, 38828, 222, 10, 15, "Index",
  CellTags->"Subsets"],
Cell[1036565, 38840, 366, 15, 30, "IndexSubentry",
  CellTags->"Subsets"],
Cell[1036934, 38857, 234, 11, 15, "Index",
  CellTags->"Sums"],
Cell[1037171, 38870, 255, 10, 15, "Index",
  CellTags->"SwapStates"],
Cell[1037429, 38882, 344, 11, 15, "Index",
  CellTags->"Symmetric cline"],
Cell[1037776, 38895, 317, 9, 15, "IndexSubentry",
  CellTags->"Symmetric cline"],
Cell[1038096, 38906, 331, 11, 15, "Index",
  CellTags->"SymmetricDiploidFrequencies"],
Cell[1038430, 38919, 331, 11, 15, "Index",
  CellTags->"SymmetricHaploidFrequencies"],
Cell[1038764, 38932, 431, 15, 15, "Index",
  CellTags->"Symmetric model"],
Cell[1039198, 38949, 1473, 49, 105, "IndexSubentry",
  CellTags->"Symmetric model"],
Cell[1040674, 39000, 477, 15, 15, "Index",
  CellTags->"SymmetricNeutralDiploidFrequencies"],
Cell[1041154, 39017, 477, 15, 15, "Index",
  CellTags->"SymmetricNeutralHaploidFrequencies"],
Cell[1041634, 39034, 279, 10, 15, "Index",
  CellTags->"SymmetricRecombination"],
Cell[1041916, 39046, 315, 10, 15, "Index",
  CellTags->"SymmetricRepresentations"],
Cell[1042234, 39058, 259, 10, 15, "Index",
  CellTags->"SymmetricSexes"],
Cell[1042496, 39070, 356, 14, 15, "Index",
  CellTags->"Symmetrise"],
Cell[1042855, 39086, 234, 11, 15, "Index",
  CellTags->"T"],
Cell[1043092, 39099, 277, 11, 15, "Index",
  CellTags->"Table"],
Cell[1043372, 39112, 220, 10, 15, "Index",
  CellTags->"Tag"],
Cell[1043595, 39124, 260, 11, 15, "Index",
  CellTags->"Tags"],
Cell[1043858, 39137, 295, 10, 15, "IndexSubentry",
  CellTags->"Tags"],
Cell[1044156, 39149, 390, 12, 15, "Index",
  CellTags->"TakeAway"],
Cell[1044549, 39163, 260, 10, 15, "Index",
  CellTags->"TakeOptions"],
Cell[1044812, 39175, 237, 11, 15, "Index",
  CellTags->"Time"],
Cell[1045052, 39188, 346, 14, 15, "Index",
  CellTags->"TimesUp"],
Cell[1045401, 39204, 375, 15, 30, "IndexSubentry",
  CellTags->"TimesUp"],
Cell[1045779, 39221, 248, 10, 15, "Index",
  CellTags->"ToBaake"],
Cell[1046030, 39233, 254, 10, 15, "Index",
  CellTags->"ToBennett"],
Cell[1046287, 39245, 284, 10, 15, "Index",
  CellTags->"ToBennettExpression"],
Cell[1046574, 39257, 260, 10, 15, "Index",
  CellTags->"ToCumulants"],
Cell[1046837, 39269, 254, 10, 15, "Index",
  CellTags->"ToMoments"],
Cell[1047094, 39281, 296, 10, 15, "Index",
  CellTags->"ToPopulationCumulants"],
Cell[1047393, 39293, 290, 10, 15, "Index",
  CellTags->"ToPopulationMoments"],
Cell[1047686, 39305, 286, 10, 15, "Index",
  CellTags->"TotalLength"],
Cell[1047975, 39317, 252, 10, 15, "Index",
  CellTags->"TotalNumber"],
Cell[1048230, 39329, 339, 12, 15, "Index",
  CellTags->"Trait"],
Cell[1048572, 39343, 271, 10, 15, "Index",
  CellTags->"TransformedRange"],
Cell[1048846, 39355, 291, 10, 15, "Index",
  CellTags->"TransformInformation"],
Cell[1049140, 39367, 269, 10, 15, "Index",
  CellTags->"TransmissionRule"],
Cell[1049412, 39379, 300, 11, 15, "Index",
  CellTags->"Transmission rules"],
Cell[1049715, 39392, 647, 21, 45, "IndexSubentry",
  CellTags->"Transmission rules"],
Cell[1050365, 39415, 272, 10, 15, "Index",
  CellTags->"TriDiagonalMatrix"],
Cell[1050640, 39427, 352, 12, 15, "Index",
  CellTags->"TruncationSelection"],
Cell[1050995, 39441, 318, 9, 15, "IndexSubentry",
  CellTags->"TruncationSelection"],
Cell[1051316, 39452, 298, 10, 15, "Index",
  CellTags->"Turelli and Barton 1994"],
Cell[1051617, 39464, 270, 10, 15, "Index",
  CellTags->"Turelli & Barton 1994"],
Cell[1051890, 39476, 240, 10, 15, "Index",
  CellTags->"Two alleles"],
Cell[1052133, 39488, 360, 13, 15, "IndexSubentry",
  CellTags->"Two alleles"],
Cell[1052496, 39503, 302, 11, 15, "Index",
  CellTags->"UMS"],
Cell[1052801, 39516, 667, 21, 45, "IndexSubentry",
  CellTags->"UMS"],
Cell[1053471, 39539, 261, 10, 15, "Index",
  CellTags->"UnionOfGametes"],
Cell[1053735, 39551, 276, 10, 15, "Index",
  CellTags->"UnlinkedRecombination"],
Cell[1054014, 39563, 286, 10, 15, "Index",
  CellTags->"UnrootedGenealogy"],
Cell[1054303, 39575, 269, 10, 15, "Index",
  CellTags->"UpperOffDiagonal"],
Cell[1054575, 39587, 302, 11, 15, "Index",
  CellTags->"USM"],
Cell[1054880, 39600, 667, 21, 45, "IndexSubentry",
  CellTags->"USM"],
Cell[1055550, 39623, 281, 10, 15, "Index",
  CellTags->"ValidMatrixQ"],
Cell[1055834, 39635, 332, 11, 15, "Index",
  CellTags->"VarianceComponents"],
Cell[1056169, 39648, 263, 9, 15, "IndexSubentry",
  CellTags->"VarianceComponents"],
Cell[1056435, 39659, 253, 11, 15, "Index",
  CellTags->"Versions"],
Cell[1056691, 39672, 260, 11, 15, "Index",
  CellTags->"WLinkedLoci"],
Cell[1056954, 39685, 441, 15, 30, "IndexSubentry",
  CellTags->"WLinkedLoci"],
Cell[1057398, 39702, 277, 10, 15, "Index",
  CellTags->"Wright-Fisher sampling"],
Cell[1057678, 39714, 247, 11, 15, "Index",
  CellTags->"X"],
Cell[1057928, 39727, 260, 11, 15, "Index",
  CellTags->"XLinkedLoci"],
Cell[1058191, 39740, 441, 15, 30, "IndexSubentry",
  CellTags->"XLinkedLoci"],
Cell[1058635, 39757, 260, 11, 15, "Index",
  CellTags->"YLinkedLoci"],
Cell[1058898, 39770, 441, 15, 30, "IndexSubentry",
  CellTags->"YLinkedLoci"],
Cell[1059342, 39787, 260, 11, 15, "Index",
  CellTags->"ZLinkedLoci"],
Cell[1059605, 39800, 441, 15, 30, "IndexSubentry",
  CellTags->"ZLinkedLoci"],
Cell[1060049, 39817, 411, 15, 15, "Index",
  CellTags->"Zygotes"],
Cell[1060463, 39834, 427, 15, 15, "Index",
  CellTags->"\[GothicA]"],
Cell[1060893, 39851, 419, 15, 15, "Index",
  CellTags->"\[GothicCapitalA]"],
Cell[1061315, 39868, 340, 11, 15, "Index",
  CellTags->"\[GothicCapitalC]"],
Cell[1061658, 39881, 612, 19, 15, "Index",
  CellTags->"\[GothicCapitalD]"],
Cell[1062273, 39902, 494, 16, 15, "Index",
  CellTags->"\!\(\(\[GothicCapitalG]\^\[RawStar]\)\)"],
Cell[1062770, 39920, 421, 15, 15, "Index",
  CellTags->"\[GothicCapitalG]"],
Cell[1063194, 39937, 435, 15, 15, "Index",
  CellTags->"\[GothicCapitalH]"],
Cell[1063632, 39954, 425, 15, 15, "Index",
  CellTags->"\[GothicCapitalJ]"],
Cell[1064060, 39971, 320, 11, 15, "Index",
  CellTags->"\[GothicK]"],
Cell[1064383, 39984, 377, 11, 15, "Index",
  CellTags->"\[GothicCapitalK]"],
Cell[1064763, 39997, 308, 11, 15, "Index",
  CellTags->"\[GothicM]"],
Cell[1065074, 40010, 308, 11, 15, "Index",
  CellTags->"\[GothicP]"],
Cell[1065385, 40023, 369, 12, 15, "Index",
  CellTags->"\[GothicP]\[GothicQ]"],
Cell[1065757, 40037, 308, 11, 15, "Index",
  CellTags->"\[GothicQ]"],
Cell[1066068, 40050, 314, 11, 15, "Index",
  CellTags->"\[GothicR]"],
Cell[1066385, 40063, 301, 11, 15, "Index",
  CellTags->"\[GothicS]"],
Cell[1066689, 40076, 421, 15, 15, "Index",
  CellTags->"\[GothicCapitalZ]"],
Cell[1067113, 40093, 348, 11, 15, "Index",
  CellTags->"\[DoubleStruckCapitalG]"],
Cell[1067464, 40106, 322, 11, 15, "Index",
  CellTags->"\[DoubleStruckCapitalM]"],
Cell[1067789, 40119, 457, 15, 15, "Index",
  CellTags->"\[DoubleStruckCapitalR]"],
Cell[1068249, 40136, 318, 11, 15, "Index",
  CellTags->"\[DoubleStruckCapitalW]"],
Cell[1068570, 40149, 358, 12, 15, "Index",
  CellTags->"\[DoubleStruckCapitalZ]"],
Cell[1068931, 40163, 310, 11, 15, "Index",
  CellTags->"\[Gamma]"],
Cell[1069244, 40176, 304, 11, 15, "Index",
  CellTags->"\[Zeta]"],
Cell[1069551, 40189, 307, 11, 15, "Index",
  CellTags->"\[CapitalMu]"],
Cell[1069861, 40202, 312, 11, 15, "Index",
  CellTags->"\[Chi]"],
Cell[1070176, 40215, 296, 11, 15, "Index",
  CellTags->"\[Sampi]"],
Cell[1070475, 40228, 290, 10, 15, "Index",
  CellTags->"$MetropolisAdjustment"],
Cell[1070768, 40240, 317, 11, 15, "Index",
  CellTags->"\[WeierstrassP]"],
Cell[1071088, 40253, 449, 12, 15, "Index",
  CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],
Cell[1071540, 40267, 320, 11, 15, "Index",
  CellTags->"\[CircleDot]"],
Cell[1071863, 40280, 394, 12, 15, "Index",
  CellTags->"\[Backslash]"],
Cell[1072260, 40294, 450, 15, 15, "Index",
  CellTags->"\[Wedge]"],
Cell[1072713, 40311, 319, 11, 15, "Index",
  CellTags->"\[CirclePlus]"]
}, Closed]],

Cell[CellGroupData[{
Cell[1073069, 40327, 34, 0, 28, "Subsubsection"],
Cell[1073106, 40329, 247, 11, 15, "Index",
  CellTags->"|."],
Cell[1073356, 40342, 233, 11, 15, "Index",
  CellTags->"\\\\"],
Cell[1073592, 40355, 243, 11, 15, "Index",
  CellTags->"<>"],
Cell[1073838, 40368, 254, 11, 15, "Index",
  CellTags->"||."],
Cell[1074095, 40381, 271, 10, 15, "Index",
  CellTags->"AddGenealogy"],
Cell[1074369, 40393, 272, 10, 15, "Index",
  CellTags->"Additive models"],
Cell[1074644, 40405, 303, 11, 15, "Index",
  CellTags->"Additive selection"],
Cell[1074950, 40418, 713, 27, 60, "IndexSubentry",
  CellTags->"Additive selection"],
Cell[1075666, 40447, 256, 10, 15, "Index",
  CellTags->"AddNode"],
Cell[1075925, 40459, 229, 10, 15, "Index",
  CellTags->"AddTag"],
Cell[1076157, 40471, 334, 14, 15, "Index",
  CellTags->"AddUp"],
Cell[1076494, 40487, 492, 21, 45, "IndexSubentry",
  CellTags->"AddUp"],
Cell[1076989, 40510, 261, 10, 15, "Index",
  CellTags->"AdmixtureFrequency"],
Cell[1077253, 40522, 352, 14, 15, "Index",
  CellTags->"Admixture models"],
Cell[1077608, 40538, 843, 33, 75, "IndexSubentry",
  CellTags->"Admixture models"],
Cell[1078454, 40573, 408, 15, 15, "Index",
  CellTags->"Adults"],
Cell[1078865, 40590, 326, 11, 15, "Index",
  CellTags->"Allele frequencies"],
Cell[1079194, 40603, 470, 15, 15, "Index",
  CellTags->"AlleleFrequencies"],
Cell[1079667, 40620, 298, 10, 15, "Index",
  CellTags->"AlleleFrequencyMean"],
Cell[1079968, 40632, 952, 29, 60, "IndexSubentry",
  CellTags->"AlleleFrequencyMean"],
Cell[1080923, 40663, 314, 11, 15, "Index",
  CellTags->"AlleleFrequencyP"],
Cell[1081240, 40676, 304, 10, 15, "Index",
  CellTags->"AlleleFrequencyPermutations"],
Cell[1081547, 40688, 366, 12, 23, "Index",
  CellTags->"AlleleFrequencyPQ"],
Cell[1081916, 40702, 314, 11, 23, "Index",
  CellTags->"AlleleFrequencyQ"],
Cell[1082233, 40715, 301, 10, 23, "Index",
  CellTags->"AlleleFrequencyTable"],
Cell[1082537, 40727, 962, 30, 68, "IndexSubentry",
  CellTags->"AlleleFrequencyTable"],
Cell[1083502, 40759, 313, 11, 23, "Index",
  CellTags->"AllelicDeviation"],
Cell[1083818, 40772, 258, 11, 23, "Index",
  CellTags->"AllelicState"],
Cell[1084079, 40785, 258, 10, 23, "Index",
  CellTags->"AllSets"],
Cell[1084340, 40797, 273, 11, 23, "Index",
  CellTags->"Ancestors"],
Cell[1084616, 40810, 255, 10, 23, "Index",
  CellTags->"Ancestry"],
Cell[1084874, 40822, 334, 11, 23, "Index",
  CellTags->"Arbitrary sets of loci"],
Cell[1085211, 40835, 240, 10, 23, "Index",
  CellTags->"Arnold 1996"],
Cell[1085454, 40847, 414, 14, 23, "Index",
  CellTags->"Asmussen and Orive 2000"],
Cell[1085871, 40863, 266, 10, 23, "Index",
  CellTags->"Asmussen et al. 1987"],
Cell[1086140, 40875, 256, 10, 23, "Index",
  CellTags->"B"],
Cell[1086399, 40887, 363, 14, 23, "Index",
  CellTags->"Baake 2001"],
Cell[1086765, 40903, 276, 11, 23, "Index",
  CellTags->"Barrier"],
Cell[1087044, 40916, 276, 10, 23, "Index",
  CellTags->"BarrierStrength"],
Cell[1087323, 40928, 240, 10, 23, "Index",
  CellTags->"Barton 1986"],
Cell[1087566, 40940, 262, 10, 23, "Index",
  CellTags->"Barton 1995"],
Cell[1087831, 40952, 240, 10, 23, "Index",
  CellTags->"Barton 2000"],
Cell[1088074, 40964, 298, 10, 23, "Index",
  CellTags->"Barton and Turelli 1991"],
Cell[1088375, 40976, 261, 10, 23, "Index",
  CellTags->"Barton & Gale 1993"],
Cell[1088639, 40988, 264, 10, 23, "Index",
  CellTags->"Barton & Shpak 1999"],
Cell[1088906, 41000, 270, 10, 23, "Index",
  CellTags->"Barton & Turelli 1991"],
Cell[1089179, 41012, 243, 10, 23, "Index",
  CellTags->"Bennett 1954"],
Cell[1089425, 41024, 251, 10, 23, "Index",
  CellTags->"BennettB"],
Cell[1089679, 41036, 251, 10, 23, "Index",
  CellTags->"BennettC"],
Cell[1089933, 41048, 275, 10, 23, "Index",
  CellTags->"BennettExpansion"],
Cell[1090211, 41060, 236, 10, 23, "Index",
  CellTags->"Biallelic"],
Cell[1090450, 41072, 358, 13, 23, "IndexSubentry",
  CellTags->"Biallelic"],
Cell[1090811, 41087, 276, 10, 23, "Index",
  CellTags->"BiallelicMutation"],
Cell[1091090, 41099, 268, 9, 23, "IndexSubentry",
  CellTags->"BiallelicMutation"],
Cell[1091361, 41110, 262, 10, 23, "Index",
  CellTags->"Birth"],
Cell[1091626, 41122, 258, 10, 23, "Index",
  CellTags->"BirthTime"],
Cell[1091887, 41134, 447, 15, 23, "Index",
  CellTags->"Boundary conditions"],
Cell[1092337, 41151, 240, 10, 23, "Index",
  CellTags->"Box"],
Cell[1092580, 41163, 246, 10, 23, "Index",
  CellTags->"Boxes"],
Cell[1092829, 41175, 293, 10, 23, "Index",
  CellTags->"Browser categories"],
Cell[1093125, 41187, 239, 11, 23, "Index",
  CellTags->"Bugs"],
Cell[1093367, 41200, 1583, 63, 158, "IndexSubentry",
  CellTags->"Bugs"],
Cell[1094953, 41265, 318, 11, 23, "Index",
  CellTags->"ChangeContext"],
Cell[1095274, 41278, 238, 10, 23, "Index",
  CellTags->"ChangeSex"],
Cell[1095515, 41290, 289, 10, 23, "Index",
  CellTags->"ClassToGenotypes"],
Cell[1095807, 41302, 253, 11, 23, "Index",
  CellTags->"Cline"],
Cell[1096063, 41315, 2662, 78, 113, "IndexSubentry",
  CellTags->"Cline"],
Cell[1098728, 41395, 325, 11, 23, "Index",
  CellTags->"ClineGradient"],
Cell[1099056, 41408, 323, 11, 23, "Index",
  CellTags->"ClineWidth"],
Cell[1099382, 41421, 695, 21, 53, "IndexSubentry",
  CellTags->"ClineWidth"],
Cell[1100080, 41444, 329, 11, 23, "Index",
  CellTags->"CoalescenceDistribution"],
Cell[1100412, 41457, 282, 10, 23, "Index",
  CellTags->"CollapseGenealogy"],
Cell[1100697, 41469, 232, 10, 23, "Index",
  CellTags->"Combine"],
Cell[1100932, 41481, 256, 10, 23, "Index",
  CellTags->"CompareLogL"],
Cell[1101191, 41493, 1075, 31, 38, "Index",
  CellTags->"Compiled"],
Cell[1102269, 41526, 1073, 31, 38, "Index",
  CellTags->"Compiling"],
Cell[1103345, 41559, 286, 10, 23, "Index",
  CellTags->"CondenseGenealogy"],
Cell[1103634, 41571, 289, 10, 23, "Index",
  CellTags->"ConstrainedIntervals"],
Cell[1103926, 41583, 754, 22, 23, "Index",
  CellTags->"ConstructMutateList"],
Cell[1104683, 41607, 442, 14, 23, "Index",
  CellTags->"ConstructMutateMatrix"],
Cell[1105128, 41623, 286, 10, 23, "Index",
  CellTags->"ContextComponentQ"],
Cell[1105417, 41635, 280, 10, 23, "Index",
  CellTags->"ContextPosition"],
Cell[1105700, 41647, 274, 10, 23, "Index",
  CellTags->"ContextStageQ"],
Cell[1105977, 41659, 283, 10, 23, "Index",
  CellTags->"ContextStructure"],
Cell[1106263, 41671, 312, 11, 23, "Index",
  CellTags->"Continuous populations"],
Cell[1106578, 41684, 665, 27, 68, "IndexSubentry",
  CellTags->"Continuous populations"],
Cell[1107246, 41713, 273, 10, 23, "Index",
  CellTags->"ContinuumVariables"],
Cell[1107522, 41725, 260, 10, 23, "Index",
  CellTags->"ConvertData"],
Cell[1107785, 41737, 291, 10, 23, "Index",
  CellTags->"ConvertHyperlinkToAddOnsLink"],
Cell[1108079, 41749, 427, 15, 23, "Index",
  CellTags->"Converting"],
Cell[1108509, 41766, 287, 10, 23, "Index",
  CellTags->"CountHeterozygotes"],
Cell[1108799, 41778, 292, 11, 23, "Index",
  CellTags->"Covariance"],
Cell[1109094, 41791, 260, 10, 23, "Index",
  CellTags->"CovarianceMidPoints"],
Cell[1109357, 41803, 289, 10, 23, "Index",
  CellTags->"Crow and Kimura 1970"],
Cell[1109649, 41815, 253, 10, 23, "Index",
  CellTags->"Cumulant"],
Cell[1109905, 41827, 332, 11, 23, "Index",
  CellTags->"CumulantDisequilibrium"],
Cell[1110240, 41840, 264, 10, 23, "Index",
  CellTags->"CumulantEquilibrium"],
Cell[1110507, 41852, 392, 11, 23, "Index",
  CellTags->"CumulantPopulationDisequilibrium"],
Cell[1110902, 41865, 268, 10, 23, "Index",
  CellTags->"CumulantReduced"],
Cell[1111173, 41877, 333, 14, 23, "Index",
  CellTags->"Cumulants"],
Cell[1111509, 41893, 426, 14, 23, "Index",
  CellTags->"Cytoplasmic inheritance"],
Cell[1111938, 41909, 440, 15, 38, "IndexSubentry",
  CellTags->"Cytoplasmic inheritance"],
Cell[1112381, 41926, 283, 11, 23, "Index",
  CellTags->"CytoplasmicLoci"],
Cell[1112667, 41939, 453, 15, 38, "IndexSubentry",
  CellTags->"CytoplasmicLoci"],
Cell[1113123, 41956, 307, 10, 23, "Index",
  CellTags->"dAlleleFrequencyPermutations"],
Cell[1113433, 41968, 235, 10, 23, "Index",
  CellTags->"Data"],
Cell[1113671, 41980, 423, 15, 38, "IndexSubentry",
  CellTags->"Data"],
Cell[1114097, 41997, 259, 11, 23, "Index",
  CellTags->"Datasets"],
Cell[1114359, 42010, 368, 14, 23, "Index",
  CellTags->"Dawson 2000"],
Cell[1114730, 42026, 262, 10, 23, "Index",
  CellTags->"Death"],
Cell[1114995, 42038, 258, 10, 23, "Index",
  CellTags->"DeathTime"],
Cell[1115256, 42050, 274, 10, 23, "Index",
  CellTags->"DefineContext"],
Cell[1115533, 42062, 271, 10, 23, "Index",
  CellTags->"DegreesOfFreedom"],
Cell[1115807, 42074, 279, 10, 23, "Index",
  CellTags->"DeletedMutations"],
Cell[1116089, 42086, 280, 10, 23, "Index",
  CellTags->"DeleteGenealogy"],
Cell[1116372, 42098, 322, 14, 23, "Index",
  CellTags->"Deme"],
Cell[1116697, 42114, 614, 20, 23, "Index",
  CellTags->"DemeSize"],
Cell[1117314, 42136, 3024, 86, 142, "IndexSubentry",
  CellTags->"DemeSize"],
Cell[1120341, 42224, 264, 10, 23, "Index",
  CellTags->"Dempster et al 1977"],
Cell[1120608, 42236, 252, 10, 23, "Index",
  CellTags->"Density"],
Cell[1120863, 42248, 270, 10, 23, "Index",
  CellTags->"Descendants"],
Cell[1121136, 42260, 263, 9, 23, "IndexSubentry",
  CellTags->"Descendants"],
Cell[1121402, 42271, 296, 10, 23, "Index",
  CellTags->"Dicytonuclear associations"],
Cell[1121701, 42283, 304, 11, 23, "Index",
  CellTags->"Diploid"],
Cell[1122008, 42296, 277, 10, 23, "Index",
  CellTags->"DiploidConstraints"],
Cell[1122288, 42308, 297, 10, 23, "Index",
  CellTags->"DiploidFrequencies"],
Cell[1122588, 42320, 332, 11, 23, "Index",
  CellTags->"DiploidGenotypeFrequency"],
Cell[1122923, 42333, 305, 10, 23, "Index",
  CellTags->"DiploidGenotypeFrequencyList"],
Cell[1123231, 42345, 316, 10, 23, "Index",
  CellTags->"DiploidGenotypeFrequencyReduced"],
Cell[1123550, 42357, 310, 10, 23, "Index",
  CellTags->"DiploidGenotypeFrequencyTable"],
Cell[1123863, 42369, 297, 10, 23, "Index",
  CellTags->"DiploidIndividuals"],
Cell[1124163, 42381, 275, 10, 23, "Index",
  CellTags->"DiploidPhenotype"],
Cell[1124441, 42393, 402, 14, 23, "Index",
  CellTags->"DiploidPsi"],
Cell[1124846, 42409, 309, 10, 23, "Index",
  CellTags->"DiploidRepresentations"],
Cell[1125158, 42421, 414, 14, 23, "Index",
  CellTags->"DiploidSource"],
Cell[1125575, 42437, 259, 10, 23, "Index",
  CellTags->"DiploidSubsets"],
Cell[1125837, 42449, 257, 10, 23, "Index",
  CellTags->"DiploidTypes"],
Cell[1126097, 42461, 283, 11, 23, "Index",
  CellTags->"Disequilibrium"],
Cell[1126383, 42474, 919, 29, 53, "IndexSubentry",
  CellTags->"Disequilibrium"],
Cell[1127305, 42505, 337, 11, 23, "Index",
  CellTags->"DisequilibriumMean"],
Cell[1127645, 42518, 744, 23, 53, "IndexSubentry",
  CellTags->"DisequilibriumMean"],
Cell[1128392, 42543, 340, 11, 23, "Index",
  CellTags->"DisequilibriumTable"],
Cell[1128735, 42556, 748, 23, 53, "IndexSubentry",
  CellTags->"DisequilibriumTable"],
Cell[1129486, 42581, 299, 11, 23, "Index",
  CellTags->"Dispersal"],
Cell[1129788, 42594, 276, 10, 23, "Index",
  CellTags->"DistanceSquared"],
Cell[1130067, 42606, 241, 10, 23, "Index",
  CellTags->"Distribution"],
Cell[1130311, 42618, 237, 10, 23, "Index",
  CellTags->"DivideZero"],
Cell[1130551, 42630, 277, 10, 23, "Index",
  CellTags->"DoReplicates"],
Cell[1130831, 42642, 353, 12, 23, "Index",
  CellTags->"DoubleCline"],
Cell[1131187, 42656, 772, 23, 53, "IndexSubentry",
  CellTags->"DoubleCline"],
Cell[1131962, 42681, 262, 10, 23, "Index",
  CellTags->"DrawSamples"],
Cell[1132227, 42693, 260, 10, 23, "Index",
  CellTags->"DropOptions"],
Cell[1132490, 42705, 243, 10, 23, "Index",
  CellTags->"Edwards 1972"],
Cell[1132736, 42717, 272, 11, 23, "Index",
  CellTags->"EmptySets"],
Cell[1133011, 42730, 270, 11, 23, "Index",
  CellTags->"Epistasis"],
Cell[1133284, 42743, 300, 11, 23, "Index",
  CellTags->"EquivalentSexes"],
Cell[1133587, 42756, 267, 10, 23, "Index",
  CellTags->"ErrorBound"],
Cell[1133857, 42768, 298, 10, 23, "Index",
  CellTags->"EstimateFamilyMoments"],
Cell[1134158, 42780, 274, 10, 23, "Index",
  CellTags->"EstimateMoments"],
Cell[1134435, 42792, 269, 11, 23, "Index",
  CellTags->"Estimating D"],
Cell[1134707, 42805, 2407, 92, 218, "IndexSubentry",
  CellTags->"Estimating D"],
Cell[1137117, 42899, 293, 10, 23, "Index",
  CellTags->"ExactEigenvalues"],
Cell[1137413, 42911, 459, 15, 23, "Index",
  CellTags->"ExactIntersection"],
Cell[1137875, 42928, 269, 10, 23, "Index",
  CellTags->"ExactProbability"],
Cell[1138147, 42940, 252, 11, 23, "Index",
  CellTags->"Expectation"],
Cell[1138402, 42953, 572, 16, 38, "IndexSubentry",
  CellTags->"Expectation"],
Cell[1138977, 42971, 329, 11, 23, "Index",
  CellTags->"ExponentialF"],
Cell[1139309, 42984, 877, 26, 53, "IndexSubentry",
  CellTags->"ExponentialF"],
Cell[1140189, 43012, 270, 10, 23, "Index",
  CellTags->"ExtantIndividuals"],
Cell[1140462, 43024, 321, 11, 23, "Index",
  CellTags->"ExtractContexts"],
Cell[1140786, 43037, 242, 10, 23, "Index",
  CellTags->"ExtractExtant"],
Cell[1141031, 43049, 283, 10, 23, "Index",
  CellTags->"ExtractGenealogy"],
Cell[1141317, 43061, 314, 11, 23, "Index",
  CellTags->"ExtractGenes"],
Cell[1141634, 43074, 285, 10, 23, "Index",
  CellTags->"ExtractInformation"],
Cell[1141922, 43086, 260, 10, 23, "Index",
  CellTags->"ExtractRepeat"],
Cell[1142185, 43098, 279, 10, 23, "Index",
  CellTags->"ExtractSubMatrix"],
Cell[1142467, 43110, 327, 11, 23, "Index",
  CellTags->"FamilyAlleleFrequencyEstimate"],
Cell[1142797, 43123, 274, 10, 23, "Index",
  CellTags->"FamilyEffects"],
Cell[1143074, 43135, 256, 10, 23, "Index",
  CellTags->"FamilyM"],
Cell[1143333, 43147, 264, 10, 23, "Index",
  CellTags->"FamilyProbability"],
Cell[1143600, 43159, 291, 11, 23, "Index",
  CellTags->"Family structure"],
Cell[1143894, 43172, 258, 10, 23, "Index",
  CellTags->"Fecundity"],
Cell[1144155, 43184, 249, 10, 23, "Index",
  CellTags->"FindHyperlinks"],
Cell[1144407, 43196, 243, 10, 23, "Index",
  CellTags->"FindIndexTag"],
Cell[1144653, 43208, 238, 10, 23, "Index",
  CellTags->"FindMLE"],
Cell[1144894, 43220, 253, 10, 23, "Index",
  CellTags->"FindNode"],
Cell[1145150, 43232, 239, 10, 23, "Index",
  CellTags->"FindPosition"],
Cell[1145392, 43244, 249, 10, 23, "Index",
  CellTags->"FindTags"],
Cell[1145644, 43256, 316, 11, 23, "Index",
  CellTags->"Fitness"],
Cell[1145963, 43269, 618, 21, 53, "IndexSubentry",
  CellTags->"Fitness"],
Cell[1146584, 43292, 305, 11, 23, "Index",
  CellTags->"FitnessSet"],
Cell[1146892, 43305, 295, 11, 23, "Index",
  CellTags->"FitnessTable"],
Cell[1147190, 43318, 475, 15, 38, "IndexSubentry",
  CellTags->"FitnessTable"],
Cell[1147668, 43335, 300, 11, 23, "Index",
  CellTags->"FixedEnds"],
Cell[1147971, 43348, 1296, 37, 67, "IndexSubentry",
  CellTags->"FixedEnds"],
Cell[1149270, 43387, 278, 10, 23, "Index",
  CellTags->"Flatten"],
Cell[1149551, 43399, 274, 10, 23, "Index",
  CellTags->"FlattenList"],
Cell[1149828, 43411, 277, 9, 23, "IndexSubentry",
  CellTags->"FlattenList"],
Cell[1150108, 43422, 274, 10, 23, "Index",
  CellTags->"FourierNormalised"],
Cell[1150385, 43434, 289, 10, 23, "Index",
  CellTags->"FourierNormalisedTable"],
Cell[1150677, 43446, 315, 10, 23, "Index",
  CellTags->"FrequencyRepresentations"],
Cell[1150995, 43458, 254, 10, 23, "Index",
  CellTags->"FromBaake"],
Cell[1151252, 43470, 260, 10, 23, "Index",
  CellTags->"FromBennett"],
Cell[1151515, 43482, 290, 10, 23, "Index",
  CellTags->"FromBennettExpression"],
Cell[1151808, 43494, 262, 10, 23, "Index",
  CellTags->"FullContext"],
Cell[1152073, 43506, 307, 10, 23, "Index",
  CellTags->"FullGenotypeFrequencyReduced"],
Cell[1152383, 43518, 301, 10, 23, "Index",
  CellTags->"FullGenotypeFrequencyTable"],
Cell[1152687, 43530, 257, 10, 23, "Index",
  CellTags->"FullOutput"],
Cell[1152947, 43542, 241, 10, 23, "Index",
  CellTags->"Function"],
Cell[1153191, 43554, 286, 11, 23, "Index",
  CellTags->"Gametes"],
Cell[1153480, 43567, 1087, 36, 68, "IndexSubentry",
  CellTags->"Gametes"],
Cell[1154570, 43605, 298, 11, 23, "Index",
  CellTags->"GameteTable"],
Cell[1154871, 43618, 440, 15, 38, "IndexSubentry",
  CellTags->"GameteTable"],
Cell[1155314, 43635, 290, 10, 23, "Index",
  CellTags->"GaussianLogLikelihood"],
Cell[1155607, 43647, 260, 10, 23, "Index",
  CellTags->"GaussianMLE"],
Cell[1155870, 43659, 270, 11, 23, "Index",
  CellTags->"Genealogies"],
Cell[1156143, 43672, 740, 27, 68, "IndexSubentry",
  CellTags->"Genealogies"],
Cell[1156886, 43701, 276, 10, 23, "Index",
  CellTags->"GenealogyToMatrix"],
Cell[1157165, 43713, 265, 10, 23, "Index",
  CellTags->"GeneralizedTransform"],
Cell[1157433, 43725, 283, 11, 23, "Index",
  CellTags->"Generating functions"],
Cell[1157719, 43738, 437, 15, 38, "IndexSubentry",
  CellTags->"Generating functions"],
Cell[1158159, 43755, 277, 10, 23, "Index",
  CellTags->"Genes and contexts"],
Cell[1158439, 43767, 334, 12, 23, "Index",
  CellTags->"Genome"],
Cell[1158776, 43781, 287, 11, 23, "Index",
  CellTags->"Genotype"],
Cell[1159066, 43794, 566, 19, 38, "IndexSubentry",
  CellTags->"Genotype"],
Cell[1159635, 43815, 299, 11, 23, "Index",
  CellTags->"Genotype frequencies"],
Cell[1159937, 43828, 301, 10, 23, "Index",
  CellTags->"GenotypeFrequencyArguments"],
Cell[1160241, 43840, 303, 10, 23, "Index",
  CellTags->"GenotypeFrequencyConvert"],
Cell[1160547, 43852, 307, 10, 23, "Index",
  CellTags->"GenotypeFrequencyTable"],
Cell[1160857, 43864, 281, 10, 23, "Index",
  CellTags->"GenotypePosition"],
Cell[1161141, 43876, 288, 10, 23, "Index",
  CellTags->"GenotypeProbability"],
Cell[1161432, 43888, 286, 9, 23, "IndexSubentry",
  CellTags->"GenotypeProbability"],
Cell[1161721, 43899, 256, 11, 23, "Index",
  CellTags->"Genotypes"],
Cell[1161980, 43912, 291, 10, 23, "Index",
  CellTags->"GlobalContinuumVariables"],
Cell[1162274, 43924, 452, 16, 23, "Index",
  CellTags->"Gnew"],
Cell[1162729, 43942, 261, 10, 23, "Index",
  CellTags->"Goodman et al 1999"],
Cell[1162993, 43954, 399, 14, 23, "Index",
  CellTags->"Griffiths-Tavare"],
Cell[1163395, 43970, 833, 26, 53, "IndexSubentry",
  CellTags->"Griffiths-Tavare"],
Cell[1164231, 43998, 276, 10, 23, "Index",
  CellTags->"Guiasu & Shenitzer 1985"],
Cell[1164510, 44010, 277, 10, 23, "Index",
  CellTags->"HaploidConstraints"],
Cell[1164790, 44022, 297, 10, 23, "Index",
  CellTags->"HaploidFrequencies"],
Cell[1165090, 44034, 332, 11, 23, "Index",
  CellTags->"HaploidGenotypeFrequency"],
Cell[1165425, 44047, 297, 10, 23, "Index",
  CellTags->"HaploidIndividuals"],
Cell[1165725, 44059, 309, 10, 23, "Index",
  CellTags->"HaploidRepresentations"],
Cell[1166037, 44071, 259, 11, 23, "Index",
  CellTags->"Haploids"],
Cell[1166299, 44084, 414, 14, 23, "Index",
  CellTags->"HaploidSource"],
Cell[1166716, 44100, 259, 10, 23, "Index",
  CellTags->"HaploidSubsets"],
Cell[1166978, 44112, 257, 10, 23, "Index",
  CellTags->"HaploidTypes"],
Cell[1167238, 44124, 314, 11, 23, "Index",
  CellTags->"Help browser"],
Cell[1167555, 44137, 281, 10, 23, "Index",
  CellTags->"Help Browser"],
Cell[1167839, 44149, 291, 9, 23, "IndexSubentry",
  CellTags->"Help Browser"],
Cell[1168133, 44160, 432, 15, 23, "Index",
  CellTags->"Hermaphrodites"],
Cell[1168568, 44177, 284, 10, 23, "Index",
  CellTags->"HeterozygoteB"],
Cell[1168855, 44189, 237, 10, 23, "Index",
  CellTags->"Hill 1974a"],
Cell[1169095, 44201, 237, 10, 23, "Index",
  CellTags->"Hill 1974b"],
Cell[1169335, 44213, 237, 10, 23, "Index",
  CellTags->"Hill 1974c"],
Cell[1169575, 44225, 303, 10, 23, "Index",
  CellTags->"Hypergeometric model"],
Cell[1169881, 44237, 256, 11, 23, "Index",
  CellTags->"Hyperlinks"],
Cell[1170140, 44250, 621, 22, 53, "IndexSubentry",
  CellTags->"Hyperlinks"],
Cell[1170764, 44274, 270, 10, 23, "Index",
  CellTags->"IncidenceMatrix"],
Cell[1171037, 44286, 290, 11, 23, "Index",
  CellTags->"Index"],
Cell[1171330, 44299, 237, 10, 23, "Index",
  CellTags->"Individual"],
Cell[1171570, 44311, 303, 10, 23, "Index",
  CellTags->"IndividualContinuumVariables"],
Cell[1171876, 44323, 323, 11, 23, "Index",
  CellTags->"IndividualRepresentations"],
Cell[1172202, 44336, 264, 10, 23, "Index",
  CellTags->"Individuals"],
Cell[1172469, 44348, 272, 10, 23, "Index",
  CellTags->"InitialiseContinuum"],
Cell[1172744, 44360, 263, 10, 23, "Index",
  CellTags->"InitialiseCovariance"],
Cell[1173010, 44372, 414, 14, 23, "Index",
  CellTags->"InitialiseDemes"],
Cell[1173427, 44388, 254, 10, 23, "Index",
  CellTags->"InitialStep"],
Cell[1173684, 44400, 277, 10, 23, "Index",
  CellTags->"InitialStepReduced"],
Cell[1173964, 44412, 270, 10, 23, "Index",
  CellTags->"InternalNodes"],
Cell[1174237, 44424, 268, 10, 23, "Index",
  CellTags->"IntervalCombine"],
Cell[1174508, 44436, 271, 10, 23, "Index",
  CellTags->"IntervalPosition"],
Cell[1174782, 44448, 295, 10, 23, "Index",
  CellTags->"InverseFourierNormalised"],
Cell[1175080, 44460, 310, 10, 23, "Index",
  CellTags->"InverseFourierNormalisedTable"],
Cell[1175393, 44472, 476, 15, 23, "Index",
  CellTags->"Island model"],
Cell[1175872, 44489, 795, 25, 53, "IndexSubentry",
  CellTags->"Island model"],
Cell[1176670, 44516, 295, 10, 23, "Index",
  CellTags->"IterateContinuum"],
Cell[1176968, 44528, 264, 11, 23, "Index",
  CellTags->"IterateExact"],
Cell[1177235, 44541, 1753, 53, 128, "IndexSubentry",
  CellTags->"IterateExact"],
Cell[1178991, 44596, 328, 14, 23, "Index",
  CellTags->"Join"],
Cell[1179322, 44612, 417, 15, 23, "Index",
  CellTags->"Juveniles"],
Cell[1179742, 44629, 310, 10, 23, "Index",
  CellTags->"Kirkpatrick and Barton 1997"],
Cell[1180055, 44641, 316, 10, 23, "Index",
  CellTags->"Kirkpatrick and Servedio 1998"],
Cell[1180374, 44653, 392, 14, 23, "Index",
  CellTags->"Kirkpatrick et al."],
Cell[1180769, 44669, 3891, 138, 293, "IndexSubentry",
  CellTags->"Kirkpatrick et al."],
Cell[1184663, 44809, 275, 10, 23, "Index",
  CellTags->"Kirkpatrick et al. 1983"],
Cell[1184941, 44821, 237, 10, 23, "Index",
  CellTags->"Kruuk 1997"],
Cell[1185181, 44833, 257, 10, 23, "Index",
  CellTags->"LeafLabels"],
Cell[1185441, 44845, 257, 10, 23, "Index",
  CellTags->"LeafOffset"],
Cell[1185701, 44857, 249, 10, 23, "Index",
  CellTags->"Leaves"],
Cell[1185953, 44869, 229, 10, 23, "Index",
  CellTags->"Life cycle"],
Cell[1186185, 44881, 3070, 111, 188, "IndexSubentry",
  CellTags->"Life cycle"],
Cell[1189258, 44994, 246, 10, 23, "Index",
  CellTags->"Li & Nei 1974"],
Cell[1189507, 45006, 480, 18, 23, "Index",
  CellTags->"Linkage"],
Cell[1189990, 45026, 451, 15, 38, "IndexSubentry",
  CellTags->"Linkage"],
Cell[1190444, 45043, 307, 10, 23, "Index",
  CellTags->"Linkage disequilibrium"],
Cell[1190754, 45055, 270, 10, 23, "Index",
  CellTags->"LinkedRecombination"],
Cell[1191027, 45067, 280, 10, 23, "Index",
  CellTags->"ListToGenealogy"],
Cell[1191310, 45079, 291, 10, 23, "Index",
  CellTags->"ListToMatrix"],
Cell[1191604, 45091, 255, 10, 23, "Index",
  CellTags->"Location"],
Cell[1191862, 45103, 232, 10, 23, "Index",
  CellTags->"Locations"],
Cell[1192097, 45115, 253, 10, 23, "Index",
  CellTags->"LocusNames"],
Cell[1192353, 45127, 288, 10, 23, "Index",
  CellTags->"LogLikelihoodDisequilibrium"],
Cell[1192644, 45139, 325, 10, 23, "Index",
  CellTags->"LogLikelihoodDisequilibriumReduced"],
Cell[1192972, 45151, 270, 10, 23, "Index",
  CellTags->"LogLikelihoodTest"],
Cell[1193245, 45163, 397, 14, 23, "Index",
  CellTags->"Log-linear models"],
Cell[1193645, 45179, 252, 10, 23, "Index",
  CellTags->"Long et al 1995"],
Cell[1193900, 45191, 269, 10, 23, "Index",
  CellTags->"LowerOffDiagonal"],
Cell[1194172, 45203, 249, 10, 23, "Index",
  CellTags->"MacCallum 1994"],
Cell[1194424, 45215, 269, 10, 23, "Index",
  CellTags->"MacCallum et al. 1998"],
Cell[1194696, 45227, 320, 11, 23, "Index",
  CellTags->"MakeCline"],
Cell[1195019, 45240, 691, 21, 53, "IndexSubentry",
  CellTags->"MakeCline"],
Cell[1195713, 45263, 296, 11, 23, "Index",
  CellTags->"MakeDiploid"],
Cell[1196012, 45276, 474, 15, 38, "IndexSubentry",
  CellTags->"MakeDiploid"],
Cell[1196489, 45293, 279, 10, 23, "Index",
  CellTags->"MakeDistanceList"],
Cell[1196771, 45305, 270, 10, 23, "Index",
  CellTags->"MakeDistances"],
Cell[1197044, 45317, 243, 10, 23, "Index",
  CellTags->"MakeFitnessSet"],
Cell[1197290, 45329, 255, 9, 23, "IndexSubentry",
  CellTags->"MakeFitnessSet"],
Cell[1197548, 45340, 262, 10, 23, "Index",
  CellTags->"MakeGenealogy"],
Cell[1197813, 45352, 278, 10, 23, "Index",
  CellTags->"MakeGenealogyPlot"],
Cell[1198094, 45364, 296, 11, 23, "Index",
  CellTags->"MakeHaploid"],
Cell[1198393, 45377, 474, 15, 38, "IndexSubentry",
  CellTags->"MakeHaploid"],
Cell[1198870, 45394, 322, 11, 23, "Index",
  CellTags->"MakeIndividuals"],
Cell[1199195, 45407, 666, 21, 53, "IndexSubentry",
  CellTags->"MakeIndividuals"],
Cell[1199864, 45430, 270, 10, 23, "Index",
  CellTags->"MakeOneWayTable"],
Cell[1200137, 45442, 268, 10, 23, "Index",
  CellTags->"MakePairwiseTable"],
Cell[1200408, 45454, 325, 11, 23, "Index",
  CellTags->"MakePopulation"],
Cell[1200736, 45467, 711, 22, 53, "IndexSubentry",
  CellTags->"MakePopulation"],
Cell[1201450, 45491, 398, 14, 23, "Index",
  CellTags->"MakeSelectionCoefficient"],
Cell[1201851, 45507, 423, 15, 38, "IndexSubentry",
  CellTags->"MakeSelectionCoefficient"],
Cell[1202277, 45524, 270, 10, 23, "Index",
  CellTags->"Mangel & Hilborn 1996"],
Cell[1202550, 45536, 316, 11, 23, "Index",
  CellTags->"Marginal fitness"],
Cell[1202869, 45549, 642, 21, 53, "IndexSubentry",
  CellTags->"Marginal fitness"],
Cell[1203514, 45572, 256, 10, 23, "Index",
  CellTags->"MarginalTable"],
Cell[1203773, 45584, 302, 11, 23, "Index",
  CellTags->"MarginalW"],
Cell[1204078, 45597, 636, 21, 53, "IndexSubentry",
  CellTags->"MarginalW"],
Cell[1204717, 45620, 277, 11, 23, "Index",
  CellTags->"MaternalLoci"],
Cell[1204997, 45633, 450, 15, 38, "IndexSubentry",
  CellTags->"MaternalLoci"],
Cell[1205450, 45650, 254, 10, 23, "Index",
  CellTags->"MatrixGamma"],
Cell[1205707, 45662, 280, 10, 23, "Index",
  CellTags->"MatrixToGenealogy"],
Cell[1205990, 45674, 291, 10, 23, "Index",
  CellTags->"MatrixToList"],
Cell[1206284, 45686, 314, 11, 23, "Index",
  CellTags->"MeanContribution"],
Cell[1206601, 45699, 400, 14, 23, "Index",
  CellTags->"Mean fitness"],
Cell[1207004, 45715, 461, 15, 38, "IndexSubentry",
  CellTags->"Mean fitness"],
Cell[1207468, 45732, 290, 11, 23, "Index",
  CellTags->"MeanW"],
Cell[1207761, 45745, 620, 21, 53, "IndexSubentry",
  CellTags->"MeanW"],
Cell[1208384, 45768, 234, 10, 23, "Index",
  CellTags->"Meiosis"],
Cell[1208621, 45780, 264, 9, 23, "IndexSubentry",
  CellTags->"Meiosis"],
Cell[1208888, 45791, 256, 10, 23, "Index",
  CellTags->"MethodC"],
Cell[1209147, 45803, 256, 10, 23, "Index",
  CellTags->"MethodP"],
Cell[1209406, 45815, 271, 11, 23, "Index",
  CellTags->"Metropolis algorithm"],
Cell[1209680, 45828, 295, 10, 23, "Index",
  CellTags->"MetropolisDisequilibrium"],
Cell[1209978, 45840, 316, 10, 23, "Index",
  CellTags->"MetropolisDisequilibriumReduced"],
Cell[1210297, 45852, 272, 10, 23, "Index",
  CellTags->"Metropolis et al. 1954"],
Cell[1210572, 45864, 382, 14, 23, "Index",
  CellTags->"MFromC"],
Cell[1210957, 45880, 226, 10, 23, "Index",
  CellTags->"Migrate"],
Cell[1211186, 45892, 311, 11, 23, "Index",
  CellTags->"MigrateExact"],
Cell[1211500, 45905, 646, 21, 53, "IndexSubentry",
  CellTags->"MigrateExact"],
Cell[1212149, 45928, 298, 11, 23, "Index",
  CellTags->"Migration"],
Cell[1212450, 45941, 2215, 79, 188, "IndexSubentry",
  CellTags->"Migration"],
Cell[1214668, 46022, 491, 15, 23, "Index",
  CellTags->"MigrationOrder"],
Cell[1215162, 46039, 524, 16, 38, "IndexSubentry",
  CellTags->"MigrationOrder"],
Cell[1215689, 46057, 308, 11, 23, "Index",
  CellTags->"MigrationRate"],
Cell[1216000, 46070, 311, 11, 23, "Index",
  CellTags->"MigrationSet"],
Cell[1216314, 46083, 259, 10, 23, "Index",
  CellTags->"Missing data"],
Cell[1216576, 46095, 352, 14, 23, "Index",
  CellTags->"Moment"],
Cell[1216931, 46111, 305, 10, 23, "Index",
  CellTags->"MomentAfterMigration"],
Cell[1217239, 46123, 332, 11, 23, "Index",
  CellTags->"MomentAfterRecombination"],
Cell[1217574, 46136, 258, 10, 23, "Index",
  CellTags->"MomentEquilibrium"],
Cell[1217835, 46148, 315, 11, 23, "Index",
  CellTags->"MomentGeneratingFunction"],
Cell[1218153, 46161, 582, 21, 53, "IndexSubentry",
  CellTags->"MomentGeneratingFunction"],
Cell[1218738, 46184, 267, 10, 23, "Index",
  CellTags->"MomentLimits"],
Cell[1219008, 46196, 232, 10, 23, "Index",
  CellTags->"MomentNew"],
Cell[1219243, 46208, 262, 10, 23, "Index",
  CellTags->"MomentReduced"],
Cell[1219508, 46220, 222, 10, 23, "Index",
  CellTags->"Moments"],
Cell[1219733, 46232, 1552, 53, 128, "IndexSubentry",
  CellTags->"Moments"],
Cell[1221288, 46287, 289, 10, 23, "Index",
  CellTags->"MomentsFromG"],
Cell[1221580, 46299, 269, 10, 23, "Index",
  CellTags->"MomentSimple"],
Cell[1221852, 46311, 302, 10, 23, "Index",
  CellTags->"MonteCarloGriffithsTavare"],
Cell[1222157, 46323, 302, 10, 23, "Index",
  CellTags->"MonteCarloProbability"],
Cell[1222462, 46335, 258, 10, 23, "Index",
  CellTags->"Mortality"],
Cell[1222723, 46347, 299, 10, 23, "Index",
  CellTags->"MostRecentCommonAncestor"],
Cell[1223025, 46359, 374, 14, 23, "Index",
  CellTags->"MToC"],
Cell[1223402, 46375, 410, 14, 23, "Index",
  CellTags->"MToCEquations"],
Cell[1223815, 46391, 263, 10, 23, "Index",
  CellTags->"Muddle"],
Cell[1224081, 46403, 295, 11, 23, "Index",
  CellTags->"Multilocus algebra"],
Cell[1224379, 46416, 1010, 36, 68, "IndexSubentry",
  CellTags->"Multilocus algebra"],
Cell[1225392, 46454, 408, 15, 23, "Index",
  CellTags->"Multilocus MS"],
Cell[1225803, 46471, 264, 11, 23, "Index",
  CellTags->"Multilocus notation"],
Cell[1226070, 46484, 344, 12, 23, "Index",
  CellTags->"Multinomial sampling"],
Cell[1226417, 46498, 332, 11, 23, "Index",
  CellTags->"MultinomialSamplingProbability"],
Cell[1226752, 46511, 289, 11, 23, "Index",
  CellTags->"Multiple alleles"],
Cell[1227044, 46524, 694, 27, 68, "IndexSubentry",
  CellTags->"Multiple alleles"],
Cell[1227741, 46553, 297, 11, 23, "Index",
  CellTags->"Multiple arguments"],
Cell[1228041, 46566, 336, 11, 23, "Index",
  CellTags->"Multiplicative models"],
Cell[1228380, 46579, 302, 11, 23, "Index",
  CellTags->"MUS"],
Cell[1228685, 46592, 667, 21, 53, "IndexSubentry",
  CellTags->"MUS"],
Cell[1229355, 46615, 287, 11, 23, "Index",
  CellTags->"Mutate"],
Cell[1229645, 46628, 607, 21, 53, "IndexSubentry",
  CellTags->"Mutate"],
Cell[1230255, 46651, 724, 22, 23, "Index",
  CellTags->"MutateCompiled"],
Cell[1230982, 46675, 263, 11, 23, "Index",
  CellTags->"Mutation"],
Cell[1231248, 46688, 1083, 33, 53, "IndexSubentry",
  CellTags->"Mutation"],
Cell[1232334, 46723, 275, 10, 23, "Index",
  CellTags->"MutationInterval"],
Cell[1232612, 46735, 297, 10, 23, "Index",
  CellTags->"MutationLabels"],
Cell[1232912, 46747, 269, 10, 23, "Index",
  CellTags->"MutationOrigin"],
Cell[1233184, 46759, 261, 10, 23, "Index",
  CellTags->"MutationRate"],
Cell[1233448, 46771, 276, 11, 23, "Index",
  CellTags->"Mutations"],
Cell[1233727, 46784, 398, 14, 23, "Index",
  CellTags->"MVariables"],
Cell[1234128, 46800, 293, 11, 23, "Index",
  CellTags->"Negative binomial"],
Cell[1234424, 46813, 828, 27, 68, "IndexSubentry",
  CellTags->"Negative binomial"],
Cell[1235255, 46842, 339, 11, 23, "Index",
  CellTags->"NegativeBinomialLogLikelihood"],
Cell[1235597, 46855, 302, 10, 23, "Index",
  CellTags->"NegativeBinomialMLE"],
Cell[1235902, 46867, 368, 11, 23, "Index",
  CellTags->"NegativeHypergeometricDistribution"],
Cell[1236273, 46880, 273, 10, 23, "Index",
  CellTags->"NeighbourArray"],
Cell[1236549, 46892, 261, 10, 23, "Index",
  CellTags->"Neighbours"],
Cell[1236813, 46904, 280, 10, 23, "Index",
  CellTags->"NetCovariance"],
Cell[1237096, 46916, 255, 10, 23, "Index",
  CellTags->"NetFecundity"],
Cell[1237354, 46928, 255, 10, 23, "Index",
  CellTags->"NetMortality"],
Cell[1237612, 46940, 384, 14, 23, "Index",
  CellTags->"NetRecombination"],
Cell[1237999, 46956, 438, 15, 38, "IndexSubentry",
  CellTags->"NetRecombination"],
Cell[1238440, 46973, 285, 11, 23, "Index",
  CellTags->"Neutral marker"],
Cell[1238728, 46986, 309, 10, 23, "Index",
  CellTags->"NeutralRepresentations"],
Cell[1239040, 46998, 309, 11, 23, "Index",
  CellTags->"NewGametes"],
Cell[1239352, 47011, 1653, 52, 98, "IndexSubentry",
  CellTags->"NewGametes"],
Cell[1241008, 47065, 249, 10, 23, "Index",
  CellTags->"NewS"],
Cell[1241260, 47077, 380, 14, 23, "Index",
  CellTags->"Node"],
Cell[1241643, 47093, 404, 14, 23, "Index",
  CellTags->"NodeFunction"],
Cell[1242050, 47109, 275, 9, 23, "IndexSubentry",
  CellTags->"NodeFunction"],
Cell[1242328, 47120, 257, 10, 23, "Index",
  CellTags->"NodeLabels"],
Cell[1242588, 47132, 257, 10, 23, "Index",
  CellTags->"NodeOffset"],
Cell[1242848, 47144, 246, 10, 23, "Index",
  CellTags->"Nodes"],
Cell[1243097, 47156, 263, 10, 23, "Index",
  CellTags->"NonMendelian"],
Cell[1243363, 47168, 366, 13, 23, "IndexSubentry",
  CellTags->"NonMendelian"],
Cell[1243732, 47183, 323, 11, 23, "Index",
  CellTags->"NonNeutralRepresentations"],
Cell[1244058, 47196, 331, 11, 23, "Index",
  CellTags->"NonSymmetricRepresentations"],
Cell[1244392, 47209, 284, 10, 23, "Index",
  CellTags->"Normalisation"],
Cell[1244679, 47221, 275, 10, 23, "Index",
  CellTags->"Normalised"],
Cell[1244957, 47233, 287, 11, 23, "Index",
  CellTags->"Notation"],
Cell[1245247, 47246, 727, 27, 68, "IndexSubentry",
  CellTags->"Notation"],
Cell[1245977, 47275, 253, 10, 23, "Index",
  CellTags->"Notation Package"],
Cell[1246233, 47287, 261, 10, 23, "Index",
  CellTags->"NumberedLink"],
Cell[1246497, 47299, 271, 11, 23, "Index",
  CellTags->"Numbering"],
Cell[1246771, 47312, 560, 21, 53, "IndexSubentry",
  CellTags->"Numbering"],
Cell[1247334, 47335, 318, 11, 23, "Index",
  CellTags->"NumberOfCoalescences"],
Cell[1247655, 47348, 266, 10, 23, "Index",
  CellTags->"NumberOfGenes"],
Cell[1247924, 47360, 915, 28, 68, "IndexSubentry",
  CellTags->"NumberOfGenes"],
Cell[1248842, 47390, 281, 10, 23, "Index",
  CellTags->"NumberOfGenesTable"],
Cell[1249126, 47402, 416, 14, 23, "Index",
  CellTags->"NumberOfIndividuals"],
Cell[1249545, 47418, 299, 10, 23, "Index",
  CellTags->"NumberOfIndividualsTable"],
Cell[1249847, 47430, 279, 10, 23, "Index",
  CellTags->"NumberOfLineages"],
Cell[1250129, 47442, 263, 10, 23, "Index",
  CellTags->"NumberOfLoci"],
Cell[1250395, 47454, 278, 10, 23, "Index",
  CellTags->"NumberOfMutations"],
Cell[1250676, 47466, 317, 10, 23, "Index",
  CellTags->"NumberOfPossibleCoalescences"],
Cell[1250996, 47478, 287, 10, 23, "Index",
  CellTags->"NumberOfSamplePartitions"],
Cell[1251286, 47490, 278, 10, 23, "Index",
  CellTags->"NumberOfSetPartitions"],
Cell[1251567, 47502, 325, 11, 23, "Index",
  CellTags->"NumericalModel"],
Cell[1251895, 47515, 294, 9, 23, "IndexSubentry",
  CellTags->"NumericalModel"],
Cell[1252192, 47526, 301, 11, 23, "Index",
  CellTags->"Numerical models"],
Cell[1252496, 47539, 1071, 37, 83, "IndexSubentry",
  CellTags->"Numerical models"],
Cell[1253570, 47578, 420, 14, 23, "Index",
  CellTags->"Observable genotype"],
Cell[1253993, 47594, 250, 11, 23, "Index",
  CellTags->"Obsolete"],
Cell[1254246, 47607, 3402, 121, 293, "IndexSubentry",
  CellTags->"Obsolete"],
Cell[1257651, 47730, 258, 10, 23, "Index",
  CellTags->"Offspring"],
Cell[1257912, 47742, 266, 11, 23, "Index",
  CellTags->"Ordered"],
Cell[1258181, 47755, 264, 10, 23, "Index",
  CellTags->"Orive & Barton 1999"],
Cell[1258448, 47767, 247, 10, 23, "Index",
  CellTags->"OtherSex"],
Cell[1258698, 47779, 275, 11, 23, "Index",
  CellTags->"Packages"],
Cell[1258976, 47792, 839, 31, 68, "IndexSubentry",
  CellTags->"Packages"],
Cell[1259818, 47825, 235, 10, 23, "Index",
  CellTags->"PackageSaver"],
Cell[1260056, 47837, 262, 11, 23, "Index",
  CellTags->"Partitions"],
Cell[1260321, 47850, 426, 15, 38, "IndexSubentry",
  CellTags->"Partitions"],
Cell[1260750, 47867, 251, 10, 23, "Index",
  CellTags->"PartitionSet"],
Cell[1261004, 47879, 414, 14, 23, "Index",
  CellTags->"Paternal inheritance"],
Cell[1261421, 47895, 277, 11, 23, "Index",
  CellTags->"PaternalLoci"],
Cell[1261701, 47908, 444, 15, 38, "IndexSubentry",
  CellTags->"PaternalLoci"],
Cell[1262148, 47925, 274, 10, 23, "Index",
  CellTags->"PatternFree"],
Cell[1262425, 47937, 281, 11, 23, "Index",
  CellTags->"Permutations"],
Cell[1262709, 47950, 325, 11, 23, "Index",
  CellTags->"Permutations in defining coefficients"],
Cell[1263037, 47963, 269, 11, 23, "Index",
  CellTags->"Phenotypes"],
Cell[1263309, 47976, 264, 10, 23, "Index",
  CellTags->"Phipps & Brill 1995"],
Cell[1263576, 47988, 245, 10, 23, "Index",
  CellTags->"Ploidy"],
Cell[1263824, 48000, 271, 10, 23, "Index",
  CellTags->"PloidyWeightList"],
Cell[1264098, 48012, 266, 10, 23, "Index",
  CellTags->"PlotGenealogy"],
Cell[1264367, 48024, 247, 10, 23, "Index",
  CellTags->"PlotLogL"],
Cell[1264617, 48036, 346, 11, 23, "Index",
  CellTags->"PopulationDisequilibrium"],
Cell[1264966, 48049, 274, 10, 23, "Index",
  CellTags->"PopulationExpectation"],
Cell[1265243, 48061, 271, 9, 23, "IndexSubentry",
  CellTags->"PopulationExpectation"],
Cell[1265517, 48072, 323, 11, 23, "Index",
  CellTags->"PopulationRepresentations"],
Cell[1265843, 48085, 380, 14, 23, "Index",
  CellTags->"Position"],
Cell[1266226, 48101, 442, 15, 38, "IndexSubentry",
  CellTags->"Position"],
Cell[1266671, 48118, 270, 10, 23, "Index",
  CellTags->"PositionsList"],
Cell[1266944, 48130, 276, 10, 23, "Index",
  CellTags->"PositionsMatrix"],
Cell[1267223, 48142, 305, 10, 23, "Index",
  CellTags->"PossibleCoalescenceOrder"],
Cell[1267531, 48154, 303, 10, 23, "Index",
  CellTags->"PossibleDiploidGenotypes"],
Cell[1267837, 48166, 272, 10, 23, "Index",
  CellTags->"PossibleGenotypes"],
Cell[1268112, 48178, 311, 11, 23, "Index",
  CellTags->"PowerF"],
Cell[1268426, 48191, 871, 27, 68, "IndexSubentry",
  CellTags->"PowerF"],
Cell[1269300, 48220, 279, 10, 23, "Index",
  CellTags->"PresentOneWayTable"],
Cell[1269582, 48232, 277, 10, 23, "Index",
  CellTags->"PresentPairwiseTable"],
Cell[1269862, 48244, 265, 10, 23, "Index",
  CellTags->"PresentResults"],
Cell[1270130, 48256, 317, 11, 23, "Index",
  CellTags->"Principal components"],
Cell[1270450, 48269, 273, 10, 23, "Index",
  CellTags->"PrintDetails"],
Cell[1270726, 48281, 275, 11, 23, "Index",
  CellTags->"Problems"],
Cell[1271004, 48294, 587, 18, 23, "IndexSubentry",
  CellTags->"Problems"],
Cell[1271594, 48314, 250, 11, 23, "Index",
  CellTags->"Products"],
Cell[1271847, 48327, 237, 10, 23, "Index",
  CellTags->"ProductSum"],
Cell[1272087, 48339, 249, 9, 23, "IndexSubentry",
  CellTags->"ProductSum"],
Cell[1272339, 48350, 263, 11, 23, "Index",
  CellTags->"QLE"],
Cell[1272605, 48363, 258, 9, 23, "IndexSubentry",
  CellTags->"QLE"],
Cell[1272866, 48374, 310, 11, 23, "Index",
  CellTags->"Quasi-linkage equilibrium"],
Cell[1273179, 48387, 312, 10, 23, "Index",
  CellTags->"RandomBottleneckedGenealogy"],
Cell[1273494, 48399, 299, 10, 23, "Index",
  CellTags->"RandomCoalescenceOrder"],
Cell[1273796, 48411, 326, 11, 23, "Index",
  CellTags->"RandomCoalescenceTimes"],
Cell[1274125, 48424, 288, 10, 23, "Index",
  CellTags->"RandomCum"],
Cell[1274416, 48436, 330, 12, 23, "Index",
  CellTags->"Random drift"],
Cell[1274749, 48450, 2349, 77, 158, "IndexSubentry",
  CellTags->"Random drift"],
Cell[1277101, 48529, 286, 11, 23, "Index",
  CellTags->"RandomDrift"],
Cell[1277390, 48542, 956, 27, 38, "IndexSubentry",
  CellTags->"RandomDrift"],
Cell[1278349, 48571, 259, 10, 23, "Index",
  CellTags->"RandomFamilies"],
Cell[1278611, 48583, 261, 10, 23, "Index",
  CellTags->"RandomFamily"],
Cell[1278875, 48595, 273, 9, 23, "IndexSubentry",
  CellTags->"RandomFamily"],
Cell[1279151, 48606, 299, 11, 23, "Index",
  CellTags->"Random genealogies"],
Cell[1279453, 48619, 270, 10, 23, "Index",
  CellTags->"RandomGenealogy"],
Cell[1279726, 48631, 241, 10, 23, "Index",
  CellTags->"RandomList"],
Cell[1279970, 48643, 259, 9, 23, "IndexSubentry",
  CellTags->"RandomList"],
Cell[1280232, 48654, 259, 11, 23, "Index",
  CellTags->"Random lists"],
Cell[1280494, 48667, 289, 10, 23, "Index",
  CellTags->"RandomMating"],
Cell[1280786, 48679, 286, 10, 23, "Index",
  CellTags->"RandomMultinomial"],
Cell[1281075, 48691, 277, 10, 23, "Index",
  CellTags->"RandomPreviousFamily"],
Cell[1281355, 48703, 288, 10, 23, "Index",
  CellTags->"Random sampling"],
Cell[1281646, 48715, 415, 15, 38, "IndexSubentry",
  CellTags->"Random sampling"],
Cell[1282064, 48732, 236, 10, 23, "Index",
  CellTags->"RandomSet"],
Cell[1282303, 48744, 371, 14, 23, "Index",
  CellTags->"Random union"],
Cell[1282677, 48760, 306, 9, 23, "IndexSubentry",
  CellTags->"Random union"],
Cell[1282986, 48771, 244, 10, 23, "Index",
  CellTags->"RandomUnion"],
Cell[1283233, 48783, 276, 10, 23, "Index",
  CellTags->"RandomUnionMethod"],
Cell[1283512, 48795, 260, 10, 23, "Index",
  CellTags->"RandomUnionObsolete"],
Cell[1283775, 48807, 256, 11, 23, "Index",
  CellTags->"Random walk"],
Cell[1284034, 48820, 378, 14, 23, "Index",
  CellTags->"Recombination"],
Cell[1284415, 48836, 1122, 39, 98, "IndexSubentry",
  CellTags->"Recombination"],
Cell[1285540, 48877, 321, 11, 23, "Index",
  CellTags->"RecombinationRate"],
Cell[1285864, 48890, 450, 15, 23, "Index",
  CellTags->"RecombinationSet"],
Cell[1286317, 48907, 283, 10, 23, "Index",
  CellTags->"Recombined"],
Cell[1286603, 48919, 262, 10, 23, "Index",
  CellTags->"ReducedData"],
Cell[1286868, 48931, 316, 11, 23, "Index",
  CellTags->"ReferencePoint"],
Cell[1287187, 48944, 273, 10, 23, "Index",
  CellTags->"ReferencePointMean"],
Cell[1287463, 48956, 1125, 37, 53, "IndexSubentry",
  CellTags->"ReferencePointMean"],
Cell[1288591, 48995, 273, 10, 23, "Index",
  CellTags->"ReferencePointSame"],
Cell[1288867, 49007, 273, 10, 23, "Index",
  CellTags->"ReferencePointZero"],
Cell[1289143, 49019, 400, 14, 23, "Index",
  CellTags->"Reference values"],
Cell[1289546, 49035, 472, 15, 38, "IndexSubentry",
  CellTags->"Reference values"],
Cell[1290021, 49052, 238, 10, 23, "Index",
  CellTags->"RemoveTag"],
Cell[1290262, 49064, 239, 10, 23, "Index",
  CellTags->"Repeat"],
Cell[1290504, 49076, 232, 10, 23, "Index",
  CellTags->"Replace"],
Cell[1290739, 49088, 262, 11, 23, "Index",
  CellTags->"ReplaceAllSpecial"],
Cell[1291004, 49101, 278, 11, 23, "Index",
  CellTags->"ReplaceRepeatedSpecial"],
Cell[1291285, 49114, 311, 11, 23, "Index",
  CellTags->"Representations"],
Cell[1291599, 49127, 308, 10, 23, "IndexSubentry",
  CellTags->"Representations"],
Cell[1291910, 49139, 286, 11, 23, "Index",
  CellTags->"Reproduction"],
Cell[1292199, 49152, 222, 10, 23, "Index",
  CellTags->"Reverse"],
Cell[1292424, 49164, 280, 10, 23, "Index",
  CellTags->"RootedGenealogy"],
Cell[1292707, 49176, 244, 10, 23, "Index",
  CellTags->"Rules"],
Cell[1292954, 49188, 234, 9, 23, "IndexSubentry",
  CellTags->"Rules"],
Cell[1293191, 49199, 251, 10, 23, "Index",
  CellTags->"SampleCovariance"],
Cell[1293445, 49211, 278, 10, 23, "Index",
  CellTags->"SampleIndividuals"],
Cell[1293726, 49223, 260, 10, 23, "Index",
  CellTags->"SamplePartition"],
Cell[1293989, 49235, 261, 11, 23, "Index",
  CellTags->"Sampling"],
Cell[1294253, 49248, 319, 11, 23, "Index",
  CellTags->"Scripts and faces"],
Cell[1294575, 49261, 414, 14, 23, "Index",
  CellTags->"SegregationRatio"],
Cell[1294992, 49277, 321, 11, 23, "Index",
  CellTags->"SelectContext"],
Cell[1295316, 49290, 272, 10, 23, "Index",
  CellTags->"SelectIndividuals"],
Cell[1295591, 49302, 232, 10, 23, "Index",
  CellTags->"Selection"],
Cell[1295826, 49314, 1704, 61, 143, "IndexSubentry",
  CellTags->"Selection"],
Cell[1297533, 49377, 437, 15, 23, "Index",
  CellTags->"SelectionCoefficient"],
Cell[1297973, 49394, 327, 11, 23, "Index",
  CellTags->"Selection coefficients"],
Cell[1298303, 49407, 519, 19, 38, "IndexSubentry",
  CellTags->"Selection coefficients"],
Cell[1298825, 49428, 317, 11, 23, "Index",
  CellTags->"SelectionExact"],
Cell[1299145, 49441, 658, 21, 53, "IndexSubentry",
  CellTags->"SelectionExact"],
Cell[1299806, 49464, 290, 11, 23, "Index",
  CellTags->"Selection on diploids"],
Cell[1300099, 49477, 888, 33, 83, "IndexSubentry",
  CellTags->"Selection on diploids"],
Cell[1300990, 49512, 304, 11, 23, "Index",
  CellTags->"SelectionRate"],
Cell[1301297, 49525, 251, 10, 23, "Index",
  CellTags->"SelectLoci"],
Cell[1301551, 49537, 217, 10, 23, "Index",
  CellTags->"Selfing"],
Cell[1301771, 49549, 235, 10, 23, "Index",
  CellTags->"Separate"],
Cell[1302009, 49561, 258, 11, 23, "Index",
  CellTags->"Servedio"],
Cell[1302270, 49574, 339, 12, 23, "Index",
  CellTags->"Set"],
Cell[1302612, 49588, 323, 10, 23, "IndexSubentry",
  CellTags->"Set"],
Cell[1302938, 49600, 293, 11, 23, "Index",
  CellTags->"Set manipulation"],
Cell[1303234, 49613, 251, 10, 23, "Index",
  CellTags->"SetPartition"],
Cell[1303488, 49625, 304, 11, 23, "Index",
  CellTags->"Sets of loci"],
Cell[1303795, 49638, 216, 10, 23, "Index",
  CellTags->"Sex"],
Cell[1304014, 49650, 394, 14, 23, "Index",
  CellTags->"Sex linkage"],
Cell[1304411, 49666, 236, 9, 23, "IndexSubentry",
  CellTags->"Sex linkage"],
Cell[1304650, 49677, 240, 10, 23, "Index",
  CellTags->"SexOfOrigin"],
Cell[1304893, 49689, 267, 10, 23, "Index",
  CellTags->"Sexual selection"],
Cell[1305163, 49701, 1209, 45, 113, "IndexSubentry",
  CellTags->"Sexual selection"],
Cell[1306375, 49748, 265, 10, 23, "Index",
  CellTags->"ShortContext"],
Cell[1306643, 49760, 278, 10, 23, "Index",
  CellTags->"SigmaMatrix"],
Cell[1306924, 49772, 247, 10, 23, "Index",
  CellTags->"SignMask"],
Cell[1307174, 49784, 236, 10, 23, "Index",
  CellTags->"SimplifyAddUp"],
Cell[1307413, 49796, 239, 10, 23, "Index",
  CellTags->"SimplifyAddUpQ"],
Cell[1307655, 49808, 261, 10, 23, "Index",
  CellTags->"SimplifyFamilies"],
Cell[1307919, 49820, 335, 11, 23, "Index",
  CellTags->"Simulating individuals"],
Cell[1308257, 49833, 503, 15, 38, "IndexSubentry",
  CellTags->"Simulating individuals"],
Cell[1308763, 49850, 284, 10, 23, "Index",
  CellTags->"SizeOfGenealogyPlot"],
Cell[1309050, 49862, 279, 10, 23, "Index",
  CellTags->"Slatkin & Excoffier 1996"],
Cell[1309332, 49874, 239, 10, 23, "Index",
  CellTags->"SlowChange"],
Cell[1309574, 49886, 274, 10, 23, "Index",
  CellTags->"SortByClass"],
Cell[1309851, 49898, 284, 9, 23, "IndexSubentry",
  CellTags->"SortByClass"],
Cell[1310138, 49909, 231, 10, 23, "Index",
  CellTags->"SortByHead"],
Cell[1310372, 49921, 254, 10, 23, "Index",
  CellTags->"SpatialCovariance"],
Cell[1310629, 49933, 323, 11, 23, "Index",
  CellTags->"Spatially varying selection"],
Cell[1310955, 49946, 268, 10, 23, "Index",
  CellTags->"Special notation"],
Cell[1311226, 49958, 239, 10, 23, "Index",
  CellTags->"SplitSet"],
Cell[1311468, 49970, 301, 11, 23, "Index",
  CellTags->"Stabilising selection"],
Cell[1311772, 49983, 1135, 40, 98, "IndexSubentry",
  CellTags->"Stabilising selection"],
Cell[1312910, 50025, 411, 15, 23, "Index",
  CellTags->"Stability"],
Cell[1313324, 50042, 275, 9, 23, "IndexSubentry",
  CellTags->"Stability"],
Cell[1313602, 50053, 320, 11, 23, "Index",
  CellTags->"StabilityDirect"],
Cell[1313925, 50066, 280, 9, 23, "IndexSubentry",
  CellTags->"StabilityDirect"],
Cell[1314208, 50077, 422, 14, 23, "Index",
  CellTags->"StabilityK"],
Cell[1314633, 50093, 313, 11, 23, "Index",
  CellTags->"StabilityKTable"],
Cell[1314949, 50106, 282, 10, 23, "Index",
  CellTags->"StabilityMatrix"],
Cell[1315234, 50118, 293, 11, 23, "Index",
  CellTags->"Stage"],
Cell[1315530, 50131, 225, 10, 23, "Index",
  CellTags->"Stages"],
Cell[1315758, 50143, 288, 9, 23, "IndexSubentry",
  CellTags->"Stages"],
Cell[1316049, 50154, 266, 10, 23, "Index",
  CellTags->"StandardPartition"],
Cell[1316318, 50166, 269, 10, 23, "Index",
  CellTags->"StandardPartitionQ"],
Cell[1316590, 50178, 285, 10, 23, "Index",
  CellTags->"StartingStepSize"],
Cell[1316878, 50190, 357, 12, 23, "Index",
  CellTags->"Stepping-stone migration"],
Cell[1317238, 50204, 347, 12, 23, "Index",
  CellTags->"Stepping-stone model"],
Cell[1317588, 50218, 501, 16, 38, "IndexSubentry",
  CellTags->"Stepping-stone model"],
Cell[1318092, 50236, 323, 11, 23, "Index",
  CellTags->"StoreExact"],
Cell[1318418, 50249, 1518, 45, 113, "IndexSubentry",
  CellTags->"StoreExact"],
Cell[1319939, 50296, 450, 15, 23, "Index",
  CellTags->"StoreResults"],
Cell[1320392, 50313, 813, 24, 38, "IndexSubentry",
  CellTags->"StoreResults"],
Cell[1321208, 50339, 264, 10, 23, "Index",
  CellTags->"StructuredArray"],
Cell[1321475, 50351, 304, 10, 23, "Index",
  CellTags->"StructuredInitialParameters"],
Cell[1321782, 50363, 327, 11, 23, "Index",
  CellTags->"StructuredLogLikelihood"],
Cell[1322112, 50376, 434, 14, 23, "Index",
  CellTags->"StructuredMLE"],
Cell[1322549, 50392, 264, 10, 23, "Index",
  CellTags->"StructuredModel"],
Cell[1322816, 50404, 288, 10, 23, "Index",
  CellTags->"StructuredModelReduce"],
Cell[1323107, 50416, 262, 11, 23, "Index",
  CellTags->"Structured models"],
Cell[1323372, 50429, 272, 9, 23, "IndexSubentry",
  CellTags->"Structured models"],
Cell[1323647, 50440, 286, 10, 23, "Index",
  CellTags->"StructuredParameter"],
Cell[1323936, 50452, 332, 11, 23, "Index",
  CellTags->"StructuredVariance"],
Cell[1324271, 50465, 248, 11, 23, "Index",
  CellTags->"Style sheets"],
Cell[1324522, 50478, 272, 10, 23, "Index",
  CellTags->"Subdivide"],
Cell[1324797, 50490, 309, 11, 23, "Index",
  CellTags->"Subscripts"],
Cell[1325109, 50503, 222, 10, 23, "Index",
  CellTags->"Subsets"],
Cell[1325334, 50515, 366, 15, 38, "IndexSubentry",
  CellTags->"Subsets"],
Cell[1325703, 50532, 234, 11, 23, "Index",
  CellTags->"Sums"],
Cell[1325940, 50545, 344, 11, 23, "Index",
  CellTags->"Symmetric cline"],
Cell[1326287, 50558, 317, 9, 23, "IndexSubentry",
  CellTags->"Symmetric cline"],
Cell[1326607, 50569, 331, 11, 23, "Index",
  CellTags->"SymmetricDiploidFrequencies"],
Cell[1326941, 50582, 331, 11, 23, "Index",
  CellTags->"SymmetricHaploidFrequencies"],
Cell[1327275, 50595, 431, 15, 23, "Index",
  CellTags->"Symmetric model"],
Cell[1327709, 50612, 1473, 49, 113, "IndexSubentry",
  CellTags->"Symmetric model"],
Cell[1329185, 50663, 477, 15, 23, "Index",
  CellTags->"SymmetricNeutralDiploidFrequencies"],
Cell[1329665, 50680, 477, 15, 23, "Index",
  CellTags->"SymmetricNeutralHaploidFrequencies"],
Cell[1330145, 50697, 279, 10, 23, "Index",
  CellTags->"SymmetricRecombination"],
Cell[1330427, 50709, 315, 10, 23, "Index",
  CellTags->"SymmetricRepresentations"],
Cell[1330745, 50721, 259, 10, 23, "Index",
  CellTags->"SymmetricSexes"],
Cell[1331007, 50733, 356, 14, 23, "Index",
  CellTags->"Symmetrise"],
Cell[1331366, 50749, 234, 11, 23, "Index",
  CellTags->"T"],
Cell[1331603, 50762, 277, 11, 23, "Index",
  CellTags->"Table"],
Cell[1331883, 50775, 220, 10, 23, "Index",
  CellTags->"Tag"],
Cell[1332106, 50787, 260, 11, 23, "Index",
  CellTags->"Tags"],
Cell[1332369, 50800, 295, 10, 23, "IndexSubentry",
  CellTags->"Tags"],
Cell[1332667, 50812, 390, 12, 23, "Index",
  CellTags->"TakeAway"],
Cell[1333060, 50826, 260, 10, 23, "Index",
  CellTags->"TakeOptions"],
Cell[1333323, 50838, 237, 11, 23, "Index",
  CellTags->"Time"],
Cell[1333563, 50851, 346, 14, 23, "Index",
  CellTags->"TimesUp"],
Cell[1333912, 50867, 375, 15, 38, "IndexSubentry",
  CellTags->"TimesUp"],
Cell[1334290, 50884, 248, 10, 23, "Index",
  CellTags->"ToBaake"],
Cell[1334541, 50896, 254, 10, 23, "Index",
  CellTags->"ToBennett"],
Cell[1334798, 50908, 284, 10, 23, "Index",
  CellTags->"ToBennettExpression"],
Cell[1335085, 50920, 260, 10, 23, "Index",
  CellTags->"ToCumulants"],
Cell[1335348, 50932, 254, 10, 23, "Index",
  CellTags->"ToMoments"],
Cell[1335605, 50944, 296, 10, 23, "Index",
  CellTags->"ToPopulationCumulants"],
Cell[1335904, 50956, 290, 10, 23, "Index",
  CellTags->"ToPopulationMoments"],
Cell[1336197, 50968, 286, 10, 23, "Index",
  CellTags->"TotalLength"],
Cell[1336486, 50980, 252, 10, 23, "Index",
  CellTags->"TotalNumber"],
Cell[1336741, 50992, 339, 12, 23, "Index",
  CellTags->"Trait"],
Cell[1337083, 51006, 271, 10, 23, "Index",
  CellTags->"TransformedRange"],
Cell[1337357, 51018, 291, 10, 23, "Index",
  CellTags->"TransformInformation"],
Cell[1337651, 51030, 269, 10, 23, "Index",
  CellTags->"TransmissionRule"],
Cell[1337923, 51042, 300, 11, 23, "Index",
  CellTags->"Transmission rules"],
Cell[1338226, 51055, 647, 21, 53, "IndexSubentry",
  CellTags->"Transmission rules"],
Cell[1338876, 51078, 272, 10, 23, "Index",
  CellTags->"TriDiagonalMatrix"],
Cell[1339151, 51090, 352, 12, 23, "Index",
  CellTags->"TruncationSelection"],
Cell[1339506, 51104, 318, 9, 23, "IndexSubentry",
  CellTags->"TruncationSelection"],
Cell[1339827, 51115, 298, 10, 23, "Index",
  CellTags->"Turelli and Barton 1994"],
Cell[1340128, 51127, 270, 10, 23, "Index",
  CellTags->"Turelli & Barton 1994"],
Cell[1340401, 51139, 240, 10, 23, "Index",
  CellTags->"Two alleles"],
Cell[1340644, 51151, 360, 13, 23, "IndexSubentry",
  CellTags->"Two alleles"],
Cell[1341007, 51166, 302, 11, 23, "Index",
  CellTags->"UMS"],
Cell[1341312, 51179, 667, 21, 53, "IndexSubentry",
  CellTags->"UMS"],
Cell[1341982, 51202, 261, 10, 23, "Index",
  CellTags->"UnionOfGametes"],
Cell[1342246, 51214, 276, 10, 23, "Index",
  CellTags->"UnlinkedRecombination"],
Cell[1342525, 51226, 286, 10, 23, "Index",
  CellTags->"UnrootedGenealogy"],
Cell[1342814, 51238, 269, 10, 23, "Index",
  CellTags->"UpperOffDiagonal"],
Cell[1343086, 51250, 302, 11, 23, "Index",
  CellTags->"USM"],
Cell[1343391, 51263, 667, 21, 53, "IndexSubentry",
  CellTags->"USM"],
Cell[1344061, 51286, 332, 11, 23, "Index",
  CellTags->"VarianceComponents"],
Cell[1344396, 51299, 263, 9, 23, "IndexSubentry",
  CellTags->"VarianceComponents"],
Cell[1344662, 51310, 253, 11, 23, "Index",
  CellTags->"Versions"],
Cell[1344918, 51323, 260, 11, 23, "Index",
  CellTags->"WLinkedLoci"],
Cell[1345181, 51336, 441, 15, 38, "IndexSubentry",
  CellTags->"WLinkedLoci"],
Cell[1345625, 51353, 277, 10, 23, "Index",
  CellTags->"Wright-Fisher sampling"],
Cell[1345905, 51365, 247, 11, 15, "Index",
  CellTags->"X"],
Cell[1346155, 51378, 260, 11, 15, "Index",
  CellTags->"XLinkedLoci"],
Cell[1346418, 51391, 441, 15, 30, "IndexSubentry",
  CellTags->"XLinkedLoci"],
Cell[1346862, 51408, 260, 11, 15, "Index",
  CellTags->"YLinkedLoci"],
Cell[1347125, 51421, 441, 15, 30, "IndexSubentry",
  CellTags->"YLinkedLoci"],
Cell[1347569, 51438, 260, 11, 15, "Index",
  CellTags->"ZLinkedLoci"],
Cell[1347832, 51451, 441, 15, 30, "IndexSubentry",
  CellTags->"ZLinkedLoci"],
Cell[1348276, 51468, 411, 15, 15, "Index",
  CellTags->"Zygotes"],
Cell[1348690, 51485, 427, 15, 15, "Index",
  CellTags->"\[GothicA]"],
Cell[1349120, 51502, 419, 15, 15, "Index",
  CellTags->"\[GothicCapitalA]"],
Cell[1349542, 51519, 340, 11, 15, "Index",
  CellTags->"\[GothicCapitalC]"],
Cell[1349885, 51532, 612, 19, 15, "Index",
  CellTags->"\[GothicCapitalD]"],
Cell[1350500, 51553, 494, 16, 15, "Index",
  CellTags->"\!\(\(\[GothicCapitalG]\^\[RawStar]\)\)"],
Cell[1350997, 51571, 421, 15, 15, "Index",
  CellTags->"\[GothicCapitalG]"],
Cell[1351421, 51588, 435, 15, 15, "Index",
  CellTags->"\[GothicCapitalH]"],
Cell[1351859, 51605, 425, 15, 15, "Index",
  CellTags->"\[GothicCapitalJ]"],
Cell[1352287, 51622, 320, 11, 15, "Index",
  CellTags->"\[GothicK]"],
Cell[1352610, 51635, 377, 11, 15, "Index",
  CellTags->"\[GothicCapitalK]"],
Cell[1352990, 51648, 308, 11, 15, "Index",
  CellTags->"\[GothicM]"],
Cell[1353301, 51661, 308, 11, 15, "Index",
  CellTags->"\[GothicP]"],
Cell[1353612, 51674, 369, 12, 15, "Index",
  CellTags->"\[GothicP]\[GothicQ]"],
Cell[1353984, 51688, 308, 11, 15, "Index",
  CellTags->"\[GothicQ]"],
Cell[1354295, 51701, 314, 11, 15, "Index",
  CellTags->"\[GothicR]"],
Cell[1354612, 51714, 301, 11, 15, "Index",
  CellTags->"\[GothicS]"],
Cell[1354916, 51727, 421, 15, 15, "Index",
  CellTags->"\[GothicCapitalZ]"],
Cell[1355340, 51744, 348, 11, 15, "Index",
  CellTags->"\[DoubleStruckCapitalG]"],
Cell[1355691, 51757, 322, 11, 15, "Index",
  CellTags->"\[DoubleStruckCapitalM]"],
Cell[1356016, 51770, 457, 15, 15, "Index",
  CellTags->"\[DoubleStruckCapitalR]"],
Cell[1356476, 51787, 318, 11, 15, "Index",
  CellTags->"\[DoubleStruckCapitalW]"],
Cell[1356797, 51800, 358, 12, 15, "Index",
  CellTags->"\[DoubleStruckCapitalZ]"],
Cell[1357158, 51814, 310, 11, 15, "Index",
  CellTags->"\[Gamma]"],
Cell[1357471, 51827, 304, 11, 15, "Index",
  CellTags->"\[Zeta]"],
Cell[1357778, 51840, 307, 11, 15, "Index",
  CellTags->"\[CapitalMu]"],
Cell[1358088, 51853, 312, 11, 15, "Index",
  CellTags->"\[Chi]"],
Cell[1358403, 51866, 296, 11, 15, "Index",
  CellTags->"\[Sampi]"],
Cell[1358702, 51879, 290, 10, 15, "Index",
  CellTags->"$MetropolisAdjustment"],
Cell[1358995, 51891, 317, 11, 15, "Index",
  CellTags->"\[WeierstrassP]"],
Cell[1359315, 51904, 449, 12, 15, "Index",
  CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],
Cell[1359767, 51918, 320, 11, 15, "Index",
  CellTags->"\[CircleDot]"],
Cell[1360090, 51931, 394, 12, 15, "Index",
  CellTags->"\[Backslash]"],
Cell[1360487, 51945, 450, 15, 15, "Index",
  CellTags->"\[Wedge]"],
Cell[1360940, 51962, 319, 11, 15, "Index",
  CellTags->"\[CirclePlus]"]
}, Closed]],

Cell[CellGroupData[{
Cell[1361296, 51978, 37, 0, 28, "Subsubsection"],
Cell[1361336, 51980, 247, 11, 23, "Index",
  CellTags->"|."],
Cell[1361586, 51993, 233, 11, 23, "Index",
  CellTags->"\\\\"],
Cell[1361822, 52006, 243, 11, 23, "Index",
  CellTags->"<>"],
Cell[1362068, 52019, 254, 11, 23, "Index",
  CellTags->"||."],
Cell[1362325, 52032, 271, 10, 23, "Index",
  CellTags->"AddGenealogy"],
Cell[1362599, 52044, 272, 10, 23, "Index",
  CellTags->"Additive models"],
Cell[1362874, 52056, 303, 11, 23, "Index",
  CellTags->"Additive selection"],
Cell[1363180, 52069, 713, 27, 68, "IndexSubentry",
  CellTags->"Additive selection"],
Cell[1363896, 52098, 256, 10, 23, "Index",
  CellTags->"AddNode"],
Cell[1364155, 52110, 229, 10, 23, "Index",
  CellTags->"AddTag"],
Cell[1364387, 52122, 334, 14, 23, "Index",
  CellTags->"AddUp"],
Cell[1364724, 52138, 492, 21, 53, "IndexSubentry",
  CellTags->"AddUp"],
Cell[1365219, 52161, 261, 10, 23, "Index",
  CellTags->"AdmixtureFrequency"],
Cell[1365483, 52173, 352, 14, 23, "Index",
  CellTags->"Admixture models"],
Cell[1365838, 52189, 843, 33, 83, "IndexSubentry",
  CellTags->"Admixture models"],
Cell[1366684, 52224, 408, 15, 23, "Index",
  CellTags->"Adults"],
Cell[1367095, 52241, 326, 11, 23, "Index",
  CellTags->"Allele frequencies"],
Cell[1367424, 52254, 470, 15, 23, "Index",
  CellTags->"AlleleFrequencies"],
Cell[1367897, 52271, 298, 10, 23, "Index",
  CellTags->"AlleleFrequencyMean"],
Cell[1368198, 52283, 952, 29, 68, "IndexSubentry",
  CellTags->"AlleleFrequencyMean"],
Cell[1369153, 52314, 314, 11, 23, "Index",
  CellTags->"AlleleFrequencyP"],
Cell[1369470, 52327, 304, 10, 23, "Index",
  CellTags->"AlleleFrequencyPermutations"],
Cell[1369777, 52339, 366, 12, 23, "Index",
  CellTags->"AlleleFrequencyPQ"],
Cell[1370146, 52353, 314, 11, 23, "Index",
  CellTags->"AlleleFrequencyQ"],
Cell[1370463, 52366, 301, 10, 23, "Index",
  CellTags->"AlleleFrequencyTable"],
Cell[1370767, 52378, 962, 30, 68, "IndexSubentry",
  CellTags->"AlleleFrequencyTable"],
Cell[1371732, 52410, 313, 11, 23, "Index",
  CellTags->"AllelicDeviation"],
Cell[1372048, 52423, 258, 11, 23, "Index",
  CellTags->"AllelicState"],
Cell[1372309, 52436, 258, 10, 23, "Index",
  CellTags->"AllSets"],
Cell[1372570, 52448, 273, 11, 23, "Index",
  CellTags->"Ancestors"],
Cell[1372846, 52461, 255, 10, 23, "Index",
  CellTags->"Ancestry"],
Cell[1373104, 52473, 334, 11, 23, "Index",
  CellTags->"Arbitrary sets of loci"],
Cell[1373441, 52486, 240, 10, 23, "Index",
  CellTags->"Arnold 1996"],
Cell[1373684, 52498, 414, 14, 23, "Index",
  CellTags->"Asmussen and Orive 2000"],
Cell[1374101, 52514, 266, 10, 23, "Index",
  CellTags->"Asmussen et al. 1987"],
Cell[1374370, 52526, 256, 10, 23, "Index",
  CellTags->"B"],
Cell[1374629, 52538, 276, 11, 23, "Index",
  CellTags->"Barrier"],
Cell[1374908, 52551, 276, 10, 23, "Index",
  CellTags->"BarrierStrength"],
Cell[1375187, 52563, 240, 10, 23, "Index",
  CellTags->"Barton 1986"],
Cell[1375430, 52575, 262, 10, 23, "Index",
  CellTags->"Barton 1995"],
Cell[1375695, 52587, 240, 10, 23, "Index",
  CellTags->"Barton 2000"],
Cell[1375938, 52599, 298, 10, 23, "Index",
  CellTags->"Barton and Turelli 1991"],
Cell[1376239, 52611, 261, 10, 23, "Index",
  CellTags->"Barton & Gale 1993"],
Cell[1376503, 52623, 264, 10, 23, "Index",
  CellTags->"Barton & Shpak 1999"],
Cell[1376770, 52635, 270, 10, 23, "Index",
  CellTags->"Barton & Turelli 1991"],
Cell[1377043, 52647, 236, 10, 23, "Index",
  CellTags->"Biallelic"],
Cell[1377282, 52659, 358, 13, 23, "IndexSubentry",
  CellTags->"Biallelic"],
Cell[1377643, 52674, 262, 10, 23, "Index",
  CellTags->"Birth"],
Cell[1377908, 52686, 258, 10, 23, "Index",
  CellTags->"BirthTime"],
Cell[1378169, 52698, 447, 15, 23, "Index",
  CellTags->"Boundary conditions"],
Cell[1378619, 52715, 240, 10, 23, "Index",
  CellTags->"Box"],
Cell[1378862, 52727, 246, 10, 23, "Index",
  CellTags->"Boxes"],
Cell[1379111, 52739, 293, 10, 23, "Index",
  CellTags->"Browser categories"],
Cell[1379407, 52751, 239, 11, 23, "Index",
  CellTags->"Bugs"],
Cell[1379649, 52764, 1583, 63, 158, "IndexSubentry",
  CellTags->"Bugs"],
Cell[1381235, 52829, 318, 11, 23, "Index",
  CellTags->"ChangeContext"],
Cell[1381556, 52842, 238, 10, 23, "Index",
  CellTags->"ChangeSex"],
Cell[1381797, 52854, 289, 10, 23, "Index",
  CellTags->"ClassToGenotypes"],
Cell[1382089, 52866, 253, 11, 23, "Index",
  CellTags->"Cline"],
Cell[1382345, 52879, 2662, 78, 113, "IndexSubentry",
  CellTags->"Cline"],
Cell[1385010, 52959, 325, 11, 23, "Index",
  CellTags->"ClineGradient"],
Cell[1385338, 52972, 323, 11, 23, "Index",
  CellTags->"ClineWidth"],
Cell[1385664, 52985, 695, 21, 53, "IndexSubentry",
  CellTags->"ClineWidth"],
Cell[1386362, 53008, 329, 11, 23, "Index",
  CellTags->"CoalescenceDistribution"],
Cell[1386694, 53021, 282, 10, 23, "Index",
  CellTags->"CollapseGenealogy"],
Cell[1386979, 53033, 232, 10, 23, "Index",
  CellTags->"Combine"],
Cell[1387214, 53045, 256, 10, 23, "Index",
  CellTags->"CompareLogL"],
Cell[1387473, 53057, 1075, 31, 38, "Index",
  CellTags->"Compiled"],
Cell[1388551, 53090, 1073, 31, 38, "Index",
  CellTags->"Compiling"],
Cell[1389627, 53123, 286, 10, 23, "Index",
  CellTags->"CondenseGenealogy"],
Cell[1389916, 53135, 289, 10, 23, "Index",
  CellTags->"ConstrainedIntervals"],
Cell[1390208, 53147, 754, 22, 23, "Index",
  CellTags->"ConstructMutateList"],
Cell[1390965, 53171, 442, 14, 23, "Index",
  CellTags->"ConstructMutateMatrix"],
Cell[1391410, 53187, 286, 10, 23, "Index",
  CellTags->"ContextComponentQ"],
Cell[1391699, 53199, 280, 10, 23, "Index",
  CellTags->"ContextPosition"],
Cell[1391982, 53211, 274, 10, 23, "Index",
  CellTags->"ContextStageQ"],
Cell[1392259, 53223, 283, 10, 23, "Index",
  CellTags->"ContextStructure"],
Cell[1392545, 53235, 312, 11, 23, "Index",
  CellTags->"Continuous populations"],
Cell[1392860, 53248, 508, 21, 53, "IndexSubentry",
  CellTags->"Continuous populations"],
Cell[1393371, 53271, 260, 10, 23, "Index",
  CellTags->"ConvertData"],
Cell[1393634, 53283, 291, 10, 23, "Index",
  CellTags->"ConvertHyperlinkToAddOnsLink"],
Cell[1393928, 53295, 427, 15, 23, "Index",
  CellTags->"Converting"],
Cell[1394358, 53312, 287, 10, 23, "Index",
  CellTags->"CountHeterozygotes"],
Cell[1394648, 53324, 292, 11, 23, "Index",
  CellTags->"Covariance"],
Cell[1394943, 53337, 260, 10, 23, "Index",
  CellTags->"CovarianceMidPoints"],
Cell[1395206, 53349, 289, 10, 23, "Index",
  CellTags->"Crow and Kimura 1970"],
Cell[1395498, 53361, 253, 10, 23, "Index",
  CellTags->"Cumulant"],
Cell[1395754, 53373, 332, 11, 23, "Index",
  CellTags->"CumulantDisequilibrium"],
Cell[1396089, 53386, 264, 10, 23, "Index",
  CellTags->"CumulantEquilibrium"],
Cell[1396356, 53398, 392, 11, 23, "Index",
  CellTags->"CumulantPopulationDisequilibrium"],
Cell[1396751, 53411, 268, 10, 23, "Index",
  CellTags->"CumulantReduced"],
Cell[1397022, 53423, 333, 14, 23, "Index",
  CellTags->"Cumulants"],
Cell[1397358, 53439, 426, 14, 23, "Index",
  CellTags->"Cytoplasmic inheritance"],
Cell[1397787, 53455, 440, 15, 38, "IndexSubentry",
  CellTags->"Cytoplasmic inheritance"],
Cell[1398230, 53472, 283, 11, 23, "Index",
  CellTags->"CytoplasmicLoci"],
Cell[1398516, 53485, 453, 15, 38, "IndexSubentry",
  CellTags->"CytoplasmicLoci"],
Cell[1398972, 53502, 307, 10, 23, "Index",
  CellTags->"dAlleleFrequencyPermutations"],
Cell[1399282, 53514, 235, 10, 23, "Index",
  CellTags->"Data"],
Cell[1399520, 53526, 423, 15, 38, "IndexSubentry",
  CellTags->"Data"],
Cell[1399946, 53543, 259, 11, 23, "Index",
  CellTags->"Datasets"],
Cell[1400208, 53556, 262, 10, 23, "Index",
  CellTags->"Death"],
Cell[1400473, 53568, 258, 10, 23, "Index",
  CellTags->"DeathTime"],
Cell[1400734, 53580, 274, 10, 23, "Index",
  CellTags->"DefineContext"],
Cell[1401011, 53592, 271, 10, 23, "Index",
  CellTags->"DegreesOfFreedom"],
Cell[1401285, 53604, 279, 10, 23, "Index",
  CellTags->"DeletedMutations"],
Cell[1401567, 53616, 280, 10, 23, "Index",
  CellTags->"DeleteGenealogy"],
Cell[1401850, 53628, 322, 14, 23, "Index",
  CellTags->"Deme"],
Cell[1402175, 53644, 614, 20, 23, "Index",
  CellTags->"DemeSize"],
Cell[1402792, 53666, 3024, 86, 142, "IndexSubentry",
  CellTags->"DemeSize"],
Cell[1405819, 53754, 264, 10, 23, "Index",
  CellTags->"Dempster et al 1977"],
Cell[1406086, 53766, 252, 10, 23, "Index",
  CellTags->"Density"],
Cell[1406341, 53778, 270, 10, 23, "Index",
  CellTags->"Descendants"],
Cell[1406614, 53790, 263, 9, 23, "IndexSubentry",
  CellTags->"Descendants"],
Cell[1406880, 53801, 296, 10, 23, "Index",
  CellTags->"Dicytonuclear associations"],
Cell[1407179, 53813, 304, 11, 23, "Index",
  CellTags->"Diploid"],
Cell[1407486, 53826, 277, 10, 23, "Index",
  CellTags->"DiploidConstraints"],
Cell[1407766, 53838, 297, 10, 23, "Index",
  CellTags->"DiploidFrequencies"],
Cell[1408066, 53850, 332, 11, 23, "Index",
  CellTags->"DiploidGenotypeFrequency"],
Cell[1408401, 53863, 305, 10, 23, "Index",
  CellTags->"DiploidGenotypeFrequencyList"],
Cell[1408709, 53875, 316, 10, 23, "Index",
  CellTags->"DiploidGenotypeFrequencyReduced"],
Cell[1409028, 53887, 310, 10, 23, "Index",
  CellTags->"DiploidGenotypeFrequencyTable"],
Cell[1409341, 53899, 297, 10, 23, "Index",
  CellTags->"DiploidIndividuals"],
Cell[1409641, 53911, 275, 10, 23, "Index",
  CellTags->"DiploidPhenotype"],
Cell[1409919, 53923, 402, 14, 23, "Index",
  CellTags->"DiploidPsi"],
Cell[1410324, 53939, 309, 10, 23, "Index",
  CellTags->"DiploidRepresentations"],
Cell[1410636, 53951, 414, 14, 23, "Index",
  CellTags->"DiploidSource"],
Cell[1411053, 53967, 259, 10, 23, "Index",
  CellTags->"DiploidSubsets"],
Cell[1411315, 53979, 257, 10, 23, "Index",
  CellTags->"DiploidTypes"],
Cell[1411575, 53991, 281, 11, 23, "Index",
  CellTags->"Disequilibrium"],
Cell[1411859, 54004, 590, 17, 23, "IndexSubentry",
  CellTags->"Disequilibrium"],
Cell[1412452, 54023, 337, 11, 23, "Index",
  CellTags->"DisequilibriumMean"],
Cell[1412792, 54036, 744, 23, 53, "IndexSubentry",
  CellTags->"DisequilibriumMean"],
Cell[1413539, 54061, 340, 11, 23, "Index",
  CellTags->"DisequilibriumTable"],
Cell[1413882, 54074, 748, 23, 53, "IndexSubentry",
  CellTags->"DisequilibriumTable"],
Cell[1414633, 54099, 276, 10, 23, "Index",
  CellTags->"DistanceSquared"],
Cell[1414912, 54111, 241, 10, 23, "Index",
  CellTags->"Distribution"],
Cell[1415156, 54123, 237, 10, 23, "Index",
  CellTags->"DivideZero"],
Cell[1415396, 54135, 277, 10, 23, "Index",
  CellTags->"DoReplicates"],
Cell[1415676, 54147, 353, 12, 23, "Index",
  CellTags->"DoubleCline"],
Cell[1416032, 54161, 772, 23, 53, "IndexSubentry",
  CellTags->"DoubleCline"],
Cell[1416807, 54186, 262, 10, 23, "Index",
  CellTags->"DrawSamples"],
Cell[1417072, 54198, 260, 10, 23, "Index",
  CellTags->"DropOptions"],
Cell[1417335, 54210, 243, 10, 23, "Index",
  CellTags->"Edwards 1972"],
Cell[1417581, 54222, 270, 11, 23, "Index",
  CellTags->"Epistasis"],
Cell[1417854, 54235, 300, 11, 23, "Index",
  CellTags->"EquivalentSexes"],
Cell[1418157, 54248, 267, 10, 23, "Index",
  CellTags->"ErrorBound"],
Cell[1418427, 54260, 298, 10, 23, "Index",
  CellTags->"EstimateFamilyMoments"],
Cell[1418728, 54272, 274, 10, 23, "Index",
  CellTags->"EstimateMoments"],
Cell[1419005, 54284, 269, 11, 23, "Index",
  CellTags->"Estimating D"],
Cell[1419277, 54297, 2407, 92, 218, "IndexSubentry",
  CellTags->"Estimating D"],
Cell[1421687, 54391, 293, 10, 23, "Index",
  CellTags->"ExactEigenvalues"],
Cell[1421983, 54403, 459, 15, 23, "Index",
  CellTags->"ExactIntersection"],
Cell[1422445, 54420, 269, 10, 23, "Index",
  CellTags->"ExactProbability"],
Cell[1422717, 54432, 252, 11, 23, "Index",
  CellTags->"Expectation"],
Cell[1422972, 54445, 572, 16, 38, "IndexSubentry",
  CellTags->"Expectation"],
Cell[1423547, 54463, 329, 11, 23, "Index",
  CellTags->"ExponentialF"],
Cell[1423879, 54476, 877, 26, 53, "IndexSubentry",
  CellTags->"ExponentialF"],
Cell[1424759, 54504, 270, 10, 23, "Index",
  CellTags->"ExtantIndividuals"],
Cell[1425032, 54516, 321, 11, 23, "Index",
  CellTags->"ExtractContexts"],
Cell[1425356, 54529, 254, 10, 23, "Index",
  CellTags->"ExtractExtant"],
Cell[1425613, 54541, 283, 10, 23, "Index",
  CellTags->"ExtractGenealogy"],
Cell[1425899, 54553, 314, 11, 23, "Index",
  CellTags->"ExtractGenes"],
Cell[1426216, 54566, 285, 10, 23, "Index",
  CellTags->"ExtractInformation"],
Cell[1426504, 54578, 260, 10, 23, "Index",
  CellTags->"ExtractRepeat"],
Cell[1426767, 54590, 279, 10, 23, "Index",
  CellTags->"ExtractSubMatrix"],
Cell[1427049, 54602, 327, 11, 23, "Index",
  CellTags->"FamilyAlleleFrequencyEstimate"],
Cell[1427379, 54615, 274, 10, 23, "Index",
  CellTags->"FamilyEffects"],
Cell[1427656, 54627, 256, 10, 23, "Index",
  CellTags->"FamilyM"],
Cell[1427915, 54639, 264, 10, 23, "Index",
  CellTags->"FamilyProbability"],
Cell[1428182, 54651, 291, 11, 23, "Index",
  CellTags->"Family structure"],
Cell[1428476, 54664, 258, 10, 23, "Index",
  CellTags->"Fecundity"],
Cell[1428737, 54676, 249, 10, 23, "Index",
  CellTags->"FindHyperlinks"],
Cell[1428989, 54688, 243, 10, 23, "Index",
  CellTags->"FindIndexTag"],
Cell[1429235, 54700, 238, 10, 23, "Index",
  CellTags->"FindMLE"],
Cell[1429476, 54712, 253, 10, 23, "Index",
  CellTags->"FindNode"],
Cell[1429732, 54724, 251, 10, 23, "Index",
  CellTags->"FindPosition"],
Cell[1429986, 54736, 249, 10, 23, "Index",
  CellTags->"FindTags"],
Cell[1430238, 54748, 316, 11, 23, "Index",
  CellTags->"Fitness"],
Cell[1430557, 54761, 618, 21, 53, "IndexSubentry",
  CellTags->"Fitness"],
Cell[1431178, 54784, 305, 11, 23, "Index",
  CellTags->"FitnessSet"],
Cell[1431486, 54797, 295, 11, 23, "Index",
  CellTags->"FitnessTable"],
Cell[1431784, 54810, 475, 15, 38, "IndexSubentry",
  CellTags->"FitnessTable"],
Cell[1432262, 54827, 300, 11, 23, "Index",
  CellTags->"FixedEnds"],
Cell[1432565, 54840, 1296, 37, 67, "IndexSubentry",
  CellTags->"FixedEnds"],
Cell[1433864, 54879, 278, 10, 23, "Index",
  CellTags->"Flatten"],
Cell[1434145, 54891, 274, 10, 23, "Index",
  CellTags->"FlattenList"],
Cell[1434422, 54903, 277, 9, 23, "IndexSubentry",
  CellTags->"FlattenList"],
Cell[1434702, 54914, 274, 10, 23, "Index",
  CellTags->"FourierNormalised"],
Cell[1434979, 54926, 289, 10, 23, "Index",
  CellTags->"FourierNormalisedTable"],
Cell[1435271, 54938, 315, 10, 23, "Index",
  CellTags->"FrequencyRepresentations"],
Cell[1435589, 54950, 262, 10, 23, "Index",
  CellTags->"FullContext"],
Cell[1435854, 54962, 307, 10, 23, "Index",
  CellTags->"FullGenotypeFrequencyReduced"],
Cell[1436164, 54974, 301, 10, 23, "Index",
  CellTags->"FullGenotypeFrequencyTable"],
Cell[1436468, 54986, 257, 10, 23, "Index",
  CellTags->"FullOutput"],
Cell[1436728, 54998, 241, 10, 23, "Index",
  CellTags->"Function"],
Cell[1436972, 55010, 286, 11, 23, "Index",
  CellTags->"Gametes"],
Cell[1437261, 55023, 1087, 36, 68, "IndexSubentry",
  CellTags->"Gametes"],
Cell[1438351, 55061, 298, 11, 23, "Index",
  CellTags->"GameteTable"],
Cell[1438652, 55074, 440, 15, 38, "IndexSubentry",
  CellTags->"GameteTable"],
Cell[1439095, 55091, 290, 10, 23, "Index",
  CellTags->"GaussianLogLikelihood"],
Cell[1439388, 55103, 260, 10, 23, "Index",
  CellTags->"GaussianMLE"],
Cell[1439651, 55115, 270, 11, 23, "Index",
  CellTags->"Genealogies"],
Cell[1439924, 55128, 740, 27, 68, "IndexSubentry",
  CellTags->"Genealogies"],
Cell[1440667, 55157, 276, 10, 23, "Index",
  CellTags->"GenealogyToMatrix"],
Cell[1440946, 55169, 265, 10, 23, "Index",
  CellTags->"GeneralizedTransform"],
Cell[1441214, 55181, 283, 11, 23, "Index",
  CellTags->"Generating functions"],
Cell[1441500, 55194, 437, 15, 38, "IndexSubentry",
  CellTags->"Generating functions"],
Cell[1441940, 55211, 277, 10, 23, "Index",
  CellTags->"Genes and contexts"],
Cell[1442220, 55223, 334, 12, 23, "Index",
  CellTags->"Genome"],
Cell[1442557, 55237, 416, 15, 23, "Index",
  CellTags->"Genotype"],
Cell[1442976, 55254, 299, 11, 23, "Index",
  CellTags->"Genotype frequencies"],
Cell[1443278, 55267, 301, 10, 23, "Index",
  CellTags->"GenotypeFrequencyArguments"],
Cell[1443582, 55279, 303, 10, 23, "Index",
  CellTags->"GenotypeFrequencyConvert"],
Cell[1443888, 55291, 307, 10, 23, "Index",
  CellTags->"GenotypeFrequencyTable"],
Cell[1444198, 55303, 281, 10, 23, "Index",
  CellTags->"GenotypePosition"],
Cell[1444482, 55315, 288, 10, 23, "Index",
  CellTags->"GenotypeProbability"],
Cell[1444773, 55327, 286, 9, 23, "IndexSubentry",
  CellTags->"GenotypeProbability"],
Cell[1445062, 55338, 256, 11, 23, "Index",
  CellTags->"Genotypes"],
Cell[1445321, 55351, 452, 16, 23, "Index",
  CellTags->"Gnew"],
Cell[1445776, 55369, 261, 10, 23, "Index",
  CellTags->"Goodman et al 1999"],
Cell[1446040, 55381, 399, 14, 23, "Index",
  CellTags->"Griffiths-Tavare"],
Cell[1446442, 55397, 833, 26, 53, "IndexSubentry",
  CellTags->"Griffiths-Tavare"],
Cell[1447278, 55425, 276, 10, 23, "Index",
  CellTags->"Guiasu & Shenitzer 1985"],
Cell[1447557, 55437, 277, 10, 23, "Index",
  CellTags->"HaploidConstraints"],
Cell[1447837, 55449, 297, 10, 23, "Index",
  CellTags->"HaploidFrequencies"],
Cell[1448137, 55461, 332, 11, 23, "Index",
  CellTags->"HaploidGenotypeFrequency"],
Cell[1448472, 55474, 297, 10, 23, "Index",
  CellTags->"HaploidIndividuals"],
Cell[1448772, 55486, 309, 10, 23, "Index",
  CellTags->"HaploidRepresentations"],
Cell[1449084, 55498, 259, 11, 23, "Index",
  CellTags->"Haploids"],
Cell[1449346, 55511, 414, 14, 23, "Index",
  CellTags->"HaploidSource"],
Cell[1449763, 55527, 259, 10, 23, "Index",
  CellTags->"HaploidSubsets"],
Cell[1450025, 55539, 257, 10, 23, "Index",
  CellTags->"HaploidTypes"],
Cell[1450285, 55551, 314, 11, 23, "Index",
  CellTags->"Help browser"],
Cell[1450602, 55564, 281, 10, 23, "Index",
  CellTags->"Help Browser"],
Cell[1450886, 55576, 291, 9, 23, "IndexSubentry",
  CellTags->"Help Browser"],
Cell[1451180, 55587, 432, 15, 23, "Index",
  CellTags->"Hermaphrodites"],
Cell[1451615, 55604, 284, 10, 23, "Index",
  CellTags->"HeterozygoteB"],
Cell[1451902, 55616, 237, 10, 23, "Index",
  CellTags->"Hill 1974a"],
Cell[1452142, 55628, 237, 10, 23, "Index",
  CellTags->"Hill 1974b"],
Cell[1452382, 55640, 237, 10, 23, "Index",
  CellTags->"Hill 1974c"],
Cell[1452622, 55652, 303, 10, 23, "Index",
  CellTags->"Hypergeometric model"],
Cell[1452928, 55664, 256, 11, 23, "Index",
  CellTags->"Hyperlinks"],
Cell[1453187, 55677, 621, 22, 53, "IndexSubentry",
  CellTags->"Hyperlinks"],
Cell[1453811, 55701, 270, 10, 23, "Index",
  CellTags->"IncidenceMatrix"],
Cell[1454084, 55713, 290, 11, 23, "Index",
  CellTags->"Index"],
Cell[1454377, 55726, 237, 10, 23, "Index",
  CellTags->"Individual"],
Cell[1454617, 55738, 323, 11, 23, "Index",
  CellTags->"IndividualRepresentations"],
Cell[1454943, 55751, 264, 10, 23, "Index",
  CellTags->"Individuals"],
Cell[1455210, 55763, 272, 10, 23, "Index",
  CellTags->"InitialiseContinuum"],
Cell[1455485, 55775, 263, 10, 23, "Index",
  CellTags->"InitialiseCovariance"],
Cell[1455751, 55787, 414, 14, 23, "Index",
  CellTags->"InitialiseDemes"],
Cell[1456168, 55803, 254, 10, 23, "Index",
  CellTags->"InitialStep"],
Cell[1456425, 55815, 277, 10, 23, "Index",
  CellTags->"InitialStepReduced"],
Cell[1456705, 55827, 270, 10, 23, "Index",
  CellTags->"InternalNodes"],
Cell[1456978, 55839, 268, 10, 23, "Index",
  CellTags->"IntervalCombine"],
Cell[1457249, 55851, 271, 10, 23, "Index",
  CellTags->"IntervalPosition"],
Cell[1457523, 55863, 295, 10, 23, "Index",
  CellTags->"InverseFourierNormalised"],
Cell[1457821, 55875, 310, 10, 23, "Index",
  CellTags->"InverseFourierNormalisedTable"],
Cell[1458134, 55887, 476, 15, 23, "Index",
  CellTags->"Island model"],
Cell[1458613, 55904, 795, 25, 53, "IndexSubentry",
  CellTags->"Island model"],
Cell[1459411, 55931, 295, 10, 23, "Index",
  CellTags->"IterateContinuum"],
Cell[1459709, 55943, 264, 11, 23, "Index",
  CellTags->"IterateExact"],
Cell[1459976, 55956, 1753, 53, 128, "IndexSubentry",
  CellTags->"IterateExact"],
Cell[1461732, 56011, 328, 14, 23, "Index",
  CellTags->"Join"],
Cell[1462063, 56027, 417, 15, 23, "Index",
  CellTags->"Juveniles"],
Cell[1462483, 56044, 310, 10, 23, "Index",
  CellTags->"Kirkpatrick and Barton 1997"],
Cell[1462796, 56056, 316, 10, 23, "Index",
  CellTags->"Kirkpatrick and Servedio 1998"],
Cell[1463115, 56068, 392, 14, 23, "Index",
  CellTags->"Kirkpatrick et al."],
Cell[1463510, 56084, 3891, 138, 293, "IndexSubentry",
  CellTags->"Kirkpatrick et al."],
Cell[1467404, 56224, 275, 10, 23, "Index",
  CellTags->"Kirkpatrick et al. 1983"],
Cell[1467682, 56236, 237, 10, 23, "Index",
  CellTags->"Kruuk 1997"],
Cell[1467922, 56248, 257, 10, 23, "Index",
  CellTags->"LeafLabels"],
Cell[1468182, 56260, 257, 10, 23, "Index",
  CellTags->"LeafOffset"],
Cell[1468442, 56272, 249, 10, 23, "Index",
  CellTags->"Leaves"],
Cell[1468694, 56284, 229, 10, 23, "Index",
  CellTags->"Life cycle"],
Cell[1468926, 56296, 3070, 111, 188, "IndexSubentry",
  CellTags->"Life cycle"],
Cell[1471999, 56409, 246, 10, 23, "Index",
  CellTags->"Li & Nei 1974"],
Cell[1472248, 56421, 480, 18, 23, "Index",
  CellTags->"Linkage"],
Cell[1472731, 56441, 451, 15, 38, "IndexSubentry",
  CellTags->"Linkage"],
Cell[1473185, 56458, 307, 10, 23, "Index",
  CellTags->"Linkage disequilibrium"],
Cell[1473495, 56470, 280, 10, 23, "Index",
  CellTags->"ListToGenealogy"],
Cell[1473778, 56482, 291, 10, 23, "Index",
  CellTags->"ListToMatrix"],
Cell[1474072, 56494, 255, 10, 23, "Index",
  CellTags->"Location"],
Cell[1474330, 56506, 232, 10, 23, "Index",
  CellTags->"Locations"],
Cell[1474565, 56518, 253, 10, 23, "Index",
  CellTags->"LocusNames"],
Cell[1474821, 56530, 288, 10, 23, "Index",
  CellTags->"LogLikelihoodDisequilibrium"],
Cell[1475112, 56542, 325, 10, 23, "Index",
  CellTags->"LogLikelihoodDisequilibriumReduced"],
Cell[1475440, 56554, 270, 10, 23, "Index",
  CellTags->"LogLikelihoodTest"],
Cell[1475713, 56566, 397, 14, 23, "Index",
  CellTags->"Log-linear models"],
Cell[1476113, 56582, 252, 10, 23, "Index",
  CellTags->"Long et al 1995"],
Cell[1476368, 56594, 269, 10, 23, "Index",
  CellTags->"LowerOffDiagonal"],
Cell[1476640, 56606, 249, 10, 23, "Index",
  CellTags->"MacCallum 1994"],
Cell[1476892, 56618, 269, 10, 23, "Index",
  CellTags->"MacCallum et al. 1998"],
Cell[1477164, 56630, 320, 11, 23, "Index",
  CellTags->"MakeCline"],
Cell[1477487, 56643, 691, 21, 53, "IndexSubentry",
  CellTags->"MakeCline"],
Cell[1478181, 56666, 296, 11, 23, "Index",
  CellTags->"MakeDiploid"],
Cell[1478480, 56679, 474, 15, 38, "IndexSubentry",
  CellTags->"MakeDiploid"],
Cell[1478957, 56696, 279, 10, 23, "Index",
  CellTags->"MakeDistanceList"],
Cell[1479239, 56708, 270, 10, 23, "Index",
  CellTags->"MakeDistances"],
Cell[1479512, 56720, 243, 10, 23, "Index",
  CellTags->"MakeFitnessSet"],
Cell[1479758, 56732, 255, 9, 23, "IndexSubentry",
  CellTags->"MakeFitnessSet"],
Cell[1480016, 56743, 262, 10, 23, "Index",
  CellTags->"MakeGenealogy"],
Cell[1480281, 56755, 278, 10, 23, "Index",
  CellTags->"MakeGenealogyPlot"],
Cell[1480562, 56767, 296, 11, 23, "Index",
  CellTags->"MakeHaploid"],
Cell[1480861, 56780, 474, 15, 38, "IndexSubentry",
  CellTags->"MakeHaploid"],
Cell[1481338, 56797, 322, 11, 23, "Index",
  CellTags->"MakeIndividuals"],
Cell[1481663, 56810, 666, 21, 53, "IndexSubentry",
  CellTags->"MakeIndividuals"],
Cell[1482332, 56833, 270, 10, 23, "Index",
  CellTags->"MakeOneWayTable"],
Cell[1482605, 56845, 268, 10, 23, "Index",
  CellTags->"MakePairwiseTable"],
Cell[1482876, 56857, 325, 11, 23, "Index",
  CellTags->"MakePopulation"],
Cell[1483204, 56870, 711, 22, 53, "IndexSubentry",
  CellTags->"MakePopulation"],
Cell[1483918, 56894, 398, 14, 23, "Index",
  CellTags->"MakeSelectionCoefficient"],
Cell[1484319, 56910, 423, 15, 38, "IndexSubentry",
  CellTags->"MakeSelectionCoefficient"],
Cell[1484745, 56927, 270, 10, 23, "Index",
  CellTags->"Mangel & Hilborn 1996"],
Cell[1485018, 56939, 316, 11, 23, "Index",
  CellTags->"Marginal fitness"],
Cell[1485337, 56952, 642, 21, 53, "IndexSubentry",
  CellTags->"Marginal fitness"],
Cell[1485982, 56975, 256, 10, 23, "Index",
  CellTags->"MarginalTable"],
Cell[1486241, 56987, 302, 11, 23, "Index",
  CellTags->"MarginalW"],
Cell[1486546, 57000, 636, 21, 53, "IndexSubentry",
  CellTags->"MarginalW"],
Cell[1487185, 57023, 277, 11, 23, "Index",
  CellTags->"MaternalLoci"],
Cell[1487465, 57036, 450, 15, 38, "IndexSubentry",
  CellTags->"MaternalLoci"],
Cell[1487918, 57053, 254, 10, 23, "Index",
  CellTags->"MatrixGamma"],
Cell[1488175, 57065, 280, 10, 23, "Index",
  CellTags->"MatrixToGenealogy"],
Cell[1488458, 57077, 291, 10, 23, "Index",
  CellTags->"MatrixToList"],
Cell[1488752, 57089, 314, 11, 23, "Index",
  CellTags->"MeanContribution"],
Cell[1489069, 57102, 400, 14, 23, "Index",
  CellTags->"Mean fitness"],
Cell[1489472, 57118, 461, 15, 38, "IndexSubentry",
  CellTags->"Mean fitness"],
Cell[1489936, 57135, 290, 11, 23, "Index",
  CellTags->"MeanW"],
Cell[1490229, 57148, 620, 21, 53, "IndexSubentry",
  CellTags->"MeanW"],
Cell[1490852, 57171, 234, 10, 23, "Index",
  CellTags->"Meiosis"],
Cell[1491089, 57183, 264, 9, 23, "IndexSubentry",
  CellTags->"Meiosis"],
Cell[1491356, 57194, 256, 10, 23, "Index",
  CellTags->"MethodC"],
Cell[1491615, 57206, 256, 10, 23, "Index",
  CellTags->"MethodP"],
Cell[1491874, 57218, 271, 11, 23, "Index",
  CellTags->"Metropolis algorithm"],
Cell[1492148, 57231, 295, 10, 23, "Index",
  CellTags->"MetropolisDisequilibrium"],
Cell[1492446, 57243, 316, 10, 23, "Index",
  CellTags->"MetropolisDisequilibriumReduced"],
Cell[1492765, 57255, 272, 10, 23, "Index",
  CellTags->"Metropolis et al. 1954"],
Cell[1493040, 57267, 382, 14, 23, "Index",
  CellTags->"MFromC"],
Cell[1493425, 57283, 226, 10, 23, "Index",
  CellTags->"Migrate"],
Cell[1493654, 57295, 311, 11, 23, "Index",
  CellTags->"MigrateExact"],
Cell[1493968, 57308, 646, 21, 53, "IndexSubentry",
  CellTags->"MigrateExact"],
Cell[1494617, 57331, 298, 11, 23, "Index",
  CellTags->"Migration"],
Cell[1494918, 57344, 2215, 79, 188, "IndexSubentry",
  CellTags->"Migration"],
Cell[1497136, 57425, 491, 15, 23, "Index",
  CellTags->"MigrationOrder"],
Cell[1497630, 57442, 524, 16, 38, "IndexSubentry",
  CellTags->"MigrationOrder"],
Cell[1498157, 57460, 308, 11, 23, "Index",
  CellTags->"MigrationRate"],
Cell[1498468, 57473, 311, 11, 23, "Index",
  CellTags->"MigrationSet"],
Cell[1498782, 57486, 259, 10, 23, "Index",
  CellTags->"Missing data"],
Cell[1499044, 57498, 352, 14, 23, "Index",
  CellTags->"Moment"],
Cell[1499399, 57514, 305, 10, 23, "Index",
  CellTags->"MomentAfterMigration"],
Cell[1499707, 57526, 332, 11, 23, "Index",
  CellTags->"MomentAfterRecombination"],
Cell[1500042, 57539, 258, 10, 23, "Index",
  CellTags->"MomentEquilibrium"],
Cell[1500303, 57551, 315, 11, 23, "Index",
  CellTags->"MomentGeneratingFunction"],
Cell[1500621, 57564, 582, 21, 53, "IndexSubentry",
  CellTags->"MomentGeneratingFunction"],
Cell[1501206, 57587, 267, 10, 23, "Index",
  CellTags->"MomentLimits"],
Cell[1501476, 57599, 232, 10, 23, "Index",
  CellTags->"MomentNew"],
Cell[1501711, 57611, 262, 10, 23, "Index",
  CellTags->"MomentReduced"],
Cell[1501976, 57623, 222, 10, 23, "Index",
  CellTags->"Moments"],
Cell[1502201, 57635, 1552, 53, 128, "IndexSubentry",
  CellTags->"Moments"],
Cell[1503756, 57690, 289, 10, 23, "Index",
  CellTags->"MomentsFromG"],
Cell[1504048, 57702, 269, 10, 23, "Index",
  CellTags->"MomentSimple"],
Cell[1504320, 57714, 302, 10, 23, "Index",
  CellTags->"MonteCarloGriffithsTavare"],
Cell[1504625, 57726, 302, 10, 23, "Index",
  CellTags->"MonteCarloProbability"],
Cell[1504930, 57738, 258, 10, 23, "Index",
  CellTags->"Mortality"],
Cell[1505191, 57750, 299, 10, 23, "Index",
  CellTags->"MostRecentCommonAncestor"],
Cell[1505493, 57762, 374, 14, 23, "Index",
  CellTags->"MToC"],
Cell[1505870, 57778, 410, 14, 23, "Index",
  CellTags->"MToCEquations"],
Cell[1506283, 57794, 263, 10, 23, "Index",
  CellTags->"Muddle"],
Cell[1506549, 57806, 295, 11, 23, "Index",
  CellTags->"Multilocus algebra"],
Cell[1506847, 57819, 1010, 36, 68, "IndexSubentry",
  CellTags->"Multilocus algebra"],
Cell[1507860, 57857, 408, 15, 23, "Index",
  CellTags->"Multilocus MS"],
Cell[1508271, 57874, 264, 11, 23, "Index",
  CellTags->"Multilocus notation"],
Cell[1508538, 57887, 344, 12, 23, "Index",
  CellTags->"Multinomial sampling"],
Cell[1508885, 57901, 332, 11, 23, "Index",
  CellTags->"MultinomialSamplingProbability"],
Cell[1509220, 57914, 289, 11, 23, "Index",
  CellTags->"Multiple alleles"],
Cell[1509512, 57927, 535, 21, 53, "IndexSubentry",
  CellTags->"Multiple alleles"],
Cell[1510050, 57950, 297, 11, 23, "Index",
  CellTags->"Multiple arguments"],
Cell[1510350, 57963, 336, 11, 23, "Index",
  CellTags->"Multiplicative models"],
Cell[1510689, 57976, 302, 11, 23, "Index",
  CellTags->"MUS"],
Cell[1510994, 57989, 667, 21, 53, "IndexSubentry",
  CellTags->"MUS"],
Cell[1511664, 58012, 287, 11, 23, "Index",
  CellTags->"Mutate"],
Cell[1511954, 58025, 607, 21, 53, "IndexSubentry",
  CellTags->"Mutate"],
Cell[1512564, 58048, 724, 22, 23, "Index",
  CellTags->"MutateCompiled"],
Cell[1513291, 58072, 263, 11, 23, "Index",
  CellTags->"Mutation"],
Cell[1513557, 58085, 736, 21, 23, "IndexSubentry",
  CellTags->"Mutation"],
Cell[1514296, 58108, 275, 10, 23, "Index",
  CellTags->"MutationInterval"],
Cell[1514574, 58120, 297, 10, 23, "Index",
  CellTags->"MutationLabels"],
Cell[1514874, 58132, 269, 10, 23, "Index",
  CellTags->"MutationOrigin"],
Cell[1515146, 58144, 261, 10, 23, "Index",
  CellTags->"MutationRate"],
Cell[1515410, 58156, 254, 10, 23, "Index",
  CellTags->"Mutations"],
Cell[1515667, 58168, 398, 14, 23, "Index",
  CellTags->"MVariables"],
Cell[1516068, 58184, 293, 11, 23, "Index",
  CellTags->"Negative binomial"],
Cell[1516364, 58197, 828, 27, 68, "IndexSubentry",
  CellTags->"Negative binomial"],
Cell[1517195, 58226, 339, 11, 23, "Index",
  CellTags->"NegativeBinomialLogLikelihood"],
Cell[1517537, 58239, 302, 10, 23, "Index",
  CellTags->"NegativeBinomialMLE"],
Cell[1517842, 58251, 368, 11, 23, "Index",
  CellTags->"NegativeHypergeometricDistribution"],
Cell[1518213, 58264, 273, 10, 23, "Index",
  CellTags->"NeighbourArray"],
Cell[1518489, 58276, 261, 10, 23, "Index",
  CellTags->"Neighbours"],
Cell[1518753, 58288, 280, 10, 23, "Index",
  CellTags->"NetCovariance"],
Cell[1519036, 58300, 255, 10, 23, "Index",
  CellTags->"NetFecundity"],
Cell[1519294, 58312, 255, 10, 23, "Index",
  CellTags->"NetMortality"],
Cell[1519552, 58324, 384, 14, 23, "Index",
  CellTags->"NetRecombination"],
Cell[1519939, 58340, 277, 9, 23, "IndexSubentry",
  CellTags->"NetRecombination"],
Cell[1520219, 58351, 285, 11, 23, "Index",
  CellTags->"Neutral marker"],
Cell[1520507, 58364, 309, 10, 23, "Index",
  CellTags->"NeutralRepresentations"],
Cell[1520819, 58376, 309, 11, 23, "Index",
  CellTags->"NewGametes"],
Cell[1521131, 58389, 1653, 52, 98, "IndexSubentry",
  CellTags->"NewGametes"],
Cell[1522787, 58443, 249, 10, 23, "Index",
  CellTags->"NewS"],
Cell[1523039, 58455, 380, 14, 23, "Index",
  CellTags->"Node"],
Cell[1523422, 58471, 404, 14, 23, "Index",
  CellTags->"NodeFunction"],
Cell[1523829, 58487, 275, 9, 23, "IndexSubentry",
  CellTags->"NodeFunction"],
Cell[1524107, 58498, 257, 10, 23, "Index",
  CellTags->"NodeLabels"],
Cell[1524367, 58510, 257, 10, 23, "Index",
  CellTags->"NodeOffset"],
Cell[1524627, 58522, 246, 10, 23, "Index",
  CellTags->"Nodes"],
Cell[1524876, 58534, 263, 10, 23, "Index",
  CellTags->"NonMendelian"],
Cell[1525142, 58546, 366, 13, 23, "IndexSubentry",
  CellTags->"NonMendelian"],
Cell[1525511, 58561, 323, 11, 23, "Index",
  CellTags->"NonNeutralRepresentations"],
Cell[1525837, 58574, 331, 11, 23, "Index",
  CellTags->"NonSymmetricRepresentations"],
Cell[1526171, 58587, 284, 10, 23, "Index",
  CellTags->"Normalisation"],
Cell[1526458, 58599, 275, 10, 23, "Index",
  CellTags->"Normalised"],
Cell[1526736, 58611, 287, 11, 23, "Index",
  CellTags->"Notation"],
Cell[1527026, 58624, 727, 27, 68, "IndexSubentry",
  CellTags->"Notation"],
Cell[1527756, 58653, 253, 10, 23, "Index",
  CellTags->"Notation Package"],
Cell[1528012, 58665, 261, 10, 23, "Index",
  CellTags->"NumberedLink"],
Cell[1528276, 58677, 271, 11, 23, "Index",
  CellTags->"Numbering"],
Cell[1528550, 58690, 560, 21, 53, "IndexSubentry",
  CellTags->"Numbering"],
Cell[1529113, 58713, 318, 11, 23, "Index",
  CellTags->"NumberOfCoalescences"],
Cell[1529434, 58726, 266, 10, 23, "Index",
  CellTags->"NumberOfGenes"],
Cell[1529703, 58738, 915, 28, 68, "IndexSubentry",
  CellTags->"NumberOfGenes"],
Cell[1530621, 58768, 281, 10, 23, "Index",
  CellTags->"NumberOfGenesTable"],
Cell[1530905, 58780, 416, 14, 23, "Index",
  CellTags->"NumberOfIndividuals"],
Cell[1531324, 58796, 299, 10, 23, "Index",
  CellTags->"NumberOfIndividualsTable"],
Cell[1531626, 58808, 279, 10, 23, "Index",
  CellTags->"NumberOfLineages"],
Cell[1531908, 58820, 263, 10, 23, "Index",
  CellTags->"NumberOfLoci"],
Cell[1532174, 58832, 278, 10, 23, "Index",
  CellTags->"NumberOfMutations"],
Cell[1532455, 58844, 317, 10, 23, "Index",
  CellTags->"NumberOfPossibleCoalescences"],
Cell[1532775, 58856, 287, 10, 23, "Index",
  CellTags->"NumberOfSamplePartitions"],
Cell[1533065, 58868, 278, 10, 23, "Index",
  CellTags->"NumberOfSetPartitions"],
Cell[1533346, 58880, 325, 11, 23, "Index",
  CellTags->"NumericalModel"],
Cell[1533674, 58893, 294, 9, 23, "IndexSubentry",
  CellTags->"NumericalModel"],
Cell[1533971, 58904, 301, 11, 23, "Index",
  CellTags->"Numerical models"],
Cell[1534275, 58917, 1071, 37, 83, "IndexSubentry",
  CellTags->"Numerical models"],
Cell[1535349, 58956, 420, 14, 23, "Index",
  CellTags->"Observable genotype"],
Cell[1535772, 58972, 250, 11, 23, "Index",
  CellTags->"Obsolete"],
Cell[1536025, 58985, 3253, 115, 278, "IndexSubentry",
  CellTags->"Obsolete"],
Cell[1539281, 59102, 258, 10, 23, "Index",
  CellTags->"Offspring"],
Cell[1539542, 59114, 264, 10, 23, "Index",
  CellTags->"Orive & Barton 1999"],
Cell[1539809, 59126, 247, 10, 23, "Index",
  CellTags->"OtherSex"],
Cell[1540059, 59138, 275, 11, 23, "Index",
  CellTags->"Packages"],
Cell[1540337, 59151, 839, 31, 68, "IndexSubentry",
  CellTags->"Packages"],
Cell[1541179, 59184, 235, 10, 23, "Index",
  CellTags->"PackageSaver"],
Cell[1541417, 59196, 414, 14, 23, "Index",
  CellTags->"Paternal inheritance"],
Cell[1541834, 59212, 277, 11, 23, "Index",
  CellTags->"PaternalLoci"],
Cell[1542114, 59225, 444, 15, 38, "IndexSubentry",
  CellTags->"PaternalLoci"],
Cell[1542561, 59242, 274, 10, 23, "Index",
  CellTags->"PatternFree"],
Cell[1542838, 59254, 325, 11, 23, "Index",
  CellTags->"Permutations in defining coefficients"],
Cell[1543166, 59267, 269, 11, 23, "Index",
  CellTags->"Phenotypes"],
Cell[1543438, 59280, 264, 10, 23, "Index",
  CellTags->"Phipps & Brill 1995"],
Cell[1543705, 59292, 245, 10, 23, "Index",
  CellTags->"Ploidy"],
Cell[1543953, 59304, 271, 10, 23, "Index",
  CellTags->"PloidyWeightList"],
Cell[1544227, 59316, 266, 10, 23, "Index",
  CellTags->"PlotGenealogy"],
Cell[1544496, 59328, 247, 10, 23, "Index",
  CellTags->"PlotLogL"],
Cell[1544746, 59340, 346, 11, 23, "Index",
  CellTags->"PopulationDisequilibrium"],
Cell[1545095, 59353, 274, 10, 23, "Index",
  CellTags->"PopulationExpectation"],
Cell[1545372, 59365, 271, 9, 23, "IndexSubentry",
  CellTags->"PopulationExpectation"],
Cell[1545646, 59376, 323, 11, 23, "Index",
  CellTags->"PopulationRepresentations"],
Cell[1545972, 59389, 380, 14, 23, "Index",
  CellTags->"Position"],
Cell[1546355, 59405, 442, 15, 38, "IndexSubentry",
  CellTags->"Position"],
Cell[1546800, 59422, 270, 10, 23, "Index",
  CellTags->"PositionsList"],
Cell[1547073, 59434, 276, 10, 23, "Index",
  CellTags->"PositionsMatrix"],
Cell[1547352, 59446, 305, 10, 23, "Index",
  CellTags->"PossibleCoalescenceOrder"],
Cell[1547660, 59458, 303, 10, 23, "Index",
  CellTags->"PossibleDiploidGenotypes"],
Cell[1547966, 59470, 272, 10, 23, "Index",
  CellTags->"PossibleGenotypes"],
Cell[1548241, 59482, 311, 11, 23, "Index",
  CellTags->"PowerF"],
Cell[1548555, 59495, 871, 27, 68, "IndexSubentry",
  CellTags->"PowerF"],
Cell[1549429, 59524, 279, 10, 23, "Index",
  CellTags->"PresentOneWayTable"],
Cell[1549711, 59536, 277, 10, 23, "Index",
  CellTags->"PresentPairwiseTable"],
Cell[1549991, 59548, 265, 10, 23, "Index",
  CellTags->"PresentResults"],
Cell[1550259, 59560, 273, 10, 23, "Index",
  CellTags->"PrintDetails"],
Cell[1550535, 59572, 275, 11, 23, "Index",
  CellTags->"Problems"],
Cell[1550813, 59585, 587, 18, 23, "IndexSubentry",
  CellTags->"Problems"],
Cell[1551403, 59605, 250, 11, 23, "Index",
  CellTags->"Products"],
Cell[1551656, 59618, 237, 10, 23, "Index",
  CellTags->"ProductSum"],
Cell[1551896, 59630, 249, 9, 23, "IndexSubentry",
  CellTags->"ProductSum"],
Cell[1552148, 59641, 263, 11, 23, "Index",
  CellTags->"QLE"],
Cell[1552414, 59654, 258, 9, 23, "IndexSubentry",
  CellTags->"QLE"],
Cell[1552675, 59665, 310, 11, 23, "Index",
  CellTags->"Quasi-linkage equilibrium"],
Cell[1552988, 59678, 312, 10, 23, "Index",
  CellTags->"RandomBottleneckedGenealogy"],
Cell[1553303, 59690, 299, 10, 23, "Index",
  CellTags->"RandomCoalescenceOrder"],
Cell[1553605, 59702, 326, 11, 23, "Index",
  CellTags->"RandomCoalescenceTimes"],
Cell[1553934, 59715, 288, 10, 23, "Index",
  CellTags->"RandomCum"],
Cell[1554225, 59727, 330, 12, 23, "Index",
  CellTags->"Random drift"],
Cell[1554558, 59741, 2349, 77, 158, "IndexSubentry",
  CellTags->"Random drift"],
Cell[1556910, 59820, 286, 11, 23, "Index",
  CellTags->"RandomDrift"],
Cell[1557199, 59833, 956, 27, 38, "IndexSubentry",
  CellTags->"RandomDrift"],
Cell[1558158, 59862, 259, 10, 23, "Index",
  CellTags->"RandomFamilies"],
Cell[1558420, 59874, 261, 10, 23, "Index",
  CellTags->"RandomFamily"],
Cell[1558684, 59886, 273, 9, 23, "IndexSubentry",
  CellTags->"RandomFamily"],
Cell[1558960, 59897, 299, 11, 23, "Index",
  CellTags->"Random genealogies"],
Cell[1559262, 59910, 270, 10, 23, "Index",
  CellTags->"RandomGenealogy"],
Cell[1559535, 59922, 241, 10, 23, "Index",
  CellTags->"RandomList"],
Cell[1559779, 59934, 259, 9, 23, "IndexSubentry",
  CellTags->"RandomList"],
Cell[1560041, 59945, 259, 11, 23, "Index",
  CellTags->"Random lists"],
Cell[1560303, 59958, 289, 10, 23, "Index",
  CellTags->"RandomMating"],
Cell[1560595, 59970, 286, 10, 23, "Index",
  CellTags->"RandomMultinomial"],
Cell[1560884, 59982, 277, 10, 23, "Index",
  CellTags->"RandomPreviousFamily"],
Cell[1561164, 59994, 288, 10, 23, "Index",
  CellTags->"Random sampling"],
Cell[1561455, 60006, 415, 15, 38, "IndexSubentry",
  CellTags->"Random sampling"],
Cell[1561873, 60023, 236, 10, 23, "Index",
  CellTags->"RandomSet"],
Cell[1562112, 60035, 371, 14, 23, "Index",
  CellTags->"Random union"],
Cell[1562486, 60051, 306, 9, 23, "IndexSubentry",
  CellTags->"Random union"],
Cell[1562795, 60062, 244, 10, 23, "Index",
  CellTags->"RandomUnion"],
Cell[1563042, 60074, 276, 10, 23, "Index",
  CellTags->"RandomUnionMethod"],
Cell[1563321, 60086, 260, 10, 23, "Index",
  CellTags->"RandomUnionObsolete"],
Cell[1563584, 60098, 256, 11, 23, "Index",
  CellTags->"Random walk"],
Cell[1563843, 60111, 378, 14, 23, "Index",
  CellTags->"Recombination"],
Cell[1564224, 60127, 796, 27, 68, "IndexSubentry",
  CellTags->"Recombination"],
Cell[1565023, 60156, 321, 11, 23, "Index",
  CellTags->"RecombinationRate"],
Cell[1565347, 60169, 450, 15, 23, "Index",
  CellTags->"RecombinationSet"],
Cell[1565800, 60186, 283, 10, 23, "Index",
  CellTags->"Recombined"],
Cell[1566086, 60198, 262, 10, 23, "Index",
  CellTags->"ReducedData"],
Cell[1566351, 60210, 316, 11, 23, "Index",
  CellTags->"ReferencePoint"],
Cell[1566670, 60223, 273, 10, 23, "Index",
  CellTags->"ReferencePointMean"],
Cell[1566946, 60235, 1125, 37, 53, "IndexSubentry",
  CellTags->"ReferencePointMean"],
Cell[1568074, 60274, 273, 10, 23, "Index",
  CellTags->"ReferencePointSame"],
Cell[1568350, 60286, 273, 10, 23, "Index",
  CellTags->"ReferencePointZero"],
Cell[1568626, 60298, 400, 14, 23, "Index",
  CellTags->"Reference values"],
Cell[1569029, 60314, 472, 15, 38, "IndexSubentry",
  CellTags->"Reference values"],
Cell[1569504, 60331, 238, 10, 23, "Index",
  CellTags->"RemoveTag"],
Cell[1569745, 60343, 239, 10, 23, "Index",
  CellTags->"Repeat"],
Cell[1569987, 60355, 232, 10, 23, "Index",
  CellTags->"Replace"],
Cell[1570222, 60367, 262, 11, 23, "Index",
  CellTags->"ReplaceAllSpecial"],
Cell[1570487, 60380, 278, 11, 23, "Index",
  CellTags->"ReplaceRepeatedSpecial"],
Cell[1570768, 60393, 311, 11, 23, "Index",
  CellTags->"Representations"],
Cell[1571082, 60406, 308, 10, 23, "IndexSubentry",
  CellTags->"Representations"],
Cell[1571393, 60418, 286, 11, 23, "Index",
  CellTags->"Reproduction"],
Cell[1571682, 60431, 222, 10, 23, "Index",
  CellTags->"Reverse"],
Cell[1571907, 60443, 280, 10, 23, "Index",
  CellTags->"RootedGenealogy"],
Cell[1572190, 60455, 244, 10, 23, "Index",
  CellTags->"Rules"],
Cell[1572437, 60467, 234, 9, 23, "IndexSubentry",
  CellTags->"Rules"],
Cell[1572674, 60478, 251, 10, 23, "Index",
  CellTags->"SampleCovariance"],
Cell[1572928, 60490, 278, 10, 23, "Index",
  CellTags->"SampleIndividuals"],
Cell[1573209, 60502, 260, 10, 23, "Index",
  CellTags->"SamplePartition"],
Cell[1573472, 60514, 261, 11, 23, "Index",
  CellTags->"Sampling"],
Cell[1573736, 60527, 319, 11, 23, "Index",
  CellTags->"Scripts and faces"],
Cell[1574058, 60540, 414, 14, 23, "Index",
  CellTags->"SegregationRatio"],
Cell[1574475, 60556, 321, 11, 23, "Index",
  CellTags->"SelectContext"],
Cell[1574799, 60569, 272, 10, 23, "Index",
  CellTags->"SelectIndividuals"],
Cell[1575074, 60581, 232, 10, 23, "Index",
  CellTags->"Selection"],
Cell[1575309, 60593, 1704, 61, 143, "IndexSubentry",
  CellTags->"Selection"],
Cell[1577016, 60656, 437, 15, 23, "Index",
  CellTags->"SelectionCoefficient"],
Cell[1577456, 60673, 327, 11, 23, "Index",
  CellTags->"Selection coefficients"],
Cell[1577786, 60686, 519, 19, 38, "IndexSubentry",
  CellTags->"Selection coefficients"],
Cell[1578308, 60707, 317, 11, 23, "Index",
  CellTags->"SelectionExact"],
Cell[1578628, 60720, 658, 21, 53, "IndexSubentry",
  CellTags->"SelectionExact"],
Cell[1579289, 60743, 290, 11, 23, "Index",
  CellTags->"Selection on diploids"],
Cell[1579582, 60756, 888, 33, 83, "IndexSubentry",
  CellTags->"Selection on diploids"],
Cell[1580473, 60791, 304, 11, 23, "Index",
  CellTags->"SelectionRate"],
Cell[1580780, 60804, 251, 10, 23, "Index",
  CellTags->"SelectLoci"],
Cell[1581034, 60816, 217, 10, 23, "Index",
  CellTags->"Selfing"],
Cell[1581254, 60828, 235, 10, 23, "Index",
  CellTags->"Separate"],
Cell[1581492, 60840, 258, 11, 23, "Index",
  CellTags->"Servedio"],
Cell[1581753, 60853, 339, 12, 23, "Index",
  CellTags->"Set"],
Cell[1582095, 60867, 323, 10, 23, "IndexSubentry",
  CellTags->"Set"],
Cell[1582421, 60879, 293, 11, 23, "Index",
  CellTags->"Set manipulation"],
Cell[1582717, 60892, 251, 10, 23, "Index",
  CellTags->"SetPartition"],
Cell[1582971, 60904, 304, 11, 23, "Index",
  CellTags->"Sets of loci"],
Cell[1583278, 60917, 216, 10, 23, "Index",
  CellTags->"Sex"],
Cell[1583497, 60929, 394, 14, 23, "Index",
  CellTags->"Sex linkage"],
Cell[1583894, 60945, 236, 9, 23, "IndexSubentry",
  CellTags->"Sex linkage"],
Cell[1584133, 60956, 240, 10, 23, "Index",
  CellTags->"SexOfOrigin"],
Cell[1584376, 60968, 267, 10, 23, "Index",
  CellTags->"Sexual selection"],
Cell[1584646, 60980, 1209, 45, 113, "IndexSubentry",
  CellTags->"Sexual selection"],
Cell[1585858, 61027, 265, 10, 23, "Index",
  CellTags->"ShortContext"],
Cell[1586126, 61039, 278, 10, 23, "Index",
  CellTags->"SigmaMatrix"],
Cell[1586407, 61051, 247, 10, 23, "Index",
  CellTags->"SignMask"],
Cell[1586657, 61063, 236, 10, 23, "Index",
  CellTags->"SimplifyAddUp"],
Cell[1586896, 61075, 239, 10, 23, "Index",
  CellTags->"SimplifyAddUpQ"],
Cell[1587138, 61087, 261, 10, 23, "Index",
  CellTags->"SimplifyFamilies"],
Cell[1587402, 61099, 335, 11, 23, "Index",
  CellTags->"Simulating individuals"],
Cell[1587740, 61112, 503, 15, 38, "IndexSubentry",
  CellTags->"Simulating individuals"],
Cell[1588246, 61129, 284, 10, 23, "Index",
  CellTags->"SizeOfGenealogyPlot"],
Cell[1588533, 61141, 279, 10, 23, "Index",
  CellTags->"Slatkin & Excoffier 1996"],
Cell[1588815, 61153, 239, 10, 23, "Index",
  CellTags->"SlowChange"],
Cell[1589057, 61165, 274, 10, 23, "Index",
  CellTags->"SortByClass"],
Cell[1589334, 61177, 284, 9, 23, "IndexSubentry",
  CellTags->"SortByClass"],
Cell[1589621, 61188, 231, 10, 23, "Index",
  CellTags->"SortByHead"],
Cell[1589855, 61200, 254, 10, 23, "Index",
  CellTags->"SpatialCovariance"],
Cell[1590112, 61212, 323, 11, 23, "Index",
  CellTags->"Spatially varying selection"],
Cell[1590438, 61225, 268, 10, 23, "Index",
  CellTags->"Special notation"],
Cell[1590709, 61237, 301, 11, 23, "Index",
  CellTags->"Stabilising selection"],
Cell[1591013, 61250, 1135, 40, 98, "IndexSubentry",
  CellTags->"Stabilising selection"],
Cell[1592151, 61292, 411, 15, 23, "Index",
  CellTags->"Stability"],
Cell[1592565, 61309, 275, 9, 23, "IndexSubentry",
  CellTags->"Stability"],
Cell[1592843, 61320, 320, 11, 23, "Index",
  CellTags->"StabilityDirect"],
Cell[1593166, 61333, 280, 9, 23, "IndexSubentry",
  CellTags->"StabilityDirect"],
Cell[1593449, 61344, 422, 14, 23, "Index",
  CellTags->"StabilityK"],
Cell[1593874, 61360, 313, 11, 23, "Index",
  CellTags->"StabilityKTable"],
Cell[1594190, 61373, 282, 10, 23, "Index",
  CellTags->"StabilityMatrix"],
Cell[1594475, 61385, 293, 11, 23, "Index",
  CellTags->"Stage"],
Cell[1594771, 61398, 225, 10, 23, "Index",
  CellTags->"Stages"],
Cell[1594999, 61410, 288, 9, 23, "IndexSubentry",
  CellTags->"Stages"],
Cell[1595290, 61421, 285, 10, 23, "Index",
  CellTags->"StartingStepSize"],
Cell[1595578, 61433, 357, 12, 23, "Index",
  CellTags->"Stepping-stone migration"],
Cell[1595938, 61447, 347, 12, 23, "Index",
  CellTags->"Stepping-stone model"],
Cell[1596288, 61461, 501, 16, 38, "IndexSubentry",
  CellTags->"Stepping-stone model"],
Cell[1596792, 61479, 323, 11, 23, "Index",
  CellTags->"StoreExact"],
Cell[1597118, 61492, 1518, 45, 113, "IndexSubentry",
  CellTags->"StoreExact"],
Cell[1598639, 61539, 450, 15, 23, "Index",
  CellTags->"StoreResults"],
Cell[1599092, 61556, 813, 24, 38, "IndexSubentry",
  CellTags->"StoreResults"],
Cell[1599908, 61582, 264, 10, 23, "Index",
  CellTags->"StructuredArray"],
Cell[1600175, 61594, 304, 10, 23, "Index",
  CellTags->"StructuredInitialParameters"],
Cell[1600482, 61606, 327, 11, 23, "Index",
  CellTags->"StructuredLogLikelihood"],
Cell[1600812, 61619, 434, 14, 23, "Index",
  CellTags->"StructuredMLE"],
Cell[1601249, 61635, 264, 10, 23, "Index",
  CellTags->"StructuredModel"],
Cell[1601516, 61647, 288, 10, 23, "Index",
  CellTags->"StructuredModelReduce"],
Cell[1601807, 61659, 262, 11, 23, "Index",
  CellTags->"Structured models"],
Cell[1602072, 61672, 272, 9, 23, "IndexSubentry",
  CellTags->"Structured models"],
Cell[1602347, 61683, 286, 10, 23, "Index",
  CellTags->"StructuredParameter"],
Cell[1602636, 61695, 332, 11, 23, "Index",
  CellTags->"StructuredVariance"],
Cell[1602971, 61708, 248, 11, 23, "Index",
  CellTags->"Style sheets"],
Cell[1603222, 61721, 272, 10, 23, "Index",
  CellTags->"Subdivide"],
Cell[1603497, 61733, 309, 11, 23, "Index",
  CellTags->"Subscripts"],
Cell[1603809, 61746, 222, 10, 23, "Index",
  CellTags->"Subsets"],
Cell[1604034, 61758, 366, 15, 38, "IndexSubentry",
  CellTags->"Subsets"],
Cell[1604403, 61775, 234, 11, 23, "Index",
  CellTags->"Sums"],
Cell[1604640, 61788, 344, 11, 23, "Index",
  CellTags->"Symmetric cline"],
Cell[1604987, 61801, 317, 9, 23, "IndexSubentry",
  CellTags->"Symmetric cline"],
Cell[1605307, 61812, 331, 11, 23, "Index",
  CellTags->"SymmetricDiploidFrequencies"],
Cell[1605641, 61825, 331, 11, 23, "Index",
  CellTags->"SymmetricHaploidFrequencies"],
Cell[1605975, 61838, 431, 15, 23, "Index",
  CellTags->"Symmetric model"],
Cell[1606409, 61855, 1473, 49, 113, "IndexSubentry",
  CellTags->"Symmetric model"],
Cell[1607885, 61906, 477, 15, 23, "Index",
  CellTags->"SymmetricNeutralDiploidFrequencies"],
Cell[1608365, 61923, 477, 15, 23, "Index",
  CellTags->"SymmetricNeutralHaploidFrequencies"],
Cell[1608845, 61940, 279, 10, 23, "Index",
  CellTags->"SymmetricRecombination"],
Cell[1609127, 61952, 315, 10, 23, "Index",
  CellTags->"SymmetricRepresentations"],
Cell[1609445, 61964, 259, 10, 23, "Index",
  CellTags->"SymmetricSexes"],
Cell[1609707, 61976, 356, 14, 23, "Index",
  CellTags->"Symmetrise"],
Cell[1610066, 61992, 234, 11, 23, "Index",
  CellTags->"T"],
Cell[1610303, 62005, 277, 11, 23, "Index",
  CellTags->"Table"],
Cell[1610583, 62018, 220, 10, 23, "Index",
  CellTags->"Tag"],
Cell[1610806, 62030, 260, 11, 23, "Index",
  CellTags->"Tags"],
Cell[1611069, 62043, 295, 10, 23, "IndexSubentry",
  CellTags->"Tags"],
Cell[1611367, 62055, 390, 12, 23, "Index",
  CellTags->"TakeAway"],
Cell[1611760, 62069, 260, 10, 23, "Index",
  CellTags->"TakeOptions"],
Cell[1612023, 62081, 237, 11, 23, "Index",
  CellTags->"Time"],
Cell[1612263, 62094, 346, 14, 23, "Index",
  CellTags->"TimesUp"],
Cell[1612612, 62110, 375, 15, 38, "IndexSubentry",
  CellTags->"TimesUp"],
Cell[1612990, 62127, 260, 10, 23, "Index",
  CellTags->"ToCumulants"],
Cell[1613253, 62139, 254, 10, 23, "Index",
  CellTags->"ToMoments"],
Cell[1613510, 62151, 296, 10, 23, "Index",
  CellTags->"ToPopulationCumulants"],
Cell[1613809, 62163, 290, 10, 23, "Index",
  CellTags->"ToPopulationMoments"],
Cell[1614102, 62175, 286, 10, 23, "Index",
  CellTags->"TotalLength"],
Cell[1614391, 62187, 252, 10, 23, "Index",
  CellTags->"TotalNumber"],
Cell[1614646, 62199, 339, 12, 23, "Index",
  CellTags->"Trait"],
Cell[1614988, 62213, 271, 10, 23, "Index",
  CellTags->"TransformedRange"],
Cell[1615262, 62225, 291, 10, 23, "Index",
  CellTags->"TransformInformation"],
Cell[1615556, 62237, 269, 10, 23, "Index",
  CellTags->"TransmissionRule"],
Cell[1615828, 62249, 300, 11, 23, "Index",
  CellTags->"Transmission rules"],
Cell[1616131, 62262, 647, 21, 53, "IndexSubentry",
  CellTags->"Transmission rules"],
Cell[1616781, 62285, 272, 10, 23, "Index",
  CellTags->"TriDiagonalMatrix"],
Cell[1617056, 62297, 352, 12, 23, "Index",
  CellTags->"TruncationSelection"],
Cell[1617411, 62311, 318, 9, 23, "IndexSubentry",
  CellTags->"TruncationSelection"],
Cell[1617732, 62322, 298, 10, 23, "Index",
  CellTags->"Turelli and Barton 1994"],
Cell[1618033, 62334, 270, 10, 23, "Index",
  CellTags->"Turelli & Barton 1994"],
Cell[1618306, 62346, 240, 10, 23, "Index",
  CellTags->"Two alleles"],
Cell[1618549, 62358, 360, 13, 23, "IndexSubentry",
  CellTags->"Two alleles"],
Cell[1618912, 62373, 302, 11, 23, "Index",
  CellTags->"UMS"],
Cell[1619217, 62386, 667, 21, 53, "IndexSubentry",
  CellTags->"UMS"],
Cell[1619887, 62409, 261, 10, 23, "Index",
  CellTags->"UnionOfGametes"],
Cell[1620151, 62421, 276, 10, 23, "Index",
  CellTags->"UnlinkedRecombination"],
Cell[1620430, 62433, 286, 10, 23, "Index",
  CellTags->"UnrootedGenealogy"],
Cell[1620719, 62445, 269, 10, 23, "Index",
  CellTags->"UpperOffDiagonal"],
Cell[1620991, 62457, 302, 11, 23, "Index",
  CellTags->"USM"],
Cell[1621296, 62470, 667, 21, 53, "IndexSubentry",
  CellTags->"USM"],
Cell[1621966, 62493, 332, 11, 23, "Index",
  CellTags->"VarianceComponents"],
Cell[1622301, 62506, 263, 9, 23, "IndexSubentry",
  CellTags->"VarianceComponents"],
Cell[1622567, 62517, 253, 11, 23, "Index",
  CellTags->"Versions"],
Cell[1622823, 62530, 260, 11, 23, "Index",
  CellTags->"WLinkedLoci"],
Cell[1623086, 62543, 441, 15, 38, "IndexSubentry",
  CellTags->"WLinkedLoci"],
Cell[1623530, 62560, 277, 10, 23, "Index",
  CellTags->"Wright-Fisher sampling"],
Cell[1623810, 62572, 247, 11, 23, "Index",
  CellTags->"X"],
Cell[1624060, 62585, 260, 11, 23, "Index",
  CellTags->"XLinkedLoci"],
Cell[1624323, 62598, 441, 15, 38, "IndexSubentry",
  CellTags->"XLinkedLoci"],
Cell[1624767, 62615, 260, 11, 23, "Index",
  CellTags->"YLinkedLoci"],
Cell[1625030, 62628, 441, 15, 38, "IndexSubentry",
  CellTags->"YLinkedLoci"],
Cell[1625474, 62645, 260, 11, 23, "Index",
  CellTags->"ZLinkedLoci"],
Cell[1625737, 62658, 441, 15, 38, "IndexSubentry",
  CellTags->"ZLinkedLoci"],
Cell[1626181, 62675, 411, 15, 23, "Index",
  CellTags->"Zygotes"],
Cell[1626595, 62692, 427, 15, 23, "Index",
  CellTags->"\[GothicA]"],
Cell[1627025, 62709, 419, 15, 23, "Index",
  CellTags->"\[GothicCapitalA]"],
Cell[1627447, 62726, 340, 11, 23, "Index",
  CellTags->"\[GothicCapitalC]"],
Cell[1627790, 62739, 612, 19, 23, "Index",
  CellTags->"\[GothicCapitalD]"],
Cell[1628405, 62760, 494, 16, 23, "Index",
  CellTags->"\!\(\(\[GothicCapitalG]\^\[RawStar]\)\)"],
Cell[1628902, 62778, 421, 15, 23, "Index",
  CellTags->"\[GothicCapitalG]"],
Cell[1629326, 62795, 435, 15, 23, "Index",
  CellTags->"\[GothicCapitalH]"],
Cell[1629764, 62812, 425, 15, 23, "Index",
  CellTags->"\[GothicCapitalJ]"],
Cell[1630192, 62829, 320, 11, 23, "Index",
  CellTags->"\[GothicK]"],
Cell[1630515, 62842, 377, 11, 23, "Index",
  CellTags->"\[GothicCapitalK]"],
Cell[1630895, 62855, 308, 11, 23, "Index",
  CellTags->"\[GothicM]"],
Cell[1631206, 62868, 308, 11, 23, "Index",
  CellTags->"\[GothicP]"],
Cell[1631517, 62881, 369, 12, 23, "Index",
  CellTags->"\[GothicP]\[GothicQ]"],
Cell[1631889, 62895, 308, 11, 23, "Index",
  CellTags->"\[GothicQ]"],
Cell[1632200, 62908, 314, 11, 23, "Index",
  CellTags->"\[GothicR]"],
Cell[1632517, 62921, 301, 11, 23, "Index",
  CellTags->"\[GothicS]"],
Cell[1632821, 62934, 421, 15, 23, "Index",
  CellTags->"\[GothicCapitalZ]"],
Cell[1633245, 62951, 348, 11, 23, "Index",
  CellTags->"\[DoubleStruckCapitalG]"],
Cell[1633596, 62964, 322, 11, 23, "Index",
  CellTags->"\[DoubleStruckCapitalM]"],
Cell[1633921, 62977, 457, 15, 23, "Index",
  CellTags->"\[DoubleStruckCapitalR]"],
Cell[1634381, 62994, 318, 11, 23, "Index",
  CellTags->"\[DoubleStruckCapitalW]"],
Cell[1634702, 63007, 358, 12, 23, "Index",
  CellTags->"\[DoubleStruckCapitalZ]"],
Cell[1635063, 63021, 310, 11, 23, "Index",
  CellTags->"\[Gamma]"],
Cell[1635376, 63034, 304, 11, 23, "Index",
  CellTags->"\[Zeta]"],
Cell[1635683, 63047, 307, 11, 23, "Index",
  CellTags->"\[CapitalMu]"],
Cell[1635993, 63060, 312, 11, 23, "Index",
  CellTags->"\[Chi]"],
Cell[1636308, 63073, 296, 11, 23, "Index",
  CellTags->"\[Sampi]"],
Cell[1636607, 63086, 290, 10, 23, "Index",
  CellTags->"$MetropolisAdjustment"],
Cell[1636900, 63098, 317, 11, 23, "Index",
  CellTags->"\[WeierstrassP]"],
Cell[1637220, 63111, 449, 12, 23, "Index",
  CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],
Cell[1637672, 63125, 320, 11, 23, "Index",
  CellTags->"\[CircleDot]"],
Cell[1637995, 63138, 394, 12, 23, "Index",
  CellTags->"\[Backslash]"],
Cell[1638392, 63152, 450, 15, 23, "Index",
  CellTags->"\[Wedge]"],
Cell[1638845, 63169, 319, 11, 23, "Index",
  CellTags->"\[CirclePlus]"]
}, Closed]],

Cell[CellGroupData[{
Cell[1639201, 63185, 34, 0, 28, "Subsubsection"],
Cell[1639238, 63187, 106, 2, 27, "Input"],
Cell[1639347, 63191, 247, 11, 23, "Index",
  CellTags->"|."],
Cell[1639597, 63204, 233, 11, 23, "Index",
  CellTags->"\\\\"],
Cell[1639833, 63217, 243, 11, 23, "Index",
  CellTags->"<>"],
Cell[1640079, 63230, 254, 11, 23, "Index",
  CellTags->"||."],
Cell[1640336, 63243, 271, 10, 23, "Index",
  CellTags->"AddGenealogy"],
Cell[1640610, 63255, 272, 10, 23, "Index",
  CellTags->"Additive models"],
Cell[1640885, 63267, 303, 11, 23, "Index",
  CellTags->"Additive selection"],
Cell[1641191, 63280, 713, 27, 68, "IndexSubentry",
  CellTags->"Additive selection"],
Cell[1641907, 63309, 256, 10, 23, "Index",
  CellTags->"AddNode"],
Cell[1642166, 63321, 229, 10, 23, "Index",
  CellTags->"AddTag"],
Cell[1642398, 63333, 334, 14, 23, "Index",
  CellTags->"AddUp"],
Cell[1642735, 63349, 492, 21, 53, "IndexSubentry",
  CellTags->"AddUp"],
Cell[1643230, 63372, 261, 10, 23, "Index",
  CellTags->"AdmixtureFrequency"],
Cell[1643494, 63384, 352, 14, 23, "Index",
  CellTags->"Admixture models"],
Cell[1643849, 63400, 843, 33, 83, "IndexSubentry",
  CellTags->"Admixture models"],
Cell[1644695, 63435, 408, 15, 23, "Index",
  CellTags->"Adults"],
Cell[1645106, 63452, 326, 11, 23, "Index",
  CellTags->"Allele frequencies"],
Cell[1645435, 63465, 470, 15, 15, "Index",
  CellTags->"AlleleFrequencies"],
Cell[1645908, 63482, 298, 10, 15, "Index",
  CellTags->"AlleleFrequencyMean"],
Cell[1646209, 63494, 952, 29, 60, "IndexSubentry",
  CellTags->"AlleleFrequencyMean"],
Cell[1647164, 63525, 314, 11, 15, "Index",
  CellTags->"AlleleFrequencyP"],
Cell[1647481, 63538, 304, 10, 15, "Index",
  CellTags->"AlleleFrequencyPermutations"],
Cell[1647788, 63550, 366, 12, 15, "Index",
  CellTags->"AlleleFrequencyPQ"],
Cell[1648157, 63564, 314, 11, 15, "Index",
  CellTags->"AlleleFrequencyQ"],
Cell[1648474, 63577, 301, 10, 15, "Index",
  CellTags->"AlleleFrequencyTable"],
Cell[1648778, 63589, 962, 30, 60, "IndexSubentry",
  CellTags->"AlleleFrequencyTable"],
Cell[1649743, 63621, 313, 11, 15, "Index",
  CellTags->"AllelicDeviation"],
Cell[1650059, 63634, 258, 11, 15, "Index",
  CellTags->"AllelicState"],
Cell[1650320, 63647, 258, 10, 15, "Index",
  CellTags->"AllSets"],
Cell[1650581, 63659, 273, 11, 15, "Index",
  CellTags->"Ancestors"],
Cell[1650857, 63672, 255, 10, 15, "Index",
  CellTags->"Ancestry"],
Cell[1651115, 63684, 312, 11, 15, "Index",
  CellTags->"Arbitrary sets of loci"],
Cell[1651430, 63697, 240, 10, 15, "Index",
  CellTags->"Arnold 1996"],
Cell[1651673, 63709, 414, 14, 15, "Index",
  CellTags->"Asmussen and Orive 2000"],
Cell[1652090, 63725, 266, 10, 15, "Index",
  CellTags->"Asmussen et al. 1987"],
Cell[1652359, 63737, 256, 10, 15, "Index",
  CellTags->"B"],
Cell[1652618, 63749, 276, 11, 15, "Index",
  CellTags->"Barrier"],
Cell[1652897, 63762, 276, 10, 15, "Index",
  CellTags->"BarrierStrength"],
Cell[1653176, 63774, 240, 10, 15, "Index",
  CellTags->"Barton 1986"],
Cell[1653419, 63786, 262, 10, 15, "Index",
  CellTags->"Barton 1995"],
Cell[1653684, 63798, 240, 10, 15, "Index",
  CellTags->"Barton 2000"],
Cell[1653927, 63810, 298, 10, 15, "Index",
  CellTags->"Barton and Turelli 1991"],
Cell[1654228, 63822, 261, 10, 15, "Index",
  CellTags->"Barton & Gale 1993"],
Cell[1654492, 63834, 264, 10, 15, "Index",
  CellTags->"Barton & Shpak 1999"],
Cell[1654759, 63846, 270, 10, 15, "Index",
  CellTags->"Barton & Turelli 1991"],
Cell[1655032, 63858, 236, 10, 15, "Index",
  CellTags->"Biallelic"],
Cell[1655271, 63870, 358, 13, 15, "IndexSubentry",
  CellTags->"Biallelic"],
Cell[1655632, 63885, 262, 10, 15, "Index",
  CellTags->"Birth"],
Cell[1655897, 63897, 258, 10, 15, "Index",
  CellTags->"BirthTime"],
Cell[1656158, 63909, 447, 15, 15, "Index",
  CellTags->"Boundary conditions"],
Cell[1656608, 63926, 240, 10, 15, "Index",
  CellTags->"Box"],
Cell[1656851, 63938, 246, 10, 15, "Index",
  CellTags->"Boxes"],
Cell[1657100, 63950, 293, 10, 15, "Index",
  CellTags->"Browser categories"],
Cell[1657396, 63962, 239, 11, 15, "Index",
  CellTags->"Bugs"],
Cell[1657638, 63975, 1449, 57, 135, "IndexSubentry",
  CellTags->"Bugs"],
Cell[1659090, 64034, 318, 11, 15, "Index",
  CellTags->"ChangeContext"],
Cell[1659411, 64047, 238, 10, 15, "Index",
  CellTags->"ChangeSex"],
Cell[1659652, 64059, 289, 10, 15, "Index",
  CellTags->"ClassToGenotypes"],
Cell[1659944, 64071, 253, 11, 15, "Index",
  CellTags->"Cline"],
Cell[1660200, 64084, 2662, 78, 105, "IndexSubentry",
  CellTags->"Cline"],
Cell[1662865, 64164, 325, 11, 15, "Index",
  CellTags->"ClineGradient"],
Cell[1663193, 64177, 323, 11, 15, "Index",
  CellTags->"ClineWidth"],
Cell[1663519, 64190, 695, 21, 45, "IndexSubentry",
  CellTags->"ClineWidth"],
Cell[1664217, 64213, 329, 11, 15, "Index",
  CellTags->"CoalescenceDistribution"],
Cell[1664549, 64226, 282, 10, 15, "Index",
  CellTags->"CollapseGenealogy"],
Cell[1664834, 64238, 232, 10, 15, "Index",
  CellTags->"Combine"],
Cell[1665069, 64250, 256, 10, 15, "Index",
  CellTags->"CompareLogL"],
Cell[1665328, 64262, 1075, 31, 30, "Index",
  CellTags->"Compiled"],
Cell[1666406, 64295, 1073, 31, 30, "Index",
  CellTags->"Compiling"],
Cell[1667482, 64328, 286, 10, 15, "Index",
  CellTags->"CondenseGenealogy"],
Cell[1667771, 64340, 289, 10, 15, "Index",
  CellTags->"ConstrainedIntervals"],
Cell[1668063, 64352, 286, 10, 15, "Index",
  CellTags->"ContextComponentQ"],
Cell[1668352, 64364, 280, 10, 15, "Index",
  CellTags->"ContextPosition"],
Cell[1668635, 64376, 274, 10, 15, "Index",
  CellTags->"ContextStageQ"],
Cell[1668912, 64388, 283, 10, 15, "Index",
  CellTags->"ContextStructure"],
Cell[1669198, 64400, 312, 11, 15, "Index",
  CellTags->"Continuous populations"],
Cell[1669513, 64413, 508, 21, 45, "IndexSubentry",
  CellTags->"Continuous populations"],
Cell[1670024, 64436, 260, 10, 15, "Index",
  CellTags->"ConvertData"],
Cell[1670287, 64448, 291, 10, 15, "Index",
  CellTags->"ConvertHyperlinkToAddOnsLink"],
Cell[1670581, 64460, 427, 15, 15, "Index",
  CellTags->"Converting"],
Cell[1671011, 64477, 287, 10, 15, "Index",
  CellTags->"CountHeterozygotes"],
Cell[1671301, 64489, 292, 11, 15, "Index",
  CellTags->"Covariance"],
Cell[1671596, 64502, 260, 10, 15, "Index",
  CellTags->"CovarianceMidPoints"],
Cell[1671859, 64514, 289, 10, 15, "Index",
  CellTags->"Crow and Kimura 1970"],
Cell[1672151, 64526, 253, 10, 15, "Index",
  CellTags->"Cumulant"],
Cell[1672407, 64538, 332, 11, 15, "Index",
  CellTags->"CumulantDisequilibrium"],
Cell[1672742, 64551, 264, 10, 15, "Index",
  CellTags->"CumulantEquilibrium"],
Cell[1673009, 64563, 392, 11, 15, "Index",
  CellTags->"CumulantPopulationDisequilibrium"],
Cell[1673404, 64576, 268, 10, 15, "Index",
  CellTags->"CumulantReduced"],
Cell[1673675, 64588, 333, 14, 15, "Index",
  CellTags->"Cumulants"],
Cell[1674011, 64604, 426, 14, 15, "Index",
  CellTags->"Cytoplasmic inheritance"],
Cell[1674440, 64620, 440, 15, 30, "IndexSubentry",
  CellTags->"Cytoplasmic inheritance"],
Cell[1674883, 64637, 283, 11, 15, "Index",
  CellTags->"CytoplasmicLoci"],
Cell[1675169, 64650, 453, 15, 30, "IndexSubentry",
  CellTags->"CytoplasmicLoci"],
Cell[1675625, 64667, 307, 10, 15, "Index",
  CellTags->"dAlleleFrequencyPermutations"],
Cell[1675935, 64679, 235, 10, 15, "Index",
  CellTags->"Data"],
Cell[1676173, 64691, 423, 15, 30, "IndexSubentry",
  CellTags->"Data"],
Cell[1676599, 64708, 259, 11, 15, "Index",
  CellTags->"Datasets"],
Cell[1676861, 64721, 262, 10, 15, "Index",
  CellTags->"Death"],
Cell[1677126, 64733, 258, 10, 15, "Index",
  CellTags->"DeathTime"],
Cell[1677387, 64745, 274, 10, 15, "Index",
  CellTags->"DefineContext"],
Cell[1677664, 64757, 271, 10, 15, "Index",
  CellTags->"DegreesOfFreedom"],
Cell[1677938, 64769, 279, 10, 15, "Index",
  CellTags->"DeletedMutations"],
Cell[1678220, 64781, 280, 10, 15, "Index",
  CellTags->"DeleteGenealogy"],
Cell[1678503, 64793, 322, 14, 15, "Index",
  CellTags->"Deme"],
Cell[1678828, 64809, 614, 20, 15, "Index",
  CellTags->"DemeSize"],
Cell[1679445, 64831, 3024, 86, 134, "IndexSubentry",
  CellTags->"DemeSize"],
Cell[1682472, 64919, 264, 10, 15, "Index",
  CellTags->"Dempster et al 1977"],
Cell[1682739, 64931, 252, 10, 15, "Index",
  CellTags->"Density"],
Cell[1682994, 64943, 270, 10, 15, "Index",
  CellTags->"Descendants"],
Cell[1683267, 64955, 263, 9, 15, "IndexSubentry",
  CellTags->"Descendants"],
Cell[1683533, 64966, 296, 10, 15, "Index",
  CellTags->"Dicytonuclear associations"],
Cell[1683832, 64978, 304, 11, 15, "Index",
  CellTags->"Diploid"],
Cell[1684139, 64991, 277, 10, 15, "Index",
  CellTags->"DiploidConstraints"],
Cell[1684419, 65003, 297, 10, 15, "Index",
  CellTags->"DiploidFrequencies"],
Cell[1684719, 65015, 332, 11, 15, "Index",
  CellTags->"DiploidGenotypeFrequency"],
Cell[1685054, 65028, 305, 10, 15, "Index",
  CellTags->"DiploidGenotypeFrequencyList"],
Cell[1685362, 65040, 316, 10, 15, "Index",
  CellTags->"DiploidGenotypeFrequencyReduced"],
Cell[1685681, 65052, 310, 10, 15, "Index",
  CellTags->"DiploidGenotypeFrequencyTable"],
Cell[1685994, 65064, 297, 10, 15, "Index",
  CellTags->"DiploidIndividuals"],
Cell[1686294, 65076, 275, 10, 15, "Index",
  CellTags->"DiploidPhenotype"],
Cell[1686572, 65088, 402, 14, 15, "Index",
  CellTags->"DiploidPsi"],
Cell[1686977, 65104, 309, 10, 15, "Index",
  CellTags->"DiploidRepresentations"],
Cell[1687289, 65116, 414, 14, 15, "Index",
  CellTags->"DiploidSource"],
Cell[1687706, 65132, 259, 10, 15, "Index",
  CellTags->"DiploidSubsets"],
Cell[1687968, 65144, 257, 10, 15, "Index",
  CellTags->"DiploidTypes"],
Cell[1688228, 65156, 281, 11, 15, "Index",
  CellTags->"Disequilibrium"],
Cell[1688512, 65169, 590, 17, 15, "IndexSubentry",
  CellTags->"Disequilibrium"],
Cell[1689105, 65188, 337, 11, 15, "Index",
  CellTags->"DisequilibriumMean"],
Cell[1689445, 65201, 744, 23, 45, "IndexSubentry",
  CellTags->"DisequilibriumMean"],
Cell[1690192, 65226, 340, 11, 15, "Index",
  CellTags->"DisequilibriumTable"],
Cell[1690535, 65239, 748, 23, 45, "IndexSubentry",
  CellTags->"DisequilibriumTable"],
Cell[1691286, 65264, 276, 10, 15, "Index",
  CellTags->"DistanceSquared"],
Cell[1691565, 65276, 241, 10, 15, "Index",
  CellTags->"Distribution"],
Cell[1691809, 65288, 237, 10, 15, "Index",
  CellTags->"DivideZero"],
Cell[1692049, 65300, 277, 10, 15, "Index",
  CellTags->"DoReplicates"],
Cell[1692329, 65312, 353, 12, 15, "Index",
  CellTags->"DoubleCline"],
Cell[1692685, 65326, 772, 23, 45, "IndexSubentry",
  CellTags->"DoubleCline"],
Cell[1693460, 65351, 262, 10, 15, "Index",
  CellTags->"DrawSamples"],
Cell[1693725, 65363, 260, 10, 15, "Index",
  CellTags->"DropOptions"],
Cell[1693988, 65375, 243, 10, 15, "Index",
  CellTags->"Edwards 1972"],
Cell[1694234, 65387, 270, 11, 15, "Index",
  CellTags->"Epistasis"],
Cell[1694507, 65400, 300, 11, 15, "Index",
  CellTags->"EquivalentSexes"],
Cell[1694810, 65413, 267, 10, 15, "Index",
  CellTags->"ErrorBound"],
Cell[1695080, 65425, 298, 10, 15, "Index",
  CellTags->"EstimateFamilyMoments"],
Cell[1695381, 65437, 274, 10, 15, "Index",
  CellTags->"EstimateMoments"],
Cell[1695658, 65449, 269, 11, 15, "Index",
  CellTags->"Estimating D"],
Cell[1695930, 65462, 2407, 92, 210, "IndexSubentry",
  CellTags->"Estimating D"],
Cell[1698340, 65556, 293, 10, 15, "Index",
  CellTags->"ExactEigenvalues"],
Cell[1698636, 65568, 459, 15, 15, "Index",
  CellTags->"ExactIntersection"],
Cell[1699098, 65585, 252, 11, 15, "Index",
  CellTags->"Expectation"],
Cell[1699353, 65598, 550, 16, 30, "IndexSubentry",
  CellTags->"Expectation"],
Cell[1699906, 65616, 329, 11, 15, "Index",
  CellTags->"ExponentialF"],
Cell[1700238, 65629, 877, 26, 45, "IndexSubentry",
  CellTags->"ExponentialF"],
Cell[1701118, 65657, 270, 10, 15, "Index",
  CellTags->"ExtantIndividuals"],
Cell[1701391, 65669, 321, 11, 15, "Index",
  CellTags->"ExtractContexts"],
Cell[1701715, 65682, 254, 10, 15, "Index",
  CellTags->"ExtractExtant"],
Cell[1701972, 65694, 283, 10, 15, "Index",
  CellTags->"ExtractGenealogy"],
Cell[1702258, 65706, 278, 11, 15, "Index",
  CellTags->"ExtractGenes"],
Cell[1702539, 65719, 297, 9, 15, "IndexSubentry",
  CellTags->"ExtractGenes"],
Cell[1702839, 65730, 285, 10, 15, "Index",
  CellTags->"ExtractInformation"],
Cell[1703127, 65742, 260, 10, 15, "Index",
  CellTags->"ExtractRepeat"],
Cell[1703390, 65754, 279, 10, 15, "Index",
  CellTags->"ExtractSubMatrix"],
Cell[1703672, 65766, 327, 11, 15, "Index",
  CellTags->"FamilyAlleleFrequencyEstimate"],
Cell[1704002, 65779, 274, 10, 15, "Index",
  CellTags->"FamilyEffects"],
Cell[1704279, 65791, 256, 10, 15, "Index",
  CellTags->"FamilyM"],
Cell[1704538, 65803, 264, 10, 15, "Index",
  CellTags->"FamilyProbability"],
Cell[1704805, 65815, 291, 11, 15, "Index",
  CellTags->"Family structure"],
Cell[1705099, 65828, 258, 10, 15, "Index",
  CellTags->"Fecundity"],
Cell[1705360, 65840, 249, 10, 15, "Index",
  CellTags->"FindHyperlinks"],
Cell[1705612, 65852, 243, 10, 15, "Index",
  CellTags->"FindIndexTag"],
Cell[1705858, 65864, 238, 10, 15, "Index",
  CellTags->"FindMLE"],
Cell[1706099, 65876, 253, 10, 15, "Index",
  CellTags->"FindNode"],
Cell[1706355, 65888, 251, 10, 15, "Index",
  CellTags->"FindPosition"],
Cell[1706609, 65900, 249, 10, 15, "Index",
  CellTags->"FindTags"],
Cell[1706861, 65912, 316, 11, 15, "Index",
  CellTags->"Fitness"],
Cell[1707180, 65925, 618, 21, 45, "IndexSubentry",
  CellTags->"Fitness"],
Cell[1707801, 65948, 305, 11, 15, "Index",
  CellTags->"FitnessSet"],
Cell[1708109, 65961, 295, 11, 15, "Index",
  CellTags->"FitnessTable"],
Cell[1708407, 65974, 475, 15, 30, "IndexSubentry",
  CellTags->"FitnessTable"],
Cell[1708885, 65991, 300, 11, 15, "Index",
  CellTags->"FixedEnds"],
Cell[1709188, 66004, 1296, 37, 59, "IndexSubentry",
  CellTags->"FixedEnds"],
Cell[1710487, 66043, 278, 10, 15, "Index",
  CellTags->"Flatten"],
Cell[1710768, 66055, 274, 10, 15, "Index",
  CellTags->"FlattenList"],
Cell[1711045, 66067, 277, 9, 15, "IndexSubentry",
  CellTags->"FlattenList"],
Cell[1711325, 66078, 274, 10, 15, "Index",
  CellTags->"FourierNormalised"],
Cell[1711602, 66090, 289, 10, 15, "Index",
  CellTags->"FourierNormalisedTable"],
Cell[1711894, 66102, 315, 10, 15, "Index",
  CellTags->"FrequencyRepresentations"],
Cell[1712212, 66114, 262, 10, 15, "Index",
  CellTags->"FullContext"],
Cell[1712477, 66126, 307, 10, 15, "Index",
  CellTags->"FullGenotypeFrequencyReduced"],
Cell[1712787, 66138, 301, 10, 15, "Index",
  CellTags->"FullGenotypeFrequencyTable"],
Cell[1713091, 66150, 257, 10, 15, "Index",
  CellTags->"FullOutput"],
Cell[1713351, 66162, 241, 10, 15, "Index",
  CellTags->"Function"],
Cell[1713595, 66174, 286, 11, 15, "Index",
  CellTags->"Gametes"],
Cell[1713884, 66187, 1087, 36, 60, "IndexSubentry",
  CellTags->"Gametes"],
Cell[1714974, 66225, 298, 11, 15, "Index",
  CellTags->"GameteTable"],
Cell[1715275, 66238, 440, 15, 30, "IndexSubentry",
  CellTags->"GameteTable"],
Cell[1715718, 66255, 290, 10, 15, "Index",
  CellTags->"GaussianLogLikelihood"],
Cell[1716011, 66267, 260, 10, 15, "Index",
  CellTags->"GaussianMLE"],
Cell[1716274, 66279, 267, 11, 15, "Index",
  CellTags->"Genealogies"],
Cell[1716544, 66292, 412, 15, 30, "IndexSubentry",
  CellTags->"Genealogies"],
Cell[1716959, 66309, 276, 10, 15, "Index",
  CellTags->"GenealogyToMatrix"],
Cell[1717238, 66321, 265, 10, 15, "Index",
  CellTags->"GeneralizedTransform"],
Cell[1717506, 66333, 277, 10, 15, "Index",
  CellTags->"Genes and contexts"],
Cell[1717786, 66345, 334, 12, 15, "Index",
  CellTags->"Genome"],
Cell[1718123, 66359, 416, 15, 15, "Index",
  CellTags->"Genotype"],
Cell[1718542, 66376, 299, 11, 15, "Index",
  CellTags->"Genotype frequencies"],
Cell[1718844, 66389, 301, 10, 15, "Index",
  CellTags->"GenotypeFrequencyArguments"],
Cell[1719148, 66401, 303, 10, 15, "Index",
  CellTags->"GenotypeFrequencyConvert"],
Cell[1719454, 66413, 307, 10, 15, "Index",
  CellTags->"GenotypeFrequencyTable"],
Cell[1719764, 66425, 281, 10, 15, "Index",
  CellTags->"GenotypePosition"],
Cell[1720048, 66437, 288, 10, 15, "Index",
  CellTags->"GenotypeProbability"],
Cell[1720339, 66449, 286, 9, 15, "IndexSubentry",
  CellTags->"GenotypeProbability"],
Cell[1720628, 66460, 256, 11, 15, "Index",
  CellTags->"Genotypes"],
Cell[1720887, 66473, 452, 16, 15, "Index",
  CellTags->"Gnew"],
Cell[1721342, 66491, 261, 10, 15, "Index",
  CellTags->"Goodman et al 1999"],
Cell[1721606, 66503, 399, 14, 15, "Index",
  CellTags->"Griffiths-Tavare"],
Cell[1722008, 66519, 833, 26, 45, "IndexSubentry",
  CellTags->"Griffiths-Tavare"],
Cell[1722844, 66547, 276, 10, 15, "Index",
  CellTags->"Guiasu & Shenitzer 1985"],
Cell[1723123, 66559, 277, 10, 15, "Index",
  CellTags->"HaploidConstraints"],
Cell[1723403, 66571, 297, 10, 15, "Index",
  CellTags->"HaploidFrequencies"],
Cell[1723703, 66583, 332, 11, 15, "Index",
  CellTags->"HaploidGenotypeFrequency"],
Cell[1724038, 66596, 297, 10, 15, "Index",
  CellTags->"HaploidIndividuals"],
Cell[1724338, 66608, 309, 10, 15, "Index",
  CellTags->"HaploidRepresentations"],
Cell[1724650, 66620, 414, 14, 15, "Index",
  CellTags->"HaploidSource"],
Cell[1725067, 66636, 259, 10, 15, "Index",
  CellTags->"HaploidSubsets"],
Cell[1725329, 66648, 257, 10, 15, "Index",
  CellTags->"HaploidTypes"],
Cell[1725589, 66660, 314, 11, 15, "Index",
  CellTags->"Help browser"],
Cell[1725906, 66673, 281, 10, 15, "Index",
  CellTags->"Help Browser"],
Cell[1726190, 66685, 291, 9, 15, "IndexSubentry",
  CellTags->"Help Browser"],
Cell[1726484, 66696, 432, 15, 15, "Index",
  CellTags->"Hermaphrodites"],
Cell[1726919, 66713, 284, 10, 15, "Index",
  CellTags->"HeterozygoteB"],
Cell[1727206, 66725, 237, 10, 15, "Index",
  CellTags->"Hill 1974a"],
Cell[1727446, 66737, 237, 10, 15, "Index",
  CellTags->"Hill 1974b"],
Cell[1727686, 66749, 237, 10, 15, "Index",
  CellTags->"Hill 1974c"],
Cell[1727926, 66761, 303, 10, 15, "Index",
  CellTags->"Hypergeometric model"],
Cell[1728232, 66773, 256, 11, 15, "Index",
  CellTags->"Hyperlinks"],
Cell[1728491, 66786, 621, 22, 45, "IndexSubentry",
  CellTags->"Hyperlinks"],
Cell[1729115, 66810, 270, 10, 15, "Index",
  CellTags->"IncidenceMatrix"],
Cell[1729388, 66822, 290, 11, 15, "Index",
  CellTags->"Index"],
Cell[1729681, 66835, 237, 10, 15, "Index",
  CellTags->"Individual"],
Cell[1729921, 66847, 323, 11, 15, "Index",
  CellTags->"IndividualRepresentations"],
Cell[1730247, 66860, 264, 10, 15, "Index",
  CellTags->"Individuals"],
Cell[1730514, 66872, 272, 10, 15, "Index",
  CellTags->"InitialiseContinuum"],
Cell[1730789, 66884, 263, 10, 15, "Index",
  CellTags->"InitialiseCovariance"],
Cell[1731055, 66896, 414, 14, 15, "Index",
  CellTags->"InitialiseDemes"],
Cell[1731472, 66912, 254, 10, 15, "Index",
  CellTags->"InitialStep"],
Cell[1731729, 66924, 277, 10, 15, "Index",
  CellTags->"InitialStepReduced"],
Cell[1732009, 66936, 270, 10, 15, "Index",
  CellTags->"InternalNodes"],
Cell[1732282, 66948, 268, 10, 15, "Index",
  CellTags->"IntervalCombine"],
Cell[1732553, 66960, 271, 10, 15, "Index",
  CellTags->"IntervalPosition"],
Cell[1732827, 66972, 295, 10, 15, "Index",
  CellTags->"InverseFourierNormalised"],
Cell[1733125, 66984, 310, 10, 15, "Index",
  CellTags->"InverseFourierNormalisedTable"],
Cell[1733438, 66996, 476, 15, 15, "Index",
  CellTags->"Island model"],
Cell[1733917, 67013, 795, 25, 45, "IndexSubentry",
  CellTags->"Island model"],
Cell[1734715, 67040, 295, 10, 15, "Index",
  CellTags->"IterateContinuum"],
Cell[1735013, 67052, 264, 11, 15, "Index",
  CellTags->"IterateExact"],
Cell[1735280, 67065, 1753, 53, 120, "IndexSubentry",
  CellTags->"IterateExact"],
Cell[1737036, 67120, 380, 14, 15, "Index",
  CellTags->"Johnson et al."],
Cell[1737419, 67136, 2235, 85, 195, "IndexSubentry",
  CellTags->"Johnson et al."],
Cell[1739657, 67223, 328, 14, 15, "Index",
  CellTags->"Join"],
Cell[1739988, 67239, 417, 15, 15, "Index",
  CellTags->"Juveniles"],
Cell[1740408, 67256, 310, 10, 15, "Index",
  CellTags->"Kirkpatrick and Barton 1997"],
Cell[1740721, 67268, 316, 10, 15, "Index",
  CellTags->"Kirkpatrick and Servedio 1998"],
Cell[1741040, 67280, 275, 10, 15, "Index",
  CellTags->"Kirkpatrick et al. 1983"],
Cell[1741318, 67292, 237, 10, 15, "Index",
  CellTags->"Kruuk 1997"],
Cell[1741558, 67304, 257, 10, 15, "Index",
  CellTags->"LeafLabels"],
Cell[1741818, 67316, 257, 10, 15, "Index",
  CellTags->"LeafOffset"],
Cell[1742078, 67328, 249, 10, 15, "Index",
  CellTags->"Leaves"],
Cell[1742330, 67340, 229, 10, 15, "Index",
  CellTags->"Life cycle"],
Cell[1742562, 67352, 3070, 111, 180, "IndexSubentry",
  CellTags->"Life cycle"],
Cell[1745635, 67465, 246, 10, 15, "Index",
  CellTags->"Li & Nei 1974"],
Cell[1745884, 67477, 480, 18, 15, "Index",
  CellTags->"Linkage"],
Cell[1746367, 67497, 451, 15, 30, "IndexSubentry",
  CellTags->"Linkage"],
Cell[1746821, 67514, 307, 10, 15, "Index",
  CellTags->"Linkage disequilibrium"],
Cell[1747131, 67526, 280, 10, 15, "Index",
  CellTags->"ListToGenealogy"],
Cell[1747414, 67538, 291, 10, 15, "Index",
  CellTags->"ListToMatrix"],
Cell[1747708, 67550, 255, 10, 15, "Index",
  CellTags->"Location"],
Cell[1747966, 67562, 232, 10, 15, "Index",
  CellTags->"Locations"],
Cell[1748201, 67574, 253, 10, 15, "Index",
  CellTags->"LocusNames"],
Cell[1748457, 67586, 288, 10, 15, "Index",
  CellTags->"LogLikelihoodDisequilibrium"],
Cell[1748748, 67598, 325, 10, 15, "Index",
  CellTags->"LogLikelihoodDisequilibriumReduced"],
Cell[1749076, 67610, 270, 10, 15, "Index",
  CellTags->"LogLikelihoodTest"],
Cell[1749349, 67622, 397, 14, 15, "Index",
  CellTags->"Log-linear models"],
Cell[1749749, 67638, 252, 10, 15, "Index",
  CellTags->"Long et al 1995"],
Cell[1750004, 67650, 269, 10, 15, "Index",
  CellTags->"LowerOffDiagonal"],
Cell[1750276, 67662, 249, 10, 15, "Index",
  CellTags->"MacCallum 1994"],
Cell[1750528, 67674, 269, 10, 15, "Index",
  CellTags->"MacCallum et al. 1998"],
Cell[1750800, 67686, 320, 11, 15, "Index",
  CellTags->"MakeCline"],
Cell[1751123, 67699, 691, 21, 45, "IndexSubentry",
  CellTags->"MakeCline"],
Cell[1751817, 67722, 296, 11, 15, "Index",
  CellTags->"MakeDiploid"],
Cell[1752116, 67735, 474, 15, 30, "IndexSubentry",
  CellTags->"MakeDiploid"],
Cell[1752593, 67752, 279, 10, 15, "Index",
  CellTags->"MakeDistanceList"],
Cell[1752875, 67764, 270, 10, 15, "Index",
  CellTags->"MakeDistances"],
Cell[1753148, 67776, 243, 10, 15, "Index",
  CellTags->"MakeFitnessSet"],
Cell[1753394, 67788, 255, 9, 15, "IndexSubentry",
  CellTags->"MakeFitnessSet"],
Cell[1753652, 67799, 262, 10, 15, "Index",
  CellTags->"MakeGenealogy"],
Cell[1753917, 67811, 278, 10, 15, "Index",
  CellTags->"MakeGenealogyPlot"],
Cell[1754198, 67823, 296, 11, 15, "Index",
  CellTags->"MakeHaploid"],
Cell[1754497, 67836, 474, 15, 30, "IndexSubentry",
  CellTags->"MakeHaploid"],
Cell[1754974, 67853, 322, 11, 15, "Index",
  CellTags->"MakeIndividuals"],
Cell[1755299, 67866, 666, 21, 45, "IndexSubentry",
  CellTags->"MakeIndividuals"],
Cell[1755968, 67889, 270, 10, 15, "Index",
  CellTags->"MakeOneWayTable"],
Cell[1756241, 67901, 268, 10, 15, "Index",
  CellTags->"MakePairwiseTable"],
Cell[1756512, 67913, 325, 11, 15, "Index",
  CellTags->"MakePopulation"],
Cell[1756840, 67926, 711, 22, 45, "IndexSubentry",
  CellTags->"MakePopulation"],
Cell[1757554, 67950, 398, 14, 15, "Index",
  CellTags->"MakeSelectionCoefficient"],
Cell[1757955, 67966, 423, 15, 30, "IndexSubentry",
  CellTags->"MakeSelectionCoefficient"],
Cell[1758381, 67983, 270, 10, 15, "Index",
  CellTags->"Mangel & Hilborn 1996"],
Cell[1758654, 67995, 316, 11, 15, "Index",
  CellTags->"Marginal fitness"],
Cell[1758973, 68008, 642, 21, 45, "IndexSubentry",
  CellTags->"Marginal fitness"],
Cell[1759618, 68031, 256, 10, 15, "Index",
  CellTags->"MarginalTable"],
Cell[1759877, 68043, 302, 11, 15, "Index",
  CellTags->"MarginalW"],
Cell[1760182, 68056, 636, 21, 45, "IndexSubentry",
  CellTags->"MarginalW"],
Cell[1760821, 68079, 254, 10, 15, "Index",
  CellTags->"MatrixGamma"],
Cell[1761078, 68091, 280, 10, 15, "Index",
  CellTags->"MatrixToGenealogy"],
Cell[1761361, 68103, 291, 10, 15, "Index",
  CellTags->"MatrixToList"],
Cell[1761655, 68115, 314, 11, 15, "Index",
  CellTags->"MeanContribution"],
Cell[1761972, 68128, 400, 14, 15, "Index",
  CellTags->"Mean fitness"],
Cell[1762375, 68144, 461, 15, 30, "IndexSubentry",
  CellTags->"Mean fitness"],
Cell[1762839, 68161, 290, 11, 15, "Index",
  CellTags->"MeanW"],
Cell[1763132, 68174, 620, 21, 45, "IndexSubentry",
  CellTags->"MeanW"],
Cell[1763755, 68197, 234, 10, 15, "Index",
  CellTags->"Meiosis"],
Cell[1763992, 68209, 264, 9, 15, "IndexSubentry",
  CellTags->"Meiosis"],
Cell[1764259, 68220, 256, 10, 15, "Index",
  CellTags->"MethodC"],
Cell[1764518, 68232, 256, 10, 15, "Index",
  CellTags->"MethodP"],
Cell[1764777, 68244, 271, 11, 15, "Index",
  CellTags->"Metropolis algorithm"],
Cell[1765051, 68257, 295, 10, 15, "Index",
  CellTags->"MetropolisDisequilibrium"],
Cell[1765349, 68269, 316, 10, 15, "Index",
  CellTags->"MetropolisDisequilibriumReduced"],
Cell[1765668, 68281, 272, 10, 15, "Index",
  CellTags->"Metropolis et al. 1954"],
Cell[1765943, 68293, 382, 14, 15, "Index",
  CellTags->"MFromC"],
Cell[1766328, 68309, 226, 10, 15, "Index",
  CellTags->"Migrate"],
Cell[1766557, 68321, 311, 11, 15, "Index",
  CellTags->"MigrateExact"],
Cell[1766871, 68334, 646, 21, 45, "IndexSubentry",
  CellTags->"MigrateExact"],
Cell[1767520, 68357, 298, 11, 15, "Index",
  CellTags->"Migration"],
Cell[1767821, 68370, 2065, 73, 165, "IndexSubentry",
  CellTags->"Migration"],
Cell[1769889, 68445, 491, 15, 15, "Index",
  CellTags->"MigrationOrder"],
Cell[1770383, 68462, 524, 16, 30, "IndexSubentry",
  CellTags->"MigrationOrder"],
Cell[1770910, 68480, 308, 11, 15, "Index",
  CellTags->"MigrationRate"],
Cell[1771221, 68493, 311, 11, 15, "Index",
  CellTags->"MigrationSet"],
Cell[1771535, 68506, 259, 10, 15, "Index",
  CellTags->"Missing data"],
Cell[1771797, 68518, 352, 14, 15, "Index",
  CellTags->"Moment"],
Cell[1772152, 68534, 305, 10, 15, "Index",
  CellTags->"MomentAfterMigration"],
Cell[1772460, 68546, 332, 11, 15, "Index",
  CellTags->"MomentAfterRecombination"],
Cell[1772795, 68559, 258, 10, 15, "Index",
  CellTags->"MomentEquilibrium"],
Cell[1773056, 68571, 267, 10, 15, "Index",
  CellTags->"MomentLimits"],
Cell[1773326, 68583, 232, 10, 15, "Index",
  CellTags->"MomentNew"],
Cell[1773561, 68595, 262, 10, 15, "Index",
  CellTags->"MomentReduced"],
Cell[1773826, 68607, 222, 10, 15, "Index",
  CellTags->"Moments"],
Cell[1774051, 68619, 1552, 53, 120, "IndexSubentry",
  CellTags->"Moments"],
Cell[1775606, 68674, 289, 10, 15, "Index",
  CellTags->"MomentsFromG"],
Cell[1775898, 68686, 269, 10, 15, "Index",
  CellTags->"MomentSimple"],
Cell[1776170, 68698, 302, 10, 15, "Index",
  CellTags->"MonteCarloGriffithsTavare"],
Cell[1776475, 68710, 302, 10, 15, "Index",
  CellTags->"MonteCarloProbability"],
Cell[1776780, 68722, 258, 10, 15, "Index",
  CellTags->"Mortality"],
Cell[1777041, 68734, 299, 10, 15, "Index",
  CellTags->"MostRecentCommonAncestor"],
Cell[1777343, 68746, 374, 14, 15, "Index",
  CellTags->"MToC"],
Cell[1777720, 68762, 410, 14, 15, "Index",
  CellTags->"MToCEquations"],
Cell[1778133, 68778, 263, 10, 15, "Index",
  CellTags->"Muddle"],
Cell[1778399, 68790, 295, 11, 15, "Index",
  CellTags->"Multilocus algebra"],
Cell[1778697, 68803, 1010, 36, 60, "IndexSubentry",
  CellTags->"Multilocus algebra"],
Cell[1779710, 68841, 390, 15, 15, "Index",
  CellTags->"Multilocus MS"],
Cell[1780103, 68858, 264, 11, 15, "Index",
  CellTags->"Multilocus notation"],
Cell[1780370, 68871, 344, 12, 15, "Index",
  CellTags->"Multinomial sampling"],
Cell[1780717, 68885, 332, 11, 15, "Index",
  CellTags->"MultinomialSamplingProbability"],
Cell[1781052, 68898, 289, 11, 15, "Index",
  CellTags->"Multiple alleles"],
Cell[1781344, 68911, 535, 21, 45, "IndexSubentry",
  CellTags->"Multiple alleles"],
Cell[1781882, 68934, 297, 11, 15, "Index",
  CellTags->"Multiple arguments"],
Cell[1782182, 68947, 336, 11, 15, "Index",
  CellTags->"Multiplicative models"],
Cell[1782521, 68960, 302, 11, 15, "Index",
  CellTags->"MUS"],
Cell[1782826, 68973, 667, 21, 45, "IndexSubentry",
  CellTags->"MUS"],
Cell[1783496, 68996, 275, 10, 15, "Index",
  CellTags->"MutationInterval"],
Cell[1783774, 69008, 297, 10, 15, "Index",
  CellTags->"MutationLabels"],
Cell[1784074, 69020, 269, 10, 15, "Index",
  CellTags->"MutationOrigin"],
Cell[1784346, 69032, 261, 10, 15, "Index",
  CellTags->"MutationRate"],
Cell[1784610, 69044, 254, 10, 15, "Index",
  CellTags->"Mutations"],
Cell[1784867, 69056, 398, 14, 15, "Index",
  CellTags->"MVariables"],
Cell[1785268, 69072, 293, 11, 15, "Index",
  CellTags->"Negative binomial"],
Cell[1785564, 69085, 828, 27, 60, "IndexSubentry",
  CellTags->"Negative binomial"],
Cell[1786395, 69114, 339, 11, 15, "Index",
  CellTags->"NegativeBinomialLogLikelihood"],
Cell[1786737, 69127, 302, 10, 15, "Index",
  CellTags->"NegativeBinomialMLE"],
Cell[1787042, 69139, 368, 11, 15, "Index",
  CellTags->"NegativeHypergeometricDistribution"],
Cell[1787413, 69152, 273, 10, 15, "Index",
  CellTags->"NeighbourArray"],
Cell[1787689, 69164, 261, 10, 15, "Index",
  CellTags->"Neighbours"],
Cell[1787953, 69176, 280, 10, 15, "Index",
  CellTags->"NetCovariance"],
Cell[1788236, 69188, 255, 10, 15, "Index",
  CellTags->"NetFecundity"],
Cell[1788494, 69200, 255, 10, 15, "Index",
  CellTags->"NetMortality"],
Cell[1788752, 69212, 384, 14, 15, "Index",
  CellTags->"NetRecombination"],
Cell[1789139, 69228, 277, 9, 15, "IndexSubentry",
  CellTags->"NetRecombination"],
Cell[1789419, 69239, 285, 11, 15, "Index",
  CellTags->"Neutral marker"],
Cell[1789707, 69252, 309, 10, 15, "Index",
  CellTags->"NeutralRepresentations"],
Cell[1790019, 69264, 309, 11, 15, "Index",
  CellTags->"NewGametes"],
Cell[1790331, 69277, 809, 27, 60, "IndexSubentry",
  CellTags->"NewGametes"],
Cell[1791143, 69306, 249, 10, 15, "Index",
  CellTags->"NewS"],
Cell[1791395, 69318, 380, 14, 15, "Index",
  CellTags->"Node"],
Cell[1791778, 69334, 404, 14, 15, "Index",
  CellTags->"NodeFunction"],
Cell[1792185, 69350, 257, 10, 15, "Index",
  CellTags->"NodeLabels"],
Cell[1792445, 69362, 257, 10, 15, "Index",
  CellTags->"NodeOffset"],
Cell[1792705, 69374, 246, 10, 15, "Index",
  CellTags->"Nodes"],
Cell[1792954, 69386, 263, 10, 15, "Index",
  CellTags->"NonMendelian"],
Cell[1793220, 69398, 366, 13, 15, "IndexSubentry",
  CellTags->"NonMendelian"],
Cell[1793589, 69413, 323, 11, 15, "Index",
  CellTags->"NonNeutralRepresentations"],
Cell[1793915, 69426, 331, 11, 15, "Index",
  CellTags->"NonSymmetricRepresentations"],
Cell[1794249, 69439, 284, 10, 15, "Index",
  CellTags->"Normalisation"],
Cell[1794536, 69451, 275, 10, 15, "Index",
  CellTags->"Normalised"],
Cell[1794814, 69463, 280, 11, 15, "Index",
  CellTags->"Notation"],
Cell[1795097, 69476, 395, 15, 30, "IndexSubentry",
  CellTags->"Notation"],
Cell[1795495, 69493, 253, 10, 15, "Index",
  CellTags->"Notation package"],
Cell[1795751, 69505, 261, 10, 15, "Index",
  CellTags->"NumberedLink"],
Cell[1796015, 69517, 271, 11, 15, "Index",
  CellTags->"Numbering"],
Cell[1796289, 69530, 560, 21, 45, "IndexSubentry",
  CellTags->"Numbering"],
Cell[1796852, 69553, 318, 11, 15, "Index",
  CellTags->"NumberOfCoalescences"],
Cell[1797173, 69566, 266, 10, 15, "Index",
  CellTags->"NumberOfGenes"],
Cell[1797442, 69578, 915, 28, 60, "IndexSubentry",
  CellTags->"NumberOfGenes"],
Cell[1798360, 69608, 281, 10, 15, "Index",
  CellTags->"NumberOfGenesTable"],
Cell[1798644, 69620, 416, 14, 15, "Index",
  CellTags->"NumberOfIndividuals"],
Cell[1799063, 69636, 299, 10, 15, "Index",
  CellTags->"NumberOfIndividualsTable"],
Cell[1799365, 69648, 279, 10, 15, "Index",
  CellTags->"NumberOfLineages"],
Cell[1799647, 69660, 263, 10, 15, "Index",
  CellTags->"NumberOfLoci"],
Cell[1799913, 69672, 278, 10, 15, "Index",
  CellTags->"NumberOfMutations"],
Cell[1800194, 69684, 317, 10, 15, "Index",
  CellTags->"NumberOfPossibleCoalescences"],
Cell[1800514, 69696, 287, 10, 15, "Index",
  CellTags->"NumberOfSamplePartitions"],
Cell[1800804, 69708, 278, 10, 15, "Index",
  CellTags->"NumberOfSetPartitions"],
Cell[1801085, 69720, 325, 11, 15, "Index",
  CellTags->"NumericalModel"],
Cell[1801413, 69733, 294, 9, 15, "IndexSubentry",
  CellTags->"NumericalModel"],
Cell[1801710, 69744, 301, 11, 15, "Index",
  CellTags->"Numerical models"],
Cell[1802014, 69757, 1071, 37, 75, "IndexSubentry",
  CellTags->"Numerical models"],
Cell[1803088, 69796, 420, 14, 15, "Index",
  CellTags->"Observable genotype"],
Cell[1803511, 69812, 250, 11, 15, "Index",
  CellTags->"Obsolete"],
Cell[1803764, 69825, 3253, 115, 270, "IndexSubentry",
  CellTags->"Obsolete"],
Cell[1807020, 69942, 258, 10, 15, "Index",
  CellTags->"Offspring"],
Cell[1807281, 69954, 264, 10, 15, "Index",
  CellTags->"Orive & Barton 1999"],
Cell[1807548, 69966, 247, 10, 15, "Index",
  CellTags->"OtherSex"],
Cell[1807798, 69978, 275, 11, 15, "Index",
  CellTags->"Packages"],
Cell[1808076, 69991, 839, 31, 60, "IndexSubentry",
  CellTags->"Packages"],
Cell[1808918, 70024, 235, 10, 15, "Index",
  CellTags->"PackageSaver"],
Cell[1809156, 70036, 274, 10, 15, "Index",
  CellTags->"PatternFree"],
Cell[1809433, 70048, 264, 10, 15, "Index",
  CellTags->"Phipps & Brill 1995"],
Cell[1809700, 70060, 245, 10, 15, "Index",
  CellTags->"Ploidy"],
Cell[1809948, 70072, 271, 10, 15, "Index",
  CellTags->"PloidyWeightList"],
Cell[1810222, 70084, 266, 10, 15, "Index",
  CellTags->"PlotGenealogy"],
Cell[1810491, 70096, 247, 10, 15, "Index",
  CellTags->"PlotLogL"],
Cell[1810741, 70108, 346, 11, 15, "Index",
  CellTags->"PopulationDisequilibrium"],
Cell[1811090, 70121, 274, 10, 15, "Index",
  CellTags->"PopulationExpectation"],
Cell[1811367, 70133, 271, 9, 15, "IndexSubentry",
  CellTags->"PopulationExpectation"],
Cell[1811641, 70144, 323, 11, 15, "Index",
  CellTags->"PopulationRepresentations"],
Cell[1811967, 70157, 362, 14, 15, "Index",
  CellTags->"Position"],
Cell[1812332, 70173, 257, 9, 15, "IndexSubentry",
  CellTags->"Position"],
Cell[1812592, 70184, 270, 10, 15, "Index",
  CellTags->"PositionsList"],
Cell[1812865, 70196, 276, 10, 15, "Index",
  CellTags->"PositionsMatrix"],
Cell[1813144, 70208, 305, 10, 15, "Index",
  CellTags->"PossibleCoalescenceOrder"],
Cell[1813452, 70220, 303, 10, 15, "Index",
  CellTags->"PossibleDiploidGenotypes"],
Cell[1813758, 70232, 272, 10, 15, "Index",
  CellTags->"PossibleGenotypes"],
Cell[1814033, 70244, 311, 11, 15, "Index",
  CellTags->"PowerF"],
Cell[1814347, 70257, 871, 27, 60, "IndexSubentry",
  CellTags->"PowerF"],
Cell[1815221, 70286, 279, 10, 15, "Index",
  CellTags->"PresentOneWayTable"],
Cell[1815503, 70298, 277, 10, 15, "Index",
  CellTags->"PresentPairwiseTable"],
Cell[1815783, 70310, 265, 10, 15, "Index",
  CellTags->"PresentResults"],
Cell[1816051, 70322, 273, 10, 15, "Index",
  CellTags->"PrintDetails"],
Cell[1816327, 70334, 275, 11, 15, "Index",
  CellTags->"Problems"],
Cell[1816605, 70347, 587, 18, 15, "IndexSubentry",
  CellTags->"Problems"],
Cell[1817195, 70367, 250, 11, 15, "Index",
  CellTags->"Products"],
Cell[1817448, 70380, 237, 10, 15, "Index",
  CellTags->"ProductSum"],
Cell[1817688, 70392, 267, 10, 15, "Index",
  CellTags->"ProductSum over sets"],
Cell[1817958, 70404, 312, 10, 15, "Index",
  CellTags->"RandomBottleneckedGenealogy"],
Cell[1818273, 70416, 299, 10, 15, "Index",
  CellTags->"RandomCoalescenceOrder"],
Cell[1818575, 70428, 326, 11, 15, "Index",
  CellTags->"RandomCoalescenceTimes"],
Cell[1818904, 70441, 288, 10, 15, "Index",
  CellTags->"RandomCum"],
Cell[1819195, 70453, 330, 12, 15, "Index",
  CellTags->"Random drift"],
Cell[1819528, 70467, 2349, 77, 150, "IndexSubentry",
  CellTags->"Random drift"],
Cell[1821880, 70546, 286, 11, 15, "Index",
  CellTags->"RandomDrift"],
Cell[1822169, 70559, 956, 27, 30, "IndexSubentry",
  CellTags->"RandomDrift"],
Cell[1823128, 70588, 259, 10, 15, "Index",
  CellTags->"RandomFamilies"],
Cell[1823390, 70600, 261, 10, 15, "Index",
  CellTags->"RandomFamily"],
Cell[1823654, 70612, 273, 9, 15, "IndexSubentry",
  CellTags->"RandomFamily"],
Cell[1823930, 70623, 299, 11, 15, "Index",
  CellTags->"Random genealogies"],
Cell[1824232, 70636, 270, 10, 15, "Index",
  CellTags->"RandomGenealogy"],
Cell[1824505, 70648, 241, 10, 15, "Index",
  CellTags->"RandomList"],
Cell[1824749, 70660, 259, 9, 15, "IndexSubentry",
  CellTags->"RandomList"],
Cell[1825011, 70671, 259, 11, 15, "Index",
  CellTags->"Random lists"],
Cell[1825273, 70684, 289, 10, 15, "Index",
  CellTags->"RandomMating"],
Cell[1825565, 70696, 286, 10, 15, "Index",
  CellTags->"RandomMultinomial"],
Cell[1825854, 70708, 277, 10, 15, "Index",
  CellTags->"RandomPreviousFamily"],
Cell[1826134, 70720, 288, 10, 15, "Index",
  CellTags->"Random sampling"],
Cell[1826425, 70732, 415, 15, 30, "IndexSubentry",
  CellTags->"Random sampling"],
Cell[1826843, 70749, 236, 10, 15, "Index",
  CellTags->"RandomSet"],
Cell[1827082, 70761, 371, 14, 15, "Index",
  CellTags->"Random union"],
Cell[1827456, 70777, 306, 9, 15, "IndexSubentry",
  CellTags->"Random union"],
Cell[1827765, 70788, 244, 10, 15, "Index",
  CellTags->"RandomUnion"],
Cell[1828012, 70800, 276, 10, 15, "Index",
  CellTags->"RandomUnionMethod"],
Cell[1828291, 70812, 260, 10, 15, "Index",
  CellTags->"RandomUnionObsolete"],
Cell[1828554, 70824, 256, 11, 15, "Index",
  CellTags->"Random walk"],
Cell[1828813, 70837, 378, 14, 15, "Index",
  CellTags->"Recombination"],
Cell[1829194, 70853, 796, 27, 60, "IndexSubentry",
  CellTags->"Recombination"],
Cell[1829993, 70882, 321, 11, 15, "Index",
  CellTags->"RecombinationRate"],
Cell[1830317, 70895, 450, 15, 15, "Index",
  CellTags->"RecombinationSet"],
Cell[1830770, 70912, 283, 10, 15, "Index",
  CellTags->"Recombined"],
Cell[1831056, 70924, 262, 10, 15, "Index",
  CellTags->"ReducedData"],
Cell[1831321, 70936, 316, 11, 15, "Index",
  CellTags->"ReferencePoint"],
Cell[1831640, 70949, 273, 10, 15, "Index",
  CellTags->"ReferencePointMean"],
Cell[1831916, 70961, 819, 27, 30, "IndexSubentry",
  CellTags->"ReferencePointMean"],
Cell[1832738, 70990, 273, 10, 15, "Index",
  CellTags->"ReferencePointSame"],
Cell[1833014, 71002, 273, 10, 15, "Index",
  CellTags->"ReferencePointZero"],
Cell[1833290, 71014, 382, 14, 15, "Index",
  CellTags->"Reference values"],
Cell[1833675, 71030, 273, 9, 15, "IndexSubentry",
  CellTags->"Reference values"],
Cell[1833951, 71041, 238, 10, 15, "Index",
  CellTags->"RemoveTag"],
Cell[1834192, 71053, 239, 10, 15, "Index",
  CellTags->"Repeat"],
Cell[1834434, 71065, 232, 10, 15, "Index",
  CellTags->"Replace"],
Cell[1834669, 71077, 262, 11, 15, "Index",
  CellTags->"ReplaceAllSpecial"],
Cell[1834934, 71090, 278, 11, 15, "Index",
  CellTags->"ReplaceRepeatedSpecial"],
Cell[1835215, 71103, 311, 11, 15, "Index",
  CellTags->"Representations"],
Cell[1835529, 71116, 308, 10, 15, "IndexSubentry",
  CellTags->"Representations"],
Cell[1835840, 71128, 286, 11, 15, "Index",
  CellTags->"Reproduction"],
Cell[1836129, 71141, 222, 10, 15, "Index",
  CellTags->"Reverse"],
Cell[1836354, 71153, 280, 10, 15, "Index",
  CellTags->"RootedGenealogy"],
Cell[1836637, 71165, 244, 10, 15, "Index",
  CellTags->"Rules"],
Cell[1836884, 71177, 234, 9, 15, "IndexSubentry",
  CellTags->"Rules"],
Cell[1837121, 71188, 251, 10, 15, "Index",
  CellTags->"SampleCovariance"],
Cell[1837375, 71200, 278, 10, 15, "Index",
  CellTags->"SampleIndividuals"],
Cell[1837656, 71212, 260, 10, 15, "Index",
  CellTags->"SamplePartition"],
Cell[1837919, 71224, 261, 11, 15, "Index",
  CellTags->"Sampling"],
Cell[1838183, 71237, 297, 11, 15, "Index",
  CellTags->"Scripts and faces"],
Cell[1838483, 71250, 414, 14, 15, "Index",
  CellTags->"SegregationRatio"],
Cell[1838900, 71266, 321, 11, 15, "Index",
  CellTags->"SelectContext"],
Cell[1839224, 71279, 272, 10, 15, "Index",
  CellTags->"SelectIndividuals"],
Cell[1839499, 71291, 232, 10, 15, "Index",
  CellTags->"Selection"],
Cell[1839734, 71303, 1361, 49, 105, "IndexSubentry",
  CellTags->"Selection"],
Cell[1841098, 71354, 437, 15, 15, "Index",
  CellTags->"SelectionCoefficient"],
Cell[1841538, 71371, 305, 11, 15, "Index",
  CellTags->"Selection coefficients"],
Cell[1841846, 71384, 519, 19, 30, "IndexSubentry",
  CellTags->"Selection coefficients"],
Cell[1842368, 71405, 317, 11, 15, "Index",
  CellTags->"SelectionExact"],
Cell[1842688, 71418, 658, 21, 45, "IndexSubentry",
  CellTags->"SelectionExact"],
Cell[1843349, 71441, 290, 11, 15, "Index",
  CellTags->"Selection on diploids"],
Cell[1843642, 71454, 888, 33, 75, "IndexSubentry",
  CellTags->"Selection on diploids"],
Cell[1844533, 71489, 304, 11, 15, "Index",
  CellTags->"SelectionRate"],
Cell[1844840, 71502, 251, 10, 15, "Index",
  CellTags->"SelectLoci"],
Cell[1845094, 71514, 217, 10, 15, "Index",
  CellTags->"Selfing"],
Cell[1845314, 71526, 235, 10, 15, "Index",
  CellTags->"Separate"],
Cell[1845552, 71538, 339, 12, 15, "Index",
  CellTags->"Set"],
Cell[1845894, 71552, 323, 10, 15, "IndexSubentry",
  CellTags->"Set"],
Cell[1846220, 71564, 293, 11, 15, "Index",
  CellTags->"Set manipulation"],
Cell[1846516, 71577, 251, 10, 15, "Index",
  CellTags->"SetPartition"],
Cell[1846770, 71589, 282, 11, 15, "Index",
  CellTags->"Sets of loci"],
Cell[1847055, 71602, 216, 10, 15, "Index",
  CellTags->"Sex"],
Cell[1847274, 71614, 394, 14, 15, "Index",
  CellTags->"Sex linkage"],
Cell[1847671, 71630, 236, 9, 15, "IndexSubentry",
  CellTags->"Sex linkage"],
Cell[1847910, 71641, 240, 10, 15, "Index",
  CellTags->"SexOfOrigin"],
Cell[1848153, 71653, 267, 10, 15, "Index",
  CellTags->"Sexual selection"],
Cell[1848423, 71665, 892, 33, 75, "IndexSubentry",
  CellTags->"Sexual selection"],
Cell[1849318, 71700, 265, 10, 15, "Index",
  CellTags->"ShortContext"],
Cell[1849586, 71712, 278, 10, 15, "Index",
  CellTags->"SigmaMatrix"],
Cell[1849867, 71724, 247, 10, 15, "Index",
  CellTags->"SignMask"],
Cell[1850117, 71736, 236, 10, 15, "Index",
  CellTags->"SimplifyAddUp"],
Cell[1850356, 71748, 239, 10, 15, "Index",
  CellTags->"SimplifyAddUpQ"],
Cell[1850598, 71760, 261, 10, 15, "Index",
  CellTags->"SimplifyFamilies"],
Cell[1850862, 71772, 335, 11, 15, "Index",
  CellTags->"Simulating individuals"],
Cell[1851200, 71785, 503, 15, 30, "IndexSubentry",
  CellTags->"Simulating individuals"],
Cell[1851706, 71802, 284, 10, 15, "Index",
  CellTags->"SizeOfGenealogyPlot"],
Cell[1851993, 71814, 279, 10, 15, "Index",
  CellTags->"Slatkin & Excoffier 1996"],
Cell[1852275, 71826, 239, 10, 15, "Index",
  CellTags->"SlowChange"],
Cell[1852517, 71838, 274, 10, 15, "Index",
  CellTags->"SortByClass"],
Cell[1852794, 71850, 284, 9, 15, "IndexSubentry",
  CellTags->"SortByClass"],
Cell[1853081, 71861, 231, 10, 15, "Index",
  CellTags->"SortByHead"],
Cell[1853315, 71873, 254, 10, 15, "Index",
  CellTags->"SpatialCovariance"],
Cell[1853572, 71885, 323, 11, 15, "Index",
  CellTags->"Spatially varying selection"],
Cell[1853898, 71898, 268, 10, 15, "Index",
  CellTags->"Special notation"],
Cell[1854169, 71910, 301, 11, 15, "Index",
  CellTags->"Stabilising selection"],
Cell[1854473, 71923, 940, 33, 75, "IndexSubentry",
  CellTags->"Stabilising selection"],
Cell[1855416, 71958, 411, 15, 15, "Index",
  CellTags->"Stability"],
Cell[1855830, 71975, 275, 9, 15, "IndexSubentry",
  CellTags->"Stability"],
Cell[1856108, 71986, 320, 11, 15, "Index",
  CellTags->"StabilityDirect"],
Cell[1856431, 71999, 280, 9, 15, "IndexSubentry",
  CellTags->"StabilityDirect"],
Cell[1856714, 72010, 422, 14, 15, "Index",
  CellTags->"StabilityK"],
Cell[1857139, 72026, 313, 11, 15, "Index",
  CellTags->"StabilityKTable"],
Cell[1857455, 72039, 282, 10, 15, "Index",
  CellTags->"StabilityMatrix"],
Cell[1857740, 72051, 293, 11, 15, "Index",
  CellTags->"Stage"],
Cell[1858036, 72064, 225, 10, 15, "Index",
  CellTags->"Stages"],
Cell[1858264, 72076, 266, 9, 15, "IndexSubentry",
  CellTags->"Stages"],
Cell[1858533, 72087, 285, 10, 15, "Index",
  CellTags->"StartingStepSize"],
Cell[1858821, 72099, 357, 12, 15, "Index",
  CellTags->"Stepping-stone migration"],
Cell[1859181, 72113, 347, 12, 15, "Index",
  CellTags->"Stepping-stone model"],
Cell[1859531, 72127, 501, 16, 30, "IndexSubentry",
  CellTags->"Stepping-stone model"],
Cell[1860035, 72145, 323, 11, 15, "Index",
  CellTags->"StoreExact"],
Cell[1860361, 72158, 1518, 45, 105, "IndexSubentry",
  CellTags->"StoreExact"],
Cell[1861882, 72205, 450, 15, 15, "Index",
  CellTags->"StoreResults"],
Cell[1862335, 72222, 813, 24, 30, "IndexSubentry",
  CellTags->"StoreResults"],
Cell[1863151, 72248, 264, 10, 15, "Index",
  CellTags->"StructuredArray"],
Cell[1863418, 72260, 304, 10, 15, "Index",
  CellTags->"StructuredInitialParameters"],
Cell[1863725, 72272, 327, 11, 15, "Index",
  CellTags->"StructuredLogLikelihood"],
Cell[1864055, 72285, 434, 14, 15, "Index",
  CellTags->"StructuredMLE"],
Cell[1864492, 72301, 264, 10, 15, "Index",
  CellTags->"StructuredModel"],
Cell[1864759, 72313, 288, 10, 15, "Index",
  CellTags->"StructuredModelReduce"],
Cell[1865050, 72325, 262, 11, 15, "Index",
  CellTags->"Structured models"],
Cell[1865315, 72338, 272, 9, 15, "IndexSubentry",
  CellTags->"Structured models"],
Cell[1865590, 72349, 286, 10, 15, "Index",
  CellTags->"StructuredParameter"],
Cell[1865879, 72361, 332, 11, 15, "Index",
  CellTags->"StructuredVariance"],
Cell[1866214, 72374, 272, 10, 15, "Index",
  CellTags->"Subdivide"],
Cell[1866489, 72386, 287, 11, 15, "Index",
  CellTags->"Subscripts"],
Cell[1866779, 72399, 222, 10, 15, "Index",
  CellTags->"Subsets"],
Cell[1867004, 72411, 366, 15, 30, "IndexSubentry",
  CellTags->"Subsets"],
Cell[1867373, 72428, 234, 11, 15, "Index",
  CellTags->"Sums"],
Cell[1867610, 72441, 344, 11, 15, "Index",
  CellTags->"Symmetric cline"],
Cell[1867957, 72454, 317, 9, 15, "IndexSubentry",
  CellTags->"Symmetric cline"],
Cell[1868277, 72465, 331, 11, 15, "Index",
  CellTags->"SymmetricDiploidFrequencies"],
Cell[1868611, 72478, 331, 11, 15, "Index",
  CellTags->"SymmetricHaploidFrequencies"],
Cell[1868945, 72491, 431, 15, 15, "Index",
  CellTags->"Symmetric model"],
Cell[1869379, 72508, 1473, 49, 105, "IndexSubentry",
  CellTags->"Symmetric model"],
Cell[1870855, 72559, 477, 15, 15, "Index",
  CellTags->"SymmetricNeutralDiploidFrequencies"],
Cell[1871335, 72576, 477, 15, 15, "Index",
  CellTags->"SymmetricNeutralHaploidFrequencies"],
Cell[1871815, 72593, 279, 10, 15, "Index",
  CellTags->"SymmetricRecombination"],
Cell[1872097, 72605, 315, 10, 15, "Index",
  CellTags->"SymmetricRepresentations"],
Cell[1872415, 72617, 259, 10, 15, "Index",
  CellTags->"SymmetricSexes"],
Cell[1872677, 72629, 356, 14, 15, "Index",
  CellTags->"Symmetrise"],
Cell[1873036, 72645, 234, 11, 15, "Index",
  CellTags->"T"],
Cell[1873273, 72658, 277, 11, 15, "Index",
  CellTags->"Table"],
Cell[1873553, 72671, 220, 10, 15, "Index",
  CellTags->"Tag"],
Cell[1873776, 72683, 260, 11, 15, "Index",
  CellTags->"Tags"],
Cell[1874039, 72696, 295, 10, 15, "IndexSubentry",
  CellTags->"Tags"],
Cell[1874337, 72708, 390, 12, 15, "Index",
  CellTags->"TakeAway"],
Cell[1874730, 72722, 260, 10, 15, "Index",
  CellTags->"TakeOptions"],
Cell[1874993, 72734, 237, 11, 15, "Index",
  CellTags->"Time"],
Cell[1875233, 72747, 346, 14, 15, "Index",
  CellTags->"TimesUp"],
Cell[1875582, 72763, 375, 15, 30, "IndexSubentry",
  CellTags->"TimesUp"],
Cell[1875960, 72780, 260, 10, 15, "Index",
  CellTags->"ToCumulants"],
Cell[1876223, 72792, 254, 10, 15, "Index",
  CellTags->"ToMoments"],
Cell[1876480, 72804, 296, 10, 15, "Index",
  CellTags->"ToPopulationCumulants"],
Cell[1876779, 72816, 290, 10, 15, "Index",
  CellTags->"ToPopulationMoments"],
Cell[1877072, 72828, 286, 10, 15, "Index",
  CellTags->"TotalLength"],
Cell[1877361, 72840, 252, 10, 15, "Index",
  CellTags->"TotalNumber"],
Cell[1877616, 72852, 339, 12, 15, "Index",
  CellTags->"Trait"],
Cell[1877958, 72866, 271, 10, 15, "Index",
  CellTags->"TransformedRange"],
Cell[1878232, 72878, 291, 10, 15, "Index",
  CellTags->"TransformInformation"],
Cell[1878526, 72890, 269, 10, 15, "Index",
  CellTags->"TransmissionRule"],
Cell[1878798, 72902, 300, 11, 15, "Index",
  CellTags->"Transmission rules"],
Cell[1879101, 72915, 472, 15, 30, "IndexSubentry",
  CellTags->"Transmission rules"],
Cell[1879576, 72932, 272, 10, 15, "Index",
  CellTags->"TriDiagonalMatrix"],
Cell[1879851, 72944, 298, 10, 15, "Index",
  CellTags->"Turelli and Barton 1994"],
Cell[1880152, 72956, 270, 10, 15, "Index",
  CellTags->"Turelli & Barton 1994"],
Cell[1880425, 72968, 240, 10, 15, "Index",
  CellTags->"Two alleles"],
Cell[1880668, 72980, 360, 13, 15, "IndexSubentry",
  CellTags->"Two alleles"],
Cell[1881031, 72995, 302, 11, 15, "Index",
  CellTags->"UMS"],
Cell[1881336, 73008, 667, 21, 45, "IndexSubentry",
  CellTags->"UMS"],
Cell[1882006, 73031, 261, 10, 15, "Index",
  CellTags->"UnionOfGametes"],
Cell[1882270, 73043, 276, 10, 15, "Index",
  CellTags->"UnlinkedRecombination"],
Cell[1882549, 73055, 286, 10, 15, "Index",
  CellTags->"UnrootedGenealogy"],
Cell[1882838, 73067, 269, 10, 15, "Index",
  CellTags->"UpperOffDiagonal"],
Cell[1883110, 73079, 302, 11, 15, "Index",
  CellTags->"USM"],
Cell[1883415, 73092, 667, 21, 45, "IndexSubentry",
  CellTags->"USM"],
Cell[1884085, 73115, 332, 11, 15, "Index",
  CellTags->"VarianceComponents"],
Cell[1884420, 73128, 263, 9, 15, "IndexSubentry",
  CellTags->"VarianceComponents"],
Cell[1884686, 73139, 253, 11, 15, "Index",
  CellTags->"Versions"],
Cell[1884942, 73152, 260, 11, 15, "Index",
  CellTags->"WLinkedLoci"],
Cell[1885205, 73165, 441, 15, 30, "IndexSubentry",
  CellTags->"WLinkedLoci"],
Cell[1885649, 73182, 277, 10, 15, "Index",
  CellTags->"Wright-Fisher sampling"],
Cell[1885929, 73194, 247, 11, 15, "Index",
  CellTags->"X"],
Cell[1886179, 73207, 260, 11, 15, "Index",
  CellTags->"XLinkedLoci"],
Cell[1886442, 73220, 441, 15, 30, "IndexSubentry",
  CellTags->"XLinkedLoci"],
Cell[1886886, 73237, 260, 11, 15, "Index",
  CellTags->"YLinkedLoci"],
Cell[1887149, 73250, 441, 15, 30, "IndexSubentry",
  CellTags->"YLinkedLoci"],
Cell[1887593, 73267, 260, 11, 15, "Index",
  CellTags->"ZLinkedLoci"],
Cell[1887856, 73280, 441, 15, 30, "IndexSubentry",
  CellTags->"ZLinkedLoci"],
Cell[1888300, 73297, 411, 15, 15, "Index",
  CellTags->"Zygotes"],
Cell[1888714, 73314, 427, 15, 15, "Index",
  CellTags->"\[GothicA]"],
Cell[1889144, 73331, 419, 15, 15, "Index",
  CellTags->"\[GothicCapitalA]"],
Cell[1889566, 73348, 340, 11, 15, "Index",
  CellTags->"\[GothicCapitalC]"],
Cell[1889909, 73361, 612, 19, 15, "Index",
  CellTags->"\[GothicCapitalD]"],
Cell[1890524, 73382, 494, 16, 15, "Index",
  CellTags->"\!\(\(\[GothicCapitalG]\^\[RawStar]\)\)"],
Cell[1891021, 73400, 421, 15, 23, "Index",
  CellTags->"\[GothicCapitalG]"],
Cell[1891445, 73417, 435, 15, 23, "Index",
  CellTags->"\[GothicCapitalH]"],
Cell[1891883, 73434, 425, 15, 23, "Index",
  CellTags->"\[GothicCapitalJ]"],
Cell[1892311, 73451, 320, 11, 23, "Index",
  CellTags->"\[GothicK]"],
Cell[1892634, 73464, 377, 11, 23, "Index",
  CellTags->"\[GothicCapitalK]"],
Cell[1893014, 73477, 308, 11, 23, "Index",
  CellTags->"\[GothicM]"],
Cell[1893325, 73490, 308, 11, 23, "Index",
  CellTags->"\[GothicP]"],
Cell[1893636, 73503, 369, 12, 23, "Index",
  CellTags->"\[GothicP]\[GothicQ]"],
Cell[1894008, 73517, 308, 11, 23, "Index",
  CellTags->"\[GothicQ]"],
Cell[1894319, 73530, 314, 11, 23, "Index",
  CellTags->"\[GothicR]"],
Cell[1894636, 73543, 301, 11, 23, "Index",
  CellTags->"\[GothicS]"],
Cell[1894940, 73556, 421, 15, 23, "Index",
  CellTags->"\[GothicCapitalZ]"],
Cell[1895364, 73573, 348, 11, 23, "Index",
  CellTags->"\[DoubleStruckCapitalG]"],
Cell[1895715, 73586, 322, 11, 23, "Index",
  CellTags->"\[DoubleStruckCapitalM]"],
Cell[1896040, 73599, 457, 15, 23, "Index",
  CellTags->"\[DoubleStruckCapitalR]"],
Cell[1896500, 73616, 318, 11, 23, "Index",
  CellTags->"\[DoubleStruckCapitalW]"],
Cell[1896821, 73629, 358, 12, 23, "Index",
  CellTags->"\[DoubleStruckCapitalZ]"],
Cell[1897182, 73643, 270, 11, 23, "Index",
  CellTags->"\[Gamma]"],
Cell[1897455, 73656, 297, 9, 23, "IndexSubentry",
  CellTags->"\[Gamma]"],
Cell[1897755, 73667, 304, 11, 23, "Index",
  CellTags->"\[Zeta]"],
Cell[1898062, 73680, 307, 11, 23, "Index",
  CellTags->"\[CapitalMu]"],
Cell[1898372, 73693, 312, 11, 23, "Index",
  CellTags->"\[Chi]"],
Cell[1898687, 73706, 296, 11, 23, "Index",
  CellTags->"\[Sampi]"],
Cell[1898986, 73719, 290, 10, 23, "Index",
  CellTags->"$MetropolisAdjustment"],
Cell[1899279, 73731, 317, 11, 23, "Index",
  CellTags->"\[WeierstrassP]"],
Cell[1899599, 73744, 449, 12, 23, "Index",
  CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],
Cell[1900051, 73758, 320, 11, 23, "Index",
  CellTags->"\[CircleDot]"],
Cell[1900374, 73771, 394, 12, 23, "Index",
  CellTags->"\[Backslash]"],
Cell[1900771, 73785, 450, 15, 23, "Index",
  CellTags->"\[Wedge]"],
Cell[1901224, 73802, 319, 11, 23, "Index",
  CellTags->"\[CirclePlus]"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1901592, 73819, 30, 0, 50, "Section"],
Cell[1901625, 73821, 143, 3, 43, "Input",
  InitializationCell->True],
Cell[1901771, 73826, 161, 3, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[1901957, 73833, 160, 4, 42, "Subsubsection",
  InitializationCell->True],
Cell[1902120, 73839, 204, 4, 43, "Input",
  InitializationCell->True],
Cell[1902327, 73845, 161, 3, 27, "Input",
  InitializationCell->True],
Cell[1902491, 73850, 504, 10, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[1903032, 73865, 154, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[1903189, 73871, 187, 3, 43, "Input",
  InitializationCell->True],
Cell[1903379, 73876, 675, 13, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[1904091, 73894, 251, 5, 28, "Subsubsection",
  InitializationCell->True],
Cell[1904345, 73901, 289, 5, 59, "Input",
  InitializationCell->True],
Cell[1904637, 73908, 127, 3, 27, "Input",
  InitializationCell->True],
Cell[1904767, 73913, 1002, 18, 155, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[1905806, 73936, 46, 0, 28, "Subsubsection"],
Cell[1905855, 73938, 211, 4, 59, "Input",
  InitializationCell->True],
Cell[1906069, 73944, 456, 8, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[1906562, 73957, 111, 3, 28, "Subsubsection"],
Cell[1906676, 73962, 174, 3, 27, "Input",
  InitializationCell->True],
Cell[1906853, 73967, 545, 10, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[1907435, 73982, 72, 0, 28, "Subsubsection"],
Cell[1907510, 73984, 143, 3, 27, "Input",
  InitializationCell->True],
Cell[1907656, 73989, 151, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[1907844, 73997, 107, 3, 28, "Subsubsection"],
Cell[1907954, 74002, 337, 5, 75, "Input",
  InitializationCell->True],
Cell[1908294, 74009, 346, 7, 59, "Input",
  InitializationCell->True],
Cell[1908643, 74018, 506, 10, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[1909186, 74033, 183, 4, 28, "Subsubsection"],
Cell[1909372, 74039, 295, 5, 59, "Input",
  InitializationCell->True],
Cell[1909670, 74046, 408, 8, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[1910115, 74059, 163, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[1910281, 74065, 208, 4, 43, "Input",
  InitializationCell->True],
Cell[1910492, 74071, 596, 11, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[1911125, 74087, 426, 8, 44, "Subsubsection",
  InitializationCell->True],
Cell[1911554, 74097, 478, 8, 91, "Input",
  InitializationCell->True],
Cell[1912035, 74107, 300, 6, 43, "Input",
  InitializationCell->True],
Cell[1912338, 74115, 479, 9, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[1912854, 74129, 330, 6, 44, "Subsubsection"],
Cell[1913187, 74137, 397, 6, 91, "Input",
  InitializationCell->True],
Cell[1913587, 74145, 208, 4, 43, "Input",
  InitializationCell->True],
Cell[1913798, 74151, 1332, 21, 171, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1915179, 74178, 69, 1, 30, "Section",
  CellTags->"MasterIndexMatrix"],

Cell[CellGroupData[{
Cell[1915273, 74183, 208, 5, 42, "Subsubsection",
  CellTags->"MasterIndexMatrix"],
Cell[1915484, 74190, 241, 4, 59, "Input",
  InitializationCell->True],
Cell[1915728, 74196, 190574, 3332, 23972, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

